@@ -42,6 +42,7 @@
 #include "mui/uigeoram.h"
 #include "mui/uiide64.h"
 #include "mui/uimmc64.h"
+#include "mui/uimouse.h"
 #include "mui/uiplus256k.h"
 #include "mui/uiplus60k.h"
 #include "mui/uiramcart.h"
@@ -84,6 +85,12 @@ static int c64_ui_specific(video_canvas_t *canvas, int idm)
       case IDM_RAMCART_SETTINGS:
         ui_ramcart_settings_dialog(canvas);
         break;
+      case IDM_DQBB_SETTINGS:
+        ui_dqbb_settings_dialog(canvas);
+        break;
+      case IDM_ISEPIC_SETTINGS:
+        ui_isepic_settings_dialog(canvas);
+        break;
       case IDM_PLUS60K_SETTINGS:
         ui_plus60k_settings_dialog(canvas);
         break;
@@ -128,6 +135,9 @@ static int c64_ui_specific(video_canvas_t *canvas, int idm)
       case IDM_KEYBOARD_SETTINGS:
 //        uikeyboard_settings_dialog(hwnd, &uikeyboard_config);
         break;
+      case IDM_MOUSE_SETTINGS:
+        ui_mouse_settings_dialog();
+        break;
     }
 
     return 0;
@@ -149,4 +159,3 @@ int c64ui_init(void)
 void c64ui_shutdown(void)
 {
 }
-
