@@ -274,9 +274,8 @@ static struct MsgPort *ai_port = NULL;
 #include "resources.h"
 #include "util.h"
 
-static int set_JOYAI_resource(resource_value_t v, void *param)
+static int set_JOYAI_resource(const char *name, void *param)
 {
-    const char *name = (const char *)v;
     char **ptr = (char **)param;
     if (*ptr != NULL && name != NULL)
         if (strcmp(name, *ptr) == 0)
@@ -286,9 +285,9 @@ static int set_JOYAI_resource(resource_value_t v, void *param)
 }
 
 #define MYRES(res, def, name) \
-  { name, RES_STRING, (resource_value_t)def, RES_EVENT_NO, NULL, (void *)&res, set_JOYAI_resource, (void *)&res },
+  { name, def, RES_EVENT_NO, NULL, &res, set_JOYAI_resource, (void *)&res },
 
-static const resource_t resources[] = {
+static const resource_string_t resources_string[] = {
     MYRES(joy_resource[0], "-1", "JOYAI1_ID")
     MYRES(keysym_1[0].resource, "0,0,-1", "JOYAI1_Up")
     MYRES(keysym_1[1].resource, "0,0,-1", "JOYAI1_Down")
@@ -306,14 +305,14 @@ static const resource_t resources[] = {
 
 int joyai_init_resources(void)
 {
-    return resources_register(resources);
+    return resources_register_string(resources_string);
 }
 
 static void get_cfg(int joy)
 {
   keysym_type *keysym = (joy == 2) ? keysym_2 : keysym_1;
   char *tmp, txt[256];
-  int i;
+  unsigned int i;
 
   sprintf(txt, "JOYAI%d_ID", joy);
   tmp = NULL;
@@ -336,7 +335,7 @@ static void set_cfg(int joy)
 {
   keysym_type *keysym = (joy == 2) ? keysym_2 : keysym_1;
   char tmp[256], txt[256];
-  int i;
+  unsigned int i;
 
   sprintf(txt, "JOYAI%d_ID", joy);
   sprintf(tmp, "%lu", joy_id[joy-1]);
@@ -401,7 +400,7 @@ static void ai_release(void)
 
 static void ai_attach(void)
 {
-  int i;
+  unsigned int i;
   for (i=0; i<2; i++) {
     get_cfg(i+1);
     if ((CTX != NULL) && (joy_id[i] != -1)) {
@@ -554,7 +553,8 @@ static struct {
 static void update_inputs(ULONG ID)
 {
   char name[256];
-  int i, num, offset;
+  unsigned int i;
+  int num, offset;
 
   for (i=0; i<inputs.count; i++) {
     if (inputs.names[i] != NULL) {
@@ -617,7 +617,8 @@ static void update_inputs(ULONG ID)
 
 static int offset_to_index(int offset)
 {
-  int i;
+  unsigned int i;
+
   for (i=0; i<inputs.count; i++) {
     if ((inputs.types[i] != TYPE_NONE) && (inputs.offsets[i] == offset)) {
       return i;
@@ -644,7 +645,8 @@ BOOL enumfunc(AIN_Device *device, void *UserData)
 
 static int offset_to_active(int type, int offset)
 {
-  int i;
+  unsigned int i;
+
   for (i=0; i<inputs.count; i++) {
     if ((inputs.types[i] == type) && (inputs.offsets[i] == offset)) {
       return i;
@@ -748,7 +750,7 @@ End,
          End;
 
       if (app) {
-	int i;
+	unsigned int i;
 
 	DoMethod(window,
 	MUIM_Notify, MUIA_Window_CloseRequest, TRUE,
@@ -825,7 +827,7 @@ End,
        }
 
       if (app) {
-        int i;
+        unsigned int i;
         set(window, MUIA_Window_Open, TRUE);
         while (running) {
           unsigned long retval = DoMethod(app, MUIM_Application_Input, &signals);
@@ -899,7 +901,8 @@ int joyai_update(int joy, int dst)
     }
 
     if (AIN_ReadDevice(CTX, ai_handle[joy-1], &ptr) == TRUE) {
-      int i, *data = ptr;
+      unsigned int i, *data = ptr;
+
       for (i=0; i<NUM_KEYSYM; i++) {
         switch (keysym[i].type) {
 
@@ -999,7 +1002,7 @@ int joyai_key(int joy, int dst, unsigned long kcode, int pressed)
 {
     BYTE value = 0;
     keysym_type *keysym = (joy == 2) ? keysym_2 : keysym_1;
-    int i;
+    unsigned int i;
 
     for (i=0; i<NUM_KEYSYM; i++) {
         if ((keysym[i].type == TYPE_NONE) && (keysym[i].rawkey == kcode)) {
