@@ -24,9 +24,13 @@
  *
  */
 
+#include "vice.h"
+
 #include <string.h>
 
 #include "private.h"
+#include "charset.h"
+#include "clipboard.h"
 #include "datasette.h"
 #include "tape.h"
 #include "statusbar.h"
@@ -52,6 +56,7 @@
 #include "translate.h"
 #include "screen-shot.h"
 #include "ui.h"
+#include "util.h"
 
 #include "mui/filereq.h"
 #include "mui/uidatasette.h"
@@ -70,6 +75,8 @@
 #include <proto/cybergraphics.h>
 #endif
 
+extern char *BrowseFile(char *select_text, char *pattern, video_canvas_t *canvas);
+
 static int do_quit_vice = 0;
 
 struct MenuItem *step_item(struct MenuItem *first_item, int idm)
@@ -133,6 +140,7 @@ static const ui_menu_toggle_t toggle_list[] = {
     { "ConfirmOnExit", IDM_TOGGLE_CONFIRM_ON_EXIT },
     { "FullScreenEnabled", IDM_TOGGLE_FULLSCREEN },
     { "StatusbarEnabled", IDM_TOGGLE_STATUSBAR },
+    { "KeySetEnable", IDM_JOYKEYS_TOGGLE },
 #if defined(HAVE_PROTO_CYBERGRAPHICS_H) && defined(HAVE_XVIDEO)
     { "VideoOverlayEnabled", IDM_TOGGLE_OVERLAY },
 #endif
@@ -218,6 +226,141 @@ void ui_register_res_values(const ui_res_value_list_t *valuelist)
   machine_specific_values = valuelist;
 }
 
+#define  ID_FTXT	MAKE_ID('F','T','X','T')
+#define  ID_CHRS	MAKE_ID('C','H','R','S')
+
+struct Library *IFFParseBase;
+
+static void ui_copy_clipboard(void)
+{
+    struct IFFHandle *iff = NULL;
+    long unitnumber = 0;
+    long error;
+    int textlen;
+    char *text = NULL;
+
+    do {
+        text = clipboard_read_screen_output("\n");
+
+        if (text == NULL)
+            break;
+
+        if (!(IFFParseBase = OpenLibrary("iffparse.library", 0L)))
+            break;
+
+        if (!(iff = AllocIFF()))
+            break;
+
+        if (!(iff->iff_Stream = (ULONG)OpenClipboard(unitnumber)))
+            break;
+
+        InitIFFasClip (iff);
+
+        if ((error = OpenIFF(iff, IFFF_WRITE)))
+            break;
+
+        if (!(error=PushChunk(iff, ID_FTXT, ID_FORM, IFFSIZE_UNKNOWN)))
+        {
+            if (!(error=PushChunk(iff, 0, ID_CHRS, IFFSIZE_UNKNOWN)))
+            {
+                textlen = strlen(text);
+                WriteChunkBytes(iff, text, textlen);
+            }
+        }
+
+    } while (0);
+
+    if (iff)
+    {
+        CloseIFF(iff);
+
+        if (iff->iff_Stream)
+            CloseClipboard((struct ClipboardHandle *)iff->iff_Stream);
+        FreeIFF(iff);
+    }
+
+    if (IFFParseBase)
+        CloseLibrary(IFFParseBase);
+
+    if (text)
+        lib_free(text);
+}
+
+static void ui_paste_clipboard_text(void)
+{
+    struct IFFHandle *iff = NULL;
+    struct ContextNode *cn;
+    long unitnumber = 0;
+    long error;
+    int textlen = 0;
+    char *text_in_petscii = NULL;
+    
+    do {
+        if (!(IFFParseBase = OpenLibrary("iffparse.library", 0L)))
+            break;
+
+        if (!(iff = AllocIFF()))
+            break;
+
+        if (!(iff->iff_Stream = (ULONG)OpenClipboard(unitnumber)))
+            break;
+
+        InitIFFasClip (iff);
+
+        if ((error = OpenIFF(iff, IFFF_READ)))
+            break;
+
+        if ((error = StopChunk(iff, ID_FTXT, ID_CHRS)))
+            break;
+
+        while(1)
+        {
+            error = ParseIFF(iff, IFFPARSE_SCAN);
+            if (error == IFFERR_EOC)
+                continue;
+            else
+                if (error)
+                    break;
+
+            cn = CurrentChunk(iff);
+
+            if ((cn) && (cn->cn_Type == ID_FTXT) && (cn->cn_ID == ID_CHRS))
+            {
+                textlen = cn->cn_Size;
+                text_in_petscii = lib_malloc(textlen + 1);
+                error = ReadChunkBytes(iff, text_in_petscii, textlen);
+                break;
+            }
+        }
+
+        if (text_in_petscii == NULL)
+            break;
+
+        text_in_petscii[textlen] = 0;
+
+        charset_petconvstring((BYTE *)text_in_petscii, 0);
+
+        kbdbuf_feed(text_in_petscii);
+
+    } while (0);
+
+    if (iff)
+    {
+        CloseIFF(iff);
+
+        if (iff->iff_Stream)
+            CloseClipboard((struct ClipboardHandle *)iff->iff_Stream);
+        FreeIFF(iff);
+    }
+
+    if (IFFParseBase)
+        CloseLibrary(IFFParseBase);
+
+    if (text_in_petscii) {
+        lib_free(text_in_petscii);
+    }
+}
+
 int ui_menu_create(video_canvas_t *canvas)
 {
   struct Screen* pubscreen = NULL;
@@ -465,6 +608,12 @@ int ui_menu_handle(video_canvas_t *canvas, int idm)
     case IDM_RESET_DRIVE11:
       drivecpu_trigger_reset(3);
       break;
+    case IDM_COPY:
+      ui_copy_clipboard();
+      break;
+    case IDM_PASTE:
+      ui_paste_clipboard_text();
+      break;
 #ifdef AMIGA_OS4
     case IDM_JOY_SETTINGS:
       ui_joystick_settings_dialog();
@@ -531,7 +680,34 @@ int ui_menu_handle(video_canvas_t *canvas, int idm)
     case IDM_DATASETTE_RESET_COUNTER:
       datasette_control(DATASETTE_CONTROL_RESET_COUNTER);
       break;
-
+    case IDM_SETTINGS_SAVE_FILE:
+      fname=BrowseFile(translate_text(IDS_CONFIG_FILENAME_SELECT), "#?", canvas);
+      if (fname != NULL)
+      {
+        if (resources_save(fname) < 0)
+        {
+          ui_error(translate_text(IDMES_CANNOT_SAVE_SETTINGS));
+        }
+        else
+        {
+          ui_message(translate_text(IDMES_SETTINGS_SAVED_SUCCESS));
+        }
+      }
+      break;
+    case IDM_SETTINGS_LOAD_FILE:
+      fname=BrowseFile(translate_text(IDS_CONFIG_FILENAME_SELECT), "#?", canvas);
+      if (fname != NULL)
+      {
+        if (resources_load(fname) < 0)
+        {
+          ui_error(translate_text(IDMES_CANNOT_LOAD_SETTINGS));
+        }
+        else
+        {
+          ui_message(translate_text(IDMES_SETTINGS_LOAD_SUCCESS));
+        }
+      }
+      break;
     case IDM_SETTINGS_SAVE:
       if (resources_save(NULL) < 0) {
         ui_error(translate_text(IDMES_CANNOT_SAVE_SETTINGS));
@@ -550,7 +726,6 @@ int ui_menu_handle(video_canvas_t *canvas, int idm)
       resources_set_defaults();
       ui_message(translate_text(IDMES_DFLT_SETTINGS_RESTORED));
       break;
-
     case IDM_MONITOR:
       if (!ui_emulation_is_paused())
           monitor_startup_trap();
