@@ -53,10 +53,10 @@
 #include "translate.h"
 
 typedef enum {
-    UI_JAM_RESET, UI_JAM_HARD_RESET, UI_JAM_MONITOR
+    UI_JAM_RESET, UI_JAM_HARD_RESET, UI_JAM_MONITOR, UI_JAM_NONE
 } ui_jam_action_t;
 
-enum {REQ_JAM_MONITOR, REQ_JAM_RESET, REQ_JAM_HARD_RESET};
+enum {REQ_JAM_NONE, REQ_JAM_RESET, REQ_JAM_HARD_RESET, REQ_JAM_MONITOR};
 
 extern video_canvas_t *canvaslist;
 
@@ -213,18 +213,26 @@ void ui_resources_shutdown(void)
 /* UI-related command-line options.  */
 
 static const cmdline_option_t cmdline_options[] = {
-    { "-saveres", SET_RESOURCE, 0, NULL, NULL,
-      "SaveResourcesOnExit", (resource_value_t)1,
-      0, IDS_SAVE_SETTINGS_ON_EXIT },
-    { "+saveres", SET_RESOURCE, 0, NULL, NULL,
-      "SaveResourcesOnExit", (resource_value_t)0,
-      0, IDS_NEVER_SAVE_SETTINGS_EXIT },
-    { "-confirmexit", SET_RESOURCE, 0, NULL, NULL,
-      "ConfirmOnExit", (resource_value_t)0,
-      0, IDS_CONFIRM_QUITING_VICE },
-    { "+confirmexit", SET_RESOURCE, 0, NULL, NULL,
-      "ConfirmOnExit", (resource_value_t)1,
-      0, IDS_NEVER_CONFIRM_QUITING_VICE },
+    { "-saveres", SET_RESOURCE, 0,
+      NULL, NULL, "SaveResourcesOnExit", (resource_value_t)1,
+      USE_PARAM_STRING, USE_DESCRIPTION_ID,
+      IDCLS_UNUSED, IDS_SAVE_SETTINGS_ON_EXIT,
+      NULL, NULL },
+    { "+saveres", SET_RESOURCE, 0,
+      NULL, NULL, "SaveResourcesOnExit", (resource_value_t)0,
+      USE_PARAM_STRING, USE_DESCRIPTION_ID,
+      IDCLS_UNUSED, IDS_NEVER_SAVE_SETTINGS_EXIT,
+      NULL, NULL },
+    { "-confirmexit", SET_RESOURCE, 0,
+      NULL, NULL, "ConfirmOnExit", (resource_value_t)1,
+      USE_PARAM_STRING, USE_DESCRIPTION_ID,
+      IDCLS_UNUSED, IDS_CONFIRM_QUITING_VICE,
+      NULL, NULL },
+    { "+confirmexit", SET_RESOURCE, 0,
+      NULL, NULL, "ConfirmOnExit", (resource_value_t)0,
+      USE_PARAM_STRING, USE_DESCRIPTION_ID,
+      IDCLS_UNUSED, IDS_NEVER_CONFIRM_QUITING_VICE,
+      NULL, NULL },
     { NULL }
 };
 
@@ -323,7 +331,7 @@ ui_jam_action_t ui_jam_dialog(const char *format, ...)
   tmp = lib_mvsprintf(format,ap);
   va_end(ap);
 
-  action=ui_requester("VICE CPU Jam", tmp, "RESET|HARD RESET|MONITOR", REQ_JAM_RESET);
+  action=ui_requester("VICE CPU Jam", tmp, "RESET|HARD RESET|MONITOR|CONTINUE", REQ_JAM_RESET);
 
   switch(action)
   {
@@ -336,6 +344,9 @@ ui_jam_action_t ui_jam_dialog(const char *format, ...)
     case REQ_JAM_MONITOR:
       jamaction=UI_JAM_MONITOR;
       break;
+    case REQ_JAM_NONE:
+      jamaction=UI_JAM_NONE;
+      break;
   }
   return jamaction;
 }
@@ -371,3 +382,8 @@ void ui_display_statustext(const char *text, int fade_out)
 void ui_display_volume(int vol)
 {
 }
+
+char* ui_get_file(const char *format,...)
+{
+    return NULL;
+}
\ No newline at end of file
