@@ -40,7 +40,8 @@ enum {
   IDM_DATASETTE_CONTROL_REWIND, IDM_DATASETTE_CONTROL_RECORD,
   IDM_DATASETTE_CONTROL_RESET, IDM_DATASETTE_RESET_COUNTER,
   IDM_CART_ATTACH_CRT, IDM_CART_ATTACH_8KB, IDM_CART_ATTACH_16KB,
-  IDM_CART_ATTACH_AR, IDM_CART_ATTACH_AT, IDM_CART_ATTACH_EPYX,
+  IDM_CART_ATTACH_AR, IDM_CART_ATTACH_AR3, IDM_CART_ATTACH_AR4,
+  IDM_CART_ATTACH_STARDOS, IDM_CART_ATTACH_AT, IDM_CART_ATTACH_EPYX,
   IDM_CART_ATTACH_IEEE488, IDM_CART_ATTACH_RR, IDM_CART_ATTACH_IDE64,
   IDM_CART_ATTACH_SS4, IDM_CART_ATTACH_SS5, IDM_CART_ATTACH_STB,
   IDM_CART_ENABLE_EXPERT, IDM_CART_MODE_OFF, IDM_CART_MODE_PRG,
@@ -55,6 +56,8 @@ enum {
   IDM_RESET_DRIVE8, IDM_RESET_DRIVE9, IDM_RESET_DRIVE10, IDM_RESET_DRIVE11,
   IDM_EXIT,
 
+  IDM_COPY, IDM_PASTE,
+
   IDM_SNAPSHOT_LOAD, IDM_SNAPSHOT_SAVE,
   IDM_EVENT_TOGGLE_RECORD, IDM_EVENT_TOGGLE_PLAYBACK, IDM_EVENT_SETMILESTONE,
   IDM_EVENT_RESETMILESTONE, IDM_EVENT_START_MODE_SAVE, IDM_EVENT_START_MODE_LOAD,
@@ -78,6 +81,7 @@ enum {
   IDM_TOGGLE_VDC_DOUBLESCAN,
   IDM_TOGGLE_VDC64KB,
   IDM_TOGGLE_STATUSBAR,
+  IDM_JOYKEYS_TOGGLE,
   IDM_TOGGLE_OVERLAY,
   IDM_SWAP_JOYSTICK,
   IDM_TOGGLE_SOUND,
@@ -89,19 +93,24 @@ enum {
   IDM_SYNC_FACTOR_NTSCOLD,
   IDM_TOGGLE_EMUID,
   IDM_MOUSE,
+  IDM_PS2_MOUSE,
 
-  IDM_VIDEO_SETTINGS, IDM_DEVICEMANAGER, IDM_DRIVE_SETTINGS, IDM_DATASETTE_SETTINGS,
-  IDM_VICII_SETTINGS, IDM_JOY_SETTINGS, IDM_JOY_DEVICE_SELECTION, 
-  IDM_JOY_FIRE_SELECTION, IDM_KEYBOARD_SETTINGS, IDM_SOUND_SETTINGS,
-  IDM_SID_SETTINGS, IDM_COMPUTER_ROM_SETTINGS, IDM_DRIVE_ROM_SETTINGS, IDM_RAM_SETTINGS,
-  IDM_RS232_SETTINGS, IDM_REU_SETTINGS, IDM_GEORAM_SETTINGS, IDM_RAMCART_SETTINGS,
-  IDM_PLUS60K_SETTINGS, IDM_PLUS256K_SETTINGS, IDM_C64_256K_SETTINGS,
-  IDM_IDE64_SETTINGS, IDM_C128_SETTINGS, IDM_VIC_SETTINGS,
-  IDM_CBM2_SETTINGS, IDM_PET_MODEL, IDM_PET_SETTINGS, IDM_PLUS4_SETTINGS,
-  IDM_TFE_SETTINGS, IDM_ACIA_SETTINGS, IDM_RS232USER_SETTINGS,
-  IDM_NETWORK_SETTINGS, IDM_PETREU_SETTINGS, IDM_MMC64_SETTINGS,
-  IDM_SIDCART_SETTINGS, IDM_DIGIMAX_SETTINGS,
+  IDM_VIDEO_SETTINGS, IDM_DEVICEMANAGER, IDM_DRIVE_SETTINGS,
+  IDM_DATASETTE_SETTINGS, IDM_VICII_SETTINGS, IDM_JOY_SETTINGS,
+  IDM_JOY_DEVICE_SELECTION, IDM_JOY_FIRE_SELECTION, IDM_KEYBOARD_SETTINGS,
+  IDM_MOUSE_SETTINGS, IDM_SOUND_SETTINGS, IDM_SID_SETTINGS,
+  IDM_COMPUTER_ROM_SETTINGS, IDM_DRIVE_ROM_SETTINGS, IDM_RAM_SETTINGS,
+  IDM_RS232_SETTINGS, IDM_REU_SETTINGS, IDM_GEORAM_SETTINGS,
+  IDM_RAMCART_SETTINGS, IDM_DQBB_SETTINGS, IDM_ISEPIC_SETTINGS,
+  IDM_PLUS60K_SETTINGS, IDM_PLUS256K_SETTINGS,
+  IDM_C64_256K_SETTINGS, IDM_IDE64_SETTINGS, IDM_C128_SETTINGS,
+  IDM_VIC_SETTINGS, IDM_CBM2_SETTINGS, IDM_PET_MODEL, IDM_PET_SETTINGS,
+  IDM_PLUS4_SETTINGS, IDM_TFE_SETTINGS, IDM_ACIA_SETTINGS,
+  IDM_RS232USER_SETTINGS, IDM_NETWORK_SETTINGS, IDM_PETREU_SETTINGS,
+  IDM_MMC64_SETTINGS,  IDM_SIDCART_SETTINGS, IDM_DIGIMAX_SETTINGS,
+  IDM_C64DTV_SETTINGS,
 
+  IDM_SETTINGS_SAVE_FILE, IDM_SETTINGS_LOAD_FILE,
   IDM_SETTINGS_SAVE, IDM_SETTINGS_LOAD, IDM_SETTINGS_DEFAULT,
   IDM_TOGGLE_SAVE_SETTINGS_ON_EXIT, IDM_TOGGLE_CONFIRM_ON_EXIT,
 
