@@ -68,7 +68,6 @@ static struct TranslateNewMenu UI_MENU_NAME[] = {
       SUB(IDMS_RESET, NULL,         IDM_DATASETTE_CONTROL_RESET)
       SUB(IDMS_RESET_COUNTER, NULL, IDM_DATASETTE_RESET_COUNTER)
     ITEMSEPARATOR()
-#if defined(UI_VIC20)
     ITEM(IDMS_ATTACH_CART_IMAGE, NULL, NULL)
       SUB(IDMS_4_8_16KB_AT_2000, NULL, IDM_CART_VIC20_8KB_2000)
       SUB(IDMS_4_8_16KB_AT_4000, NULL, IDM_CART_VIC20_16KB_4000)
@@ -77,48 +76,6 @@ static struct TranslateNewMenu UI_MENU_NAME[] = {
       SUB(IDMS_4KB_AT_B000,      NULL, IDM_CART_VIC20_4KB_B000)
     ITEM(IDMS_DETACH_CART_IMAGE, NULL, IDM_CART_DETACH)
     ITEMSEPARATOR()
-#endif
-#if defined(UI_PLUS4)
-    ITEM(IDMS_ATTACH_CART_IMAGE, NULL, NULL)
-      SUB(IDMS_C1_LOW_IMAGE, NULL, IDM_CART_ATTACH_C1LO)
-      SUB(IDMS_C1_HIGH_IMAGE, NULL, IDM_CART_ATTACH_C1HI)
-      SUB(IDMS_C2_LOW_IMAGE, NULL, IDM_CART_ATTACH_C2LO)
-      SUB(IDMS_C2_HIGH_IMAGE, NULL, IDM_CART_ATTACH_C2HI)
-      SUBSEPARATOR()
-      SUB(IDMS_FUNCTION_LOW_3PLUS1, NULL, IDM_CART_ATTACH_FUNCLO)
-      SUB(IDMS_FUNCTION_HIGH_3PLUS1, NULL, IDM_CART_ATTACH_FUNCHI)
-    ITEM(IDMS_DETACH_CART_IMAGE, NULL, IDM_CART_DETACH)
-    ITEMSEPARATOR()
-#endif
-#if !defined(UI_CBM2) && !defined(UI_PET) && !defined(UI_PLUS4) && !defined(UI_VIC20)
-    ITEM(IDMS_ATTACH_CART_IMAGE, NULL, NULL)
-      SUB(IDMS_CRT_IMAGE, NULL,               IDM_CART_ATTACH_CRT)
-      SUBSEPARATOR()
-      SUB(IDMS_GENERIC_8KB_IMAGE, NULL,       IDM_CART_ATTACH_8KB)
-      SUB(IDMS_GENERIC_16KB_IMAGE, NULL,      IDM_CART_ATTACH_16KB)
-      SUB(IDMS_ACTION_REPLAY_IMAGE, NULL,     IDM_CART_ATTACH_AR)
-      SUB(IDMS_ATOMIC_POWER_IMAGE, NULL,      IDM_CART_ATTACH_AT)
-      SUB(IDMS_EPYX_FASTLOAD_IMAGE, NULL,     IDM_CART_ATTACH_EPYX)
-      SUB(IDMS_IEEE488_INTERFACE_IMAGE, NULL, IDM_CART_ATTACH_IEEE488)
-      SUB(IDMS_RETRO_REPLAY_IMAGE, NULL,      IDM_CART_ATTACH_RR)
-      SUB(IDMS_IDE64_INTERFACE_IMAGE, NULL,   IDM_CART_ATTACH_IDE64)
-      SUB(IDMS_SUPER_SNAPSHOT_4_IMAGE, NULL,  IDM_CART_ATTACH_SS4)
-      SUB(IDMS_SUPER_SNAPSHOT_5_IMAGE, NULL,  IDM_CART_ATTACH_SS5)
-      SUB(IDMS_STRUCTURED_BASIC_IMAGE, NULL,  IDM_CART_ATTACH_STB)
-/* AmigaOS only support one submenu level */
-    ITEM(IDMS_EXPERT_CART, NULL, NULL)
-      SUB(IDMS_ENABLE, NULL, IDM_CART_ENABLE_EXPERT)
-      SUBSEPARATOR()
-      SUBTOGGLE(IDMS_OFF, NULL,    IDM_CART_MODE_OFF)
-      SUBTOGGLE(IDMS_PRG, NULL,    IDM_CART_MODE_PRG)
-      SUBTOGGLE(IDMS_ON, NULL,     IDM_CART_MODE_ON)
-    ITEM(IDMS_SET_CART_AS_DEFAULT, NULL, IDM_CART_SET_DEFAULT)
-    ITEMTOGGLE(IDMS_RESET_ON_CART_CHANGE, NULL, IDM_TOGGLE_CART_RESET)
-    ITEMSEPARATOR()
-    ITEM(IDMS_DETACH_CART_IMAGE, NULL,  IDM_CART_DETACH)
-    ITEM(IDMS_CART_FREEZE, "Z", IDM_CART_FREEZE)
-    ITEMSEPARATOR()
-#endif
     ITEMTOGGLE(IDMS_PAUSE, NULL, IDM_PAUSE)
     ITEM(IDMS_MONITOR, "M", IDM_MONITOR)
     ITEM(IDMS_RESET, NULL, NULL)
@@ -131,6 +88,9 @@ static struct TranslateNewMenu UI_MENU_NAME[] = {
       SUB(IDMS_DRIVE_11, NULL, IDM_RESET_DRIVE11)
     ITEMSEPARATOR()
     ITEM(IDMS_EXIT, "X", IDM_EXIT)
+  TITLE(IDMS_EDIT, NULL)
+    ITEM(IDMS_COPY, NULL, IDM_COPY)
+    ITEM(IDMS_PASTE, NULL, IDM_PASTE)
   TITLE(IDMS_SNAPSHOT, NULL)
     ITEM(IDMS_LOAD_SNAPSHOT_IMAGE, NULL, IDM_SNAPSHOT_LOAD)
     ITEM(IDMS_SAVE_SNAPSHOT_IMAGE, NULL, IDM_SNAPSHOT_SAVE)
@@ -151,9 +111,6 @@ static struct TranslateNewMenu UI_MENU_NAME[] = {
     ITEM(IDMS_START_SOUND_RECORD, NULL, IDM_SOUND_RECORD_START)
     ITEM(IDMS_STOP_SOUND_RECORD, NULL, IDM_SOUND_RECORD_STOP)
     ITEMSEPARATOR()
-#if !defined(UI_C128) && !defined(UI_CBM2) && !defined(UI_PET) && !defined(UI_PLUS4) && !defined(UI_VIC20)
-    ITEM(IDMS_NETPLAY, NULL, IDM_NETWORK_SETTINGS)
-#endif
   TITLE(IDMS_OPTIONS, NULL)
     ITEM(IDMS_REFRESH_RATE, NULL, NULL)
       SUBTOGGLE(IDMS_AUTO, NULL, IDM_REFRESH_RATE_AUTO)
@@ -178,83 +135,38 @@ static struct TranslateNewMenu UI_MENU_NAME[] = {
       SUBTOGGLE(IDMS_CUSTOM, NULL, IDM_MAXIMUM_SPEED_CUSTOM)
     ITEMTOGGLE(IDMS_WARP_MODE, "W", IDM_TOGGLE_WARP_MODE)
     ITEMSEPARATOR()
-#if !defined(UI_C128)
     ITEMTOGGLE(IDMS_FULLSCREEN, "D", IDM_TOGGLE_FULLSCREEN)
     ITEMTOGGLE(IDMS_FULLSCREEN_STATUSBAR, NULL, IDM_TOGGLE_STATUSBAR)
     ITEMSEPARATOR()
-#endif
     ITEMTOGGLE(IDMS_VIDEO_CACHE, NULL, IDM_TOGGLE_VIDEOCACHE)
     ITEMTOGGLE(IDMS_DOUBLE_SIZE, NULL, IDM_TOGGLE_DOUBLESIZE)
     ITEMTOGGLE(IDMS_DOUBLE_SCAN, NULL, IDM_TOGGLE_DOUBLESCAN)
-#if !defined(UI_CBM2) && !defined(UI_PET)
     ITEMTOGGLE(IDMS_PAL_EMULATION, NULL, IDM_TOGGLE_FASTPAL)
     ITEMTOGGLE(IDMS_SCALE2X, NULL, IDM_TOGGLE_SCALE2X)
-#endif
-#if defined(UI_C128)
-    ITEM(IDMS_VDC_SETTINGS, NULL, NULL)
-      SUBTOGGLE(IDMS_DOUBLE_SIZE, NULL, IDM_TOGGLE_VDC_DOUBLESIZE)
-      SUBTOGGLE(IDMS_DOUBLE_SCAN, NULL, IDM_TOGGLE_VDC_DOUBLESCAN)
-      SUBSEPARATOR()
-      SUBTOGGLE(IDMS_64KB_VIDEO_MEMORY, NULL, IDM_TOGGLE_VDC64KB)
-#endif
 #if defined(HAVE_PROTO_CYBERGRAPHICS_H) && defined(HAVE_XVIDEO)
     ITEMTOGGLE(IDMS_VIDEO_OVERLAY, NULL, IDM_TOGGLE_OVERLAY)
 #endif
     ITEMSEPARATOR()
     ITEM(IDMS_SWAP_JOYSTICKS, "J", IDM_SWAP_JOYSTICK)
+    ITEM(IDMS_ENABLE_JOY_KEYS, NULL, IDM_JOYKEYS_TOGGLE)
     ITEMSEPARATOR()
     ITEMTOGGLE(IDMS_SOUND_PLAYBACK, NULL, IDM_TOGGLE_SOUND)
     ITEMSEPARATOR()
     ITEMTOGGLE(IDMS_TRUE_DRIVE_EMU, NULL, IDM_TOGGLE_DRIVE_TRUE_EMULATION)
     ITEMTOGGLE(IDMS_VIRTUAL_DEVICE_TRAPS, NULL, IDM_TOGGLE_VIRTUAL_DEVICES)
-#if defined(UI_CBM2) || defined(UI_PET)
-    ITEM(IDMS_DRIVE_SYNC_FACTOR, NULL, NULL)
-      SUBTOGGLE(IDMS_PAL,  NULL, IDM_SYNC_FACTOR_PAL)
-      SUBTOGGLE(IDMS_NTSC, NULL, IDM_SYNC_FACTOR_NTSC)
-#endif
     ITEMSEPARATOR()
-#if !defined(UI_CBM2) && !defined(UI_PET)
     ITEM(IDMS_VIDEO_STANDARD, NULL, NULL)
       SUBTOGGLE(IDMS_PAL_G, NULL, IDM_SYNC_FACTOR_PAL)
       SUBTOGGLE(IDMS_NTSC_M, NULL, IDM_SYNC_FACTOR_NTSC)
-#if !defined(UI_C128) && !defined(UI_PLUS4) && !defined(UI_VIC20)
-      SUBTOGGLE(IDMS_OLD_NTSC_M, NULL, IDM_SYNC_FACTOR_NTSCOLD)
-#endif
-#endif
-#if !defined(UI_PLUS4)
     ITEMSEPARATOR()
     ITEMTOGGLE(IDMS_EMU_ID, NULL, IDM_TOGGLE_EMUID)
-#if defined(UI_VIC20)
     ITEMTOGGLE (IDMS_VIC_1112_IEEE_488, NULL, IDM_IEEE488)
-#endif
-#if defined(UI_C128)
-    ITEMTOGGLE(IDMS_IEEE_488_INTERFACE, NULL, IDM_IEEE488)
-#endif
-#if !defined(UI_CBM2) && !defined(UI_PET) && !defined(UI_VIC20)
-    ITEMTOGGLE(IDMS_1351_MOUSE, "Q", IDM_MOUSE)
-#endif
-#endif
   TITLE(IDMS_SETTINGS, NULL)
     ITEM(IDMS_VIDEO_SETTINGS, NULL,     IDM_VIDEO_SETTINGS)
-#if defined(UI_VIC20)
     ITEM(IDMS_VIC_SETTINGS, NULL, IDM_VIC_SETTINGS)
-#endif
-#if defined(UI_CBM2)
-    ITEM(IDMS_CBM2_SETTINGS, NULL, IDM_CBM2_SETTINGS)
-#endif
-#if defined(UI_PET)
-    ITEM(IDMS_SET_PET_MODEL, NULL, IDM_PET_MODEL)
-    ITEM(IDMS_PET_SETTINGS, NULL, IDM_PET_SETTINGS)
-#endif
     ITEM(IDMS_PERIPHERAL_SETTINGS, NULL,IDM_DEVICEMANAGER)
     ITEM(IDMS_DRIVE_SETTINGS, NULL,     IDM_DRIVE_SETTINGS)
     ITEM(IDMS_DATASETTE_SETTINGS, NULL, IDM_DATASETTE_SETTINGS)
-#if defined(UI_PLUS4)
-    ITEM(IDMS_PLUS4_SETTINGS, NULL, IDM_PLUS4_SETTINGS)
-#endif
-#if !defined(UI_PET) && !defined(UI_PLUS4) && !defined(UI_VIC20)
-    ITEM(IDMS_VICII_SETTINGS, NULL,    IDM_VICII_SETTINGS)
-#endif
 #ifdef AMIGA_OS4
     ITEM(IDMS_JOYSTICK_SETTINGS, NULL,  IDM_JOY_SETTINGS)
 #else
@@ -264,45 +176,16 @@ static struct TranslateNewMenu UI_MENU_NAME[] = {
 #endif
     ITEM(IDMS_KEYBOARD_SETTINGS, NULL,  IDM_KEYBOARD_SETTINGS)
     ITEM(IDMS_SOUND_SETTINGS, NULL,     IDM_SOUND_SETTINGS)
-#if !defined(UI_PET) && !defined(UI_PLUS4) && !defined(UI_VIC20)
-    ITEM(IDMS_SID_SETTINGS, NULL,       IDM_SID_SETTINGS)
-#endif
     ITEM(IDMS_COMPUTER_ROM_SETTINGS, NULL,       IDM_COMPUTER_ROM_SETTINGS)
     ITEM(IDMS_DRIVE_ROM_SETTINGS, NULL,       IDM_DRIVE_ROM_SETTINGS)
     ITEM(IDMS_RAM_SETTINGS, NULL,       IDM_RAM_SETTINGS)
     ITEM(IDMS_RS232_SETTINGS, NULL,       IDM_RS232_SETTINGS)
-#if defined(UI_C128)
-    ITEM(IDMS_C128_SETTINGS, NULL,      IDM_C128_SETTINGS)
-#endif
     ITEM(IDMS_CART_IO_SETTINGS, NULL, NULL)
-#if !defined(UI_VIC20) && !defined(UI_CBM2) && !defined(UI_PET) && !defined(UI_PLUS4)
-      SUB(IDMS_REU_SETTINGS, NULL,      IDM_REU_SETTINGS)
-      SUB(IDMS_GEORAM_SETTINGS, NULL,      IDM_GEORAM_SETTINGS)
-      SUB(IDMS_RAMCART_SETTINGS, NULL,      IDM_RAMCART_SETTINGS)
-#if !defined(UI_C128)
-      SUB(IDMS_PLUS60K_SETTINGS, NULL,      IDM_PLUS60K_SETTINGS)
-      SUB(IDMS_PLUS256K_SETTINGS, NULL,      IDM_PLUS256K_SETTINGS)
-      SUB(IDMS_256K_SETTINGS, NULL,      IDM_C64_256K_SETTINGS)
-      SUB(IDMS_MMC64_SETTINGS, NULL,      IDM_MMC64_SETTINGS)
-#endif
-      SUB(IDMS_IDE64_SETTINGS, NULL,    IDM_IDE64_SETTINGS)
-#ifdef HAVE_TFE
-      SUB(IDMS_ETHERNET_SETTINGS, NULL, IDM_TFE_SETTINGS)
-#endif
-#endif
-#if !defined(UI_VIC20)
-      SUB(IDMS_ACIA_SETTINGS, NULL,    IDM_ACIA_SETTINGS)
-#endif
-#if defined(UI_PET)
-      SUB(IDMS_PETREU_SETTINGS, NULL,    IDM_PETREU_SETTINGS)
-#endif
-#if !defined(UI_CBM2) && !defined(UI_PET) && !defined(UI_PLUS4)
       SUB(IDMS_RS232_USERPORT_SETTINGS, NULL,    IDM_RS232USER_SETTINGS)
-#endif
-#if defined(UI_PET) || defined(UI_PLUS4) || defined(UI_VIC20)
       SUB(IDMS_SIDCART_SETTINGS, NULL,    IDM_SIDCART_SETTINGS)
-#endif
     ITEMSEPARATOR()
+    ITEM(IDMS_SAVE_CURRENT_SETTINGS_FILE, NULL, IDM_SETTINGS_SAVE_FILE)
+    ITEM(IDMS_LOAD_SAVED_SETTINGS_FILE, NULL,   IDM_SETTINGS_LOAD_FILE)
     ITEM(IDMS_SAVE_CURRENT_SETTINGS, NULL, IDM_SETTINGS_SAVE)
     ITEM(IDMS_LOAD_SAVED_SETTINGS, NULL,   IDM_SETTINGS_LOAD)
     ITEM(IDMS_SET_DEFAULT_SETTINGS, NULL,  IDM_SETTINGS_DEFAULT)
@@ -332,4 +215,3 @@ static struct TranslateNewMenu UI_MENU_NAME[] = {
 static struct NewMenu UI_TRANSLATED_MENU_NAME[sizeof(UI_MENU_NAME)/sizeof(UI_MENU_NAME[0])];
 
 #endif /* _VIC20UIRES_H_ */
-
