@@ -69,6 +69,9 @@ ui_menu_toggle  c64_ui_menu_toggles[]={
     { "REU", MENU_TOGGLE_REU },
     { "GEORAM", MENU_TOGGLE_GEORAM },
     { "RAMCART", MENU_TOGGLE_RAMCART },
+    { "DQBB", MENU_TOGGLE_DQBB },
+    { "Isepic", MENU_TOGGLE_ISEPIC },
+    { "IsepicSwitch", MENU_TOGGLE_ISEPIC_SWITCH },
     { "PLUS60K", MENU_TOGGLE_PLUS60K },
     { "PLUS256K", MENU_TOGGLE_PLUS256K },
     { "256K", MENU_TOGGLE_C64_256K },
@@ -160,6 +163,19 @@ ui_res_possible_values c64viciiBorders[] = {
         {-1, 0}
 };
 
+ui_res_possible_values c64mousetypes[] = {
+        {0, MENU_MOUSE_TYPE_1351},
+        {1, MENU_MOUSE_TYPE_NEOS},
+        {2, MENU_MOUSE_TYPE_AMIGA},
+        {-1, 0}
+};
+
+ui_res_possible_values c64mouseports[] = {
+        {1, MENU_MOUSE_PORT_JOY1},
+        {2, MENU_MOUSE_PORT_JOY2},
+        {-1, 0}
+};
+
 ui_res_value_list c64_ui_res_values[] = {
     {"REUsize", ReuSize},
     {"GeoRAMsize", GeoRAMSize},
@@ -169,6 +185,8 @@ ui_res_value_list c64_ui_res_values[] = {
     {"DIGIMAXbase", DigimaxBase},
     {"MMC64_revision", MMC64Revision},
     {"VICIIBorderMode", c64viciiBorders},
+    {"Mousetype", c64mousetypes},
+    {"Mouseport", c64mouseports},
     {NULL,NULL}
 };
 
@@ -195,6 +213,21 @@ static ui_cartridge_t c64_ui_cartridges[]={
     "Action Replay",
     },
     {
+    MENU_CART_ATTACH_AR3,
+    CARTRIDGE_ACTION_REPLAY3,
+    "Action Replay 3",
+    },
+    {
+    MENU_CART_ATTACH_AR4,
+    CARTRIDGE_ACTION_REPLAY4,
+    "Action Replay 4",
+    },
+    {
+    MENU_CART_ATTACH_STARDOS,
+    CARTRIDGE_STARDOS,
+    "StarDOS",
+    },
+    {
     MENU_CART_ATTACH_AT,
     CARTRIDGE_ATOMIC_POWER,
     "Atomic Power"
@@ -297,6 +330,9 @@ void c64_ui_specific(void *msg, void *window)
         case MENU_RAMCART_FILE:
             ui_select_file(windowlist[0]->savepanel,RAMCART_FILE,(void*)0);
             break;
+        case MENU_DQBB_FILE:
+            ui_select_file(windowlist[0]->savepanel,DQBB_FILE,(void*)0);
+            break;
         case MENU_PLUS60K_FILE:
             ui_select_file(windowlist[0]->savepanel,PLUS60K_FILE,(void*)0);
             break;
