@@ -74,6 +74,9 @@ const uint32 MENU_CART_ATTACH_CRT				= 'M040';
 const uint32 MENU_CART_ATTACH_8KB				= 'M041';
 const uint32 MENU_CART_ATTACH_16KB				= 'M042';
 const uint32 MENU_CART_ATTACH_AR				= 'M043';
+const uint32 MENU_CART_ATTACH_AR3				= 'M158';
+const uint32 MENU_CART_ATTACH_AR4				= 'M159';
+const uint32 MENU_CART_ATTACH_STARDOS			= 'M160';
 const uint32 MENU_CART_ATTACH_AT				= 'M044';
 const uint32 MENU_CART_ATTACH_EPYX				= 'M045';
 const uint32 MENU_CART_ATTACH_IEEE488			= 'M046';
@@ -108,6 +111,9 @@ const uint32 MENU_CART_VIC20_4KB_B000			= 'M064';
 const uint32 ATTACH_C64_CART					= 'MA01';
 const uint32 ATTACH_VIC20_CART					= 'MA02';
 
+const uint32 MENU_COPY						= 'M161';
+const uint32 MENU_PASTE						= 'M162';
+
 const uint32 MENU_TOGGLE_SOUND					= 'M100';
 const uint32 MENU_TOGGLE_WARP_MODE				= 'M101';
 const uint32 MENU_TOGGLE_DRIVE_TRUE_EMULATION	= 'M102';
@@ -119,6 +125,9 @@ const uint32 MENU_TOGGLE_VIDEOCACHE				= 'M108';
 const uint32 MENU_TOGGLE_REU					= 'M109';
 const uint32 MENU_TOGGLE_GEORAM					= 'M143';
 const uint32 MENU_TOGGLE_RAMCART					= 'M145';
+const uint32 MENU_TOGGLE_DQBB						= 'M165';
+const uint32 MENU_TOGGLE_ISEPIC					= 'M166';
+const uint32 MENU_TOGGLE_ISEPIC_SWITCH				= 'M167';
 const uint32 MENU_TOGGLE_PLUS60K					= 'M146';
 const uint32 MENU_TOGGLE_PLUS256K					= 'M148';
 const uint32 MENU_TOGGLE_C64_256K					= 'M144';
@@ -128,6 +137,7 @@ const uint32 MENU_TOGGLE_MMC64					= 'M039';
 const uint32 MENU_TOGGLE_MMC64_FLASHJUMPER			= 'M057';
 const uint32 MENU_TOGGLE_MMC64_SAVE					= 'M068';
 const uint32 MENU_TOGGLE_MMC64_READ_ONLY				= 'M058';
+const uint32 MENU_TOGGLE_C64DTV_WRITE_ENABLE			= 'M099';
 const uint32 MENU_TOGGLE_SIDCART					= 'M085';
 const uint32 MENU_TOGGLE_SIDCART_FILTERS				= 'M086';
 const uint32 MENU_TOGGLE_MOUSE					= 'M110';
@@ -210,6 +220,8 @@ const uint32 MENU_RAMCART_SIZE_128					= 'M458';
 
 const uint32 MENU_RAMCART_FILE					= 'M034';
 
+const uint32 MENU_DQBB_FILE						= 'M168';
+
 const uint32 MENU_PLUS60K_BASE_D040					= 'M459';
 const uint32 MENU_PLUS60K_BASE_D100					= 'M460';
 
@@ -255,6 +267,18 @@ const uint32 MENU_MMC64_REVISION_B					= 'M067';
 const uint32 MENU_MMC64_BIOS_FILE					= 'M059';
 const uint32 MENU_MMC64_IMAGE_FILE					= 'M065';
 
+const uint32 MENU_C64DTV_REVISION_2					= 'M137';
+const uint32 MENU_C64DTV_REVISION_3					= 'M138';
+
+const uint32 MENU_HUMMER_JOY_PORT_1					= 'M139';
+const uint32 MENU_HUMMER_JOY_PORT_2					= 'M150';
+
+const uint32 MENU_HUMMER_USERPORT_NONE				= 'M105';
+const uint32 MENU_HUMMER_USERPORT_ADC				= 'M163';
+const uint32 MENU_HUMMER_USERPORT_JOY				= 'M164';
+
+const uint32 MENU_C64DTV_ROM_FILE					= 'M151';
+
 const uint32 MENU_SOUND_RECORD_AIFF					= 'M069';
 const uint32 MENU_SOUND_RECORD_IFF					= 'M080';
 const uint32 MENU_SOUND_RECORD_MP3					= 'M081';
@@ -279,6 +303,15 @@ const uint32 MENU_VICII_BORDERS_NORMAL				= 'M096';
 const uint32 MENU_VICII_BORDERS_FULL				= 'M097';
 const uint32 MENU_VICII_BORDERS_DEBUG				= 'M098';
 
+const uint32 MENU_TOGGLE_PS2MOUSE					= 'M152';
+
+const uint32 MENU_MOUSE_TYPE_1351				= 'M153';
+const uint32 MENU_MOUSE_TYPE_NEOS				= 'M154';
+const uint32 MENU_MOUSE_TYPE_AMIGA				= 'M155';
+
+const uint32 MENU_MOUSE_PORT_JOY1				= 'M156';
+const uint32 MENU_MOUSE_PORT_JOY2				= 'M157';
+
 const uint32 MENU_ABOUT							= 'M901';
 const uint32 MENU_CONTRIBUTORS					= 'M902';
 const uint32 MENU_LICENSE						= 'M904';
