@@ -36,6 +36,7 @@
 #include "lib.h"
 #include "resources.h"
 #include "machine.h"
+#include "translate.h"
 #include "types.h"
 
 /* ------------------------------------------------------------------------ */
@@ -54,11 +55,13 @@ static void kbd_debug(const char *format, ...)
 
 /* ------------------------------------------------------------------------ */
 
+#ifndef COMMON_KBD
 /* 40/80 column key.  */
 static key_ctrl_column4080_func_t key_ctrl_column4080_func = NULL;
 
 /* CAPS key.  */
 static key_ctrl_caps_func_t key_ctrl_caps_func = NULL;
+#endif
 
 struct _convmap {
     /* Conversion map.  */
@@ -125,7 +128,10 @@ int kbd_resources_init(void)
 }
 
 static const cmdline_option_t cmdline_options[] = {
-    { "-keymap", SET_RESOURCE, 1, NULL, NULL, "KeymapIndex", NULL,
+    { "-keymap", SET_RESOURCE, 1,
+      NULL, NULL, "KeymapIndex", NULL,
+      USE_PARAM_STRING, USE_DESCRIPTION_STRING,
+      IDCLS_UNUSED, IDCLS_UNUSED,
       "<number>", "Specify index of used keymap" },
     { NULL },
 };
