@@ -28,6 +28,7 @@
 
 #include <Alert.h>
 #include <Application.h>
+#include <Clipboard.h>
 #include <FilePanel.h>
 #include <Menu.h>
 #include <MenuBar.h>
@@ -39,16 +40,16 @@
 #include <signal.h>
 #include <stdio.h>
 #include <stdlib.h>
-
-#if defined(__BEOS__) && defined(WORDS_BIGENDIAN)
+#include <sys/utsname.h>
 #include <string.h>
-#endif
 
 extern "C" {
 #include "attach.h"
 #include "autostart.h"
 #include "archdep.h"
+#include "charset.h"
 #include "cmdline.h"
+#include "clipboard.h"
 #include "constants.h"
 #include "datasette.h"
 #include "drive.h"
@@ -59,6 +60,7 @@ extern "C" {
 #include "interrupt.h" 
 #include "joy.h"
 #include "kbd.h"
+#include "kbdbuf.h"
 #include "keyboard.h"
 #include "lib.h"
 #include "log.h"
@@ -261,15 +263,19 @@ static void ui_exit_early(void)
 }
 
 
-static void save_snapshot_trap(WORD unused_addr, void *unused_data)
+/* this check is needed for haiku, since it always returns 1 on
+   SupportsWindowMode() */
+int CheckForHaiku(void)
 {
-	ui_select_file(windowlist[0]->savepanel,SNAPSHOTSAVE_FILE,(void*)0);
+	struct utsname name;
+
+	uname(&name);
+	if (!strncasecmp(name.sysname,"Haiku",5))
+		return -1;
+	return 0;
 }
 
-static void load_snapshot_trap(WORD unused_addr, void *unused_data)
-{
-	ui_select_file(windowlist[0]->filepanel,SNAPSHOTLOAD_FILE,(void*)0);
-}
+/* ------------------------------------------------------------------------ */
 
 typedef struct {
     char    name[256];
@@ -415,6 +421,55 @@ int ui_emulation_is_paused(void)
     return is_paused;
 }
 
+static void ui_copy_clipboard(void)
+{
+    BMessage *clippy = (BMessage *)NULL;
+    char *text = NULL;
+
+    text = clipboard_read_screen_output("\n");
+
+    if (text != NULL)
+    {
+        if (be_clipboard->Lock())
+        {
+            be_clipboard->Clear();
+            if (clippy = be_clipboard->Data())
+            {
+                clippy->AddData("text/plain", B_MIME_TYPE, text, strlen(text));
+                be_clipboard->Commit();
+            }
+            be_clipboard->Unlock();
+        }
+        lib_free(text);
+    }
+}
+
+static void ui_paste_clipboard_text(void)
+{
+    const char *text;
+    char *text_in_petscii = NULL;
+    int32 textlen = 0;
+    BMessage *clippy = (BMessage *)NULL;
+
+    if (be_clipboard->Lock())
+    {
+        if (clippy = be_clipboard->Data())
+        {
+            clippy->FindData("text/plain", B_MIME_TYPE, (const void **)&text, &textlen);
+
+            if (textlen != 0)
+            {
+                text_in_petscii = (char *)lib_malloc(textlen + 1);
+                memcpy(text_in_petscii, text, textlen);
+                text_in_petscii[textlen] = 0;
+                charset_petconvstring((unsigned char *)text_in_petscii, 0);
+                kbdbuf_feed(text_in_petscii);
+                lib_free(text_in_petscii);
+            }
+        }
+        be_clipboard->Unlock();
+    }
+} 
 
 /* here the stuff for queueing and dispatching ui commands */
 /*---------------------------------------------------------*/
@@ -565,12 +620,11 @@ void ui_dispatch_events(void)
 		        datasette_control(DATASETTE_CONTROL_RESET_COUNTER);
 				break;
 			case MENU_SNAPSHOT_LOAD:
-				interrupt_maincpu_trigger_trap(
-					load_snapshot_trap,	(void*) 0);
+				ui_select_file(filepanel, SNAPSHOTLOAD_FILE, (void*)0);
 				break;
 			case MENU_SNAPSHOT_SAVE:
-				interrupt_maincpu_trigger_trap(
-					save_snapshot_trap, (void*) 0);
+				ui_select_file(windowlist[0]->savepanel,
+								SNAPSHOTSAVE_FILE, (void*)0);
 				break;
 			case MENU_LOADQUICK:
 				scan_files();
@@ -627,42 +681,38 @@ void ui_dispatch_events(void)
 			case MENU_PAUSE:
         		ui_pause_emulation();
         		break;
+            case MENU_COPY:
+			ui_copy_clipboard();
+			break;
+            case MENU_PASTE:
+			ui_paste_clipboard_text();
+			break;
         	case MENU_SOUND_RECORD_AIFF:
-                  ui_select_file(windowlist[0]->savepanel,AIFF_FILE,(void*)0);
-                  resources_set_string("SoundRecordDeviceName", "");
-                  resources_set_string("SoundRecordDeviceName", "aiff");
-                  ui_display_statustext("Sound Recording Started...", 1);
-        		break;	
+				resources_set_string("SoundRecordDeviceName", "");
+				ui_select_file(windowlist[0]->savepanel,AIFF_FILE,(void*)0);
+				break;
         	case MENU_SOUND_RECORD_IFF:
-                  ui_select_file(windowlist[0]->savepanel,IFF_FILE,(void*)0);
-                  resources_set_string("SoundRecordDeviceName", "");
-                  resources_set_string("SoundRecordDeviceName", "iff");
-                  ui_display_statustext("Sound Recording Started...", 1);
-        		break;	
+				resources_set_string("SoundRecordDeviceName", "");
+				ui_select_file(windowlist[0]->savepanel,IFF_FILE,(void*)0);
+				break;
 #ifdef USE_LAMEMP3
         	case MENU_SOUND_RECORD_MP3:
-                  ui_select_file(windowlist[0]->savepanel,MP3_FILE,(void*)0);
-                  resources_set_string("SoundRecordDeviceName", "");
-                  resources_set_string("SoundRecordDeviceName", "mp3");
-                  ui_display_statustext("Sound Recording Started...", 1);
-        		break;	
+				resources_set_string("SoundRecordDeviceName", "");
+				ui_select_file(windowlist[0]->savepanel,MP3_FILE,(void*)0);
+				break;
 #endif
         	case MENU_SOUND_RECORD_VOC:
-                  ui_select_file(windowlist[0]->savepanel,VOC_FILE,(void*)0);
-                  resources_set_string("SoundRecordDeviceName", "");
-                  resources_set_string("SoundRecordDeviceName", "voc");
-                  ui_display_statustext("Sound Recording Started...", 1);
-        		break;	
+				resources_set_string("SoundRecordDeviceName", "");
+				ui_select_file(windowlist[0]->savepanel,VOC_FILE,(void*)0);
+				break;
         	case MENU_SOUND_RECORD_WAV:
-                  ui_select_file(windowlist[0]->savepanel,WAV_FILE,(void*)0);
-                  resources_set_string("SoundRecordDeviceName", "");
-                  resources_set_string("SoundRecordDeviceName", "wav");
-                  ui_display_statustext("Sound Recording Started...", 1);
-        		break;	
+				resources_set_string("SoundRecordDeviceName", "");
+				ui_select_file(windowlist[0]->savepanel,WAV_FILE,(void*)0);
+				break;
         	case MENU_SOUND_RECORD_STOP:
-                  resources_set_string("SoundRecordDeviceName", "");
-                  ui_display_statustext("Sound Recording Stopped...", 1);
-       		break;	
+				resources_set_string("SoundRecordDeviceName", "");
+				ui_display_statustext("Sound Recording Stopped...", 1);
+				break;
         	case MENU_DRIVE_SETTINGS:
         		ui_drive();
         		break;	
@@ -708,15 +758,19 @@ void ui_dispatch_events(void)
 				char *abouttext;
 				abouttext = util_concat(
 					"BeVICE Version ", VERSION,"\n",
-					"(c) 1998-2007 Andreas Boose\n",
-					"(c) 1998-2007 Dag Lem\n",
-					"(c) 1998-2007 Tibor Biczo\n",
+					"(c) 1998-2008 Andreas Boose\n",
+					"(c) 1998-2008 Dag Lem\n",
+					"(c) 1998-2008 Tibor Biczo\n",
+					"(c) 1999-2008 Andreas Matthies\n",
+					"(c) 1999-2008 Martin Pottendorfer\n",
+					"(c) 2000-2008 Spiro Trikaliotis\n",
+					"(c) 2005-2008 Marco van den Heuvel\n",
+					"(c) 2006-2008 Christian Vogelgsang\n",
+					"(c) 2007-2008 Fabrizio Gennari\n",
+					"(c) 2007-2008 M. Kiesel\n",
+					"(c) 2007-2008 Hannu Nuotio\n",
+					"(c) 2007-2008 Daniel Kahlin\n",
 					"(c) 1999-2007 Andreas Dehmel\n",
-					"(c) 1999-2007 Andreas Matthies\n",
-					"(c) 1999-2007 Martin Pottendorfer\n",
-					"(c) 2000-2007 Spiro Trikaliotis\n",
-					"(c) 2005-2007 Marco van den Heuvel\n",
-					"(c) 2006-2007 Christian Vogelgsang\n",
 					"(c) 1999-2005 Thomas Bretz\n",
 					"(c) 2003-2005 David Hansel\n",
 					"(c) 2000-2004 Markus Brenner\n",
@@ -913,23 +967,24 @@ void ui_show_text(
 /* Report an error to the user (`printf()' style).  */
 void ui_error(const char *format, ...)
 {
-	BAlert *messagebox;
     char tmp[1024];
     va_list args;
 
     va_start(args, format);
     vsprintf(tmp, format, args);
     va_end(args);
-    messagebox = new BAlert("error", tmp, "OK", NULL, NULL, 
-    	B_WIDTH_AS_USUAL, B_STOP_ALERT);
-	vsync_suspend_speed_eval();
-	messagebox->Go();
+
+    ui_error_string(tmp);
 }
 
 /* Report an error to the user (one string).  */
 void ui_error_string(const char *text)
 {
-	ui_error(text);
+    BAlert *messagebox;
+
+    messagebox = new BAlert("error", text, "OK", NULL, NULL, B_WIDTH_AS_USUAL, B_STOP_ALERT);
+    vsync_suspend_speed_eval();
+    messagebox->Go();
 }
 
 /* Report a message to the user (`printf()' style).  */
@@ -1301,7 +1356,7 @@ int ui_set_window_mode(int use_direct_window)
 			w->Lock();
 			
 			/* only use DirectWindow if Window Mode is supported */
-			if (!w->SupportsWindowMode())
+			if (!w->SupportsWindowMode() || CheckForHaiku())
 				use_direct_window = 0;
 			
 			w->use_direct_window = use_direct_window;
@@ -1326,3 +1381,8 @@ int ui_set_window_mode(int use_direct_window)
 void ui_display_volume(int vol)
 {
 }
+
+char* ui_get_file(const char *format,...)
+{
+    return NULL;
+}
