@@ -119,27 +119,29 @@ BMenuBar *menu_create(int machine_class) {
 			new BMessage(MENU_FLIP_PREVIOUS), 'N', B_CONTROL_KEY));
 		menu->AddSeparatorItem();
 
-		menu->AddItem(new BMenuItem("Attach Tape", 
-			new BMessage(MENU_ATTACH_TAPE), 'T'));
-		menu->AddItem(new BMenuItem("Detach Tape", 
-			new BMessage(MENU_DETACH_TAPE)));
+		if (machine_class != VICE_MACHINE_C64DTV) {
+			menu->AddItem(new BMenuItem("Attach Tape", 
+				new BMessage(MENU_ATTACH_TAPE), 'T'));
+			menu->AddItem(new BMenuItem("Detach Tape", 
+				new BMessage(MENU_DETACH_TAPE)));
 
-		menu->AddItem(submenu = new BMenu("Datasette Control"));
-		submenu->AddItem(new BMenuItem("Start", 
-			new BMessage(MENU_DATASETTE_START)));
-		submenu->AddItem(new BMenuItem("Stop", 
-			new BMessage(MENU_DATASETTE_STOP)));
-		submenu->AddItem(new BMenuItem("Forward", 
-			new BMessage(MENU_DATASETTE_FORWARD)));
-		submenu->AddItem(new BMenuItem("Rewind", 
-			new BMessage(MENU_DATASETTE_REWIND)));
-		submenu->AddItem(new BMenuItem("Record", 
-			new BMessage(MENU_DATASETTE_RECORD)));
-		submenu->AddItem(new BMenuItem("Reset", 
-			new BMessage(MENU_DATASETTE_RESET)));
-		submenu->AddItem(new BMenuItem("Reset Counter", 
-			new BMessage(MENU_DATASETTE_COUNTER)));
-		menu->AddSeparatorItem();
+			menu->AddItem(submenu = new BMenu("Datasette Control"));
+			submenu->AddItem(new BMenuItem("Start", 
+				new BMessage(MENU_DATASETTE_START)));
+			submenu->AddItem(new BMenuItem("Stop", 
+				new BMessage(MENU_DATASETTE_STOP)));
+			submenu->AddItem(new BMenuItem("Forward", 
+				new BMessage(MENU_DATASETTE_FORWARD)));
+			submenu->AddItem(new BMenuItem("Rewind", 
+				new BMessage(MENU_DATASETTE_REWIND)));
+			submenu->AddItem(new BMenuItem("Record", 
+				new BMessage(MENU_DATASETTE_RECORD)));
+			submenu->AddItem(new BMenuItem("Reset", 
+				new BMessage(MENU_DATASETTE_RESET)));
+			submenu->AddItem(new BMenuItem("Reset Counter", 
+				new BMessage(MENU_DATASETTE_COUNTER)));
+			menu->AddSeparatorItem();
+		}
 		if (machine_class == VICE_MACHINE_C64) {
 			menu->AddItem(submenu = new BMenu("Attach cartridge image"));
 			submenu->AddItem(new BMenuItem("CRT",
@@ -150,6 +152,12 @@ BMenuBar *menu_create(int machine_class) {
 				new BMessage(MENU_CART_ATTACH_16KB)));
 			submenu->AddItem(new BMenuItem("Action Replay",
 				new BMessage(MENU_CART_ATTACH_AR)));
+			submenu->AddItem(new BMenuItem("Action Replay 3",
+				new BMessage(MENU_CART_ATTACH_AR3)));
+			submenu->AddItem(new BMenuItem("Action Replay 4",
+				new BMessage(MENU_CART_ATTACH_AR4)));
+			submenu->AddItem(new BMenuItem("StarDOS",
+				new BMessage(MENU_CART_ATTACH_STARDOS)));
 			submenu->AddItem(new BMenuItem("Atomic Power",
 				new BMessage(MENU_CART_ATTACH_AT)));
 			submenu->AddItem(new BMenuItem("Epyx fastload",
@@ -250,6 +258,16 @@ BMenuBar *menu_create(int machine_class) {
 	menu->AddItem(new BMenuItem("Quit", 
 		new BMessage(MENU_EXIT_REQUESTED), 'Q'));
 
+	/* create the EDIT menu */
+	menu = new BMenu("Edit");
+	menubar->AddItem(menu);
+	if (!vsid_mode) {
+		menu->AddItem(new BMenuItem("Copy", 
+			new BMessage(MENU_COPY)));
+		menu->AddItem(new BMenuItem("Paste", 
+			new BMessage(MENU_PASTE)));
+      }
+
 	/* create the OPTIONS menu */
 	menu = new BMenu("Options");
 	menubar->AddItem(menu);
@@ -315,6 +333,7 @@ BMenuBar *menu_create(int machine_class) {
 				new BMessage(MENU_TOGGLE_FASTPAL), 'P', B_CONTROL_KEY));
 		}
 		if (machine_class == VICE_MACHINE_C64
+			|| machine_class == VICE_MACHINE_C64DTV
 			|| machine_class == VICE_MACHINE_C128
 			|| machine_class == VICE_MACHINE_PLUS4
 			|| machine_class == VICE_MACHINE_VIC20) {
@@ -333,7 +352,9 @@ BMenuBar *menu_create(int machine_class) {
 		}
 		menu->AddSeparatorItem();
 
-		if (machine_class == VICE_MACHINE_C128 || machine_class == VICE_MACHINE_C64) {
+		if (machine_class == VICE_MACHINE_C128
+			|| machine_class == VICE_MACHINE_C64
+			|| machine_class == VICE_MACHINE_C64DTV) {
 				menu->AddItem(submenu = new BMenu("VIC-II Border mode"));
 				submenu->SetRadioMode(true);
 				submenu->AddItem(new BMenuItem("Normal",
@@ -352,7 +373,7 @@ BMenuBar *menu_create(int machine_class) {
 	submenu->AddItem(new BMenuItem("Sound Record AIFF",
 		new BMessage(MENU_SOUND_RECORD_AIFF)));
 	submenu->AddItem(new BMenuItem("Sound Record IFF",
-		new BMessage(MENU_SOUND_RECORD_AIFF)));
+		new BMessage(MENU_SOUND_RECORD_IFF)));
 #ifdef USE_LAMEMP3
 	submenu->AddItem(new BMenuItem("Sound Record MP3",
 		new BMessage(MENU_SOUND_RECORD_MP3)));
@@ -374,7 +395,8 @@ BMenuBar *menu_create(int machine_class) {
 	}
 	if (machine_class == VICE_MACHINE_C64
 		|| machine_class == VICE_MACHINE_C128
-		|| machine_class == VICE_MACHINE_VIC20) {
+		|| machine_class == VICE_MACHINE_VIC20
+		|| machine_class == VICE_MACHINE_C64DTV) {
 		menu->AddItem(submenu = new BMenu("Video Standard"));
 		submenu->SetRadioMode(true);
 		submenu->AddItem(new BMenuItem("PAL-G", 
@@ -395,15 +417,64 @@ BMenuBar *menu_create(int machine_class) {
 
 	if (!vsid_mode) {
 		if (machine_class == VICE_MACHINE_C64
+			|| machine_class == VICE_MACHINE_C64DTV
 			|| machine_class == VICE_MACHINE_C128) {
 			
 			menu->AddSeparatorItem();
 			menu->AddItem(new BMenuItem("Emulator ID",
 				new BMessage(MENU_TOGGLE_EMUID)));
-			menu->AddItem(new BMenuItem("1351 mouse",
+			menu->AddItem(new BMenuItem("Grab mouse events",
 				new BMessage(MENU_TOGGLE_MOUSE)));
+		}
+		if (machine_class == VICE_MACHINE_C64DTV) {
+			menu->AddItem(new BMenuItem("PS/2 mouse",
+				new BMessage(MENU_TOGGLE_PS2MOUSE)));
 			menu->AddSeparatorItem();
+			menu->AddItem(submenu = new BMenu("C64DTV Options"));
+				submenu->AddItem(new BMenuItem("C64DTV ROM File",
+					new BMessage(MENU_C64DTV_ROM_FILE)));
+				submenu->AddItem(extsubmenu = new BMenu("C64DTV revision"));
+					extsubmenu->SetRadioMode(true);
+					extsubmenu->AddItem(new BMenuItem("DTV2",
+						new BMessage(MENU_C64DTV_REVISION_2)));
+					extsubmenu->AddItem(new BMenuItem("DTV3",
+						new BMessage(MENU_C64DTV_REVISION_3)));
+				submenu->AddItem(new BMenuItem("C64DTV ROM writable",
+					new BMessage(MENU_TOGGLE_C64DTV_WRITE_ENABLE)));
+				submenu->AddItem(extsubmenu = new BMenu("Hummer Userport device"));
+					extsubmenu->SetRadioMode(true);
+					extsubmenu->AddItem(new BMenuItem("None",
+						new BMessage(MENU_HUMMER_USERPORT_NONE)));
+					extsubmenu->AddItem(new BMenuItem("ADC",
+						new BMessage(MENU_HUMMER_USERPORT_ADC)));
+					extsubmenu->AddItem(new BMenuItem("Joystick",
+						new BMessage(MENU_HUMMER_USERPORT_JOY)));
+				submenu->AddItem(extsubmenu = new BMenu("Joystick port mapped to Hummer Userport"));
+					extsubmenu->SetRadioMode(true);
+					extsubmenu->AddItem(new BMenuItem("Joy1",
+						new BMessage(MENU_HUMMER_JOY_PORT_1)));
+					extsubmenu->AddItem(new BMenuItem("Joy2",
+						new BMessage(MENU_HUMMER_JOY_PORT_2)));
+		}
+		if (machine_class == VICE_MACHINE_C64
+			|| machine_class == VICE_MACHINE_C128) {
 
+			menu->AddItem(submenu = new BMenu("Mouse Options"));
+			submenu->AddItem(extsubmenu = new BMenu("Mouse Type"));
+				extsubmenu->SetRadioMode(true);
+				extsubmenu->AddItem(new BMenuItem("1351",
+					new BMessage(MENU_MOUSE_TYPE_1351)));
+				extsubmenu->AddItem(new BMenuItem("NEOS",
+					new BMessage(MENU_MOUSE_TYPE_NEOS)));
+				extsubmenu->AddItem(new BMenuItem("AMIGA",
+					new BMessage(MENU_MOUSE_TYPE_AMIGA)));
+			submenu->AddItem(extsubmenu = new BMenu("Mouse Port"));
+				extsubmenu->SetRadioMode(true);
+				extsubmenu->AddItem(new BMenuItem("Joy1",
+					new BMessage(MENU_MOUSE_PORT_JOY1)));
+				extsubmenu->AddItem(new BMenuItem("Joy2",
+					new BMessage(MENU_MOUSE_PORT_JOY2)));
+			menu->AddSeparatorItem();
 			menu->AddItem(submenu = new BMenu("Expansion Carts"));
 			uppermenu = menu;
 			menu = submenu;
@@ -506,6 +577,18 @@ BMenuBar *menu_create(int machine_class) {
 				new BMessage(MENU_DIGIMAX_BASE_DFE0)));
 
 			if (machine_class == VICE_MACHINE_C64) {
+				menu->AddItem(submenu = new BMenu("Double Quick Brown Box Options"));
+				submenu->AddItem(new BMenuItem("DQBB emulation",
+					new BMessage(MENU_TOGGLE_DQBB)));
+				submenu->AddItem(new BMenuItem("DQBB File",
+					new BMessage(MENU_DQBB_FILE)));
+
+				menu->AddItem(submenu = new BMenu("Isepic Options"));
+				submenu->AddItem(new BMenuItem("Isepic emulation",
+					new BMessage(MENU_TOGGLE_ISEPIC)));
+				submenu->AddItem(new BMenuItem("Isepic switch",
+					new BMessage(MENU_TOGGLE_ISEPIC_SWITCH)));
+
 				menu->AddItem(submenu = new BMenu("PLUS60K Options"));
 				submenu->AddItem(new BMenuItem("PLUS60K emulation",
 					new BMessage(MENU_TOGGLE_PLUS60K)));
@@ -662,9 +745,12 @@ BMenuBar *menu_create(int machine_class) {
 			new BMessage(MENU_DEVICE_SETTINGS)));
 		menu->AddItem(new BMenuItem("Drive ...", 
 			new BMessage(MENU_DRIVE_SETTINGS)));
-		menu->AddItem(new BMenuItem("Datasette ...",
-			new BMessage(MENU_DATASETTE_SETTINGS)));
+		if (machine_class != VICE_MACHINE_C64DTV) {
+			menu->AddItem(new BMenuItem("Datasette ...",
+				new BMessage(MENU_DATASETTE_SETTINGS)));
+		}
 		if (machine_class == VICE_MACHINE_C64
+			|| machine_class == VICE_MACHINE_C64DTV
 			|| machine_class == VICE_MACHINE_C128) {
 			menu->AddItem(new BMenuItem("VIC-II ...", 
 				new BMessage(MENU_VICII_SETTINGS)));
@@ -676,6 +762,7 @@ BMenuBar *menu_create(int machine_class) {
 	menu->AddItem(new BMenuItem("Sound ...", 
 		new BMessage(MENU_SOUND_SETTINGS)));
 	if (machine_class == VICE_MACHINE_C64
+		|| machine_class == VICE_MACHINE_C64DTV
 		|| machine_class == VICE_MACHINE_C128
 		|| machine_class == VICE_MACHINE_CBM2) {
 		menu->AddItem(new BMenuItem("SID ...", 
