@@ -35,7 +35,6 @@
 #include "video.h"
 
 struct video_draw_buffer_callback_s;
-struct video_resource_chip_s;
 
 struct video_canvas_s {
     unsigned int initialized;
@@ -47,7 +46,6 @@ struct video_canvas_s {
     struct viewport_s *viewport;
     struct geometry_s *geometry;
     struct palette_s *palette;
-    struct video_resource_chip_s *video_resource_chip;
 	
     /* Pointer to the canvas' ViceWindow */
 #ifdef EXACT_TYPE_NEEDED
