@@ -37,7 +37,6 @@
 #include <errno.h>
 #include <io.h>
 #include <process.h>
-#include <signal.h>
 #include <sys/wait.h>
 #include <sys/stat.h>
 #include <unistd.h>
@@ -69,7 +68,7 @@ int archdep_init(int *argc, char **argv)
 
     argv0 = lib_stralloc(argv[0]);
 
-    orig_workdir = getcwd(NULL, GET_PATH_MAX);
+    orig_workdir = getcwd(NULL, PATH_MAX);
     atexit(restore_workdir);
 
     return 0;
@@ -124,9 +123,9 @@ char *archdep_default_sysfile_pathlist(const char *emu_id)
         const char *boot_path = archdep_boot_path();
 
         default_path = util_concat(boot_path, "/", emu_id,
-                                   FINDPATH_SEPARATOR_STRING,
+                                   ARCHDEP_FINDPATH_SEPARATOR_STRING,
                                    boot_path, "/", "DRIVES",
-                                   FINDPATH_SEPARATOR_STRING,
+                                   ARCHDEP_FINDPATH_SEPARATOR_STRING,
                                    boot_path, "/", "PRINTER",
                                    NULL);
     }
@@ -198,32 +197,6 @@ int archdep_default_logger(const char *level_string, const char *txt)
     return 0;
 }
 
-static RETSIGTYPE break64(int sig)
-{
-
-#ifdef SYS_SIGLIST_DECLARED
-    log_message(LOG_DEFAULT, "Received signal %d (%s).",
-                sig, sys_siglist[sig]);
-#else
-    log_message(LOG_DEFAULT, "Received signal %d.", sig);
-#endif
-
-    exit (-1);
-}
-
-void archdep_setup_signals(int do_core_dumps)
-{
-    signal(SIGINT, SIG_IGN);
-
-    if (!do_core_dumps) {
-        signal(SIGSEGV,  break64);
-        signal(SIGILL,   break64);
-        signal(SIGPIPE,  break64);
-        signal(SIGHUP,   break64);
-        signal(SIGQUIT,  break64);
-    }
-}
-
 int archdep_path_is_relative(const char *path)
 {
     if (path == NULL)
@@ -236,12 +209,19 @@ int archdep_path_is_relative(const char *path)
 }
 
 int archdep_spawn(const char *name, char **argv,
-                  const char *stdout_redir, const char *stderr_redir)
+                  char **pstdout_redir, const char *stderr_redir)
 {
     int new_stdout, new_stderr;
     int old_stdout_mode, old_stderr_mode;
     int old_stdout, old_stderr;
     int retval;
+    char *stdout_redir = NULL;
+
+    if (pstdout_redir != NULL) {
+        if (*pstdout_redir == NULL)
+            *pstdout_redir = archdep_tmpnam();
+        stdout_redir = *pstdout_redir;
+    }
 
     new_stdout = new_stderr = old_stdout = old_stderr = -1;
 
@@ -344,6 +324,28 @@ char *archdep_tmpnam(void)
         return lib_stralloc(tmpnam(NULL));
 }
 
+FILE *archdep_mkstemp_fd(char **filename, const char *mode)
+{
+    char *tmp;
+    FILE *fd;
+
+    if (getenv("temp"))
+        tmp = util_concat(getenv("temp"), tmpnam(NULL), NULL);
+    else if (getenv("tmp"))
+        tmp = util_concat(getenv("tmp"), tmpnam(NULL), NULL);
+    else
+        tmp = lib_stralloc(tmpnam(NULL));
+
+    fd = fopen(tmp, mode);
+
+    if (fd == NULL)
+        return NULL;
+
+    *filename = tmp;
+
+    return fd;
+}
+
 int archdep_file_is_gzip(const char *name)
 {
     size_t l = strlen(name);
