@@ -81,29 +81,6 @@ static TUI_MENU_CALLBACK(toggle_MachineVideoStandard_callback)
     }
 }
 
-static TUI_MENU_CALLBACK(toggle_PALMode_callback)
-{
-    int value;
-
-    resources_get_int("PALMode", &value);
-
-    if (been_activated) {
-        value = (value + 1) % 3;
-        resources_set_int("PALMode", value);
-    }
-
-    switch (value) {
-      case 0:
-        return "Fast PAL";
-      case 1:
-        return "Y/C cable (sharp)";
-      case 2:
-        return "Composite (blurry)";
-      default:
-        return "unknown";
-    }
-}
-
 static tui_menu_item_def_t vicii_menu_items[] = {
     { "Video _Cache:",
       "Enable screen cache (disabled when using triple buffering)",
@@ -113,10 +90,6 @@ static tui_menu_item_def_t vicii_menu_items[] = {
       "Enable PAL emulation",
       toggle_PALEmulation_callback, NULL, 3,
       TUI_MENU_BEH_RESUME, NULL, NULL },
-    { "PAL _Mode:",
-      "Change PAL Mode",
-      toggle_PALMode_callback, NULL, 20,
-      TUI_MENU_BEH_CONTINUE, NULL, NULL },
     { "--" },
     { "Sprite-_Background Collisions:",
       "Emulate sprite-background collision register",
@@ -161,10 +134,63 @@ static tui_menu_item_def_t vcd_menu_items[] = {
 TUI_MENU_DEFINE_TOGGLE(Mouse)
 TUI_MENU_DEFINE_TOGGLE(EmuID)
 
+static TUI_MENU_CALLBACK(toggle_MouseType_callback)
+{
+    int value;
+
+    resources_get_int("Mousetype", &value);
+
+    if (been_activated) {
+        value = (value + 1) % 3;
+        resources_set_int("Mousetype", value);
+    }
+
+    switch (value) {
+      case 0:
+        return "1351";
+      case 1:
+        return "NEOS";
+      case 2:
+        return "AMIGA";
+      default:
+        return "unknown";
+    }
+}
+
+static TUI_MENU_CALLBACK(toggle_MousePort_callback)
+{
+    int value;
+
+    resources_get_int("Mouseport", &value);
+    value--;
+
+    if (been_activated) {
+        value = (value + 1) % 2;
+        resources_set_int("Mouseport", value+1);
+    }
+
+    switch (value) {
+      case 0:
+        return "Joy1";
+      case 1:
+        return "Joy2";
+      default:
+        return "unknown";
+    }
+}
+
 static tui_menu_item_def_t ioextenstions_menu_items[] = {
     { "--" },
-    { "1351 _Mouse Emulation:",
-      "Emulate a C1351 proportional mouse connected to joystick port #1",
+    { "Mouse Type:",
+      "Change Mouse Type",
+      toggle_MouseType_callback, NULL, 20,
+      TUI_MENU_BEH_CONTINUE, NULL, NULL },
+    { "Mouse Port:",
+      "Change Mouse Port",
+      toggle_MousePort_callback, NULL, 20,
+      TUI_MENU_BEH_CONTINUE, NULL, NULL },
+    { "Grab mouse events:",
+      "Emulate a mouse",
       toggle_Mouse_callback, NULL, 3,
       TUI_MENU_BEH_CONTINUE, NULL, NULL },
     { "_Emulator Identification:",
