@@ -36,13 +36,11 @@
 #include "joy.h"
 #include "joystick.h"
 #include "resources.h"
+#include "translate.h"
 #include "tui.h"
 #include "types.h"
 
 
-/* Notice that this has to be `int' to make resources work.  */
-static int keyset1[9], keyset2[9];
-
 #ifdef COMMON_KBD
 int joystick_port_map[2];
 #endif
@@ -123,11 +121,15 @@ int joystick_arch_init_resources(void)
 /* ------------------------------------------------------------------------- */
 
 static const cmdline_option_t cmdline_options[] = {
-    { "-joydev1", SET_RESOURCE, 1, NULL, NULL,
-      "JoyDevice1", NULL,
+    { "-joydev1", SET_RESOURCE, 1,
+      NULL, NULL, "JoyDevice1", NULL,
+      USE_PARAM_STRING, USE_DESCRIPTION_STRING,
+      IDCLS_UNUSED, IDCLS_UNUSED,
       "<number>", "Set input device for joystick #1" },
-    { "-joydev2", SET_RESOURCE, 1, NULL, NULL,
-      "JoyDevice2", NULL,
+    { "-joydev2", SET_RESOURCE, 1,
+      NULL, NULL, "JoyDevice2", NULL,
+      USE_PARAM_STRING, USE_DESCRIPTION_STRING,
+      IDCLS_UNUSED, IDCLS_UNUSED,
       "<number>", "Set input device for joystick #2" },
     { NULL }
 };
