@@ -202,11 +202,9 @@ void kbd_flush_commands(void)
             break;
           case KCMD_TOGGLE_STATUSBAR:
             if (statusbar_enabled()) {
-                resources_set_value("ShowStatusbar",
-                                    (resource_value_t)STATUSBAR_MODE_OFF);
+                resources_set_int("ShowStatusbar", STATUSBAR_MODE_OFF);
             } else {
-                resources_set_value("ShowStatusbar",
-                                    (resource_value_t)STATUSBAR_MODE_ON);
+                resources_set_int("ShowStatusbar", STATUSBAR_MODE_ON);
             }
             break;
           case KCMD_DATASETTE_START:
@@ -388,8 +386,7 @@ static void my_kbd_interrupt_handler(void)
                 }
             } else {
                 /* "Normal" key.  */
-                if (!joystick_handle_key(kcode, 1))
-                    keyboard_key_pressed((signed long)kcode);
+                keyboard_key_pressed((signed long)kcode);
             }
         }
 
@@ -425,8 +422,7 @@ static void my_kbd_interrupt_handler(void)
 
         if (!modifiers.left_alt && !modifiers.right_alt) {
             /* "Normal" key.  */
-            if (!joystick_handle_key(kcode, 0))
-                keyboard_key_released((signed long)kcode);
+            keyboard_key_released((signed long)kcode);
         }
 
     }
@@ -562,3 +558,16 @@ const char *kbd_arch_keynum_to_keyname(signed long keynum)
     return keyname;
 }
 
+void kbd_initialize_numpad_joykeys(int* joykeys)
+{
+    joykeys[0] = K_RIGHTCTRL;
+    joykeys[1] = K_KP1;
+    joykeys[2] = K_KP2;
+    joykeys[3] = K_KP3;
+    joykeys[4] = K_KP4;
+    joykeys[5] = K_KP6;
+    joykeys[6] = K_KP7;
+    joykeys[7] = K_KP8;
+    joykeys[8] = K_KP9;
+}
+
