@@ -35,6 +35,7 @@
 #include <stdio.h>
 #include <sys/movedata.h>
 #include <unistd.h>
+#include <string.h>
 
 #include "cmdline.h"
 #include "datasette.h"
@@ -47,6 +48,7 @@
 #include "resources.h"
 #include "sound.h"
 #include "statusbar.h"
+#include "translate.h"
 #include "tui.h"
 #include "tui_backend.h"
 #include "tuicharset.h"
@@ -75,19 +77,19 @@ extern BITMAP *status_bitmap;
 /* UI-related resources and command-line options.  */
 
 /* Flag: Use keyboard LEDs?  */
-static int use_leds;
+static unsigned int use_leds;
 
-static int statusbar_is_enabled;
+static unsigned int statusbar_is_enabled;
 
-static int set_use_leds(resource_value_t v, void *param)
+static int set_use_leds(int v, void *param)
 {
-    use_leds = (int)v;
+    use_leds = v;
     return 0;
 }
 
-static int set_statusbar_enabled(resource_value_t v, void *param) 
+static int set_statusbar_enabled(int v, void *param) 
 {
-    statusbar_is_enabled = (int)v;
+    statusbar_is_enabled = v;
     if (statusbar_enabled()) {
         statusbar_prepare();
         statusbar_update();
@@ -115,15 +117,25 @@ void ui_resources_shutdown(void)
 }
 
 static const cmdline_option_t cmdline_options[] = {
-    { "-leds", SET_RESOURCE, 0, NULL, NULL, "UseLeds", (resource_value_t)1,
+    { "-leds", SET_RESOURCE, 0,
+      NULL, NULL, "UseLeds", (resource_value_t)1,
+      USE_PARAM_STRING, USE_DESCRIPTION_STRING,
+      IDCLS_UNUSED, IDCLS_UNUSED,
       NULL, "Enable usage of PC keyboard LEDs" },
-    { "+leds", SET_RESOURCE, 0, NULL, NULL, "UseLeds", (resource_value_t)0,
+    { "+leds", SET_RESOURCE, 0,
+      NULL, NULL, "UseLeds", (resource_value_t)0,
+      USE_PARAM_STRING, USE_DESCRIPTION_STRING,
+      IDCLS_UNUSED, IDCLS_UNUSED,
       NULL, "Disable usage of PC keyboard LEDs" },
-    { "-statusbar", SET_RESOURCE, 0, NULL, NULL, "ShowStatusbar",
-      (resource_value_t)0,
+    { "-statusbar", SET_RESOURCE, 0,
+      NULL, NULL, "ShowStatusbar", (resource_value_t)0,
+      USE_PARAM_STRING, USE_DESCRIPTION_STRING,
+      IDCLS_UNUSED, IDCLS_UNUSED,
       NULL, "Disable the Statusbar" },
-    { "+statusbar", SET_RESOURCE, 0, NULL, NULL, "ShowStatusbar",
-      (resource_value_t)1,
+    { "+statusbar", SET_RESOURCE, 0,
+      NULL, NULL, "ShowStatusbar", (resource_value_t)1,
+      USE_PARAM_STRING, USE_DESCRIPTION_STRING,
+      IDCLS_UNUSED, IDCLS_UNUSED,
       NULL, "Enable the Statusbar" },
     { NULL },
 };
@@ -267,6 +279,22 @@ void ui_error(const char *format,...)
     lib_free(tmp);
 }
 
+void ui_message(const char *format,...)
+{
+    char *tmp;
+    va_list ap;
+
+    enable_text();
+    tui_clear_screen();
+
+    va_start(ap, format);
+    tmp = lib_mvsprintf(format, ap);
+    tui_message(tmp);
+
+    disable_text();
+    lib_free(tmp);
+}
+
 ui_jam_action_t ui_jam_dialog(const char *format,...)
 {
     char *tmp;
@@ -588,3 +616,7 @@ void ui_display_volume(int vol)
 {
 }
 
+char* ui_get_file(const char *format,...)
+{
+    return NULL;
+}
