@@ -24,13 +24,16 @@
  *
  */
 
-// Joystick Dialog
-#define ID_SATURATION  0x11
-#define ID_BRIGHTNESS  0x12
-#define ID_GAMMA       0x13
-#define ID_CONTRAST    0x14
-#define ID_SCANLINE    0x15 // Only in PAL-TRUE and double-size
-#define ID_BLUR        0x16 // Only in PAL-TRUE
-#define ID_DEFAULT     0x17
+// Color Dialog
+#define ID_SATURATION      0x11
+#define ID_BRIGHTNESS      0x12
+#define ID_GAMMA           0x13
+#define ID_CONTRAST        0x14
+#define ID_SCANLINE        0x15 // Only in PAL-TRUE and double-size
+#define ID_BLUR            0x16 // Only in PAL-TRUE
+#define ID_TINT            0x17
+#define ID_ODDLINE_PHASE   0x18
+#define ID_ODDLINE_OFFSET  0x19
+#define ID_DEFAULT         0x1a
 
 extern void color_dialog(HWND hwnd);
