@@ -38,6 +38,10 @@
 
 #include <os2.h>
 
+#ifdef WATCOM_COMPILE
+#include <process.h>
+#endif
+
 #include "dialogs.h"
 #include "dlg-monitor.h"
 
@@ -73,17 +77,6 @@ int trigger_console_exit;
 
 // --------------------------------------------------------------------------
 
-static char *fmt(unsigned int val, unsigned char sz)
-{
-    static char txt[5];
-
-    char tmp[7];
-    sprintf(tmp, "%%0%ix", sz);
-    sprintf(txt, tmp, val);
-
-    return txt;
-}
-
 static const char *mon_dis(MEMSPACE mem, WORD loc, unsigned int *size)
 {
     const BYTE op = mon_get_mem_val(mem, loc);
