@@ -61,11 +61,9 @@
 #include "dlg-fileio.h"      // ViceFileDialog
 #include "video-resources.h" // VIDEO_RESOURCE_PAL_*
 
-// --------------------------------------------------------------------------
-//#define VIDEO_RESOURCE_PAL_MODE_BLUR  2
-//#define VIDEO_RESOURCE_PAL_MODE_SHARP 1
-//#define VIDEO_RESOURCE_PAL_MODE_FAST  0
-// --------------------------------------------------------------------------
+#ifdef __X64DTV__
+#include "c64dtv-resources.h"
+#endif
 
 #ifdef __XCBM__
 #include "cbm2mem.h"     // cbm2_set_model
@@ -113,11 +111,13 @@ static const char *EXTERNAL_PALETTE="TedExternalPalette";
 
 #if defined HAVE_CRTC && !defined __XCBM__
 static const char *VIDEO_CACHE="CrtcVideoCache";
+#ifdef HAVE_PAL
 static const char *DOUBLE_SIZE="CrtcDoubleSize";
 static const char *DOUBLE_SCAN="CrtcDoubleScan";
 #endif
+#endif
 /*
-#if defined __X64__ || defined __X128__ || defined __XVIC__ || defined __XPLUS4__
+#if defined __X64__ || defined __X128__ || defined __XVIC__ || defined __XPLUS4__ || defined __X64DTV__
 static const char *VIDEO_CACHE="ViciiVideoCache";
 #else // __XPET__ || __XCBM__
 static const char *VIDEO_CACHE="CrtcVideoCache";
@@ -400,10 +400,8 @@ void menu_action(HWND hwnd, USHORT idm) //, MPARAM mp2)
         {
             int val1, val2;
             resources_get_int("PALEmulation", &val1);
-            resources_get_int("PALMode",      &val2);
             if (!val1)
             {
-                resources_set_int("PALMode",      VIDEO_RESOURCE_PAL_MODE_FAST);
                 resources_set_int("PALEmulation", 1);
                 return;
             }
@@ -412,12 +410,10 @@ void menu_action(HWND hwnd, USHORT idm) //, MPARAM mp2)
             {
 #ifndef HAVE_TED
             case 0:
-                resources_set_int("PALMode",      VIDEO_RESOURCE_PAL_MODE_TRUE);
                 resources_set_int("PALEmulation", 1);
                 return;
 #endif
             case 1:
-                resources_set_int("PALMode",      VIDEO_RESOURCE_PAL_MODE_FAST);
                 resources_set_int("PALEmulation", 0);
                 return;
             }
@@ -426,21 +422,6 @@ void menu_action(HWND hwnd, USHORT idm) //, MPARAM mp2)
     case IDM_PALOFF:
         resources_set_int("PALEmulation", 0);
         return;
-#ifndef HAVE_TED
-    case IDM_PALFAST:
-        resources_set_int("PALMode",      VIDEO_RESOURCE_PAL_MODE_FAST);
-        resources_set_int("PALEmulation", 1);
-        return;
-#endif
-    case IDM_PALON:
-        resources_set_int("PALMode",      VIDEO_RESOURCE_PAL_MODE_TRUE);
-        resources_set_int("PALEmulation", 1);
-        return;
-        /*
-    case IDM_FAKEPAL:
-        toggle("PALEmulation");
-        return;
-     */
     case IDM_DSIZE:
         interrupt_maincpu_trigger_trap(toggle_async, (resource_value_t*)DOUBLE_SIZE);
         return;
@@ -483,7 +464,7 @@ void menu_action(HWND hwnd, USHORT idm) //, MPARAM mp2)
         return;
 #endif
 
-#if defined __X64__ || defined __X128__ || defined __XVIC__
+#if defined __X64__ || defined __X128__ || defined __XVIC__ || defined __X64DTV__
     case IDM_PAL:
         resources_set_int("MachineVideoStandard",
                           MACHINE_SYNC_PAL);
@@ -500,7 +481,7 @@ void menu_action(HWND hwnd, USHORT idm) //, MPARAM mp2)
 #endif // __X64__
 #endif //  __X64__ || __X128__ || __XVIC__
 
-#if defined __X64__ || defined __X128__
+#if defined __X64__ || defined __X128__ || defined __X64DTV__
         /*
     case IDM_KERNALREV0:
         resources_set_string("KernalRev", "0");
@@ -531,6 +512,15 @@ void menu_action(HWND hwnd, USHORT idm) //, MPARAM mp2)
     case IDM_RAMCART:
         toggle("RAMCART");
         return;
+    case IDM_DQBB:
+        toggle("DQBB");
+        return;
+    case IDM_ISEPIC:
+        toggle("Isepic");
+        return;
+    case IDM_ISEPIC_SWITCH:
+        toggle("IsepicSwitch");
+        return;
     case IDM_DIGIMAX:
         toggle("DIGIMAX");
         return;
@@ -561,6 +551,10 @@ void menu_action(HWND hwnd, USHORT idm) //, MPARAM mp2)
         resources_set_int("REUSize", (idm&0xff)<<7);
         return;
 
+    case IDM_REUFILE:
+        resources_set_string("REUfilename", ViceFileSelect(hwnd, 1));
+        return;
+
     case IDM_GEORAM64:
     case IDM_GEORAM128:
     case IDM_GEORAM256:
@@ -571,11 +565,23 @@ void menu_action(HWND hwnd, USHORT idm) //, MPARAM mp2)
         resources_set_int("GEORAMSize", (idm&0xff)<<6);
         return;
 
+    case IDM_GEORAMFILE:
+        resources_set_string("GEORAMfilename", ViceFileSelect(hwnd, 1));
+        return;
+
     case IDM_RAMCART64:
     case IDM_RAMCART128:
         resources_set_int("RAMCARTSize", (idm&0xf)<<6);
         return;
 
+    case IDM_RAMCARTFILE:
+        resources_set_string("RAMCARTfilename", ViceFileSelect(hwnd, 1));
+        return;
+
+    case IDM_DQBBFILE:
+        resources_set_string("DQBBfilename", ViceFileSelect(hwnd, 1));
+        return;
+
     case IDM_DIGIMAXDD00:
         resources_set_int("DIGIMAXbase", 0xdd00);
         return;
@@ -606,15 +612,60 @@ void menu_action(HWND hwnd, USHORT idm) //, MPARAM mp2)
     case IDM_PLUS60KD100:
         resources_set_int("PLUS60Kbase", 0xd100);
         return;
+
+    case IDM_PLUS60KFILE:
+        resources_set_string("PLUS60Kfilename", ViceFileSelect(hwnd, 1));
+        return;
+
+    case IDM_PLUS256KFILE:
+        resources_set_string("PLUS256Kfilename", ViceFileSelect(hwnd, 1));
+        return;
+
     case IDM_C64_256K_BASEDE00:
     case IDM_C64_256K_BASEDE80:
     case IDM_C64_256K_BASEDF00:
     case IDM_C64_256K_BASEDF80:
         resources_set_int("C64_256Kbase", ((idm&3)*80)+0xde00);
         return;
+
+    case IDM_C64_256KFILE:
+        resources_set_string("C64_256Kfilename", ViceFileSelect(hwnd, 1));
+        return;
 #endif
 
 #endif // __X64__ || __X128__
+#ifdef __X64DTV__
+    case IDM_C64DTV_FLASHROM_ATTACH:
+        resources_set_string("c64dtvromfilename", ViceFileSelect(hwnd, 0));
+        return;
+    case IDM_C64DTV_FLASHROM_DETACH:
+        resources_set_string("c64dtvromfilename", "");
+        return;
+    case IDM_C64DTV_FLASHROM_RW:
+        toggle("c64dtvromrw");
+        return;
+    case IDM_DTV2:
+        resources_set_int("DtvRevision", 2);
+        return;
+    case IDM_DTV3:
+        resources_set_int("DtvRevision", 3);
+        return;
+    case IDM_HUMMER_USERPORT_NONE:
+        resources_set_int("HummerUserportDevice", HUMMER_USERPORT_NONE);
+        return;
+    case IDM_HUMMER_USERPORT_ADC:
+        resources_set_int("HummerUserportDevice", HUMMER_USERPORT_ADC);
+        return;
+    case IDM_HUMMER_USERPORT_JOY:
+        resources_set_int("HummerUserportDevice", HUMMER_USERPORT_JOY);
+        return;
+    case IDM_HUMMER_JOY1:
+        resources_set_int("HummerUserportJoyPort", 1);
+        return;
+    case IDM_HUMMER_JOY2:
+        resources_set_int("HummerUserportJoyPort", 2);
+        return;
+#endif
 #ifdef __XPET__
     case IDM_PETREU:
         toggle("PETREU");
@@ -632,6 +683,10 @@ void menu_action(HWND hwnd, USHORT idm) //, MPARAM mp2)
     case IDM_PETREU2048:
         resources_set_int("PETREUSize", 2048);
         return;
+
+    case IDM_PETREUFILE:
+        resources_set_string("PETREUfilename", ViceFileSelect(hwnd, 1));
+        return;
 #endif
 #ifdef HAVE_MOUSE
     case IDM_MOUSE:
@@ -698,7 +753,7 @@ void menu_action(HWND hwnd, USHORT idm) //, MPARAM mp2)
     case IDM_VCACHE:
 #ifdef __XCBM__
         {
-            long val;
+            int val;
             resources_get_int("UseVicII", &val);
             toggle(val?VIDEO_CACHE:"CrtcVideoCache");
         }
@@ -1162,7 +1217,7 @@ void menu_select(HWND hwnd, USHORT item)
     case IDM_VIEW:
         WinEnableMenuItem(hwnd, IDM_LOGWIN,  hwndLog    !=NULLHANDLE);
         WinEnableMenuItem(hwnd, IDM_MONITOR, hwndMonitor!=NULLHANDLE);
-#if defined __X64__ || defined __X128__
+#if defined __X64__ || defined __X128__ || defined __X64DTV__
         resources_get_int(EXTERNAL_PALETTE, &val);
         WinEnableMenuItem(hwnd, IDM_COLOR, !val);
 #endif
@@ -1176,7 +1231,7 @@ void menu_select(HWND hwnd, USHORT item)
 #endif
         return;
 
-#if defined __X64__ || defined __X128__ || defined __XVIC__
+#if defined __X64__ || defined __X128__ || defined __XVIC__ || defined __X64DTV__
         /*
          //
          // A change online is not possible yet.
@@ -1265,30 +1320,48 @@ void menu_select(HWND hwnd, USHORT item)
         resources_get_int("REU", &val);
         WinCheckMenuItem(hwnd,  IDM_REU,     val);
         WinEnableMenuItem(hwnd, IDM_REUSIZE, val);
+        WinEnableMenuItem(hwnd, IDM_REUFILE, val);
         resources_get_int("GEORAM", &val);
         WinCheckMenuItem(hwnd,  IDM_GEORAM,     val);
         WinEnableMenuItem(hwnd, IDM_GEORAMSIZE, val);
+        WinEnableMenuItem(hwnd, IDM_GEORAMFILE, val);
         resources_get_int("RAMCART", &val);
         WinCheckMenuItem(hwnd,  IDM_RAMCART,     val);
         WinEnableMenuItem(hwnd, IDM_RAMCARTSIZE, val);
+        WinEnableMenuItem(hwnd, IDM_RAMCARTFILE, val);
         resources_get_int("DIGIMAX", &val);
         WinCheckMenuItem(hwnd,  IDM_DIGIMAX,     val);
         WinEnableMenuItem(hwnd, IDM_DIGIMAXBASE, val);
 #endif
 #ifdef __X64__
+        resources_get_int("DQBB", &val);
+        WinCheckMenuItem(hwnd,  IDM_DQBB,     val);
+        WinEnableMenuItem(hwnd, IDM_DQBBFILE, val);
+        resources_get_int("Isepic", &val);
+        WinCheckMenuItem(hwnd,  IDM_ISEPIC,     val);
+        resources_get_int("IsepicSwitch", &val);
+        WinCheckMenuItem(hwnd,  IDM_ISEPIC_SWITCH,     val);
         resources_get_int("PLUS60K", &val);
         WinCheckMenuItem(hwnd,  IDM_PLUS60K,     val);
         WinEnableMenuItem(hwnd, IDM_PLUS60KBASE, val);
+        WinEnableMenuItem(hwnd, IDM_PLUS60KFILE, val);
         resources_get_int("PLUS256K", &val);
         WinCheckMenuItem(hwnd,  IDM_PLUS256K,     val);
+        WinEnableMenuItem(hwnd, IDM_PLUS256KFILE, val);
         resources_get_int("C64_256K", &val);
         WinCheckMenuItem(hwnd,  IDM_C64_256K,     val);
         WinEnableMenuItem(hwnd, IDM_C64_256K_BASE, val);
+        WinEnableMenuItem(hwnd, IDM_C64_256KFILE,  val);
+#endif
+#ifdef __X64DTV__
+        resources_get_int("c64dtvromrw", &val);
+        WinCheckMenuItem(hwnd,  IDM_C64DTV_FLASHROM_RW,     val);
 #endif
 #ifdef __XPET__
         resources_get_int("REU", &val);
-        WinCheckMenuItem(hwnd,  IDM_REU,     val);
-        WinEnableMenuItem(hwnd, IDM_REUSIZE, val);
+        WinCheckMenuItem(hwnd,  IDM_PETREU,     val);
+        WinEnableMenuItem(hwnd, IDM_PETREUSIZE, val);
+        WinEnableMenuItem(hwnd, IDM_PETREUFILE, val);
         WinCheckRes(hwnd, IDM_CHARSET,  "Basic1Chars");
         WinCheckRes(hwnd, IDM_EOI,      "EoiBlank");
         WinCheckRes(hwnd, IDM_ROMPATCH, "Basic1");
@@ -1352,6 +1425,25 @@ void menu_select(HWND hwnd, USHORT item)
         return;
 #endif
 
+#ifdef __X64DTV__
+    case IDM_C64DTV_REVISION:
+        resources_get_int("DtvRevision", &val);
+        WinCheckMenuItem(hwnd, IDM_DTV2,   val==2);
+        WinCheckMenuItem(hwnd, IDM_DTV3,   val==3);
+        return;
+    case IDM_C64DTV_HUMMER_MAPPED_JOY:
+        resources_get_int("HummerUserportJoyPort", &val);
+        WinCheckMenuItem(hwnd, IDM_HUMMER_JOY1,   val==1);
+        WinCheckMenuItem(hwnd, IDM_HUMMER_JOY2,   val==2);
+        return;
+    case IDM_HUMMER_USERPORT_DEVICE:
+        resources_get_int("HummerUserportDevice", &val);
+        WinCheckMenuItem(hwnd, IDM_HUMMER_USERPORT_NONE, val==HUMMER_USERPORT_NONE);
+        WinCheckMenuItem(hwnd, IDM_HUMMER_USERPORT_ADC,  val==HUMMER_USERPORT_ADC);
+        WinCheckMenuItem(hwnd, IDM_HUMMER_USERPORT_JOY,  val==HUMMER_USERPORT_JOY);
+        return;
+#endif
+
 #if defined __X64__ || defined __X128__
     case IDM_REUSIZE:
         resources_get_int("REUSize", &val);
@@ -1490,7 +1582,7 @@ void menu_select(HWND hwnd, USHORT item)
         }
         return;
 #endif // HAVE_RESID
-#if defined __X64__ || defined __X128__ || defined __XCBM__
+#if defined __X64__ || defined __X128__ || defined __XCBM__ || defined __X64DTV__
     case IDM_SIDCHIP:
         resources_get_int("SidModel", &val);
         WinCheckMenuItem(hwnd, IDM_SC6581,   val==0);
@@ -1568,13 +1660,8 @@ void menu_select(HWND hwnd, USHORT item)
         int val1, val2;
 
         resources_get_int("PALEmulation", &val1);
-        resources_get_int("PALMode",      &val2);
 
         WinCheckMenuItem(hwnd, IDM_PALOFF,  !val1);
-#ifndef HAVE_TED
-        WinCheckMenuItem(hwnd, IDM_PALFAST, val1 && val2==VIDEO_RESOURCE_PAL_MODE_FAST);
-#endif
-        WinCheckMenuItem(hwnd, IDM_PALON,   val1 && val2==VIDEO_RESOURCE_PAL_MODE_TRUE);
     }
     return;
 #endif
