@@ -24,11 +24,17 @@
  *
  */
 
+#include "vice.h"
+
 #include <os2.h>
 #include <os2me.h>
 
 #include <ctype.h>
 
+#ifdef WATCOM_COMPILE
+#include <mcios2.h>
+#endif
+
 #include "log.h"
 
 int sound_err(log_t log, ULONG rc, char *s)
