@@ -62,6 +62,7 @@
 #include "cmdline.h"
 #include "machine.h"   // vsid_mode
 #include "resources.h"
+#include "translate.h"
 
 /* ------------------------ ui resources ------------------------ */
 
@@ -94,9 +95,15 @@ void ui_resources_shutdown(void)
 }
 
 static const cmdline_option_t cmdline_options[] = {
-    { "-leds", SET_RESOURCE, 0, NULL, NULL, "UseLeds", (resource_value_t) 1,
+    { "-leds", SET_RESOURCE, 0,
+      NULL, NULL, "UseLeds", (resource_value_t) 1,
+      USE_PARAM_STRING, USE_DESCRIPTION_STRING,
+      IDCLS_UNUSED, IDCLS_UNUSED,
       NULL, "Enable usage of PC keyboard LEDs" },
-    { "+leds", SET_RESOURCE, 0, NULL, NULL, "UseLeds", (resource_value_t) 0,
+    { "+leds", SET_RESOURCE, 0,
+      NULL, NULL, "UseLeds", (resource_value_t) 0,
+      USE_PARAM_STRING, USE_DESCRIPTION_STRING,
+      IDCLS_UNUSED, IDCLS_UNUSED,
       NULL, "Disable usage of PC keyboard LEDs" },
     NULL,
 };
@@ -116,6 +123,11 @@ int c64ui_init(void)
     return 0;
 }
 
+int c64dtvui_init(void)
+{
+    return 0;
+}
+
 int c128ui_init(void)
 {
     return 0;
@@ -155,6 +167,10 @@ void c64ui_shutdown(void)
 {
 }
 
+void c64dtvui_shutdown(void)
+{
+}
+
 void c128ui_shutdown(void)
 {
 }
@@ -279,9 +295,6 @@ void ui_enable_drive_status(ui_drive_enable_t state, int *drive_led_color)
 void ui_display_drive_current_image(unsigned int drive_number,
                                     const char *image)
 {
-    const ULONG flCmd =
-        DT_TEXTATTRS|DT_VCENTER|DT_LEFT|DT_ERASERECT|DT_WORDBREAK;
-
     if (image && *image)
     {
         int pos=0, i;
@@ -338,6 +351,21 @@ void ui_error(const char *format,...)
     lib_free(txt);
 }
 
+void ui_message(const char *format,...)
+{
+    char *txt, *tmp;
+
+    va_list ap;
+    va_start(ap, format);
+    tmp = lib_mvsprintf(format, ap);
+    txt = util_concat(" Message from emulation thread:\n ", tmp, NULL);
+    lib_free(tmp);
+
+    ViceErrorDlg(HWND_DESKTOP, PTR_SKULL, txt);
+
+    lib_free(txt);
+}
+
 ui_jam_action_t ui_jam_dialog(const char *format,...)
 {
     ULONG rc;
@@ -346,20 +374,22 @@ ui_jam_action_t ui_jam_dialog(const char *format,...)
 
     va_list ap;
 
-    const int sz   = sizeof(MB2INFO)+2*sizeof(MB2D);
+    const int sz   = sizeof(MB2INFO)+3*sizeof(MB2D);
 
     MB2INFO *mb    = malloc(sz);
     mb->cb         = sz;
     mb->hIcon      = WinLoadPointer(HWND_DESKTOP, NULLHANDLE, PTR_SKULL);
-    mb->cButtons   = 3;
+    mb->cButtons   = 4;
     mb->flStyle    = MB_CUSTOMICON|WS_VISIBLE;
     mb->hwndNotify = NULLHANDLE;
     strcpy(mb->mb2d[0].achText, "  ~Hard Reset  ");
     strcpy(mb->mb2d[1].achText, "  ~Soft Reset  ");
-    strcpy(mb->mb2d[2].achText, "   ~Monitor   ");
+    strcpy(mb->mb2d[2].achText, "  ~Monitor     ");
+    strcpy(mb->mb2d[3].achText, "  ~Continue    ");
     mb->mb2d[0].idButton = UI_JAM_HARD_RESET;
     mb->mb2d[1].idButton = UI_JAM_RESET;
     mb->mb2d[2].idButton = UI_JAM_MONITOR;
+    mb->mb2d[3].idButton = UI_JAM_NONE;
     mb->mb2d[0].flStyle  = BS_DEFAULT;
     mb->mb2d[1].flStyle  = 0;
     mb->mb2d[2].flStyle  = 0;
@@ -401,3 +431,7 @@ void ui_display_statustext(const char *text, int fade_out)
 {
 }
 
+char* ui_get_file(const char *format,...)
+{
+    return NULL;
+}
