@@ -61,6 +61,10 @@
 #include <graph.h>
 #endif
 
+#ifdef WATCOM_COMPILE
+#include <process.h>
+#endif
+
 #include "video.h"
 #include "videoarch.h"
 
@@ -74,6 +78,7 @@
 #include "dragndrop.h"
 #include "cmdline.h"
 #include "resources.h"
+#include "translate.h"
 #include "viewport.h"
 
 #include "machine.h"         // machine_canvas_screenshot
@@ -254,19 +259,19 @@ void CanvasDisplaySpeed(int speed, int frame_rate, int warp_enabled)
             lib_free(txt);
         }
     }
-    /*
+#if 0
     else
     {
-        extern FNVMIENTRY *pfnVMIEntry;         // The entry of VMAN.DLL
+        extern FNVMIENTRY *pfnVMIEntry;
         TEXTBLTINFO txt;
         memset(&txt, 0, sizeof(TEXTBLTINFO));
 
         txt.ulLength = sizeof(TEXTBLTINFO);
 
 
-        (*pfnVMIEntry)(0, 18/*VMI_CMD_TEXT/, &txt, 0);
+        (*pfnVMIEntry)(0, 18 VMI_CMD_TEXT/, &txt, 0);
     }
-    */
+#endif
 }
 
 /* ------------------------------------------------------------------------ */
@@ -529,28 +534,40 @@ void video_arch_resources_shutdown(void)
 
 static const cmdline_option_t cmdline_options1[] = {
 #ifndef DIRECT_ACCESS
-    { "-stretch", SET_RESOURCE, 1, NULL, NULL, "WindowStretchFactor", NULL,
+    { "-stretch", SET_RESOURCE, 1,
+      NULL, NULL, "WindowStretchFactor", NULL,
+      USE_PARAM_STRING, USE_DESCRIPTION_STRING,
+      IDCLS_UNUSED, IDCLS_UNUSED,
       "<number>", "Specify stretch factor for PM Windows (1,2,3,...)" },
 #endif
-    { "-border",  SET_RESOURCE, 1, NULL, NULL, "PMBorderType", NULL,
+    { "-border",  SET_RESOURCE, 1,
+      NULL, NULL, "PMBorderType", NULL,
+      USE_PARAM_STRING, USE_DESCRIPTION_STRING,
+      IDCLS_UNUSED, IDCLS_UNUSED,
       "<number>", "Specify window border type (1=small, 2=dialog, else=no border)" },
-    { "-menu", SET_RESOURCE, 0, NULL, NULL, "Menubar", (resource_value_t) 1,
+    { "-menu", SET_RESOURCE, 0,
+      NULL, NULL, "Menubar", (resource_value_t) 1,
+      USE_PARAM_STRING, USE_DESCRIPTION_STRING,
+      IDCLS_UNUSED, IDCLS_UNUSED,
       NULL, "Enable Main Menu Bar" },
-    { "+menu", SET_RESOURCE, 0, NULL, NULL, "Menubar", (resource_value_t) 0,
+    { "+menu", SET_RESOURCE, 0,
+      NULL, NULL, "Menubar", (resource_value_t) 0,
+      USE_PARAM_STRING, USE_DESCRIPTION_STRING,
+      IDCLS_UNUSED, IDCLS_UNUSED,
       NULL, "Disable Main Menu Bar" },
-/*
-    { "-status", SET_RESOURCE, 0, NULL, NULL, "Statusbar", (resource_value_t) 1,
-      NULL, "Enable Status Bar" },
-    { "+status", SET_RESOURCE, 0, NULL, NULL, "Statusbar", (resource_value_t) 0,
-      NULL, "Disable Status Bar" },
-*/
     NULL
 };
 
 static const cmdline_option_t cmdline_options2[] = {
-    { "-logwin", SET_RESOURCE, 0, NULL, NULL, "Logwin", (resource_value_t) 1,
+    { "-logwin", SET_RESOURCE, 0,
+      NULL, NULL, "Logwin", (resource_value_t) 1,
+      USE_PARAM_STRING, USE_DESCRIPTION_STRING,
+      IDCLS_UNUSED, IDCLS_UNUSED,
       NULL, "Enable Logging Window" },
-    { "+logwin", SET_RESOURCE, 0, NULL, NULL, "Logwin", (resource_value_t) 0,
+    { "+logwin", SET_RESOURCE, 0,
+      NULL, NULL, "Logwin", (resource_value_t) 0,
+      USE_PARAM_STRING, USE_DESCRIPTION_STRING,
+      IDCLS_UNUSED, IDCLS_UNUSED,
       NULL, "Disable Logging Window" },
     NULL
 };
@@ -677,10 +694,20 @@ int video_init(void) // initialize Dive
                 divecaps.fScreenDirect?", Direct access supported":"",
                 divecaps.fBankSwitched?", Bank switch required":"");
 
+    // As DIVE does not support conversion between RGB and BGR formats,
+    // we have to match the source FCC with the desktop FCC
+    if (divecaps.fccColorEncoding==FOURCC_BGR4 ||
+        divecaps.fccColorEncoding==FOURCC_BGR3)
+    {
+        divecaps.fccColorEncoding=FOURCC_BGR3;
+    } else
+    if (divecaps.fccColorEncoding==FOURCC_RGB4 ||
+        divecaps.fccColorEncoding==FOURCC_RGB3)
+    {
+        divecaps.fccColorEncoding=FOURCC_RGB3;
+    } else
     if (divecaps.fccColorEncoding!=FOURCC_LUT8 &&
-        divecaps.fccColorEncoding!=FOURCC_R565 &&
-        divecaps.fccColorEncoding!=FOURCC_RGB3 &&
-        divecaps.fccColorEncoding!=FOURCC_RGB4)
+        divecaps.fccColorEncoding!=FOURCC_R565)
         divecaps.fccColorEncoding = FOURCC_RGB3;
 
     rc = divecaps.fccColorEncoding;
@@ -730,7 +757,7 @@ static ULONG GetDepth(FOURCC fcc)
     case FOURCC_R555:
     case FOURCC_R664: return 16;
     case FOURCC_RGB3:
-    case FOURCC_BGR3:// return 24;
+    case FOURCC_BGR3: return 24;
     case FOURCC_RGB4:
     case FOURCC_BGR4: return 32;
     }
@@ -747,7 +774,7 @@ static ULONG GetRed(FOURCC fcc, ULONG n)
     case FOURCC_RGB3:
     case FOURCC_RGB4: return n<<16;
     case FOURCC_BGR3:
-    case FOURCC_BGR4: return n<<16;
+    case FOURCC_BGR4: return n;
     }
     return 0;
 }
@@ -777,7 +804,7 @@ static ULONG GetBlue(FOURCC fcc, ULONG n)
     case FOURCC_RGB3:
     case FOURCC_RGB4: return n;
     case FOURCC_BGR3:
-    case FOURCC_BGR4: return n;
+    case FOURCC_BGR4: return n<<16;
     }
     return 0;
 }
@@ -886,8 +913,6 @@ void VideoBufferFree(video_canvas_t *c)
 
 void WmDestroy(HWND hwnd)
 {
-    ULONG rc;
-
     video_canvas_t *c = GetCanvas(hwnd);
 
     if (!c)
@@ -1081,19 +1106,6 @@ void VideoCanvasBlit(video_canvas_t *c,
         log_message(vidlog, "Debug - fbuf read y: %d + %d > %d, c->height=%d", ys, h, bufh, c->height);
         h = bufh-ys;
     }
-    if (xs<0)
-    {
-        log_message(vidlog, "Debug - fbuf read x: %d < 0", xs);
-        w += xs;
-        xs = 0;
-    }
-    if (ys<0)
-    {
-        log_message(vidlog, "Debug - fbuf read y: %d < 0", ys);
-        h += ys;
-        ys = 0;
-
-    }
     if (xi+w > c->width)
     {
         log_message(vidlog, "Debug - scr write x x%d: %d + %d > %d", dsx, xi, w, c->width);
@@ -1104,18 +1116,6 @@ void VideoCanvasBlit(video_canvas_t *c,
         log_message(vidlog, "Debug - scr write y x%d: %d + %d > %d", dsy, yi, h, c->height);
         h = c->height-yi;
     }
-    if (xi<0)
-    {
-        log_message(vidlog, "Debug - scr write x: %d < 0", xi);
-        w += xi;
-        xi = 0;
-    }
-    if (yi<0)
-    {
-        log_message(vidlog, "Debug - scr write y: %d < 0", yi);
-        h += yi;
-        yi = 0;
-    }
 
 #ifndef DIRECT_ACCESS
     //
@@ -1351,6 +1351,7 @@ static int WmTranslateAccel(HWND hwnd, MPARAM mp1)
     return FALSE;
 }
 
+#ifdef HAVE_MOUSE
 static void DisplayPopupMenu(HWND hwnd, POINTS *pts)
 {
     const video_canvas_t *c = GetCanvas(hwnd);
@@ -1358,6 +1359,7 @@ static void DisplayPopupMenu(HWND hwnd, POINTS *pts)
     WinPopupMenu(hwnd, hwnd, c->hwndPopupMenu, pts->x, pts->y, 0,
                  PU_MOUSEBUTTON2DOWN|PU_HCONSTRAIN|PU_VCONSTRAIN);
 }
+#endif
 
 MRESULT EXPENTRY CanvasWinProc(HWND hwnd, ULONG msg, MPARAM mp1, MPARAM mp2)
 {
@@ -1551,7 +1553,7 @@ static void InitMenuBar(video_canvas_t *c)
     // WM_UPDATEFRAME also hides the loaded popup menu
     // the size is also corrected
     //
-    set_menu((void*)menu, (void*)c->hwndClient);
+    set_menu(menu, (void*)c->hwndClient);
 }
 /*
 void InitStatusBar(video_canvas_t *c)
@@ -1945,7 +1947,6 @@ void video_canvas_resize(video_canvas_t *c, UINT wnew, UINT hnew)
     // dive_alloc/free and video_canvas_refresh
     //
     SWP swp;
-    ULONG rc;
 
     UINT wold = c->width;
     UINT hold = c->height;
@@ -2049,6 +2050,7 @@ void VideoConvertPalette(video_canvas_t *c, int num, palette_entry_t *src) //, R
 
     ULONG ulTrg=0;
     ULONG ulSrc=0;
+    FOURCC fccSrc = FOURCC_RGB3;
 
     char target[0x400]; // max: 256*4b
     char source[0x400]; // max: 256*4b
@@ -2062,11 +2064,17 @@ void VideoConvertPalette(video_canvas_t *c, int num, palette_entry_t *src) //, R
         return;
     }
 
+    // As DIVE does not support conversion between RGB and BGR formats,
+    // we have to match the source FCC with the desktop FCC
+    if ((c->divesetup.fccSrcColorFormat==FOURCC_BGR3) ||
+        (c->divesetup.fccSrcColorFormat==FOURCC_BGR4))
+        fccSrc = FOURCC_BGR3;
+
     memset(&setup, 0, sizeof(SETUP_BLITTER));
 
     setup.ulStructLen          = sizeof(SETUP_BLITTER);
     setup.pVisDstRects         = calloc(1, sizeof(RECTL));
-    setup.fccSrcColorFormat    = FOURCC_RGB3;
+    setup.fccSrcColorFormat    = fccSrc;
     setup.fccDstColorFormat    = c->divesetup.fccSrcColorFormat;
     setup.ulSrcHeight          = 1;
     setup.ulDstHeight          = 1;
@@ -2083,7 +2091,7 @@ void VideoConvertPalette(video_canvas_t *c, int num, palette_entry_t *src) //, R
         return;
     }
 
-    rc=DiveAllocImageBuffer(inst, &ulSrc, FOURCC_RGB3, num, 1, 0, source);
+    rc=DiveAllocImageBuffer(inst, &ulSrc, fccSrc, num, 1, 0, source);
     if (rc)
         log_error(vidlog, "VideoConvertPalette - DiveAllocImageBuffer (src) failed, rc=0x%x", rc);
     else
@@ -2095,11 +2103,22 @@ void VideoConvertPalette(video_canvas_t *c, int num, palette_entry_t *src) //, R
         else
         {
             int i;
-            for (i=0; i<num; i++)
+            if (fccSrc == FOURCC_RGB3)
             {
-                source[i*3]   = src[i].red;
-                source[i*3+1] = src[i].green;
-                source[i*3+2] = src[i].blue;
+                for (i=0; i<num; i++)
+                {
+                    source[i*3]   = src[i].red;
+                    source[i*3+1] = src[i].green;
+                    source[i*3+2] = src[i].blue;
+                }
+            } else
+            {
+                for (i=0; i<num; i++)
+                {
+                    source[i*3]   = src[i].blue;
+                    source[i*3+1] = src[i].green;
+                    source[i*3+2] = src[i].red;
+                }
             }
 
             rc = DiveSetupBlitter(inst, &setup);
@@ -2240,3 +2259,4 @@ void fullscreen_capability(cap_fullscreen_t *cap_fullscreen)
 {
     cap_fullscreen->device_num = 0;
 }
+
