@@ -271,20 +271,18 @@ int kbd_update_joykeys(int port)
 
   sprintf(b, "%02x%02x%02x%02x%02x", JoystickKeys[port].up, JoystickKeys[port].down, JoystickKeys[port].left, JoystickKeys[port].right, JoystickKeys[port].fire);
   rsrc = (port == 0) ? Rsrc_JoyKeys1 : Rsrc_JoyKeys2;
-  return resources_set_value(rsrc, b);
+  return resources_set_string(rsrc, b);
 }
 
-static int set_keymap_index(resource_value_t v, void *param)
+static int set_keymap_index(int v, void *param)
 {
-  keymap_index = (int)v;
+  keymap_index = v;
   memset(last_keys, 0, 32);
   return 0;
 }
 
-static int set_joystick_keys1(resource_value_t v, void *param)
+static int set_joystick_keys1(const char *name, void *param)
 {
-  const char *name = (const char *)v;
-
   if ((JoyKeyString1 != NULL) && (name != NULL) && (strcmp(name, JoyKeyString1) == 0))
     return 0;
 
@@ -295,30 +293,29 @@ static int set_joystick_keys1(resource_value_t v, void *param)
   return 0;
 }
 
-static int set_joystick_keys2(resource_value_t v, void *param)
+static int set_joystick_keys2(const char *name, void *param)
 {
-  const char *name = (const char *)v;
-
   if ((JoyKeyString2 != NULL) && (name != NULL) && (strcmp(name, JoyKeyString2) == 0))
     return 0;
 
-  if (kbd_parse_joykeys((char*)v, JoystickKeys+1) != 0) return 1;
+  if (kbd_parse_joykeys(name, JoystickKeys+1) != 0) return 1;
 
   util_string_set(&JoyKeyString2, name);
 
   return 0;
 }
 
-static const resource_t resources[] = {
-  {"KeymapIndex", RES_INTEGER, (resource_value_t) 0,
-    RES_EVENT_NO, NULL,                                   \
-    (void *)&keymap_index, set_keymap_index, NULL },
-  {Rsrc_JoyKeys1, RES_STRING, (resource_value_t) DefaultJoyKeys1,
-    RES_EVENT_NO, NULL,                                   \
-    (void *)&JoyKeyString1, set_joystick_keys1, NULL},
-  {Rsrc_JoyKeys2, RES_STRING, (resource_value_t) DefaultJoyKeys2,
-    RES_EVENT_NO, NULL,                                   \
-    (void *)&JoyKeyString2, set_joystick_keys2, NULL},
+static const resource_string_t resources_string[] = {
+  {Rsrc_JoyKeys1, DefaultJoyKeys1, RES_EVENT_NO, NULL,
+    &JoyKeyString1, set_joystick_keys1, NULL},
+  {Rsrc_JoyKeys2, DefaultJoyKeys2, RES_EVENT_NO, NULL,
+    &JoyKeyString2, set_joystick_keys2, NULL},
+  {NULL}
+};
+
+static const resource_int_t resources_int[] = {
+  {"KeymapIndex", 0, RES_EVENT_NO, NULL,
+    &keymap_index, set_keymap_index, NULL },
   {NULL}
 };
 
@@ -327,7 +324,10 @@ int kbd_resources_init(void)
   sprintf(DefaultJoyKeys1, "%02x%02x%02x%02x%02x", KeyJoy1_Up, KeyJoy1_Down, KeyJoy1_Left, KeyJoy1_Right, KeyJoy1_Fire);
   sprintf(DefaultJoyKeys2, "%02x%02x%02x%02x%02x", KeyJoy2_Up, KeyJoy2_Down, KeyJoy2_Left, KeyJoy2_Right, KeyJoy2_Fire);
 
-  return resources_register(resources);
+  if (resources_register_string(resources_string) < 0)
+    return -1;
+
+  return resources_register_int(resources_int);
 }
 
 
