@@ -44,6 +44,10 @@
 #include <vfork.h>
 #endif
 
+#ifdef HAVE_STRINGS_H
+#include <strings.h>
+#endif
+
 #include "archdep.h"
 #include "findpath.h"
 #include "ioutil.h"
@@ -53,10 +57,16 @@
 #include "ui.h"
 #include "util.h"
 
+#ifdef __NeXT__
+#define waitpid(p, s, o)  wait3((union wait *)(s), (o), (struct rusage *) 0)
+#endif
 
 static char *argv0 = NULL;
 static char *boot_path = NULL;
 
+/* alternate storage of preferences */
+const char *archdep_pref_path = NULL; /* NULL -> use home_path + ".vice" */
+
 int archdep_init(int *argc, char **argv)
 {
     argv0 = lib_stralloc(argv[0]);
@@ -224,46 +234,62 @@ char *archdep_make_backup_filename(const char *fname)
 
 char *archdep_default_resource_file_name(void)
 {
-    const char *home;
-
-    home = archdep_home_path();
-    return util_concat(home, "/.vice/vicerc", NULL);
+    if(archdep_pref_path==NULL) {
+      const char *home;
+      
+      home = archdep_home_path();
+      return util_concat(home, "/.vice/vicerc", NULL);
+    } else {
+      return util_concat(archdep_pref_path, "/vicerc", NULL);
+    }
 }
 
 char *archdep_default_fliplist_file_name(void)
 {
-    const char *home;
+    if(archdep_pref_path==NULL) {
+      const char *home;
 
-    home = archdep_home_path();
-    return util_concat(home, "/.vice/fliplist-", machine_name, ".vfl", NULL);
+      home = archdep_home_path();
+      return util_concat(home, "/.vice/fliplist-", machine_name, ".vfl", NULL);
+    } else {
+      return util_concat(archdep_pref_path, "/fliplist-", machine_name, ".vfl", NULL);
+    }
 }
 
 char *archdep_default_save_resource_file_name(void)
-{
+{ 
     char *fname;
     const char *home;
-    char *viceuserdir;
+    const char *viceuserdir;
 
-    home = archdep_home_path();
-
-    viceuserdir = util_concat(home, "/.vice", NULL);
+    if(archdep_pref_path==NULL) {
+      home = archdep_home_path();
+      viceuserdir = util_concat(home, "/.vice", NULL);
+    } else {
+      viceuserdir = archdep_pref_path;
+    }
 
     if (access(viceuserdir, F_OK)) {
         mkdir(viceuserdir, 0700);
     }
 
     fname = util_concat(viceuserdir, "/vicerc", NULL);
-
-    lib_free(viceuserdir);
+    
+    if(archdep_pref_path==NULL) {
+      lib_free(viceuserdir);
+    }
 
     return fname;
 }
 
 #if defined(MACOSX_COCOA)
-FILE *default_log_file = stdout;
+int default_log_fd = 0;
 FILE *archdep_open_default_log_file(void)
 {
-    return default_log_file;
+    int newFd = dup(default_log_fd);
+    FILE *file = fdopen(newFd,"w");
+    setlinebuf(file);
+    return file;
 }
 #else
 FILE *archdep_open_default_log_file(void)
@@ -399,7 +425,8 @@ char *archdep_tmpnam(void)
 
     sprintf(tmp_string,"vice%d.tmp",tmp_string_counter++);
     return lib_stralloc(tmp_string);
-#elif HAVE_MKSTEMP
+#else
+#ifdef HAVE_MKSTEMP
     char *tmpName;
     const char mkstempTemplate[] = "/vice.XXXXXX";
     int fd;
@@ -423,6 +450,7 @@ char *archdep_tmpnam(void)
 #else
     return lib_stralloc(tmpnam(NULL));
 #endif
+#endif
 }
 
 FILE *archdep_mkstemp_fd(char **filename, const char *mode)
@@ -512,7 +540,11 @@ int archdep_file_set_gzip(const char *name)
 
 int archdep_mkdir(const char *pathname, int mode)
 {
+#ifndef __NeXT__
     return mkdir(pathname, (mode_t)mode);
+#else
+    return mkdir(pathname, mode);
+#endif
 }
 
 int archdep_stat(const char *file_name, unsigned int *len, unsigned int *isdir)
