@@ -85,6 +85,10 @@
 #define ARCHDEP_RS232_DEV3 "rs232.dump"
 #define ARCHDEP_RS232_DEV4 "|lpr"
 
+/* Default MIDI devices.  */
+#define ARCHDEP_MIDI_IN_DEV  "/dev/midi"
+#define ARCHDEP_MIDI_OUT_DEV "/dev/midi"
+
 /* Default location of raw disk images.  */
 #define ARCHDEP_RAWDRIVE_DEFAULT "/dev/fd0"
 
@@ -105,6 +109,9 @@
 
 extern const char *archdep_home_path(void);
 
+/* set this path to customize the preference storage */ 
+extern const char *archdep_pref_path;
+
 /* Define the default system directory (where the ROMs are).  */
 #ifdef __NetBSD__
 #define LIBDIR          PREFIX "/share/vice"
