@@ -61,6 +61,10 @@
 #include <errno.h>
 #include <signal.h>
 
+#ifdef OPENSERVER6_COMPILE
+#include <sys/signal.h>
+#endif
+
 #include "coproc.h"
 
 #include "log.h"
@@ -72,6 +76,34 @@
 #define SA_RESTART      0
 #endif
 
+#ifdef __NeXT__
+int sigaction(int sig, const struct sigaction *act, struct sigaction *oact)
+{
+  struct sigvec vec, ovec;
+  int st;
+
+  vec.sv_handler = act->sa_handler;
+  vec.sv_mask = act->sa_mask;
+  vec.sv_flags = act->sa_flags;
+
+  st = sigvec(sig, &vec, &ovec);
+
+  if (oact)
+  {
+    oact->sa_handler = ovec.sv_handler;
+    oact->sa_mask = ovec.sv_mask;
+    oact->sa_flags = ovec.sv_flags;
+  }
+  return st;
+}
+
+int sigemptyset(sigset_t *set)
+{
+  *set = 0;
+  return 0;
+}
+#endif
+
 static struct sigaction ignore;
 
 int fork_coproc(int *fd_wr, int *fd_rd, char *cmd)
