@@ -29,8 +29,11 @@
 #include <stdio.h>
 #include <string.h>
 
+#include "cartridge.h"
+#include "keyboard.h"
 #include "prefs_gp2x.h"
 #include "resources.h"
+#include "uitext_gp2x.h"
 #include "videoarch.h"
 #include "vkeyboard_gp2x.h"
 
@@ -61,12 +64,9 @@ void c64ui_draw_resid_string(unsigned char *screen, int menu_x, int menu_y)
   int sidengine;
 
   resources_get_int("SidEngine", &sidengine);
-  if(sidengine)
-  {
+  if (sidengine) {
     draw_ascii_string(screen, display_width, menu_x, menu_y, "ReSID", menu_fg, menu_bg);
-  }
-  else
-  {
+  } else {
     draw_ascii_string(screen, display_width, menu_x, menu_y, "FastSID", menu_fg, menu_bg);
   }
 }
@@ -93,110 +93,112 @@ char *keyb_c64vic[]={
 	"  ctrl QWERTYUIOP@*\x1e rstr F3 ",
 	"  r/s   ASDFGHJKL:;= rtrn F5 ",
 	"  c=     ZXCVBNM,./v>     F7 ",
-	"          space              ",
+	"  lsh     space          rsh ",
 	"                             ",
 	NULL
 };
 
 int c64_keytable[] = {
 		/* x, y, row,column */
-		4, 2, 7,1, /* <- */
-		6, 2, 7,0, /* 1 */
-		7, 2, 7,3, /* 2 */
-		8, 2, 1,0, /* 3 */
-		9, 2, 1,3, /* 4 */
-		10, 2, 2,0, /* 5 */
-		11, 2, 2,3, /* 6 */
-		12, 2, 3,0, /* 7 */
-		13, 2, 3,3, /* 8 */
-		14, 2, 4,0, /* 9 */
-		15, 2, 4,3, /* 0 */
-		16, 2, 5,0, /* + */
-		17, 2, 5,3, /* - */
-		18, 2, 6,0, /* £ */
-		19, 2, 6,3, /* c/h */
+		 4, 2, 7, 1, /* <- */
+		 6, 2, 7, 0, /* 1 */
+		 7, 2, 7, 3, /* 2 */
+		 8, 2, 1, 0, /* 3 */
+		 9, 2, 1, 3, /* 4 */
+		10, 2, 2, 0, /* 5 */
+		11, 2, 2, 3, /* 6 */
+		12, 2, 3, 0, /* 7 */
+		13, 2, 3, 3, /* 8 */
+		14, 2, 4, 0, /* 9 */
+		15, 2, 4, 3, /* 0 */
+		16, 2, 5, 0, /* + */
+		17, 2, 5, 3, /* - */
+		18, 2, 6, 0, /* £ */
+		19, 2, 6, 3, /* c/h */
+		
+		 7, 3, 7, 6, /* q */
+		 8, 3, 1, 1, /* w */
+		 9, 3, 1, 6, /* e */
+		10, 3, 2, 1, /* r */
+		11, 3, 2, 6, /* t */
+		12, 3, 3, 1, /* y */
+		13, 3, 3, 6, /* u */
+		14, 3, 4, 1, /* i */
+		15, 3, 4, 6, /* o */
+		16, 3, 5, 1, /* p */
+		17, 3, 5, 6, /* @ */
+		18, 3, 6, 1, /* * */
+		19, 3, 6, 6, /* up arrow */
 
-		7, 3, 7,6, /* q */
-		8, 3, 1,1, /* w */
-		9, 3, 1,6, /* e */
-		10, 3, 2,1, /* r */
-		11, 3, 2,6, /* t */
-		12, 3, 3,1, /* y */
-		13, 3, 3,6, /* u */
-		14, 3, 4,1, /* i */
-		15, 3, 4,6, /* o */
-		16, 3, 5,1, /* p */
-		17, 3, 5,6, /* @ */
-		18, 3, 6,1, /* * */
-		19, 3, 6,6, /* up arrow */
+		 2, 3, 7, 2, /* ctrl ijb mod */
+		 3, 3, 7, 2, /* ctrl ijb mod */
+		 4, 3, 7, 2, /* ctrl ijb mod */
+		 5, 3, 7, 2, /* ctrl ijb mod */
 
-		2,3, 7,2, /* ctrl ijb mod */
-		3,3, 7,2, /* ctrl ijb mod */
-		4,3, 7,2, /* ctrl ijb mod */
-		5,3, 7,2, /* ctrl ijb mod */
+		 8, 4, 1, 2, /* a */
+		 9, 4, 1, 5, /* s */
+		10, 4, 2, 2, /* d */
+		11, 4, 2, 5, /* f */
+		12, 4, 3, 2, /* g */
+		13, 4, 3, 5, /* h */
+		14, 4, 4, 2, /* j */
+		15, 4, 4, 5, /* k */
+		16, 4, 5, 2, /* l */
+		17, 4, 5, 5, /* : */
+		18, 4, 6, 2, /* ; */
+		19, 4, 6, 5, /* = */
 
-		8, 4, 1,2, /* a */
-		9, 4, 1,5, /* s */
-		10, 4, 2,2, /* d */
-		11, 4, 2,5, /* f */
-		12, 4, 3,2, /* g */
-		13, 4, 3,5, /* h */
-		14, 4, 4,2, /* j */
-		15, 4, 4,5, /* k */
-		16, 4, 5,2, /* l */
-		17, 4, 5,5, /* : */
-		18, 4, 6,2, /* ; */
-		19, 4, 6,5, /* = */
+		 2, 5, 7, 5, /* c= */
+		 3, 5, 7, 5, /* c= */
 
-		2, 5, 7,5, /* c= */
-		3, 5, 7,5, /* c= */
-		9, 5, 1,4, /* z */
-		10, 5, 2,7, /* x */
-		11, 5, 2,4, /* c */
-		12, 5, 3,7, /* v */
-		13, 5, 3,4, /* b */
-		14, 5, 4,7, /* n */
-		15, 5, 4,4, /* m */
-		16, 5, 5,7, /* , */
-		17, 5, 5,4, /* . */
-		18, 5, 6,7, /* / */
-		19, 5, 0,7, /* down */
-		20, 5, 0,2, /* right */
+		 9, 5, 1, 4, /* z */
+		10, 5, 2, 7, /* x */
+		11, 5, 2, 4, /* c */
+		12, 5, 3, 7, /* v */
+		13, 5, 3, 4, /* b */
+		14, 5, 4, 7, /* n */
+		15, 5, 4, 4, /* m */
+		16, 5, 5, 7, /* , */
+		17, 5, 5, 4, /* . */
+		18, 5, 6, 7, /* / */
+		19, 5, 0, 7, /* down */
+		20, 5, 0, 2, /* right */
 
-		2, 4, 7,7, /* run/stop */
-		3, 4, 7,7, /* */
-		4, 4, 7,7, /* */
+		 2, 4, 7, 7, /* run/stop */
+		 3, 4, 7, 7, /* */
+		 4, 4, 7, 7, /* */
 
-		10,6, 7,4, /* space */
-		11,6, 7,4, /* space */
-		12,6, 7,4, /* space */
-		13,6, 7,4, /* space */
-		14,6, 7,4, /* space */
+		10, 6, 7, 4, /* space */
+		11, 6, 7, 4, /* space */
+		12, 6, 7, 4, /* space */
+		13, 6, 7, 4, /* space */
+		14, 6, 7, 4, /* space */
 
-		21, 4, 0,1, /* return */
-		22, 4, 0,1, /* return */
-		23, 4, 0,1, /* return */
-		24, 4, 0,1, /* return */
+		21, 4, 0, 1, /* return */
+		22, 4, 0, 1, /* return */
+		23, 4, 0, 1, /* return */
+		24, 4, 0, 1, /* return */
 
-#if 0
-		23, 5, 0|128,7, /* crsr up */
-		23, 6, 0,7, /* crsr down */
-		22, 6, 0|128,2, /* crsr left */
-		24, 6, 0,2, /* crsr right */
-#endif
+		21, 2, 0, 0, /* delete */
+		22, 2, 0, 0, /* delete */
+		23, 2, 0, 0, /* delete */
 
-		21, 2, 0,0, /* delete */
-		22, 2, 0,0, /* delete */
-		23, 2, 0,0, /* delete */
+		26, 2, 0, 4, /* f1 */
+		27, 2, 0, 4, /* f1 */
+		26, 3, 0, 5, /* f3 */
+		27, 3, 0, 5, /* f3 */
+		26, 4, 0, 6, /* f5 */
+		27, 4, 0, 6, /* f5 */
+		26, 5, 0, 3, /* f7 */
+		27, 5, 0, 3, /* f7 */
 
-		26, 2, 0,4, /* f1 */
-		27, 2, 0,4, /* f1 */
-		26, 3, 0,5, /* f3 */
-		27, 3, 0,5, /* f3 */
-		26, 4, 0,6, /* f5 */
-		27, 4, 0,6, /* f5 */
-		26, 5, 0,3, /* f7 */
-		27, 5, 0,3, /* f7 */
+		 2, 6, 1, 7, /* lshift */
+		 3, 6, 1, 7, /* lshift */
+		 4, 6, 1, 7, /* lshift */
+
+		25, 6, 6, 4, /* rshift */
+		26, 6, 6, 4, /* rshift */
+		27, 6, 6, 4, /* rshift */
 
 		0 
 };
