@@ -41,3 +41,8 @@ void ui_display_event_time(unsigned int current, unsigned int total)
 void ui_display_volume(int vol)
 {
 }
+
+char* ui_get_file(const char *format,...)
+{
+    return NULL;
+}
