@@ -47,6 +47,7 @@
 #include "uijoystick2.h"
 #include "uikeyboard.h"
 #include "uimenu.h"
+#include "uimidi.h"
 #include "uimouse.h"
 #include "uiperipheraliec.h"
 #include "uiscreenshot.h"
@@ -67,7 +68,7 @@
 
 UI_MENU_DEFINE_RADIO(MachineVideoStandard)
 
-ui_menu_entry_t set_video_standard_submenu[] = {
+static ui_menu_entry_t set_video_standard_c128_submenu[] = {
     { N_("*PAL-G"), (ui_callback_t)radio_MachineVideoStandard,
       (ui_callback_data_t)MACHINE_SYNC_PAL, NULL },
     { N_("*NTSC-M"), (ui_callback_t)radio_MachineVideoStandard,
@@ -207,8 +208,8 @@ UI_CALLBACK(set_function_rom_name)
 
     vsync_suspend_speed_eval();
 
-    filename = ui_select_file(_("Function ROM image"), NULL, 0, False,
-                              last_dir, "*", &button, False, NULL);
+    filename = ui_select_file(_("Function ROM image"), NULL, 0, 0,
+                              last_dir, "*", &button, 0, NULL,  UI_FC_LOAD);
 
     if (button == UI_BUTTON_OK && filename != NULL) {
         if (resources_set_string(resname, filename) < 0)
@@ -256,8 +257,12 @@ static ui_menu_entry_t io_extensions_submenu[] = {
     { N_("*IEEE488 interface emulation"),
       (ui_callback_t)toggle_IEEE488, NULL, NULL },
 #ifdef HAVE_MOUSE
-    { N_("*1351 Mouse Emulation"),
+    { N_("*Mouse Emulation"),
       NULL, NULL, mouse_submenu },
+#endif
+#ifdef HAVE_MIDI
+    { N_("MIDI Emulation"),
+      NULL, NULL, midi_c64_submenu },
 #endif
     { NULL }
 };
@@ -546,6 +551,10 @@ static void c128ui_dynamic_menu_shutdown(void)
 
 int c128ui_init(void)
 {
+    memcpy(set_video_standard_submenu,
+           set_video_standard_c128_submenu,
+           sizeof(set_video_standard_c128_submenu));
+
     ui_set_application_icon(c128_icon_data);
     c128ui_dynamic_menu_create();
     ui_set_left_menu(c128_left_menu);
