@@ -42,14 +42,17 @@
 #include "uicommands.h"
 #include "uidatasette.h"
 #include "uidigimax.h"
+#include "uidqbb.h"
 #include "uidrive.h"
 #include "uidrivec64.h"
 #include "uidrivec64vic20.h"
 #include "uigeoram.h"
 #include "uiide64.h"
+#include "uiisepic.h"
 #include "uijoystick2.h"
 #include "uikeyboard.h"
 #include "uimenu.h"
+#include "uimidi.h"
 #include "uimmc64.h"
 #include "uimouse.h"
 #include "uiperipheraliec.h"
@@ -70,7 +73,7 @@
 
 UI_MENU_DEFINE_RADIO(MachineVideoStandard)
 
-ui_menu_entry_t set_video_standard_submenu[] = {
+static ui_menu_entry_t set_video_standard_c64_submenu[] = {
     { N_("*PAL-G"), (ui_callback_t)radio_MachineVideoStandard,
       (ui_callback_data_t)MACHINE_SYNC_PAL, NULL },
     { N_("*NTSC-M"), (ui_callback_t)radio_MachineVideoStandard,
@@ -273,6 +276,10 @@ static ui_menu_entry_t io_extensions_submenu[] = {
       NULL, NULL, georam_submenu },
     { N_("RAM Expansion Cart"),
       NULL, NULL, ramcart_submenu },
+    { N_("Double Quick Brown Box cartridge"),
+      NULL, NULL, dqbb_submenu },
+    { N_("Isepic cartridge"),
+      NULL, NULL, isepic_submenu },
     { N_("PLUS60K RAM Expansion"),
       NULL, NULL, plus60k_submenu },
     { N_("PLUS256K RAM Expansion"),
@@ -292,8 +299,12 @@ static ui_menu_entry_t io_extensions_submenu[] = {
     { N_("*Emulator identification"),
       (ui_callback_t)toggle_EmuID, NULL, NULL },
 #ifdef HAVE_MOUSE
-    { N_("*1351 Mouse Emulation"),
+    { N_("*Mouse Emulation"),
       NULL, NULL, mouse_submenu },
+#endif
+#ifdef HAVE_MIDI
+    { N_("MIDI Emulation"),
+      NULL, NULL, midi_c64_submenu },
 #endif
     { NULL }
 };
@@ -536,6 +547,10 @@ static void c64ui_dynamic_menu_shutdown(void)
 
 int c64ui_init(void)
 {
+    memcpy(set_video_standard_submenu, 
+           set_video_standard_c64_submenu,
+           sizeof(set_video_standard_c64_submenu));
+
     ui_set_application_icon(c64_icon_data);
     c64ui_dynamic_menu_create();
 
@@ -554,4 +569,3 @@ void c64ui_shutdown(void)
 {
     c64ui_dynamic_menu_shutdown();
 }
-
