@@ -28,6 +28,7 @@
 
 #include <stdio.h>
 #include <stdlib.h>
+#include <string.h>
 
 #include "debug.h"
 #include "icon.h"
@@ -99,7 +100,7 @@ static ui_menu_entry_t sidcart_clock_submenu[] = {
     { NULL }
 };
 
-ui_menu_entry_t sidcart_submenu[] = {
+static ui_menu_entry_t sidcart_submenu[] = {
     { N_("*Enable SID cart"),
       (ui_callback_t)toggle_SidCart, NULL, NULL },
     { N_("SID engine"),
