@@ -39,9 +39,9 @@ void ui_cmdline_show_help(unsigned int num_options,
     printf(_("\nAvailable command-line options:\n\n"));
     for (i = 0; i < num_options; i++) {
         fputs(options[i].name, stdout);
-        if (options[i].need_arg && options[i].param_name != NULL)
-            printf(" %s", options[i].param_name);
-        printf("\n\t%s\n", _(options[i].description));
+        if (options[i].need_arg && cmdline_options_get_param(i) != NULL)
+            printf(" %s", cmdline_options_get_param(i));
+        printf("\n\t%s\n", cmdline_options_get_description(i));
     }
     putchar('\n');
 }
