@@ -46,6 +46,7 @@
 #include "uidrivevic20.h"
 #include "uikeyboard.h"
 #include "uimenu.h"
+#include "uimidi.h"
 #include "uiperipheraliec.h"
 #include "uiromset.h"
 #include "uirs232.h"
@@ -136,7 +137,7 @@ static ui_menu_entry_t sidcart_clock_submenu[] = {
     { NULL }
 };
 
-ui_menu_entry_t sidcart_submenu[] = {
+static ui_menu_entry_t sidcart_submenu[] = {
     { N_("*Enable SID cart"),
       (ui_callback_t)toggle_SidCart, NULL, NULL },
     { N_("SID engine"),
@@ -258,8 +259,8 @@ static UI_CALLBACK(attach_cartridge)
 
     vsync_suspend_speed_eval();
     filename = ui_select_file(_("Attach cartridge image"),
-                              NULL, 0, False, last_dir, "*.prg", &button,
-                              False, NULL);
+                              NULL, 0, 0, last_dir, "*.prg", &button,
+                              0, NULL, UI_FC_LOAD);
     switch (button) {
       case UI_BUTTON_OK:
         if (cartridge_attach_image(type, filename) < 0)
@@ -291,7 +292,7 @@ static ui_menu_entry_t attach_cartridge_image_submenu[] = {
     { N_("Smart-attach cartridge image..."),
       (ui_callback_t)attach_cartridge,
       (ui_callback_data_t)CARTRIDGE_VIC20_DETECT, NULL,
-      XK_c, UI_HOTMOD_META },
+      KEYSYM_c, UI_HOTMOD_META },
     { "--" },
     { N_("Attach 4/8/16KB image at $2000..."),
       (ui_callback_t)attach_cartridge,
@@ -469,6 +470,10 @@ static ui_menu_entry_t vic20_menu[] = {
       NULL, NULL, memory_settings_submenu },
     { N_("SID cartridge settings"),
       NULL, NULL, sidcart_submenu },
+#ifdef HAVE_MIDI
+    { N_("MIDI emulation"),
+      NULL, NULL, midi_vic20_submenu },
+#endif
     { NULL }
 };
 
