@@ -164,16 +164,18 @@ int usb_joystick_init(void)
 	if (fd < 0)
 	    continue;
 
+#if defined(USB_GET_REPORT_ID) && !defined(__DragonFly__)
 	if (ioctl(fd, USB_GET_REPORT_ID, &id) < 0) {
 	    log_warning(joystick_log,
-			_("Cannot get report id for joystick device `%s'."),
+			"Cannot get report id for joystick device `%s'.",
 			dev);
 	    close(fd);
 	}
+#endif
 
 	if ((report=hid_get_report_desc(fd)) == NULL) {
 	    log_warning(joystick_log,
-		_("Cannot report description for joystick device `%s'."),
+		"Cannot report description for joystick device `%s'.",
 		dev);
 	    close(fd);
 	    continue;
@@ -184,7 +186,11 @@ int usb_joystick_init(void)
 
 	found = 0;
 	is_joy = 0;
+#if !defined(HAVE_USBHID_H) && !defined(HAVE_LIBUSB_H) && defined(HAVE_LIBUSBHID)
+        for (d=hid_start_parse(report, id);
+#else
 	for (d=hid_start_parse(report, 1<<hid_input, id);
+#endif
 	     hid_get_item(d, &h);) {
 	    if (h.kind == hid_collection
 		&& HID_PAGE(h.usage) == HUP_GENERIC_DESKTOP
@@ -233,13 +239,13 @@ int usb_joystick_init(void)
 	    close(fd);
 	    usb_free_item(usb_joy_item+i);
 	    log_message(joystick_log,
-		     _("Not all axes found in joystick device `%s'."), dev);
+		     "Not all axes found in joystick device `%s'.", dev);
 	    continue;
 	}
 	
 	if ((usb_joy_buf[i]=malloc(usb_joy_size[i])) == NULL) {
 	    log_warning(joystick_log,
-			_("Cannot allocate buffer for joystick device `%s'."),
+			"Cannot allocate buffer for joystick device `%s'.",
 			dev);
 	    close(fd);
 	    usb_free_item(usb_joy_item+i);
@@ -247,7 +253,7 @@ int usb_joystick_init(void)
 	}
 
 	log_message(joystick_log,
-		    _("USB joystick found: `%s'."), dev);
+		    "USB joystick found: `%s'.", dev);
 	usb_joy_fd[i] = fd;
 	i++;
     }
