@@ -1,8 +1,8 @@
-#!/bin/sh
+#!/bin/bash
 # make-bindist.sh for Mac OSX
 # written by Christian Vogelgsang <chris@vogelgsang.org>
 #
-# make-bindist.sh <top_srcdir> <strip> <vice-version> <zip|nozip>
+# make-bindist.sh <top_srcdir> <strip> <vice-version> <zip|nozip> <ui_type> [sdk_tag]
 
 RUN_PATH=`dirname $0`
 
@@ -13,6 +13,7 @@ STRIP=$2
 VICE_VERSION=$3
 ZIP=$4
 UI_TYPE=$5
+SDK_TAG=$6
 
 # ui type
 if [ "x$UI_TYPE" = "x" ]; then
@@ -42,7 +43,11 @@ fi
 echo "  binary format: $BIN_FORMAT"
 
 # setup BUILD dir
-BUILD_DIR=vice-macosx-$UI_TYPE-$BIN_FORMAT-$VICE_VERSION
+if [ x"$SDK_TAG" != "x" ]; then
+  BUILD_DIR=vice-macosx-$UI_TYPE-$BIN_FORMAT-$SDK_TAG-$VICE_VERSION
+else
+  BUILD_DIR=vice-macosx-$UI_TYPE-$BIN_FORMAT-$VICE_VERSION
+fi
 if [ -d $BUILD_DIR ]; then
   rm -rf $BUILD_DIR
 fi
@@ -59,12 +64,13 @@ if [ ! -d $TOOL_DIR ]; then
 fi
 
 # define emulators and command line tools
-EMULATORS="x64 x128 xcbm2 xpet xplus4 xvic"
+EMULATORS="x64 x64dtv x128 xcbm2 xpet xplus4 xvic"
 TOOLS="c1541 petcat cartconv"
 
 # define data files for emulators
 ROM_COMMON="DRIVES PRINTER"
 ROM_x64=C64
+ROM_x64dtv=C64DTV
 ROM_x128=C128
 ROM_xcbm2=CBM-II
 ROM_xpet=PET
@@ -75,7 +81,7 @@ ROM_REMOVE="{beos,amiga,dos,os2,win,RO}*.vkm"
 DOC_REMOVE="texi2html *.tex *.texi MSDOS* Minix* *.beos *.dos Win32*"
 # define droppable file types
 DROP_TYPES="x64|g64|d64|d71|d81|t64|tap|prg|p00"
-DROP_FORMATS="x64 g64 d64 d71 d81 t64 tap prg p00"
+DROP_FORMATS="x64 g64 d64 d71 d81 t64 tap prg p00 crt"
 
 # launcher script
 LAUNCHER=x11-launcher.sh
@@ -93,8 +99,8 @@ if [ "$UI_TYPE" != "cocoa" ]; then
 fi
 
 # make sure icon is available
-if [ ! -e $RUN_PATH/VICE.icns ]; then
-  echo "ERROR: missing icon: $RUNPATH/VICE.icns"
+if [ ! -e $RUN_PATH/Resources/VICE.icns ]; then
+  echo "ERROR: missing icon: $RUNPATH/Resources/VICE.icns"
   exit 1
 fi
 
@@ -117,6 +123,8 @@ copy_tree () {
   (cd "$1" && tar --exclude 'Makefile*' --exclude .svn -c -f - .) | (cd "$2" && tar xf -)
 }
 
+ALL_ICONS="VICEFile floppy525 tape cartridge"
+
 create_info_plist () {
   SRC="$1"
   TGT="$2"
@@ -125,9 +133,23 @@ create_info_plist () {
   if [ "$UI_TYPE" = "cocoa" ]; then
     ADDON="  <key>CFBundleDocumentTypes</key><array>"
     for type in $DROP_FORMATS ; do
+      # default icon
+      ICON="VICEFile"
+      case "$type" in
+      [xgd][678][41])
+        ICON="floppy525"
+        ;;
+      tap|t64)
+        ICON="tape"
+        ;;
+      crt)
+        ICON="cartridge"
+        ;;
+      esac
       ADDLINE="<dict><key>CFBundleTypeExtensions</key><array><string>$type</string></array>"
-      ADDLINE="$ADDLINE <key>CFBundleTypeIconFile</key><string>VICEFile</string>"
-      ADDLINE="$ADDLINE <key>CFBundleTypeName</key><string>$type VICE File</string></dict>"
+      ADDLINE="$ADDLINE <key>CFBundleTypeIconFile</key><string>$ICON</string>"
+      ADDLINE="$ADDLINE <key>CFBundleTypeName</key><string>$type VICE File</string>"
+      ADDLINE="$ADDLINE <key>CFBundleTypeRole</key><string>Editor</string></dict>"
       ADDON="$ADDON $ADDLINE"
     done
     ADDON="$ADDON </array></dict>"
@@ -160,7 +182,8 @@ for bundle in $BUNDLES ; do
     APP_ETC=$APP_RESOURCES/etc
   fi
 
-  echo -n "  bundling $bundle.app: "
+  echo "  bundling $bundle.app: "
+  echo -n "    "
   
   if [ "$PLATYPUS" = "1" ]; then
     # --- use platypus for bundling ---
@@ -168,7 +191,7 @@ for bundle in $BUNDLES ; do
     $PLATYPUS_PATH \
         -a VICE \
         -o none \
-        -i $RUN_PATH/VICE.icns \
+        -i $RUN_PATH/Resources/VICE.icns \
         -V "$VICE_VERSION" \
         -u "The VICE Team" \
         -I "org.viceteam.VICE" \
@@ -188,12 +211,29 @@ for bundle in $BUNDLES ; do
     mkdir -p $APP_RESOURCES
 
     # copy icons
-    echo -n "[icons] "
-    cp $RUN_PATH/VICE.icns $APP_RESOURCES/
+    ICON="$RUN_PATH/Resources/$bundle.icns"
+    if [ ! -e "$ICON" ]; then
+      ICON="$RUN_PATH/Resources/VICE.icns"
+    fi
+    ICON_BASE="`basename \"$ICON\"`"
+    echo -n "[icon=$ICON_BASE] "
+    cp $ICON $APP_RESOURCES/
 
     # setup Info.plist
     echo -n "[Info.plist] "
     create_info_plist "$RUN_PATH/Info.plist" "$APP_CONTENTS/Info.plist"
+    
+    # copy extra icons
+    echo -n "[FTIcons:"
+    for icon in $ALL_ICONS ; do
+      ICON_FILE="$RUN_PATH/Resources/$icon.icns"
+      if [ -e "$ICON_FILE" ]; then
+        echo -n "$icon "
+        cp $ICON_FILE $APP_RESOURCES/
+      fi
+    done
+    echo "] "
+    echo -n "    "
 
     # copy launcher for non-cocoa
     if [ "$UI_TYPE" != "cocoa" ]; then
@@ -217,18 +257,34 @@ for bundle in $BUNDLES ; do
       # rename emu nib
       RES_LANGUAGES="English"
       for lang in $RES_LANGUAGES ; do
+        echo -n "[lang:$lang"
+        
         RES_DIR="$APP_RESOURCES/$lang.lproj"
         # make emu nib the MainMenu.nib
         EMU_NIB="$RES_DIR/$bundle.nib"
         if [ -e "$EMU_NIB" ]; then
-          echo -n "[$lang emu nib] "
+          echo -n " nib"
           MAIN_NIB="$RES_DIR/MainMenu.nib"
           mv "$EMU_NIB" "$MAIN_NIB"
         else 
-          echo -n "[MISSING: $lang emu nib] "
+          echo -n " **MISSING:nib"
         fi
         # remove unwanted emu nibs
         rm -f "$RES_DIR/x*.nib"
+        
+        # make ResourceTree for emu
+        EMU_RT="$RES_DIR/$bundle-ResourceTree.plist"
+        if [ -e "$EMU_RT" ]; then
+          echo -n " res"
+          MAIN_RT="$RES_DIR/ResourceTree.plist"
+          mv "$EMU_RT" "$MAIN_RT"
+        else
+          echo -n " **MISSING:res"
+        fi
+        # remove unwanted resource trees
+        rm -f "$RES_DIR/*-ResourceTree.plist"
+        
+        echo -n "]"
       done
     fi
   fi
