@@ -92,7 +92,9 @@ int             rl_meta_chars = 1;
 /*
 **  Declarations.
 */
-STATIC CHAR     *editinput();
+STATIC CHAR *editinput(void);
+
+#if 0
 extern int      read();
 extern int      write();
 #if     defined(USE_TERMCAP)
@@ -100,13 +102,13 @@ extern char     *getenv();
 extern char     *tgetstr();
 extern int      tgetent();
 #endif  /* defined(USE_TERMCAP) */
+#endif
 
 /*
 **  TTY input/output functions.
 */
 
-STATIC void
-TTYflush()
+STATIC void TTYflush(void)
 {
     if (ScreenCount) {
         (void)write(1, Screen, ScreenCount);
@@ -114,9 +116,7 @@ TTYflush()
     }
 }
 
-STATIC void
-TTYput(c)
-    CHAR        c;
+STATIC void TTYput(CHAR c)
 {
     Screen[ScreenCount] = c;
     if (++ScreenCount >= ScreenSize - 1) {
@@ -125,17 +125,13 @@ TTYput(c)
     }
 }
 
-STATIC void
-TTYputs(p)
-    CHAR        *p;
+STATIC void TTYputs(CHAR *p)
 {
     while (*p)
         TTYput(*p++);
 }
 
-STATIC void
-TTYshow(c)
-    CHAR        c;
+STATIC void TTYshow(CHAR c)
 {
     if (c == DEL) {
         TTYput('^');
@@ -154,16 +150,13 @@ TTYshow(c)
         TTYput(c);
 }
 
-STATIC void
-TTYstring(p)
-    CHAR        *p;
+STATIC void TTYstring(CHAR *p)
 {
     while (*p)
         TTYshow(*p++);
 }
 
-STATIC unsigned int
-TTYget()
+STATIC unsigned int TTYget(void)
 {
     CHAR        c;
 
@@ -179,16 +172,13 @@ TTYget()
 
 #define TTYback()       (backspace ? TTYputs((CHAR *)backspace) : TTYput('\b'))
 
-STATIC void
-TTYbackn(n)
-    int         n;
+STATIC void TTYbackn(int n)
 {
     while (--n >= 0)
         TTYback();
 }
 
-STATIC void
-TTYinfo()
+STATIC void TTYinfo(void)
 {
     static int          init;
 #if     defined(USE_TERMCAP)
@@ -244,10 +234,7 @@ TTYinfo()
 /*
 **  Print an array of words in columns.
 */
-STATIC void
-columns(ac, av)
-    int         ac;
-    CHAR        **av;
+STATIC void columns(int ac, CHAR **av)
 {
     CHAR        *p;
     int         i;
@@ -277,8 +264,7 @@ columns(ac, av)
     }
 }
 
-STATIC void
-reposition()
+STATIC void reposition(void)
 {
     int         i;
     CHAR        *p;
@@ -289,9 +275,7 @@ reposition()
         TTYshow(*p);
 }
 
-STATIC void
-left(Change)
-    STATUS      Change;
+STATIC void left(STATUS Change)
 {
     TTYback();
     if (Point) {
@@ -306,26 +290,21 @@ left(Change)
         Point--;
 }
 
-STATIC void
-right(Change)
-    STATUS      Change;
+STATIC void right(STATUS Change)
 {
     TTYshow(Line[Point]);
     if (Change == CSmove)
         Point++;
 }
 
-STATIC STATUS
-ring_bell()
+STATIC STATUS ring_bell(void)
 {
     TTYput('\07');
     TTYflush();
     return CSstay;
 }
 
-STATIC STATUS
-do_macro(c)
-    unsigned int        c;
+STATIC STATUS do_macro(unsigned int c)
 {
     CHAR                name[4];
 
@@ -341,9 +320,7 @@ do_macro(c)
     return CSstay;
 }
 
-STATIC STATUS
-do_forward(move)
-    STATUS      move;
+STATIC STATUS do_forward(STATUS move)
 {
     int         i;
     CHAR        *p;
@@ -366,9 +343,7 @@ do_forward(move)
     return CSstay;
 }
 
-STATIC STATUS
-do_case(type)
-    CASE        type;
+STATIC STATUS do_case(CASE type)
 {
     int         i;
     int         end;
@@ -395,20 +370,17 @@ do_case(type)
     return CSstay;
 }
 
-STATIC STATUS
-case_down_word()
+STATIC STATUS case_down_word(void)
 {
     return do_case(TOlower);
 }
 
-STATIC STATUS
-case_up_word()
+STATIC STATUS case_up_word(void)
 {
     return do_case(TOupper);
 }
 
-STATIC void
-ceol()
+STATIC void ceol(void)
 {
     int         extras;
     int         i;
@@ -431,8 +403,7 @@ ceol()
         TTYback();
 }
 
-STATIC void
-clear_line()
+STATIC void clear_line(void)
 {
     Point = -strlen(Prompt);
     TTYput('\r');
@@ -442,9 +413,7 @@ clear_line()
     Line[0] = '\0';
 }
 
-STATIC STATUS
-insert_string(p)
-    CHAR        *p;
+STATIC STATUS insert_string(CHAR *p)
 {
     SIZE_T      len;
     int         i;
@@ -474,21 +443,17 @@ insert_string(p)
     return Point == End ? CSstay : CSmove;
 }
 
-STATIC CHAR *
-next_hist()
+STATIC CHAR *next_hist(void)
 {
     return H.Pos >= H.Size - 1 ? NULL : H.Lines[++H.Pos];
 }
 
-STATIC CHAR *
-prev_hist()
+STATIC CHAR *prev_hist(void)
 {
     return H.Pos == 0 ? NULL : H.Lines[--H.Pos];
 }
 
-STATIC STATUS
-do_insert_hist(p)
-    CHAR        *p;
+STATIC STATUS do_insert_hist(CHAR *p)
 {
     if (p == NULL)
         return ring_bell();
@@ -499,9 +464,7 @@ do_insert_hist(p)
     return insert_string(p);
 }
 
-STATIC STATUS
-do_hist(move)
-    CHAR        *(*move)();
+STATIC STATUS do_hist(CHAR *(*move)(void))
 {
     CHAR        *p;
     int         i;
@@ -514,26 +477,22 @@ do_hist(move)
     return do_insert_hist(p);
 }
 
-STATIC STATUS
-h_next()
+STATIC STATUS h_next(void)
 {
     return do_hist(next_hist);
 }
 
-STATIC STATUS
-h_prev()
+STATIC STATUS h_prev(void)
 {
     return do_hist(prev_hist);
 }
 
-STATIC STATUS
-h_first()
+STATIC STATUS h_first(void)
 {
     return do_insert_hist(H.Lines[H.Pos = 0]);
 }
 
-STATIC STATUS
-h_last()
+STATIC STATUS h_last(void)
 {
     return do_insert_hist(H.Lines[H.Pos = H.Size - 1]);
 }
@@ -541,11 +500,7 @@ h_last()
 /*
 **  Return zero if pat appears as a substring in text.
 */
-STATIC int
-substrcmp(text, pat, len)
-    char        *text;
-    char        *pat;
-    int         len;
+STATIC int substrcmp(char *text, char *pat, int len)
 {
     CHAR        c;
 
@@ -557,15 +512,12 @@ substrcmp(text, pat, len)
     return 1;
 }
 
-STATIC CHAR *
-search_hist(search, move)
-    CHAR        *search;
-    CHAR        *(*move)();
+STATIC CHAR *search_hist(CHAR *search, CHAR *(*move)(void))
 {
     static CHAR *old_search;
     int         len;
     int         pos;
-    int         (*match)();
+    int         (*match)(char *text, char *pat, int len);
     char        *pat;
 
     /* Save or get remembered search pattern. */
@@ -598,12 +550,11 @@ search_hist(search, move)
     return NULL;
 }
 
-STATIC STATUS
-h_search()
+STATIC STATUS h_search(void)
 {
     static int  Searching;
     CONST char  *old_prompt;
-    CHAR        *(*move)();
+    CHAR        *(*move)(void);
     CHAR        *p;
 
     if (Searching)
@@ -624,8 +575,7 @@ h_search()
     return do_insert_hist(p);
 }
 
-STATIC STATUS
-fd_char()
+STATIC STATUS fd_char(void)
 {
     int         i;
 
@@ -638,10 +588,7 @@ fd_char()
     return CSstay;
 }
 
-STATIC void
-save_yank(begin, i)
-    int         begin;
-    int         i;
+STATIC void save_yank(int begin, int i)
 {
     if (Yanked) {
         DISPOSE(Yanked);
@@ -657,9 +604,7 @@ save_yank(begin, i)
     }
 }
 
-STATIC STATUS
-delete_string(count)
-    int         count;
+STATIC STATUS delete_string(int count)
 {
     int         i;
     CHAR        *p;
@@ -700,8 +645,7 @@ delete_string(count)
     return CSmove;
 }
 
-STATIC STATUS
-bk_char()
+STATIC STATUS bk_char(void)
 {
     int         i;
 
@@ -715,8 +659,7 @@ bk_char()
     return CSstay;
 }
 
-STATIC STATUS
-bk_del_char()
+STATIC STATUS bk_del_char(void)
 {
     int         i;
 
@@ -730,8 +673,7 @@ bk_del_char()
     return delete_string(i);
 }
 
-STATIC STATUS
-redisplay()
+STATIC STATUS redisplay(void)
 {
     TTYputs((CHAR *)NEWLINE);
     TTYputs((CHAR *)Prompt);
@@ -739,8 +681,7 @@ redisplay()
     return CSmove;
 }
 
-STATIC STATUS
-kill_line()
+STATIC STATUS kill_line(void)
 {
     int         i;
 
@@ -765,9 +706,7 @@ kill_line()
     return CSstay;
 }
 
-STATIC STATUS
-insert_char(c)
-    int         c;
+STATIC STATUS insert_char(int c)
 {
     STATUS      s;
     CHAR        buff[2];
@@ -792,8 +731,7 @@ insert_char(c)
     return s;
 }
 
-STATIC STATUS
-meta()
+STATIC STATUS meta(void)
 {
     unsigned int        c;
     KEYMAP              *kp;
@@ -830,9 +768,7 @@ meta()
     return ring_bell();
 }
 
-STATIC STATUS
-emacs(c)
-    unsigned int        c;
+STATIC STATUS emacs(unsigned int c)
 {
     STATUS              s;
     KEYMAP              *kp;
@@ -852,9 +788,7 @@ emacs(c)
     return s;
 }
 
-STATIC STATUS
-TTYspecial(c)
-    unsigned int        c;
+STATIC STATUS TTYspecial(unsigned int c)
 {
     if (ISMETA(c))
         return CSdispatch;
@@ -880,8 +814,7 @@ TTYspecial(c)
     return CSdispatch;
 }
 
-STATIC CHAR *
-editinput()
+STATIC CHAR *editinput(void)
 {
     unsigned int        c;
 
@@ -918,9 +851,7 @@ editinput()
     return NULL;
 }
 
-STATIC void
-hist_add(p)
-    CHAR        *p;
+STATIC void hist_add(CHAR *p)
 {
     int         i;
 
@@ -941,20 +872,15 @@ hist_add(p)
 **  For compatibility with FSF readline.
 */
 /* ARGSUSED0 */
-void
-rl_reset_terminal(p)
-    char        *p;
+void rl_reset_terminal(char *p)
 {
 }
 
-void
-rl_initialize()
+void rl_initialize(void)
 {
 }
 
-char *
-readline(prompt)
-    CONST char  *prompt;
+char *readline(CONST char *prompt)
 {
     CHAR        *line;
 
@@ -982,9 +908,7 @@ readline(prompt)
     return (char *)line;
 }
 
-void
-add_history(p)
-    char        *p;
+void add_history(char *p)
 {
     if (p == NULL || *p == '\0')
         return;
@@ -996,8 +920,7 @@ add_history(p)
     hist_add((CHAR *)p);
 }
 
-STATIC STATUS
-beg_line()
+STATIC STATUS beg_line(void)
 {
     if (Point) {
         Point = 0;
@@ -1006,14 +929,12 @@ beg_line()
     return CSstay;
 }
 
-STATIC STATUS
-del_char()
+STATIC STATUS del_char(void)
 {
     return delete_string(Repeat == NO_ARG ? 1 : Repeat);
 }
 
-STATIC STATUS
-end_line()
+STATIC STATUS end_line(void)
 {
     if (Point != End) {
         Point = End;
@@ -1026,8 +947,7 @@ end_line()
 **  Move back to the beginning of the current word and return an
 **  allocated copy of it.
 */
-STATIC CHAR *
-find_word()
+STATIC CHAR *find_word(void)
 {
     static char SEPS[] = "#;&|^$=`'{}()<>\n\t ";
     CHAR        *p;
@@ -1044,8 +964,7 @@ find_word()
     return new;
 }
 
-STATIC STATUS
-c_complete()
+STATIC STATUS c_complete(void)
 {
     CHAR        *p;
     CHAR        *word;
@@ -1066,8 +985,7 @@ c_complete()
     return ring_bell();
 }
 
-STATIC STATUS
-c_possible()
+STATIC STATUS c_possible(void)
 {
     CHAR        **av;
     CHAR        *word;
@@ -1087,15 +1005,13 @@ c_possible()
     return ring_bell();
 }
 
-STATIC STATUS
-accept_line()
+STATIC STATUS accept_line(void)
 {
     Line[End] = '\0';
     return CSdone;
 }
 
-STATIC STATUS
-transpose()
+STATIC STATUS transpose(void)
 {
     CHAR        c;
 
@@ -1112,16 +1028,14 @@ transpose()
     return CSstay;
 }
 
-STATIC STATUS
-quote()
+STATIC STATUS quote(void)
 {
     unsigned int        c;
 
     return (c = TTYget()) == EOF ? CSeof : insert_char((int)c);
 }
 
-STATIC STATUS
-wipe()
+STATIC STATUS wipe(void)
 {
     int         i;
 
@@ -1138,15 +1052,13 @@ wipe()
     return delete_string(Mark - Point);
 }
 
-STATIC STATUS
-mk_set()
+STATIC STATUS mk_set(void)
 {
     Mark = Point;
     return CSstay;
 }
 
-STATIC STATUS
-exchange()
+STATIC STATUS exchange(void)
 {
     unsigned int        c;
 
@@ -1161,16 +1073,14 @@ exchange()
     return CSstay;
 }
 
-STATIC STATUS
-yank()
+STATIC STATUS yank(void)
 {
     if (Yanked && *Yanked)
         return insert_string(Yanked);
     return CSstay;
 }
 
-STATIC STATUS
-copy_region()
+STATIC STATUS copy_region(void)
 {
     if (Mark > End)
         return ring_bell();
@@ -1183,8 +1093,7 @@ copy_region()
     return CSstay;
 }
 
-STATIC STATUS
-move_to_char()
+STATIC STATUS move_to_char(void)
 {
     unsigned int        c;
     int                 i;
@@ -1200,14 +1109,12 @@ move_to_char()
     return CSstay;
 }
 
-STATIC STATUS
-fd_word()
+STATIC STATUS fd_word(void)
 {
     return do_forward(CSmove);
 }
 
-STATIC STATUS
-fd_kill_word()
+STATIC STATUS fd_kill_word(void)
 {
     int         i;
 
@@ -1220,8 +1127,7 @@ fd_kill_word()
     return CSstay;
 }
 
-STATIC STATUS
-bk_word()
+STATIC STATUS bk_word(void)
 {
     int         i;
     CHAR        *p;
@@ -1241,8 +1147,7 @@ bk_word()
     return CSstay;
 }
 
-STATIC STATUS
-bk_kill_word()
+STATIC STATUS bk_kill_word(void)
 {
     (void)bk_word();
     if (OldPoint != Point)
@@ -1250,10 +1155,7 @@ bk_kill_word()
     return CSstay;
 }
 
-STATIC int
-argify(line, avp)
-    CHAR        *line;
-    CHAR        ***avp;
+STATIC int argify(CHAR *line, CHAR ***avp)
 {
     CHAR        *c;
     CHAR        **p;
@@ -1296,8 +1198,7 @@ argify(line, avp)
     return ac;
 }
 
-STATIC STATUS
-last_argument()
+STATIC STATUS last_argument(void)
 {
     CHAR        **av;
     CHAR        *p;
@@ -1373,4 +1274,3 @@ STATIC KEYMAP   MetaMap[16]= {
     {   'w',            copy_region     },
     {   0,              NULL            }
 };
-
