@@ -42,14 +42,28 @@
 #include <fcntl.h>
 #include <stdio.h>
 #include <string.h>
+
+#ifdef HAVE_SYS_IOCTL_H
 #include <sys/ioctl.h>
+#endif
+
 #include <sys/time.h>
 #include <sys/types.h>
 #include <sys/stat.h>
+
+#ifndef VMS
 #include <termios.h>
+#else
+#include "vmstermios.h"
+#endif
+
 #include <unistd.h>
 
-#ifdef MINIX_SUPPORT
+#if defined(MINIX_SUPPORT) || defined(OPENSERVER6_COMPILE)
+#include <sys/select.h>
+#endif
+
+#if defined(__QNX__) && !defined(__QNXNTO__)
 #include <sys/select.h>
 #endif
 
@@ -57,18 +71,57 @@
 #include "coproc.h"
 #include "log.h"
 #include "resources.h"
+#include "rs232.h"
+#include "translate.h"
 #include "types.h"
 
-#define MAXRS232 4
+#ifdef __NeXT__
+int cfsetispeed(struct termios *t, int speed)
+{ 
+  t->c_ispeed = speed; 
+  return 0; 
+}
+
+int cfsetospeed(struct termios *t, int speed)
+{
+  t->c_ispeed = speed;
+  return 0;
+}
+
+int tcgetattr(int fildes, struct termios *tp)
+{
+  return ioctl(fildes, TIOCGETA, tp);
+}
+
+int tcsetattr(int fd, int opt, const struct termios *t)
+{
+  int st;
+
+  switch(opt)
+  {
+    case TCSANOW:
+      st = ioctl(fd, TIOCSETA, t);
+      break;
+    case TCSADRAIN:
+      st = ioctl(fd, TIOCSETAW, t);
+      break;
+    case TCSAFLUSH:
+      st = ioctl(fd, TIOCSETAF, t);
+      break;
+    default:
+      st = -1;
+      errno = EINVAL;
+      break;
+  }
+  return st;
+}
+#endif
 
 /* ------------------------------------------------------------------------- */
 
 /* resource handling */
 
-#define NUM_DEVICES 4
-
-extern char *devfile[NUM_DEVICES];
-static int devbaud[NUM_DEVICES];
+static int devbaud[RS232_NUM_DEVICES];
 
 static int set_devbaud(int val, void *param)
 {
@@ -100,14 +153,26 @@ void rs232_resources_shutdown(void)
 }
 
 static const cmdline_option_t cmdline_options[] = {
-    { "-rsdev1baud", SET_RESOURCE, 1, NULL, NULL, "RsDevice1Baud", NULL,
-      "<baudrate>", N_("Specify baudrate of first RS232 device") },
-    { "-rsdev2baud", SET_RESOURCE, 1, NULL, NULL, "RsDevice2Baud", NULL,
-      "<baudrate>", N_("Specify baudrate of second RS232 device") },
-    { "-rsdev3baud", SET_RESOURCE, 1, NULL, NULL, "RsDevice3Baud", NULL,
-      "<baudrate>", N_("Specify baudrate of third RS232 device") },
-    { "-rsdev4baud", SET_RESOURCE, 1, NULL, NULL, "RsDevice4Baud", NULL,
-      "<baudrate>", N_("Specify baudrate of 4th RS232 device") },
+    { "-rsdev1baud", SET_RESOURCE, 1,
+      NULL, NULL, "RsDevice1Baud", NULL,
+      USE_PARAM_STRING, USE_DESCRIPTION_STRING,
+      IDCLS_UNUSED, IDCLS_UNUSED,
+      N_("<baudrate>"), N_("Specify baudrate of first RS232 device") },
+    { "-rsdev2baud", SET_RESOURCE, 1,
+      NULL, NULL, "RsDevice2Baud", NULL,
+      USE_PARAM_STRING, USE_DESCRIPTION_STRING,
+      IDCLS_UNUSED, IDCLS_UNUSED,
+      N_("<baudrate>"), N_("Specify baudrate of second RS232 device") },
+    { "-rsdev3baud", SET_RESOURCE, 1,
+      NULL, NULL, "RsDevice3Baud", NULL,
+      USE_PARAM_STRING, USE_DESCRIPTION_STRING,
+      IDCLS_UNUSED, IDCLS_UNUSED,
+      N_("<baudrate>"), N_("Specify baudrate of third RS232 device") },
+    { "-rsdev4baud", SET_RESOURCE, 1,
+      NULL, NULL, "RsDevice4Baud", NULL,
+      USE_PARAM_STRING, USE_DESCRIPTION_STRING,
+      IDCLS_UNUSED, IDCLS_UNUSED,
+      N_("<baudrate>"), N_("Specify baudrate of 4th RS232 device") },
     { NULL }
 };
 
@@ -131,7 +196,7 @@ typedef struct rs232 {
 #define T_TTY           1
 #define T_PROC          2
 
-static rs232_t fds[MAXRS232];
+static rs232_t fds[RS232_NUM_DEVICES];
 
 static log_t rs232_log = LOG_ERR;
 
@@ -144,7 +209,7 @@ void rs232_init(void)
 {
     int i;
 
-    for (i = 0; i < MAXRS232; i++)
+    for (i = 0; i < RS232_NUM_DEVICES; i++)
         fds[i].inuse = 0;
 
     rs232_log = log_open("RS232");
@@ -221,7 +286,7 @@ void rs232_reset(void)
 {
     int i;
 
-    for (i = 0; i < MAXRS232; i++) {
+    for (i = 0; i < RS232_NUM_DEVICES; i++) {
         if (fds[i].inuse) {
             rs232_close(i);
         }
@@ -233,42 +298,42 @@ int rs232_open(int device)
 {
     int i, fd;
 
-    for (i = 0; i < MAXRS232; i++) {
+    for (i = 0; i < RS232_NUM_DEVICES; i++) {
         if (!fds[i].inuse)
             break;
     }
-    if (i >= MAXRS232) {
-        log_error(rs232_log, _("No more devices available."));
+    if (i >= RS232_NUM_DEVICES) {
+        log_error(rs232_log, "No more devices available.");
         return -1;
     }
 
 #ifdef DEBUG
-    log_message(rs232_log, _("rs232_open(device=%d)."), device);
+    log_message(rs232_log, "rs232_open(device=%d).", device);
 #endif
 
-    if (devfile[device][0] == '|') {
+    if (rs232_devfile[device][0] == '|') {
 #ifdef MINIX_SUPPORT
         log_error(rs232_log, "Forking not supported on minix.");
         return -1;
 #else
-        if (fork_coproc(&fds[i].fd_w, &fds[i].fd_r, devfile[device] + 1) < 0) {
+        if (fork_coproc(&fds[i].fd_w, &fds[i].fd_r, rs232_devfile[device] + 1) < 0) {
             log_error(rs232_log, "Cannot fork process.");
             return -1;
         }
 #endif
         fds[i].type = T_PROC;
         fds[i].inuse = 1;
-        fds[i].file = devfile[device];
+        fds[i].file = rs232_devfile[device];
     } else {
-        fd = open(devfile[device], O_RDWR | O_NOCTTY | O_CREAT | O_TRUNC,
+        fd = open(rs232_devfile[device], O_RDWR | O_NOCTTY | O_CREAT | O_TRUNC,
                   S_IRUSR | S_IWUSR | S_IRGRP | S_IROTH);
         if (fd < 0) {
-            log_error(rs232_log, _("Cannot open file \"%s\": %s"),
-                      devfile[device], strerror(errno));
+            log_error(rs232_log, "Cannot open file \"%s\": %s",
+                      rs232_devfile[device], strerror(errno));
             return -1;
         }
         fds[i].fd_r = fds[i].fd_w = fd;
-        fds[i].file = devfile[device];
+        fds[i].file = rs232_devfile[device];
 
         if (isatty(fd)) {
             fds[i].type = T_TTY;
@@ -289,12 +354,12 @@ void rs232_close(int fd)
     log_debug(rs232_log, "close(fd=%d).", fd);
 #endif
 
-    if (fd < 0 || fd >= MAXRS232) {
-        log_error(rs232_log, _("Attempt to close invalid fd %d."), fd);
+    if (fd < 0 || fd >= RS232_NUM_DEVICES) {
+        log_error(rs232_log, "Attempt to close invalid fd %d.", fd);
         return;
     }
     if (!fds[fd].inuse) {
-        log_error(rs232_log, _("Attempt to close non-open fd %d."), fd);
+        log_error(rs232_log, "Attempt to close non-open fd %d.", fd);
         return;
     }
 
@@ -313,12 +378,12 @@ int rs232_putc(int fd, BYTE b)
 {
     ssize_t n;
 
-    if (fd < 0 || fd >= MAXRS232) {
-        log_error(rs232_log, _("Attempt to write to invalid fd %d."), fd);
+    if (fd < 0 || fd >= RS232_NUM_DEVICES) {
+        log_error(rs232_log, "Attempt to write to invalid fd %d.", fd);
         return -1;
     }
     if (!fds[fd].inuse) {
-        log_error(rs232_log, _("Attempt to write to non-open fd %d."), fd);
+        log_error(rs232_log, "Attempt to write to non-open fd %d.", fd);
         return -1;
     }
 
@@ -330,7 +395,7 @@ int rs232_putc(int fd, BYTE b)
     do {
         n = write(fds[fd].fd_w, &b, 1);
         if (n < 0)
-            log_error(rs232_log, _("Error writing: %s."), strerror(errno));
+            log_error(rs232_log, "Error writing: %s.", strerror(errno));
     } while (n != 1);
 
     return 0;
@@ -344,12 +409,12 @@ int rs232_getc(int fd, BYTE * b)
     fd_set rdset;
     struct timeval ti;
 
-    if (fd < 0 || fd >= MAXRS232) {
-        log_error(rs232_log, _("Attempt to read from invalid fd %d."), fd);
+    if (fd < 0 || fd >= RS232_NUM_DEVICES) {
+        log_error(rs232_log, "Attempt to read from invalid fd %d.", fd);
         return -1;
     }
     if (!fds[fd].inuse) {
-        log_error(rs232_log, _("Attempt to read from non-open fd %d."), fd);
+        log_error(rs232_log, "Attempt to read from non-open fd %d.", fd);
         return -1;
     }
 
@@ -376,3 +441,20 @@ int rs232_getc(int fd, BYTE * b)
     return 0;
 }
 
+/* set the status lines of the RS232 device */
+int rs232_set_status(int fd, enum rs232handshake_out status)
+{
+    return -1;
+}
+
+/* get the status lines of the RS232 device */
+enum rs232handshake_in rs232_get_status(int fd)
+{
+    /*! \todo dummy */
+    return RS232_HSI_CTS | RS232_HSI_DSR;
+}
+
+/* set the bps rate of the physical device */
+void rs232_set_bps(int fd, unsigned int bps)
+{
+}
