@@ -6,7 +6,11 @@
 #ifdef USE_GNOMEUI
 #include "x11/gnome/videoarch.h"
 #else
+#ifdef VMS
+#include "x11xawvideoarch.h"
+#else
 #include "x11/xaw/videoarch.h"
 #endif
 #endif
+#endif
 
