@@ -64,15 +64,19 @@ void ui_about(gpointer data)
 #else
 	"The VICE Team",
 #endif
-        "Copyright @ 1998-2007 Andreas Boose",
-        "Copyright @ 1998-2007 Tibor Biczo",
+        "Copyright @ 1998-2008 Andreas Boose",
+        "Copyright @ 1998-2008 Tibor Biczo",
+        "Copyright @ 1999-2008 Andreas Matthies",
+        "Copyright @ 1999-2008 Martin Pottendorfer",
+        "Copyright @ 1998-2008 Dag Lem",
+        "Copyright @ 2000-2008 Spiro Trikaliotis",
+        "Copyright @ 2005-2008 Marco van den Heuvel",
+        "Copyright @ 2006-2008 Christian Vogelgsang",
+        "Copyright @ 2007-2008 Fabrizio Gennari",
+        "Copyright @ 2007-2008 M. Kiesel",
+        "Copyright @ 2007-2008 Hannu Nuotio",
+        "Copyright @ 2007-2008 Daniel Kahlin",
         "Copyright @ 1999-2007 Andreas Dehmel",
-        "Copyright @ 1999-2007 Andreas Matthies",
-        "Copyright @ 1999-2007 Martin Pottendorfer",
-        "Copyright @ 1998-2007 Dag Lem",
-        "Copyright @ 2000-2007 Spiro Trikaliotis",
-        "Copyright @ 2005-2007 Marco van den Heuvel",
-        "Copyright @ 2006-2007 Christian Vogelgsang",
         "Copyright @ 1999-2005 Thomas Bretz",
         "Copyright @ 2003-2005 David Hansel",
         "Copyright @ 2000-2004 Markus Brenner",
@@ -89,7 +93,7 @@ void ui_about(gpointer data)
 	NULL};
     const gchar *transl = _(
 	"Martin Pottendorfer - German\n"
-	"Peter Karlsson - Swedish\n"
+	"Peter Krefting - Swedish\n"
 	"Andrea Musuruane - Italian\n"
 	"Paul Dube - French\n"
 	"Marco van den Heuvel - Dutch\n"
@@ -101,7 +105,7 @@ void ui_about(gpointer data)
 	about = g_object_new(GTK_TYPE_ABOUT_DIALOG,
 			     "name", "V I C E", 
 			     "version", VERSION, 
-			     "copyright", _("(c) 1998 - 2007 The Vice Team"), 
+			     "copyright", _("(c) 1998 - 2008 The Vice Team"), 
 			     "comments", "Versatile Commodore Emulator",
 			     "authors", authors, 
 			     "documenters", docs, 
