@@ -33,8 +33,13 @@
 #include "ui.h"
 #include "uiarch.h"
 
+#ifdef VMS
+#include "x11menu.h"
+#else
+
 /* The ".." will go away once the UI stuff is separated.  */
 #include "../x11menu.h"
+#endif
 
 extern struct ui_menu_entry_s ui_menu_separator[];
 
@@ -45,6 +50,7 @@ extern int ui_menu_any_open(void);
 extern void ui_menu_update_all(void);
 extern Widget ui_menu_create(const char *name, ...);
 extern void uimenu_shutdown(void);
+extern int ui_dispatch_hotkeys(int key);
 
 /* ------------------------------------------------------------------------- */
 
