@@ -60,6 +60,7 @@
 
 #include <X11/IntrinsicP.h>
 #include <X11/StringDefs.h>
+#include <X11/Xmu/Drawing.h>
 
 #include "lib.h"
 
@@ -72,9 +73,6 @@
 
  *===========================================================================*/
 
-Pixmap XmuCreateStippledPixmap();
-extern void XawInitializeWidgetSet();
-
 #define	SUPERCLASS	&(simpleClassRec)
 
 #define	FontAscent(f)	((f)->max_bounds.ascent)
@@ -87,8 +85,14 @@ extern void XawInitializeWidgetSet();
 #define abs(a)			((a) < 0 ? -(a) : (a))
 #endif
 
+#ifndef max
 #define max(a,b)		((a) > (b) ? (a) : (b))
+#endif
+
+#ifndef min
 #define min(a,b)		((a) < (b) ? (a) : (b))
+#endif
+
 #define XtStrlen(s)		((s) ? strlen(s) : 0)
 
 #define	TypeAlloc(t,n)		(t *)lib_malloc(sizeof(t) * n)
