@@ -118,50 +118,9 @@ static void ui_display_drive_current_image2(void);
 
 /* ------------------------------------------------------------------------- */
 
-void ui_check_mouse_cursor()
-{
-#ifdef USE_XF86_EXTENSIONS
-    int window_doublesize;
-    if (fullscreen_is_enabled)
-        return;
-#endif
-    if (_mouse_enabled) {
-#ifdef USE_XF86_EXTENSIONS
-        if (fullscreen_is_enabled) {
-            if (resources_get_int("FullscreenDoubleSize",
-                &window_doublesize) < 0)
-                return;
-        } else
-#endif
-
-	if (ui_cached_video_canvas->videoconfig->doublesizex)
-	    mouse_accelx = 2;   
-	
-	if (ui_cached_video_canvas->videoconfig->doublesizey)
-	    mouse_accely = 2;   
-
-        XDefineCursor(display,XtWindow(canvas), blankCursor);
-        cursor_is_blank = 1;
-
-        XGrabKeyboard(display, XtWindow(canvas),
-                      1, GrabModeAsync,
-                      GrabModeAsync,  CurrentTime);
-        XGrabPointer(display, XtWindow(canvas), 1,
-                     PointerMotionMask | ButtonPressMask |
-                     ButtonReleaseMask,
-                     GrabModeAsync, GrabModeAsync,
-                     XtWindow(canvas),
-                     None, CurrentTime);
-    } else if (cursor_is_blank) {
-        XUndefineCursor(display,XtWindow(canvas));
-        XUngrabPointer(display, CurrentTime);
-        XUngrabKeyboard(display, CurrentTime);
-    }
-}
-
 void ui_restore_mouse(void)
 {
-#ifdef USE_XF86_EXTENSIONS
+#if 0
     if (fullscreen_is_enabled)
         return;
 #endif
@@ -195,6 +154,8 @@ static void initBlankCursor(void)
 static void mouse_handler1351(Widget w, XtPointer client_data, XEvent *report,
                               Boolean *ctd)
 {
+    if (!_mouse_enabled) return;
+
     switch(report->type) {
       case MotionNotify:
         mouse_move(report->xmotion.x,report->xmotion.y);
@@ -215,7 +176,8 @@ static Widget left_menu, right_menu, drive8_menu, drive9_menu;
 
 /* Translations for the left and right menus.  */
 static XtTranslations left_menu_translations, right_menu_translations;
-static XtTranslations drive8_menu_translations, drive9_menu_translations;
+static XtTranslations left_menu_disabled_translations, right_menu_disabled_translations;
+static XtTranslations drive8_menu_translations = NULL, drive9_menu_translations = NULL;
 
 /* Application context. */
 static XtAppContext app_context;
@@ -278,6 +240,62 @@ static char *filesel_dir = NULL;
 
 /* ------------------------------------------------------------------------- */
 
+void ui_check_mouse_cursor()
+{
+    int i;
+#if 0
+    int window_doublesize;
+    if (fullscreen_is_enabled)
+        return;
+#endif
+    if (_mouse_enabled) {
+        for (i = 0; i < num_app_shells; i++) {
+            XtOverrideTranslations(app_shells[i].canvas, left_menu_disabled_translations);
+            XtOverrideTranslations(app_shells[i].canvas, right_menu_disabled_translations);
+        }
+#if 0
+        if (fullscreen_is_enabled) {
+            if (resources_get_int("FullscreenDoubleSize",
+                &window_doublesize) < 0)
+                return;
+        } else
+#endif
+
+	if (ui_cached_video_canvas->videoconfig->doublesizex)
+	    mouse_accelx = 2;   
+	else
+	    mouse_accelx = 4;
+	
+	if (ui_cached_video_canvas->videoconfig->doublesizey)
+	    mouse_accely = 2;   
+	else
+	    mouse_accely = 4;
+
+        XDefineCursor(display,XtWindow(canvas), blankCursor);
+        cursor_is_blank = 1;
+
+        XGrabKeyboard(display, XtWindow(canvas),
+                      1, GrabModeAsync,
+                      GrabModeAsync,  CurrentTime);
+        XGrabPointer(display, XtWindow(canvas), 1,
+                     PointerMotionMask | ButtonPressMask |
+                     ButtonReleaseMask,
+                     GrabModeAsync, GrabModeAsync,
+                     XtWindow(canvas),
+                     None, CurrentTime);
+    } else if (cursor_is_blank) {
+        XUndefineCursor(display,XtWindow(canvas));
+        XUngrabPointer(display, CurrentTime);
+        XUngrabKeyboard(display, CurrentTime);
+        for (i = 0; i < num_app_shells; i++) {
+            XtOverrideTranslations(app_shells[i].canvas, left_menu_translations);
+            XtOverrideTranslations(app_shells[i].canvas, right_menu_translations);
+        }
+    }
+}
+
+/* ------------------------------------------------------------------------- */
+
 static int alloc_colormap(void);
 static Widget build_file_selector(Widget parent, ui_button_t *button_return);
 static Widget build_error_dialog(Widget parent, ui_button_t *button_return,
@@ -349,6 +367,7 @@ static String fallback_resources[] = {
     "*resetButton.label:			     Reset",
     "*hardResetButton.label:                         Hard Reset",
     "*monButton.label:			   	     Monitor",
+    "*noneButton.label:			   	     Continue",
     "*debugButton.label:		   	     XDebugger",
     "*noButton.label:				     No",
     "*licenseButton.label:			     License...",
@@ -453,8 +472,6 @@ int ui_init(int *argc, char **argv)
 
     ui_common_init();
 
-    ui_hotkey_init();
-
     enabled_drives = UI_DRIVE_ENABLE_NONE;
 
     finish_prepare_wm_command();
@@ -466,8 +483,6 @@ void ui_shutdown(void)
 {
     int i;
 
-    ui_hotkey_shutdown();
-
     for (i = 0; i < num_app_shells; i++)
         lib_free(app_shells[i].title);
 
@@ -509,13 +524,13 @@ int ui_init_finish(void)
         }
         if (!classes[i].name) {
             log_error(ui_log,
-                      _("This display does not support suitable %dbit visuals."),
+                      "This display does not support suitable %dbit visuals.",
                       depth);
             log_error(ui_log,
-                      _("Please select a bit depth supported by your display."));
+                      "Please select a bit depth supported by your display.");
             return -1;
         } else {
-            log_message(ui_log, _("Found %dbit/%s visual."),
+            log_message(ui_log, "Found %dbit/%s visual.",
                         depth, classes[i].name);
             have_truecolor = (classes[i].class == TrueColor);
         }
@@ -532,7 +547,7 @@ int ui_init_finish(void)
                 if (XMatchVisualInfo(display, screen, depths[i],
                                      classes[j].class, &visualinfo)) {
                     depth = depths[i];
-                    log_message(ui_log, _("Found %dbit/%s visual."),
+                    log_message(ui_log, "Found %dbit/%s visual.",
                                 depth, classes[j].name);
                     have_truecolor = (classes[j].class == TrueColor);
                     done = 1;
@@ -540,7 +555,7 @@ int ui_init_finish(void)
                 }
             }
         if (!done) {
-            log_error(ui_log, _("Cannot autodetect a proper visual."));
+            log_error(ui_log, "Cannot autodetect a proper visual.");
             return -1;
         }
     }
@@ -577,7 +592,7 @@ int ui_init_finish(void)
                     wm_command_data,
                     wm_command_size);
 
-#ifdef USE_XF86_EXTENSIONS
+#ifdef HAVE_FULLSCREEN
     if (fullscreen_init() < 0)
         return -1;
 #endif 
@@ -606,8 +621,8 @@ Window x11ui_get_X11_window()
 }
 
 /* Create a shell with a canvas widget in it.  */
-int x11ui_open_canvas_window(video_canvas_t *c, const char *title,
-                             int width, int height, int no_autorepeat)
+int ui_open_canvas_window(video_canvas_t *c, const char *title,
+			  int width, int height, int no_autorepeat)
 {
     /* Note: this is correct because we never destroy CanvasWindows.  */
     Widget shell, speed_label, statustext_label;
@@ -626,7 +641,7 @@ int x11ui_open_canvas_window(video_canvas_t *c, const char *title,
     XtVaSetValues(_ui_top_level, XtNcolormap, colormap, NULL);
 
     if (++num_app_shells > MAX_APP_SHELLS) {
-        log_error(ui_log, _("Maximum number of toplevel windows reached."));
+        log_error(ui_log, "Maximum number of toplevel windows reached.");
         return -1;
     }
 
@@ -845,6 +860,17 @@ int x11ui_open_canvas_window(video_canvas_t *c, const char *title,
     if (icon_pixmap)
         XtVaSetValues(shell, XtNiconPixmap, icon_pixmap, NULL);
 
+    XtAddEventHandler(canvas,
+                      (EnterWindowMask | LeaveWindowMask | KeyReleaseMask
+                      | KeyPressMask), True,
+                      (XtEventHandler)kbd_event_handler, NULL);
+
+    /* FIXME: ...REALLY ugly... */
+    XtAddEventHandler(XtParent(canvas),
+                      (EnterWindowMask | LeaveWindowMask
+                      | KeyReleaseMask | KeyPressMask), True,
+                      (XtEventHandler)kbd_event_handler, NULL);
+
     if (no_autorepeat) {
         XtAddEventHandler(canvas, EnterWindowMask, False,
                           (XtEventHandler) ui_autorepeat_off, NULL);
@@ -941,6 +967,16 @@ void ui_set_left_menu(ui_menu_entry_t *menu)
     left_menu_translations = XtParseTranslationTable(translation_table);
     lib_free(translation_table);
 
+    translation_table =
+        util_concat("<Btn1Down>: \n",
+               "@Num_Lock<Btn1Down>: \n",
+               "Lock <Btn1Down>: \n"
+               "@Scroll_Lock <Btn1Down>: \n",
+               NULL);
+
+    left_menu_disabled_translations = XtParseTranslationTable(translation_table);
+    lib_free(translation_table);
+
     for (i = 0; i < num_app_shells; i++)
         XtOverrideTranslations(app_shells[i].canvas, left_menu_translations);
 
@@ -966,6 +1002,16 @@ void ui_set_right_menu(ui_menu_entry_t *menu)
     right_menu_translations = XtParseTranslationTable(translation_table);
     lib_free(translation_table);
 
+    translation_table =
+        util_concat("<Btn3Down>: \n",
+               "@Num_Lock<Btn3Down>: \n",
+               "Lock <Btn3Down>: \n"
+               "@Scroll_Lock <Btn3Down>: \n",
+               NULL);
+
+    right_menu_disabled_translations = XtParseTranslationTable(translation_table);
+    lib_free(translation_table);
+
     for (i = 0; i < num_app_shells; i++)
         XtOverrideTranslations(app_shells[i].canvas, right_menu_translations);
 
@@ -992,8 +1038,6 @@ void ui_destroy_drive9_menu(void)
 
 void ui_set_drive8_menu(Widget w)
 {
-    char *translation_table;
-    char *name = XtName(w);
     int i;
 
     for (i = 0; i < num_app_shells; i++)
@@ -1001,15 +1045,20 @@ void ui_set_drive8_menu(Widget w)
             XtDestroyWidget(w);
             return;
 	}
-    
-    translation_table =
-        util_concat("<Btn1Down>: XawPositionSimpleMenu(", name, ") MenuPopup(", name, ")\n",
-               "@Num_Lock<Btn1Down>: XawPositionSimpleMenu(", name, ") MenuPopup(", name, ")\n",
-               "Lock <Btn1Down>: XawPositionSimpleMenu(", name, ") MenuPopup(", name, ")\n"
-               "@Scroll_Lock <Btn1Down>: XawPositionSimpleMenu(", name, ") MenuPopup(", name, ")\n",
-               NULL);
-    drive8_menu_translations = XtParseTranslationTable(translation_table);
-    lib_free(translation_table);
+
+    if (!drive8_menu_translations) {
+	char *translation_table;
+	char *name = XtName(w);
+
+	translation_table =
+	    util_concat("<Btn1Down>: XawPositionSimpleMenu(", name, ") MenuPopup(", name, ")\n",
+		"@Num_Lock<Btn1Down>: XawPositionSimpleMenu(", name, ") MenuPopup(", name, ")\n",
+		"Lock <Btn1Down>: XawPositionSimpleMenu(", name, ") MenuPopup(", name, ")\n"
+		"@Scroll_Lock <Btn1Down>: XawPositionSimpleMenu(", name, ") MenuPopup(", name, ")\n",
+		NULL);
+	drive8_menu_translations = XtParseTranslationTable(translation_table);
+	lib_free(translation_table);
+    }
 
     for (i = 0; i < num_app_shells; i++)
         XtOverrideTranslations(app_shells[i].drive_widgets[app_shells[i].drive_mapping[0]].current_image, 
@@ -1022,8 +1071,6 @@ void ui_set_drive8_menu(Widget w)
 
 void ui_set_drive9_menu(Widget w)
 {
-    char *translation_table;
-    char *name = XtName(w);
     int i;
 
     for (i = 0; i < num_app_shells; i++)
@@ -1032,14 +1079,19 @@ void ui_set_drive9_menu(Widget w)
             return;
 	}
 
-    translation_table =
-        util_concat("<Btn1Down>: XawPositionSimpleMenu(", name, ") MenuPopup(", name, ")\n",
-               "@Num_Lock<Btn1Down>: XawPositionSimpleMenu(", name, ") MenuPopup(", name, ")\n",
-               "Lock <Btn1Down>: XawPositionSimpleMenu(", name, ") MenuPopup(", name, ")\n"
-               "@Scroll_Lock <Btn1Down>: XawPositionSimpleMenu(", name, ") MenuPopup(", name, ")\n",
-               NULL);
-    drive9_menu_translations = XtParseTranslationTable(translation_table);
-    lib_free(translation_table);
+    if (!drive9_menu_translations) {
+	char *translation_table;
+	char *name = XtName(w);
+
+	translation_table =
+	    util_concat("<Btn1Down>: XawPositionSimpleMenu(", name, ") MenuPopup(", name, ")\n",
+		"@Num_Lock<Btn1Down>: XawPositionSimpleMenu(", name, ") MenuPopup(", name, ")\n",
+		"Lock <Btn1Down>: XawPositionSimpleMenu(", name, ") MenuPopup(", name, ")\n"
+		"@Scroll_Lock <Btn1Down>: XawPositionSimpleMenu(", name, ") MenuPopup(", name, ")\n",
+		NULL);
+	drive9_menu_translations = XtParseTranslationTable(translation_table);
+	lib_free(translation_table);
+    }
 
     for (i = 0; i < num_app_shells; i++)
         XtOverrideTranslations(app_shells[i].drive_widgets[app_shells[i].drive_mapping[1]].current_image, 
@@ -1106,7 +1158,7 @@ void ui_exit(void)
         ui_autorepeat_on();
         ui_restore_mouse();
 
-#ifdef USE_XF86_EXTENSIONS
+#ifdef HAVE_FULLSCREEN
         fullscreen_suspend(0);
 #endif
         lib_free(s);
@@ -1135,7 +1187,7 @@ static int alloc_colormap(void)
         && !have_truecolor) {
         colormap = DefaultColormap(display, screen);
     } else {
-        log_message(ui_log, _("Using private colormap."));
+        log_message(ui_log, "Using private colormap.");
         colormap = XCreateColormap(display, RootWindow(display, screen),
                                    visual, AllocNone);
     }
@@ -1438,15 +1490,12 @@ void ui_dispatch_events(void)
 
     while (XtAppPending(app_context))
         ui_dispatch_next_event();
-#ifdef USE_XF86_DGA2_EXTENSIONS
-    dga2_mode_update();
-#endif
 }
 
 void x11ui_fullscreen(int i)
 {
-    static Atom _net_wm_state = -1;
-    static Atom _net_wm_state_fullscreen = -1;
+    static Atom _net_wm_state = None;
+    static Atom _net_wm_state_fullscreen = None;
     XEvent xev;
     int mode;
     
@@ -1458,7 +1507,7 @@ void x11ui_fullscreen(int i)
     else
 	mode = 0;
     
-    if (_net_wm_state == -1)
+    if (_net_wm_state == None)
     {
 	_net_wm_state = XInternAtom(display, "_NET_WM_STATE", False);
 	_net_wm_state_fullscreen = XInternAtom(display, "_NET_WM_STATE_FULLSCREEN", False);
@@ -1475,6 +1524,14 @@ void x11ui_fullscreen(int i)
 		SubstructureRedirectMask, &xev);
 }
 
+int
+ui_fullscreen_statusbar(struct video_canvas_s *canvas, int enable)
+{
+    log_message(ui_log, 
+		"Toggling of Statusbar/Menu in Xaw is not supported.");
+    return 0;
+}
+
 /* Resize one window. */
 void x11ui_resize_canvas_window(ui_window_t w, int width, int height, int hwscale)
 {
@@ -1586,6 +1643,7 @@ DEFINE_BUTTON_CALLBACK(UI_BUTTON_YES)
 DEFINE_BUTTON_CALLBACK(UI_BUTTON_NO)
 DEFINE_BUTTON_CALLBACK(UI_BUTTON_CLOSE)
 DEFINE_BUTTON_CALLBACK(UI_BUTTON_MON)
+DEFINE_BUTTON_CALLBACK(UI_BUTTON_NONE)
 /*DEFINE_BUTTON_CALLBACK(UI_BUTTON_DEBUG)*/
 DEFINE_BUTTON_CALLBACK(UI_BUTTON_RESET)
 DEFINE_BUTTON_CALLBACK(UI_BUTTON_HARDRESET)
@@ -1688,6 +1746,11 @@ ui_jam_action_t ui_jam_dialog(const char *format, ...)
     XtAddCallback(tmp, XtNcallback, UI_BUTTON_MON_callback,
                   (XtPointer) &button);
 
+    tmp = XtVaCreateManagedWidget
+        ("noneButton", commandWidgetClass, bbox, NULL);
+    XtAddCallback(tmp, XtNcallback, UI_BUTTON_NONE_callback,
+                  (XtPointer) &button);
+
     ui_popup(XtParent(jam_dialog), "VICE", False);
     button = UI_BUTTON_NONE;
     do
@@ -1703,12 +1766,14 @@ ui_jam_action_t ui_jam_dialog(const char *format, ...)
     switch (button) {
       case UI_BUTTON_MON:
         ui_restore_mouse();
-#ifdef USE_XF86_EXTENSIONS
+#ifdef HAVE_FULLSCREEN
         fullscreen_suspend(0);
 #endif
         return UI_JAM_MONITOR;
       case UI_BUTTON_HARDRESET:
         return UI_JAM_HARD_RESET;
+      case UI_BUTTON_NONE:
+        return UI_JAM_NONE;
       case UI_BUTTON_RESET:
       default:
         return UI_JAM_RESET;
@@ -1732,7 +1797,8 @@ char *ui_select_file(const char *title,
                      unsigned int unit), unsigned int unit,
                      unsigned int allow_autostart, const char *default_dir,
                      const char *default_pattern, ui_button_t *button_return,
-                     unsigned int show_preview, int *attach_wp)
+                     unsigned int show_preview, int *attach_wp,
+		     ui_filechooser_t action)
 {
     static ui_button_t button;
     char *ret;
@@ -1920,7 +1986,7 @@ void ui_popup(Widget w, const char *title, Boolean wait_popdown)
 {
     Widget s = NULL;
 
-#ifdef USE_XF86_EXTENSIONS
+#ifdef HAVE_FULLSCREEN
     fullscreen_suspend(1);
 #endif
 
@@ -2005,7 +2071,7 @@ void ui_popdown(Widget w)
     if (--popped_up_count < 0)
         popped_up_count = 0;
 
-#ifdef USE_XF86_EXTENSIONS
+#ifdef HAVE_FULLSCREEN
     fullscreen_resume();
 #endif
 }
