@@ -8,6 +8,7 @@
 #define HAVE_ALLOCA             1
 #define RETSIGTYPE              void
 #define HAVE_RESID              1
+#define HAVE_RESID_FP           1
 #define HAVE_PNG                1
 #define HAVE_ZLIB               1
 #define HAS_JOYSTICK            1
@@ -43,11 +44,13 @@
 #define HAVE_TFE                1
 #define HAVE_FFMPEG             1
 #define HAVE_OPENCBM            1
+#define HAVE_MIDI               1
 #define HAVE_CRTDBG             1
 #define HAS_TRANSLATION         1
 #define HAVE_HTONL              1
 #define HAVE_HTONS              1
 #define HAVE_NETWORK            1
+#define HAVE_GETCWD             1
 
 #define __i386__                1
 
