@@ -33,6 +33,7 @@
 
 #include "datasette.h"
 #include "drive.h"
+#include "intl.h"
 #include "lib.h"
 #include "res.h"
 #include "resources.h"
@@ -170,6 +171,10 @@ void statusbar_create(HWND hwnd)
                                status_hwnd[number_of_status_windows],
                                (HMENU)IDC_SLIDER,
                                NULL,NULL);
+
+    resources_get_int("SoundVolume", &res_val);
+    SendMessage(slider_hwnd[number_of_status_windows], TBM_SETPOS, 1, 100 - res_val);
+
     /* Max Steps */
     SendMessage(slider_hwnd[number_of_status_windows], TBM_SETRANGEMAX, 1, 100);
 
@@ -179,9 +184,6 @@ void statusbar_create(HWND hwnd)
     SetStatusWindowParts(status_hwnd[number_of_status_windows]);
 
     number_of_status_windows++;
-
-    resources_get_int("SoundVolume", &res_val);
-    statusbar_display_volume(res_val);
 }
 
 void statusbar_destroy(void)
@@ -476,7 +478,7 @@ void statusbar_handle_WMDRAWITEM(WPARAM wparam, LPARAM lparam)
             led.top = part_top + 22;
             led.bottom = part_top + 38;
 
-            DrawText(hDC, translate_text(IDS_JOYSTICK), -1, &led, 0);
+            DrawText(hDC, translate_text(IDS_JOYSTICK_C), -1, &led, 0);
 
             for (joynum = 1; joynum <= 2; joynum ++) {
 
@@ -559,10 +561,10 @@ void statusbar_notify(HWND window, int window_index, WPARAM wparam, LPARAM lpara
         slider_pos = SendMessage(slider_hwnd[window_index], TBM_GETPOS, 0, 0);
         resources_set_int("SoundVolume", 100 - slider_pos);
 
-        if (nmhdr->code == NM_RELEASEDCAPTURE)
+        if (nmhdr->code == (UINT)NM_RELEASEDCAPTURE)
             SetFocus(window);
 
-        if (nmhdr->code == NM_CUSTOMDRAW) {
+        if (nmhdr->code == (UINT)NM_CUSTOMDRAW) {
             NMCUSTOMDRAW *lpNMCustomDraw = (NMCUSTOMDRAW*)lparam;
 #ifndef CDIS_FOCUS
 #define CDIS_FOCUS 16
