@@ -224,7 +224,7 @@ static const resource_int_t resources_int[] = {
       &ui_resources.window_xpos[1], set_window_xpos, (void *)1 },
     { "Window1Ypos", CW_USEDEFAULT, RES_EVENT_NO, NULL,
       &ui_resources.window_ypos[1], set_window_ypos, (void *)1 },
-    { "VBLANKSync", 1, RES_EVENT_NO, NULL,
+    { "VBLANKSync", 0, RES_EVENT_NO, NULL,
       &ui_resources.vblank_sync, set_vblank_sync, NULL },
     { "AlwaysOnTop", 0, RES_EVENT_NO, NULL,
       &ui_resources.alwaysontop, set_alwaysontop, NULL },
@@ -264,24 +264,36 @@ int ui_vblank_sync_enabled()
 /* UI-related command-line options.  */
 
 static const cmdline_option_t cmdline_options[] = {
-    { "-saveres", SET_RESOURCE, 0, NULL, NULL,
-      "SaveResourcesOnExit", (resource_value_t)1,
-      0, IDS_SAVE_SETTINGS_ON_EXIT },
-    { "+saveres", SET_RESOURCE, 0, NULL, NULL,
-      "SaveResourcesOnExit", (resource_value_t)0,
-      0, IDS_NO_SAVE_SETTINGS_ON_EXIT },
-    { "-confirmexit", SET_RESOURCE, 0, NULL, NULL,
-      "ConfirmOnExit", (resource_value_t)0,
-      0, IDS_CONFIRM_QUIT_VICE },
-    { "+confirmexit", SET_RESOURCE, 0, NULL, NULL,
-      "ConfirmOnExit", (resource_value_t)1,
-      0, IDS_NO_CONFIRM_QUIT_VICE },
-    { "-singlecpu", SET_RESOURCE, 0, NULL, NULL,
-      "SingleCPU", (resource_value_t)0,
-      0, IDS_USE_ALL_CPU_SMP },
-    { "+singlecpu", SET_RESOURCE, 0, NULL, NULL,
-      "SingleCPU", (resource_value_t)1,
-      0, IDS_USE_FIRST_CPU_SMP },
+    { "-saveres", SET_RESOURCE, 0,
+      NULL, NULL, "SaveResourcesOnExit", (resource_value_t)1,
+      USE_PARAM_STRING, USE_DESCRIPTION_ID,
+      IDCLS_UNUSED, IDS_SAVE_SETTINGS_ON_EXIT,
+      NULL, NULL },
+    { "+saveres", SET_RESOURCE, 0,
+      NULL, NULL, "SaveResourcesOnExit", (resource_value_t)0,
+      USE_PARAM_STRING, USE_DESCRIPTION_ID,
+      IDCLS_UNUSED, IDS_NO_SAVE_SETTINGS_ON_EXIT,
+      NULL, NULL },
+    { "-confirmexit", SET_RESOURCE, 0,
+      NULL, NULL, "ConfirmOnExit", (resource_value_t)1,
+      USE_PARAM_STRING, USE_DESCRIPTION_ID,
+      IDCLS_UNUSED, IDS_CONFIRM_QUIT_VICE,
+      NULL, NULL },
+    { "+confirmexit", SET_RESOURCE, 0,
+      NULL, NULL, "ConfirmOnExit", (resource_value_t)0,
+      USE_PARAM_STRING, USE_DESCRIPTION_ID,
+      IDCLS_UNUSED, IDS_NO_CONFIRM_QUIT_VICE,
+      NULL, NULL },
+    { "-singlecpu", SET_RESOURCE, 0,
+      NULL, NULL, "SingleCPU", (resource_value_t)1,
+      USE_PARAM_STRING, USE_DESCRIPTION_ID,
+      IDCLS_UNUSED, IDS_USE_ALL_CPU_SMP,
+      NULL, NULL },
+    { "+singlecpu", SET_RESOURCE, 0,
+      NULL, NULL, "SingleCPU", (resource_value_t)0,
+      USE_PARAM_STRING, USE_DESCRIPTION_ID,
+      IDCLS_UNUSED, IDS_USE_FIRST_CPU_SMP,
+      NULL, NULL },
     { NULL }
 };
 
