@@ -28,6 +28,7 @@
 
 #include "vice.h"
 
+#include <assert.h>
 #include <stdio.h>
 #include <string.h>
 #include <windows.h>
@@ -40,6 +41,8 @@
 #include "attach.h"
 #include "autostart.h"
 #include "archdep.h"
+#include "charset.h"
+#include "clipboard.h"
 #include "debug.h"
 #include "drive.h"
 #include "drivecpu.h"
@@ -47,7 +50,9 @@
 #include "fullscrn.h"
 #include "imagecontents.h"
 #include "interrupt.h"
+#include "intl.h"
 #include "kbd.h"
+#include "kbdbuf.h"
 #include "lib.h"
 #include "log.h"
 #include "machine.h"
@@ -70,6 +75,7 @@
 #include "uifliplist.h"
 #include "uihelp.h"
 #include "uijoystick.h"
+#include "uikeyboard.h"
 #include "uilib.h"
 #include "uimediafile.h"
 #include "uinetwork.h"
@@ -124,19 +130,16 @@ static const ui_menu_toggle_t toggle_list[] = {
     { "Sound", IDM_TOGGLE_SOUND },
     { "DriveTrueEmulation", IDM_TOGGLE_DRIVE_TRUE_EMULATION },
     { "WarpMode", IDM_TOGGLE_WARP_MODE },
-    { "WarpMode", IDM_TOGGLE_WARP_MODE|0x00010000 },
     { "VirtualDevices", IDM_TOGGLE_VIRTUAL_DEVICES },
     { "SaveResourcesOnExit", IDM_TOGGLE_SAVE_SETTINGS_ON_EXIT },
     { "ConfirmOnExit", IDM_TOGGLE_CONFIRM_ON_EXIT },
     { "FullScreenEnabled", IDM_TOGGLE_FULLSCREEN },
     { "AlwaysOnTop", IDM_TOGGLE_ALWAYSONTOP },
+    { "KeySetEnable", IDM_JOYKEYS_TOGGLE },
 #ifdef DEBUG
     { "MainCPU_TRACE", IDM_TOGGLE_MAINCPU_TRACE },
-    { "MainCPU_TRACE", IDM_TOGGLE_MAINCPU_TRACE|0x00010000 },
     { "Drive0CPU_TRACE", IDM_TOGGLE_DRIVE0CPU_TRACE },
-    { "Drive0CPU_TRACE", IDM_TOGGLE_DRIVE0CPU_TRACE|0x00010000 },
     { "Drive1CPU_TRACE", IDM_TOGGLE_DRIVE1CPU_TRACE },
-    { "Drive1CPU_TRACE", IDM_TOGGLE_DRIVE1CPU_TRACE|0x00010000 },
 #endif
     { NULL, 0 }
 };
@@ -219,92 +222,59 @@ static const struct {
     { NULL, 0}
 };
 
+ui_menu_translation_table_t monitor_trans_popup_table[] = {
+    { 1, IDS_MP_FILE },
+    { 1, IDS_MP_DEBUG },
+    { 1, IDS_MP_VIEW },
+    { 1, IDS_MP_WINDOW },
+    { 0, 0 }
+};
+
+ui_popup_translation_table_t monitor_trans_item_table[] = {
+    { IDM_MON_OPEN, IDS_MI_MON_OPEN },
+    { IDM_MON_SAVE, IDS_MI_MON_SAVE },
+    { IDM_MON_PRINT, IDS_MI_MON_PRINT },
+    { IDM_EXIT, IDS_MI_MON_EXIT },
+    { IDM_MON_STOP_DEBUG, IDS_MI_MON_STOP_DEBUG },
+    { IDM_MON_STOP_EXEC, IDS_MI_MON_STOP_EXEC },
+    { IDM_MON_STEP_INTO, IDS_MI_MON_STEP_INTO },
+    { IDM_MON_STEP_OVER, IDS_MI_MON_STEP_OVER },
+    { IDM_MON_SKIP_RETURN, IDS_MI_MON_SKIP_RETURN },
+    { IDM_MON_GOTO_CURSOR, IDS_MI_MON_GOTO_CURSOR },
+    { IDM_MON_EVAL, IDS_MI_MON_EVAL },
+    { IDM_MON_CURRENT, IDS_MI_MON_CURRENT },
+    { IDM_MON_WND_EVAL, IDS_MI_MON_WND_EVAL },
+    { IDM_MON_WND_REG, IDS_MI_MON_WND_REG },
+    { IDM_MON_WND_MEM, IDS_MI_MON_WND_MEM },
+    { IDM_MON_WND_DIS, IDS_MI_MON_WND_DIS },
+    { IDM_MON_WND_CONSOLE, IDS_MI_MON_WND_CONSOLE },
+    { IDM_MON_COMPUTER, IDS_MI_MON_COMPUTER },
+    { IDM_MON_DRIVE8, IDS_MI_MON_DRIVE8 },
+    { IDM_MON_DRIVE9, IDS_MI_MON_DRIVE9 },
+    { IDM_MON_CASCADE, IDS_MI_MON_CASCADE },
+    { IDM_MON_TILE_VERT, IDS_MI_MON_TILE_VERT },
+    { IDM_MON_TILE_HORIZ, IDS_MI_MON_TILE_HORIZ },
+    { IDM_MON_ARRANGE_ICONS, IDS_MI_MON_ARRANGE_ICONS },
+    { 0, 0 }
+};
+
 /* ------------------------------------------------------------------------ */
-#ifdef DEBUG
-#define UI_DEBUG_HOTKEYS                                                \
-    { FVIRTKEY | FALT | FNOINVERT, VK_F10, IDM_TOGGLE_MAINCPU_TRACE },     \
-    { FVIRTKEY | FALT | FNOINVERT, VK_F11, IDM_TOGGLE_DRIVE0CPU_TRACE },   \
-    { FVIRTKEY | FALT | FNOINVERT, VK_F12, IDM_TOGGLE_DRIVE1CPU_TRACE },
-#else
-#define UI_DEBUG_HOTKEYS
-#endif /* DEBUG*/
-
-#define UI_COMMON_HOTKEYS                                                   \
-    { FVIRTKEY | FCONTROL | FALT | FNOINVERT, 'R', IDM_RESET_HARD },        \
-    { FVIRTKEY | FALT | FNOINVERT, 'R', IDM_RESET_SOFT },                   \
-    { FVIRTKEY | FALT | FNOINVERT, '4', IDM_FORMFEED_PRINTERIEC4 },         \
-    { FVIRTKEY | FALT | FNOINVERT, '5', IDM_FORMFEED_PRINTERIEC5 },         \
-    { FVIRTKEY | FALT | FNOINVERT, '8', IDM_ATTACH_8 },                     \
-    { FVIRTKEY | FALT | FNOINVERT, '9', IDM_ATTACH_9 },                     \
-    { FVIRTKEY | FALT | FNOINVERT, '0', IDM_ATTACH_10 },                    \
-    { FVIRTKEY | FALT | FNOINVERT, '1', IDM_ATTACH_11 },                    \
-    { FVIRTKEY | FALT | FNOINVERT, 'A', IDM_DETACH_ALL },                   \
-    { FVIRTKEY | FALT | FNOINVERT, 'T', IDM_ATTACH_TAPE },                  \
-    { FVIRTKEY | FALT | FNOINVERT, 'L', IDM_LOADQUICK },                    \
-    { FVIRTKEY | FALT | FNOINVERT, 'S', IDM_SAVEQUICK },                    \
-    { FVIRTKEY | FALT | FNOINVERT, 'M', IDM_MONITOR },                      \
-    { FVIRTKEY | FALT | FNOINVERT, 'X', IDM_EXIT },                         \
-    { FVIRTKEY | FALT | FNOINVERT, 'W', IDM_TOGGLE_WARP_MODE },             \
-    { FVIRTKEY | FALT | FNOINVERT, 'I', IDM_FLIP_ADD },                     \
-    { FVIRTKEY | FALT | FNOINVERT, 'K', IDM_FLIP_REMOVE },                  \
-    { FVIRTKEY | FALT | FNOINVERT, 'N', IDM_FLIP_NEXT },                    \
-    { FVIRTKEY | FALT | FNOINVERT, 'B', IDM_FLIP_PREVIOUS },                \
-    { FVIRTKEY | FALT | FNOINVERT, 'J', IDM_SWAP_JOYSTICK },                \
-    { FVIRTKEY | FALT | FNOINVERT, 'C', IDM_MEDIAFILE },                    \
-    { FVIRTKEY | FALT | FNOINVERT, 'G', IDM_EVENT_SETMILESTONE },           \
-    { FVIRTKEY | FALT | FNOINVERT, 'H', IDM_EVENT_RESETMILESTONE },         \
-    { FVIRTKEY | FALT | FNOINVERT, 'D', IDM_TOGGLE_FULLSCREEN },            \
-    { FVIRTKEY | FALT | FNOINVERT, VK_RETURN, IDM_TOGGLE_FULLSCREEN },      \
-    { FVIRTKEY | FALT | FNOINVERT, VK_PAUSE, IDM_PAUSE },                   \
-    { FVIRTKEY | FALT | FNOINVERT, VK_OEM_PLUS, IDM_SINGLE_FRAME_ADVANCE }, \
-    { FVIRTKEY | FALT | FNOINVERT, VK_ADD, IDM_SINGLE_FRAME_ADVANCE }
-
-static ACCEL c64_accel[] = {
-    { FVIRTKEY | FALT | FNOINVERT, 'Z', IDM_CART_FREEZE },
-    { FVIRTKEY | FALT | FNOINVERT, 'Q', IDM_MOUSE },
-    UI_DEBUG_HOTKEYS
-    UI_COMMON_HOTKEYS
-};
-
-static ACCEL c128_accel[] = {
-    { FVIRTKEY | FALT | FNOINVERT, 'Q', IDM_MOUSE },
-    UI_DEBUG_HOTKEYS
-    UI_COMMON_HOTKEYS
-};
-
-static ACCEL cbm2_accel[] = {
-    UI_DEBUG_HOTKEYS
-    UI_COMMON_HOTKEYS
-};
-
-static ACCEL vic_accel[] = {
-    UI_DEBUG_HOTKEYS
-    UI_COMMON_HOTKEYS
-};
-
-static ACCEL pet_accel[] = {
-    UI_DEBUG_HOTKEYS
-    UI_COMMON_HOTKEYS
-};
-
-static ACCEL plus4_accel[] = {
-    UI_DEBUG_HOTKEYS
-    UI_COMMON_HOTKEYS
-};
-
-/*static HBRUSH led_red;
-static HBRUSH led_green;
-static HBRUSH led_black;
-static HBRUSH tape_motor_on_brush;
-static HBRUSH tape_motor_off_brush;
-*/
 static HWND main_hwnd;
-static HWND slider_hwnd;
 
 static int emu_menu;
 
 static int pause_pending;
 
+static ui_menu_translation_table_t *menu_translation_table;
+static ui_popup_translation_table_t *popup_translation_table;
+
+void ui_register_translation_tables(ui_menu_translation_table_t *menu_table, ui_popup_translation_table_t *popup_table)
+{
+    menu_translation_table = menu_table;
+    popup_translation_table = popup_table;
+    ui_update_menu();
+}
+
 /* Initialize the UI before setting all the resource values.  */
 int ui_init(int *argc, char **argv)
 {
@@ -313,40 +283,29 @@ int ui_init(int *argc, char **argv)
     switch (machine_class) {
       case VICE_MACHINE_C64:
         emu_menu = IDR_MENUC64;
-        ui_accelerator = CreateAcceleratorTable(c64_accel, 
-            sizeof(c64_accel) / sizeof(ACCEL));
+        break;
+      case VICE_MACHINE_C64DTV:
+        emu_menu = IDR_MENUC64DTV;
         break;
       case VICE_MACHINE_C128:
         emu_menu = IDR_MENUC128;
-        ui_accelerator = CreateAcceleratorTable(c128_accel, 
-            sizeof(c128_accel) / sizeof(ACCEL));
         break;
       case VICE_MACHINE_VIC20:
         emu_menu = IDR_MENUVIC;
-        ui_accelerator = CreateAcceleratorTable(vic_accel,
-            sizeof(vic_accel)/ sizeof(ACCEL));
         break;
       case VICE_MACHINE_PET:
         emu_menu = IDR_MENUPET;
-        ui_accelerator = CreateAcceleratorTable(pet_accel,
-            sizeof(pet_accel) / sizeof(ACCEL));
         break;
       case VICE_MACHINE_PLUS4:
         emu_menu = IDR_MENUPLUS4;
-        ui_accelerator = CreateAcceleratorTable(plus4_accel,
-            sizeof(plus4_accel) / sizeof(ACCEL));
         break;
       case VICE_MACHINE_CBM2:
         emu_menu = IDR_MENUCBM2;
-        ui_accelerator = CreateAcceleratorTable(cbm2_accel,
-            sizeof(cbm2_accel) / sizeof(ACCEL));
         break;
       default:
         log_debug("UI: No menu entries for this machine defined!");
         log_debug("UI: Using C64 type UI menues.");
         emu_menu = IDR_MENUC64;
-        ui_accelerator = CreateAcceleratorTable(c64_accel,
-            sizeof(c64_accel) / sizeof(ACCEL));
     }
 
     /* Register the window class.  */
@@ -383,7 +342,6 @@ int ui_init(int *argc, char **argv)
        needs an application window to be created to initialize itself, and
        because this might allow us to support more than one emulation window
        in the future.  */
-#if 1
     main_hwnd = CreateWindow(APPLICATION_CLASS_MAIN,
                              TEXT("No title"), /* (for now) */
                              WS_OVERLAPPED | WS_CLIPCHILDREN | WS_BORDER
@@ -397,7 +355,6 @@ int ui_init(int *argc, char **argv)
                              NULL,
                              winmain_instance,
                              NULL);
-#endif
     InitCommonControls();
 
     number_of_windows = 0;
@@ -410,11 +367,13 @@ int ui_init(int *argc, char **argv)
 void ui_shutdown(void)
 {
    statusbar_delete_brushes();
+   uikeyboard_shutdown();
 }
 
 /* Initialize the UI after setting all the resource values.  */
 int ui_init_finish(void)
 {
+    ui_accelerator = uikeyboard_create_accelerator_table();
     ui_fullscreen_init();
     atexit(ui_exit);
     return 0;
@@ -441,9 +400,84 @@ void ui_exit(void)
     uilib_shutdown();
 }
 
+static void ui_translate_menu_popups(HMENU menu, ui_popup_translation_table_t *trans_table)
+{
+    int pos1 = -1;
+    int pos2 = -1;
+    int pos3 = -1;
+
+    HMENU menu1 = NULL;
+    HMENU menu2 = NULL;
+    HMENU menu3 = NULL;
+
+    int i = 0;
+
+    if (trans_table == NULL)
+        return;
+
+    while (trans_table[i].level != 0)
+    {
+        switch (trans_table[i].level)
+        {
+            case 1:
+                menu1 = NULL;
+                while (menu1 == NULL)
+                {
+                    pos1++;
+                    menu1 = GetSubMenu(menu, pos1);
+                }
+                if (trans_table[i].ids != 0)
+                    ModifyMenu(menu, (UINT)pos1, MF_BYPOSITION | MF_STRING | MF_POPUP, (UINT)menu1, translate_text(trans_table[i].ids));
+                pos2 = -1;
+                pos3 = -1;
+                break;
+            case 2:
+                menu2 = NULL;
+                while (menu2 == NULL)
+                {
+                    pos2++;
+                    menu2 = GetSubMenu(menu1, pos2);
+                }
+                ModifyMenu(menu1, (UINT)pos2, MF_BYPOSITION | MF_STRING | MF_POPUP, (UINT)menu2, translate_text(trans_table[i].ids));
+                pos3 = -1;
+                break;
+            case 3:
+                menu3 = NULL;
+                while (menu3 == NULL)
+                {
+                    pos3++;
+                    menu3 = GetSubMenu(menu2, pos3);
+                }
+                ModifyMenu(menu2, (UINT)pos3, MF_BYPOSITION | MF_STRING | MF_POPUP, (UINT)menu3, translate_text(trans_table[i].ids));
+                break;
+        }
+        i++;
+    }
+}
+
+static void ui_translate_menu_items(HMENU menu, ui_menu_translation_table_t *trans_table)
+{
+    int i = 0;
+
+    if (trans_table == NULL)
+        return;
+
+    while (trans_table[i].idm != 0)
+    {
+        ModifyMenu(menu, trans_table[i].idm, MF_BYCOMMAND | MF_STRING, trans_table[i].idm, translate_text(trans_table[i].ids));
+        i++;
+    }
+}
+
+void ui_translate_monitor_menu(HMENU menu)
+{
+  ui_translate_menu_popups(menu, (ui_popup_translation_table_t *)monitor_trans_popup_table);
+  ui_translate_menu_items(menu, (ui_menu_translation_table_t *)monitor_trans_item_table);
+}
+
 /*  Create a Window for the emulation.  */
 HWND ui_open_canvas_window(const char *title, unsigned int width,
-                           unsigned int height, int fullscreen)
+                           unsigned int height)
 {
     HWND hwnd;
     int xpos, ypos;
@@ -475,14 +509,15 @@ HWND ui_open_canvas_window(const char *title, unsigned int width,
     window_canvas_ysize[number_of_windows] = height;
     number_of_windows++;
 
-    if (!fullscreen) {
-        statusbar_create(hwnd);
-    }
+    statusbar_create(hwnd);
 
     ui_resize_canvas_window(hwnd, width, height);
 
-    menu=LoadMenu(winmain_instance, MAKEINTRESOURCE(translate_res(emu_menu)));
+    menu=LoadMenu(winmain_instance, MAKEINTRESOURCE(emu_menu));
+    ui_translate_menu_items(menu, menu_translation_table);
+    ui_translate_menu_popups(menu, popup_translation_table);
     SetMenu(hwnd,menu);
+    uikeyboard_menu_shortcuts(menu);
     ShowWindow(hwnd, winmain_cmd_show);
     return hwnd;
 
@@ -493,7 +528,13 @@ void ui_update_menu()
 HMENU menu;
 int   i;
 
-    menu = LoadMenu(winmain_instance, MAKEINTRESOURCE(translate_res(emu_menu)));
+    menu = LoadMenu(winmain_instance, MAKEINTRESOURCE(emu_menu));
+    if (menu_translation_table != NULL)
+    {
+        ui_translate_menu_items(menu, menu_translation_table);
+        ui_translate_menu_popups(menu, popup_translation_table);
+        uikeyboard_menu_shortcuts(menu);
+    }
     for (i = 0; i < number_of_windows; i++) {
         SetMenu(window_handles[i], menu);
     }
@@ -579,7 +620,7 @@ void ui_register_res_values(const ui_res_value_list_t *valuelist)
 static void update_menus(HWND hwnd)
 {
     HMENU menu = GetMenu(hwnd);
-    int i, j;
+    unsigned int i, j;
     int value;
     int result;
     const char *lang;
@@ -661,7 +702,7 @@ static void update_menus(HWND hwnd)
 
 static void ui_set_language(unsigned int lang_id)
 {
-    int i;
+    unsigned int i;
 
     for (i = 0; (ui_lang_menu_entries[i].lang_code != NULL)
         && (i < countof(ui_lang_menu_entries)); i++) {
@@ -731,6 +772,25 @@ void ui_message(const char *format, ...)
     lib_free(tmp);
 }
 
+/* Let the user browse for a filename */
+char *ui_get_file(const char *format,...)
+{
+    char *tmp;
+    char *st;
+    va_list args;
+
+    va_start(args, format);
+    tmp = lib_mvsprintf(format, args);
+    va_end(args);
+
+    st = uilib_select_file(NULL, tmp, UILIB_FILTER_ALL,
+                                UILIB_SELECTOR_TYPE_FILE_LOAD,
+                                UILIB_SELECTOR_STYLE_DISK);
+    lib_free(tmp);
+
+    return st;
+}
+
 /* Handle the "CPU JAM" case.  */
 ui_jam_action_t ui_jam_dialog(const char *format,...)
 {
@@ -743,11 +803,19 @@ ui_jam_action_t ui_jam_dialog(const char *format,...)
     txt = lib_mvsprintf(format, ap);
     txt2 = lib_msprintf(translate_text(IDS_START_MONITOR), txt);
     st = system_mbstowcs_alloc(txt2);
-    ret = ui_messagebox(st, translate_text(IDS_VICE_CPU_JAM), MB_YESNO);
+    ret = ui_messagebox(st, translate_text(IDS_VICE_CPU_JAM), MB_YESNOCANCEL);
     system_mbstowcs_free(st);
     lib_free(txt2);
     lib_free(txt);
-    return (ret == IDYES) ? UI_JAM_MONITOR : UI_JAM_HARD_RESET;
+    switch (ret) {
+        case IDYES:
+            return UI_JAM_MONITOR;
+        case IDNO:
+            return UI_JAM_HARD_RESET;
+        case IDCANCEL:
+            return UI_JAM_NONE;
+    }
+    return UI_JAM_NONE;
 //    UI_JAM_RESET, UI_JAM_HARD_RESET, UI_JAM_MONITOR
 }
 
@@ -1063,6 +1131,124 @@ static void reset_dialog_proc(WPARAM wparam)
     }
 }
 
+/* ------------------------------------------------------------------------ */
+
+static void ui_copy_clipboard(HWND window)
+{
+    BOOL clipboard_is_open = FALSE;
+    char * text = NULL;
+    HGLOBAL globaltext = NULL;
+
+    do {
+        char * p;
+
+        if ( ! OpenClipboard(window) ) {
+            break;
+        }
+        clipboard_is_open = TRUE;
+
+        if ( ! EmptyClipboard() ) {
+            break;
+        }
+
+        text = clipboard_read_screen_output("\r\n");
+        if (text == NULL) {
+            break;
+        }
+
+        globaltext = GlobalAlloc(GMEM_DDESHARE, strlen(text) + 1);
+        if (globaltext == NULL) {
+            break;
+        }
+
+        p = GlobalLock(globaltext);
+        strcpy(p, text);
+
+        SetClipboardData(CF_TEXT, globaltext);
+
+    } while (0);
+
+    if (globaltext) {
+        GlobalUnlock(globaltext);
+    }
+
+    if (text) {
+        lib_free(text);
+    }
+
+    if (clipboard_is_open) {
+        CloseClipboard();
+    }
+}
+
+static void ui_paste_clipboard_text(HWND window)
+{
+    HANDLE hdata;
+    BOOL clipboard_is_open = FALSE;
+    char * text = NULL;
+    char * text_in_petscii = NULL;
+    
+    do {
+        DWORD size;
+
+        if ( ! OpenClipboard(window) ) {
+            break;
+        }
+
+        clipboard_is_open = TRUE;
+
+        hdata = GetClipboardData(CF_TEXT);
+
+        if ( ! hdata ) {
+            break;
+        }
+
+        text = GlobalLock(hdata);
+
+        if (text == NULL) {
+            break;
+        }
+
+        size = GlobalSize(hdata);
+
+        if (size < 1) {
+            break;
+        }
+
+        /*
+         * Allocate memmory for the string to convert in petscii.
+         * Note: As we are not sure if the original text is null-terminated,
+         *       do *not* use lib_stralloc()!
+         */
+        text_in_petscii = lib_malloc(size + 1);
+
+        if (text_in_petscii == NULL) {
+            break;
+        }
+
+        memcpy(text_in_petscii, text, size);
+        text_in_petscii[size] = 0;
+
+        charset_petconvstring(text_in_petscii, 0);
+
+        kbdbuf_feed(text_in_petscii);
+
+    } while (0);
+
+    if (text_in_petscii) {
+        lib_free(text_in_petscii);
+    }
+
+    if (text) {
+        GlobalUnlock(text);
+    }
+
+    if (clipboard_is_open) {
+        CloseClipboard();
+    }
+}
+
+
 /* ------------------------------------------------------------------------ */
 
 /* FIXME: tmp hack.  */
@@ -1115,22 +1301,39 @@ static void handle_default_command(WPARAM wparam, LPARAM lparam, HWND hwnd)
     }
 }
 
+static void handle_wm_initmenupopup(HMENU menu)
+{
+    /* enable PASTE iff the clipboard contains "our" format: */
+
+    EnableMenuItem(menu, IDM_EDIT_PASTE, 
+        MF_BYCOMMAND 
+        | ( IsClipboardFormatAvailable(CF_TEXT) ? MF_ENABLED : MF_GRAYED));
+}
+
 static void handle_wm_command(WPARAM wparam, LPARAM lparam, HWND hwnd)
 {
+    TCHAR *st_name;
+
+    wparam &= 0xffff;
     /* Handle machine specific commands first.  */
     if (ui_machine_specific)
         ui_machine_specific(wparam, hwnd);
 
     switch (wparam) {
       case IDM_DEVICEMANAGER:
-      case IDM_FORMFEED_PRINTERIEC4 | 0x00010000:
-      case IDM_FORMFEED_PRINTERIEC5 | 0x00010000:
+      case IDM_FORMFEED_PRINTERIEC4:
+      case IDM_FORMFEED_PRINTERIEC5:
         uiperipheral_command(hwnd, wparam);
         break;
-      case IDM_EXIT | 0x00010000:
       case IDM_EXIT:
         PostMessage(hwnd, WM_CLOSE, wparam, lparam);
         break;
+      case IDM_EDIT_COPY:
+        ui_copy_clipboard(hwnd);
+        break;
+      case IDM_EDIT_PASTE:
+        ui_paste_clipboard_text(hwnd);
+        break;
       case IDM_ABOUT:
       case IDM_HELP:
       case IDM_CONTRIBUTORS:
@@ -1139,10 +1342,6 @@ static void handle_wm_command(WPARAM wparam, LPARAM lparam, HWND hwnd)
       case IDM_CMDLINE:
         uihelp_dialog(hwnd, wparam);
         break;
-      case IDM_ATTACH_8 | 0x00010000:
-      case IDM_ATTACH_9 | 0x00010000:
-      case IDM_ATTACH_10 | 0x00010000:
-      case IDM_ATTACH_11 | 0x00010000:
       case IDM_ATTACH_8:
       case IDM_ATTACH_9:
       case IDM_ATTACH_10:
@@ -1151,21 +1350,15 @@ static void handle_wm_command(WPARAM wparam, LPARAM lparam, HWND hwnd)
       case IDM_DETACH_9:
       case IDM_DETACH_10:
       case IDM_DETACH_11:
-      case IDM_DETACH_ALL | 0x00010000:
       case IDM_DETACH_ALL:
-      case IDM_ATTACH_TAPE | 0x00010000:
       case IDM_ATTACH_TAPE:
       case IDM_DETACH_TAPE:
       case IDM_AUTOSTART:
         uiattach_command(hwnd, wparam);
         break;
-      case IDM_FLIP_ADD | 0x00010000:
       case IDM_FLIP_ADD:
-      case IDM_FLIP_REMOVE | 0x00010000:
       case IDM_FLIP_REMOVE:
-      case IDM_FLIP_NEXT | 0x00010000:
       case IDM_FLIP_NEXT:
-      case IDM_FLIP_PREVIOUS | 0x00010000:
       case IDM_FLIP_PREVIOUS:
       case IDM_FLIP_LOAD:
       case IDM_FLIP_SAVE:
@@ -1181,40 +1374,32 @@ static void handle_wm_command(WPARAM wparam, LPARAM lparam, HWND hwnd)
       case IDM_DATASETTE_RESET_COUNTER:
         uidatasette_command(hwnd, wparam);
         break;
-      case IDM_SNAPSHOT_LOAD | 0x00010000:
       case IDM_SNAPSHOT_LOAD:
         ui_snapshot_load(hwnd);
         break;
-      case IDM_SNAPSHOT_SAVE | 0x00010000:
       case IDM_SNAPSHOT_SAVE:
         ui_snapshot_save(hwnd);
         break;
-      case IDM_SAVEQUICK | 0x00010000:
       case IDM_SAVEQUICK:
         ui_quicksnapshot_save(hwnd);
         break;
-      case IDM_LOADQUICK | 0x00010000:
       case IDM_LOADQUICK:
         ui_quicksnapshot_load(hwnd);
         break;
-      case IDM_MEDIAFILE | 0x00010000:
       case IDM_MEDIAFILE:
         SuspendFullscreenModeKeep(hwnd);
         ui_mediafile_save_dialog(hwnd);
         ResumeFullscreenModeKeep(hwnd);
         break;
       case IDM_SINGLE_FRAME_ADVANCE:
-      case IDM_SINGLE_FRAME_ADVANCE | 0x00010000:
         pause_pending = 1;
         if (!is_paused) {
             break;
         }
         // fall through
       case IDM_PAUSE:
-      case IDM_PAUSE | 0x00010000:
         ui_pause_emulation();
         break;
-      case IDM_MONITOR | 0x00010000:
       case IDM_MONITOR:
         if (!ui_emulation_is_paused())
             monitor_startup_trap();
@@ -1223,8 +1408,6 @@ static void handle_wm_command(WPARAM wparam, LPARAM lparam, HWND hwnd)
             monitor_startup();
 */
         break;
-      case IDM_RESET_HARD + 0x00010000:
-      case IDM_RESET_SOFT + 0x00010000:
       case IDM_RESET_HARD:
       case IDM_RESET_SOFT:
         reset_dialog_proc(wparam);
@@ -1251,7 +1434,6 @@ static void handle_wm_command(WPARAM wparam, LPARAM lparam, HWND hwnd)
       case IDM_JOY_SETTINGS:
         ui_joystick_settings_dialog(hwnd);
         break;
-      case IDM_SWAP_JOYSTICK | 0x00010000:
       case IDM_SWAP_JOYSTICK:
         ui_joystick_swap_joystick();
         break;
@@ -1261,11 +1443,54 @@ static void handle_wm_command(WPARAM wparam, LPARAM lparam, HWND hwnd)
       case IDM_RAM_SETTINGS:
         ui_ram_settings_dialog(hwnd);
         break;
-      case IDM_TOGGLE_FULLSCREEN | 0x00010000:
       case IDM_TOGGLE_FULLSCREEN:
         vsync_suspend_speed_eval();
         SwitchFullscreenMode(hwnd);
         break;
+      case IDM_SETTINGS_SAVE_FILE:
+          if ((st_name = uilib_select_file(hwnd, translate_text(IDS_SAVE_CONFIG_FILE),
+              UILIB_FILTER_ALL, UILIB_SELECTOR_TYPE_FILE_SAVE,
+              UILIB_SELECTOR_STYLE_DEFAULT)) != NULL)
+          {
+              char *name;
+
+              name = system_wcstombs_alloc(st_name);
+
+              if (resources_save(st_name) < 0)
+              {
+                  ui_error(translate_text(IDS_CANNOT_SAVE_SETTINGS));
+              }
+              else
+              {
+                  ui_message(translate_text(IDS_SETTINGS_SAVED_SUCCESS));
+              }
+              uifliplist_save_settings();
+              system_wcstombs_free(name);
+              lib_free(st_name);
+          }
+          break;
+      case IDM_SETTINGS_LOAD_FILE:
+          if ((st_name = uilib_select_file(hwnd, translate_text(IDS_LOAD_CONFIG_FILE),
+              UILIB_FILTER_ALL, UILIB_SELECTOR_TYPE_FILE_LOAD,
+              UILIB_SELECTOR_STYLE_DEFAULT)) != NULL)
+          {
+              char *name;
+
+              name = system_wcstombs_alloc(st_name);
+
+              if (resources_load(st_name) < 0)
+              {
+                  ui_error(translate_text(IDS_CANNOT_LOAD_SETTINGS));
+              }
+              else
+              {
+                  ui_message(translate_text(IDS_SETTINGS_LOADED_SUCCESS));
+              }
+              uifliplist_save_settings();
+              system_wcstombs_free(name);
+              lib_free(st_name);
+          }
+          break;
       case IDM_SETTINGS_SAVE:
         if (resources_save(NULL) < 0)
             ui_error(translate_text(IDS_CANNOT_SAVE_SETTINGS));
@@ -1288,9 +1513,7 @@ static void handle_wm_command(WPARAM wparam, LPARAM lparam, HWND hwnd)
       case IDM_EVENT_TOGGLE_RECORD:
       case IDM_EVENT_TOGGLE_PLAYBACK:
       case IDM_EVENT_SETMILESTONE:
-      case IDM_EVENT_SETMILESTONE | 0x00010000:
       case IDM_EVENT_RESETMILESTONE:
-      case IDM_EVENT_RESETMILESTONE | 0x00010000:
         uievent_command(hwnd, wparam);
         break;
       case IDM_NETWORK_SETTINGS:
@@ -1427,6 +1650,15 @@ static void ui_wm_dropfiles(HWND window, WPARAM wparam)
     DragFinish(hDrop);
 }
 
+static void ui_redraw_all_windows(void)
+{
+    int i;
+
+    for (i = 0; i < number_of_windows; i++) {
+        InvalidateRect(window_handles[i], NULL, FALSE);
+    }
+}
+
 /* Window procedure.  All messages are handled here.  */
 static long CALLBACK window_proc(HWND window, UINT msg,
                                  WPARAM wparam, LPARAM lparam)
@@ -1442,6 +1674,11 @@ static long CALLBACK window_proc(HWND window, UINT msg,
       case WM_CREATE:
         DragAcceptFiles(window, TRUE);
         return 0;
+      case WM_WINDOWPOSCHANGED:
+        /* SRT: if focus is changed in full-screen mode, this message is sent 
+          Make sure that all windows are repainted.*/
+        ui_redraw_all_windows();
+        break;
       case WM_SETREDRAW:
 //      log_debug("WM_SETREDRAW %s", wparam == TRUE? "TRUE" : "FALSE");
         break;
@@ -1485,7 +1722,13 @@ static long CALLBACK window_proc(HWND window, UINT msg,
         return 0;
       case WM_DRAWITEM:
         statusbar_handle_WMDRAWITEM(wparam,lparam);
+        /* SRT: Make sure that all windows are repainted.
+          This message seems to be a good candidate for the remote desktop. */
+        ui_redraw_all_windows();
         return 0;
+      case WM_INITMENUPOPUP:
+        handle_wm_initmenupopup((HMENU)wparam);
+        break;
       case WM_COMMAND:
         handle_wm_command(wparam, lparam, window);
         return 0;
@@ -1575,6 +1818,9 @@ static long CALLBACK window_proc(HWND window, UINT msg,
       case WM_NCLBUTTONDOWN:
         vsync_suspend_speed_eval();
         break;
+      case WM_RBUTTONDOWN:
+        ui_paste_clipboard_text(window);
+        break;
       case WM_NOTIFY:
         statusbar_notify(window, window_index, wparam, lparam);
         break;
