@@ -30,17 +30,16 @@
 #include <windows.h>
 #include <tchar.h>
 
+#include "intl.h"
 #include "res.h"
 #include "resources.h"
+#include "rs232.h"
 #include "translate.h"
 #include "uiacia.h"
 #include "winmain.h"
-#include "intl.h"
 #include "uilib.h"
 
 
-#define MAXRS232 4
-
 
 static const int interrupt_names[] = {
     IDS_NONE, IDS_IRQ, IDS_NMI, 0
@@ -104,21 +103,21 @@ static void init_acia_dialog(HWND hwnd)
     int xpos;
     int xsize, ysize;
 
-    SetWindowText(hwnd, intl_translate_text_new(IDS_ACIA_CAPTION));
+    SetWindowText(hwnd, translate_text(IDS_ACIA_CAPTION));
     temp_hwnd = GetDlgItem(hwnd, IDC_ACIA_ENABLE);
-    SetWindowText(temp_hwnd, intl_translate_text_new(IDS_ACIA_ENABLE));
+    SetWindowText(temp_hwnd, translate_text(IDS_ACIA_ENABLE));
     temp_hwnd = GetDlgItem(hwnd, IDC_ACIA_DEVICE_LABEL);
-    SetWindowText(temp_hwnd, intl_translate_text_new(IDS_ACIA_DEVICE));
+    SetWindowText(temp_hwnd, translate_text(IDS_ACIA_DEVICE));
     temp_hwnd = GetDlgItem(hwnd, IDC_ACIA_LOCATION_LABEL);
-    SetWindowText(temp_hwnd, intl_translate_text_new(IDS_ACIA_LOCATION));
+    SetWindowText(temp_hwnd, translate_text(IDS_ACIA_LOCATION));
     temp_hwnd = GetDlgItem(hwnd, IDC_ACIA_INTERRUPT_LABEL);
-    SetWindowText(temp_hwnd, intl_translate_text_new(IDS_ACIA_INTERRUPT));
+    SetWindowText(temp_hwnd, translate_text(IDS_ACIA_INTERRUPT));
     temp_hwnd = GetDlgItem(hwnd, IDC_ACIA_MODE_LABEL);
-    SetWindowText(temp_hwnd, intl_translate_text_new(IDS_ACIA_MODE));
+    SetWindowText(temp_hwnd, translate_text(IDS_ACIA_MODE));
     temp_hwnd = GetDlgItem(hwnd, IDOK);
-    SetWindowText(temp_hwnd, intl_translate_text_new(IDS_OK));
+    SetWindowText(temp_hwnd, translate_text(IDS_OK));
     temp_hwnd = GetDlgItem(hwnd, IDCANCEL);
-    SetWindowText(temp_hwnd, intl_translate_text_new(IDS_CANCEL));
+    SetWindowText(temp_hwnd, translate_text(IDS_CANCEL));
 
     GetClientRect(hwnd, &rect);
 
@@ -209,7 +208,7 @@ static void init_acia_dialog(HWND hwnd)
 
     resources_get_int("Acia1Dev", &res_value);
     temp_hwnd = GetDlgItem(hwnd, IDC_ACIA_DEVICE);
-    for (i = 0; i < MAXRS232; i++) {
+    for (i = 0; i < RS232_NUM_DEVICES; i++) {
         TCHAR st[20];
         _stprintf(st, translate_text(IDS_RS232_DEVICE_I), i + 1);
         SendMessage(temp_hwnd, CB_ADDSTRING, 0, (LPARAM)st);
@@ -224,7 +223,7 @@ static void init_acia_dialog(HWND hwnd)
         for (res_value_loop = 0; interrupt_names[res_value_loop];
             res_value_loop++) {
             SendMessage(temp_hwnd, CB_ADDSTRING, 0,
-                        (LPARAM)(TCHAR *)intl_translate_text_new(interrupt_names[res_value_loop]));
+                        (LPARAM)(TCHAR *)translate_text(interrupt_names[res_value_loop]));
         }
         SendMessage(temp_hwnd, CB_SETCURSEL, (WPARAM)res_value, 0);
     }
@@ -237,7 +236,7 @@ static void init_acia_dialog(HWND hwnd)
         for (res_value_loop = 0; mode_names[res_value_loop];
             res_value_loop++) {
             SendMessage(temp_hwnd, CB_ADDSTRING, 0,
-                        (LPARAM)(TCHAR *)intl_translate_text_new(mode_names[res_value_loop]));
+                        (LPARAM)(TCHAR *)translate_text(mode_names[res_value_loop]));
         }
         SendMessage(temp_hwnd, CB_SETCURSEL, (WPARAM)res_value, 0);
     }
