@@ -32,6 +32,7 @@
 #include <windows.h>
 
 #include "cartridge.h"
+#include "intl.h"
 #include "keyboard.h"
 #include "lib.h"
 #include "res.h"
@@ -85,6 +86,18 @@ static const uicart_params_t c64_ui_cartridges[] = {
         IDS_ATTACH_AR3_CART_IMAGE,
         UILIB_FILTER_ALL | UILIB_FILTER_BIN
     },
+    {
+        IDM_CART_ATTACH_AR4,
+        CARTRIDGE_ACTION_REPLAY4,
+        IDS_ATTACH_AR4_CART_IMAGE,
+        UILIB_FILTER_ALL | UILIB_FILTER_BIN
+    },
+    {
+        IDM_CART_ATTACH_STARDOS,
+        CARTRIDGE_STARDOS,
+        IDS_ATTACH_STARDOS_CART_IMAGE,
+        UILIB_FILTER_ALL | UILIB_FILTER_BIN
+    },
     {
         IDM_CART_ATTACH_AT,
         CARTRIDGE_ATOMIC_POWER,
@@ -152,12 +165,14 @@ static void uic64cart_attach(WPARAM wparam, HWND hwnd,
 
 void uic64cart_proc(WPARAM wparam, HWND hwnd)
 {
-    switch (wparam) {
+    switch (wparam & 0xffff) {
       case IDM_CART_ATTACH_CRT:
       case IDM_CART_ATTACH_8KB:
       case IDM_CART_ATTACH_16KB:
       case IDM_CART_ATTACH_AR:
       case IDM_CART_ATTACH_AR3:
+      case IDM_CART_ATTACH_AR4:
+      case IDM_CART_ATTACH_STARDOS:
       case IDM_CART_ATTACH_AT:
       case IDM_CART_ATTACH_EPYX:
       case IDM_CART_ATTACH_IEEE488:
@@ -175,7 +190,6 @@ void uic64cart_proc(WPARAM wparam, HWND hwnd)
       case IDM_CART_DETACH:
         cartridge_detach_image();
         break;
-      case IDM_CART_FREEZE|0x00010000:
       case IDM_CART_FREEZE:
         keyboard_clear_keymatrix();
         cartridge_trigger_freeze();
