@@ -33,7 +33,7 @@
 struct uicart_params_s {
     WPARAM wparam;
     int type;
-    TCHAR *title;
+    int title;
     DWORD filter;
 };
 typedef struct uicart_params_s uicart_params_t;
