@@ -25,28 +25,35 @@
  *
  */
 
+#include "config.h"
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <windows.h>
 
 #include "cmdline.h"
+#include "intl.h"
 #include "lib.h"
+#include "translate.h"
 #include "uilib.h"
 
 
-/* This does not work as stdout is directed to null.  */
+/* This does not work as stdout is directed to null.
+   This function is temporarily extended during the
+   transition to string tables.  */
+
 void ui_cmdline_show_help(unsigned int num_options,
-                          cmdline_option_ram_t *options, void *userparam)
+                          cmdline_option_ram_t *options,
+                          void *userparam)
 {
     unsigned int i;
 
     printf("\nAvailable command-line options:\n\n");
     for (i = 0; i < num_options; i++) {
         fputs(options[i].name, stdout);
-        if (options[i].need_arg && options[i].param_name != NULL)
-            printf(" %s", options[i].param_name);
-        printf("\n\t%s\n", options[i].description);
+        if (options[i].need_arg && cmdline_options_get_param(i) != NULL)
+            printf(" %s", cmdline_options_get_param(i));
+        printf("\n\t%s\n", cmdline_options_get_description(i));
     }
     putchar('\n');
 }
-
