@@ -32,9 +32,11 @@
 
 #include "archdep.h"
 #include "fliplist.h"
+#include "intl.h"
 #include "lib.h"
 #include "res.h"
 #include "system.h"
+#include "translate.h"
 #include "ui.h"
 #include "uilib.h"
 #include "util.h"
@@ -44,14 +46,14 @@ static void uifliplist_load_dialog(HWND hwnd)
 {
     TCHAR *st_name;
 
-    if ((st_name = uilib_select_file(hwnd, TEXT("Load flip list file"),
+    if ((st_name = uilib_select_file(hwnd, translate_text(IDS_LOAD_FLIP_LIST_FILE),
         UILIB_FILTER_FLIPLIST, UILIB_SELECTOR_TYPE_FILE_LOAD,
         UILIB_SELECTOR_STYLE_DEFAULT)) != NULL) {
         char *name;
 
         name = system_wcstombs_alloc(st_name);
         if (fliplist_load_list((unsigned int)-1, name, 0) != 0)
-            ui_error("Cannot read flip list file");
+            ui_error(translate_text(IDS_CANNOT_READ_FLIP_LIST));
         system_wcstombs_free(name);
         lib_free(st_name);
     }
@@ -61,7 +63,7 @@ static void uifliplist_save_dialog(HWND hwnd)
 {
     TCHAR *st_name;
 
-    if ((st_name = uilib_select_file(hwnd, TEXT("Save flip list file"),
+    if ((st_name = uilib_select_file(hwnd, translate_text(IDS_SAVE_FLIP_LIST_FILE),
         UILIB_FILTER_FLIPLIST, UILIB_SELECTOR_TYPE_FILE_SAVE,
         UILIB_SELECTOR_STYLE_DEFAULT)) != NULL) {
         char *name;
@@ -71,7 +73,7 @@ static void uifliplist_save_dialog(HWND hwnd)
         util_add_extension(&name, "vfl");
 
         if (fliplist_save_list((unsigned int)-1, name) != 0)
-            ui_error("Cannot write flip list file");
+            ui_error(translate_text(IDS_CANNOT_WRITE_FLIP_LIST));
         system_wcstombs_free(name);
         lib_free(st_name);
     }
@@ -87,20 +89,16 @@ void uifliplist_save_settings(void)
 
 void uifliplist_command(HWND hwnd, WPARAM wparam)
 {
-    switch (wparam) {
-      case IDM_FLIP_ADD | 0x00010000:
+    switch (wparam & 0xffff) {
       case IDM_FLIP_ADD:
         fliplist_add_image(8);
         break;
-      case IDM_FLIP_REMOVE | 0x00010000:
       case IDM_FLIP_REMOVE:
         fliplist_remove(8, NULL);
         break;
-      case IDM_FLIP_NEXT | 0x00010000:
       case IDM_FLIP_NEXT:
         fliplist_attach_head(8, 1);
         break;
-      case IDM_FLIP_PREVIOUS | 0x00010000:
       case IDM_FLIP_PREVIOUS:
         fliplist_attach_head(8, 0);
         break;
