@@ -31,6 +31,7 @@
 #include <tchar.h>
 #include <windows.h>
 
+#include "intl.h"
 #include "lib.h"
 #include "res.h"
 #include "resources.h"
@@ -39,7 +40,6 @@
 #include "uiide64.h"
 #include "uilib.h"
 #include "winmain.h"
-#include "intl.h"
 
 
 static void enable_ide64_controls(HWND hwnd)
@@ -72,7 +72,7 @@ static void update_text(HWND hwnd)
 
     total = (cylinders_idx + 1) * (heads_idx + 1) * sectors_idx / 2;
 
-    str = lib_msprintf(intl_translate_text_new(IDS_IDE64_TOTAL_SIZE), total);
+    str = lib_msprintf(translate_text(IDS_IDE64_TOTAL_SIZE), total);
     st = system_mbstowcs_alloc(str);
     SetDlgItemText(hwnd, IDC_IDE64_SIZE, st);
     system_mbstowcs_free(st);
@@ -192,7 +192,7 @@ static BOOL CALLBACK dialog_proc(HWND hwnd, UINT msg, WPARAM wparam,
         command = LOWORD(wparam);
         switch (command) {
           case IDC_IDE64_HDIMAGE_BROWSE:
-            uilib_select_browse(hwnd, intl_translate_text_new(IDS_IDE64_SELECT_IMAGE),
+            uilib_select_browse(hwnd, translate_text(IDS_IDE64_SELECT_IMAGE),
                                 UILIB_FILTER_ALL,
                                 UILIB_SELECTOR_TYPE_FILE_SAVE,
                                 IDC_IDE64_HDIMAGE_FILE);
