@@ -44,6 +44,7 @@
 #include "diskimage.h"
 #include "fullscrn.h"
 #include "imagecontents.h"
+#include "intl.h"
 #include "lib.h"
 #include "res.h"
 #include "resources.h"
@@ -55,7 +56,6 @@
 #include "vdrive-internal.h"
 #include "vsync.h"
 #include "winmain.h"
-#include "intl.h"
 
 
 /* Mingw & pre VC 6 headers doesn't have this definition */
@@ -77,11 +77,13 @@ typedef struct uilib_filefilter_s uilib_filefilter_t;
 
 static uilib_filefilter_t uilib_filefilter[] = {
     { IDS_ALL_FILES_FILTER, TEXT("*.*") },
+    { IDS_ZIPPED_FILES_FILTER, TEXT("*.zip;*.bz2;*.gz;*.d6z;*.d7z;*.d8z;*.g6z;*.g4z;*.x6z") },
     { IDS_PALETTE_FILES_FILTER, TEXT("*.vpl") },
     { IDS_SNAPSHOT_FILES_FILTER, TEXT("*.vsf") },
+    { IDS_PRGP00_FILES_FILTER, TEXT("*.prg;*.p00") },
+    { IDS_TAPE_IMAGE_FILES_FILTER, TEXT("*.t64;*.tap") },
     { IDS_DISK_IMAGE_FILES_FILTER, TEXT("*.d64;*.d71;*.d80;*.d81;*.d82;*.g64;*.g41;*.x64") },
-    { IDS_TAPE_IMAGE_FILES_FILTER, TEXT("*.t64;*.p00;*.tap;*.prg") },
-    { IDS_ZIPPED_FILES_FILTER, TEXT("*.zip;*.bz2;*.gz;*.d6z;*.d7z;*.d8z;*.g6z;*.g4z;*.x6z") },
+    { IDS_CBM_IMAGE_FILES_FILTER, TEXT("*.d64;*.d71;*.d80;*.d81;*.d82;*.g64;*.g41;*.x64;*.t64;*.tap;*.prg;*.p00") },
     { IDS_CRT_FILES_FILTER, TEXT("*.crt") },
     { IDS_RAW_CART_FILES_FILTER, TEXT("*.bin") },
     { IDS_FLIP_LIST_FILES_FILTER, TEXT("*.vfl") },
@@ -516,83 +518,81 @@ static UINT APIENTRY uilib_select_hook_proc(HWND hwnd, UINT uimsg,
     return 0;
 }
 
-/* The following stuff implements a history for the file filter.    */
-/* The filter selected by the user in the OpenFile window is        */
-/* gets the default one in the next OpenFile window                 */
-/* As the same window is used for different file types and          */
-/* filter lists some more work has to be done...                    */
-#define UI_LIB_FILTER_HISTORY_LENGTH   8
-static DWORD last_filterlist;
-static DWORD filter_history[UI_LIB_FILTER_HISTORY_LENGTH];
-static DWORD filter_history_current;
+static struct filter_per_list_s {
+    DWORD filterlist;
+    DWORD active_filter;
+    struct filter_per_list_s *next;
+};
 
-static DWORD get_index_from_filterbit(DWORD filterbit, DWORD filterlist)
+typedef struct filter_per_list_s filter_per_list_t;
+static filter_per_list_t filter_history;
+static filter_per_list_t *filter_history_last;
+
+
+static void update_filter_history(DWORD current_filter, DWORD last_filterlist)
 {
-    DWORD b;
-    int j = 0;
+    filter_per_list_t *fl = filter_history.next;
 
-    for (b = 1; b <= filterbit; b <<= 1) {
-        if (filterlist & b)
-            j++;
-        if (b == filterbit)
-            break;
+    if (filter_history_last == NULL)
+        filter_history_last = &filter_history;
+
+    while (fl && fl->filterlist != last_filterlist)
+        fl = fl->next;
+
+    if (fl) {
+        fl->active_filter = current_filter;
+    } else {
+        fl = lib_malloc(sizeof(filter_per_list_t));
+        fl->filterlist = last_filterlist;
+        fl->active_filter = current_filter;
+        fl->next = NULL;
+        filter_history_last->next = fl;
+        filter_history_last = fl;
     }
-
-    return j;
 }
 
-static void update_filter_history(DWORD current_filter)
+static DWORD get_last_active_filter(DWORD last_filterlist)
 {
-    int i;
-    DWORD b;
-    for (i = 0, b = 1; uilib_filefilter[i].name != 0; i++, b <<= 1) {
-        if ((b & last_filterlist) 
-            && (get_index_from_filterbit(b, last_filterlist)
-            == current_filter)) {
-            filter_history[filter_history_current++] = b;
-            if (filter_history_current >= UI_LIB_FILTER_HISTORY_LENGTH)
-                filter_history_current = 0;
-            break;
-        }
-    }
+    filter_per_list_t *fl = filter_history.next;
+
+    while (fl && fl->filterlist != last_filterlist)
+        fl = fl->next;
+
+    if (fl)
+        return fl->active_filter;
+    else
+        return 0;
 }
 
 static TCHAR *set_filter(DWORD filterlist, DWORD *filterindex)
 {
-    DWORD i, j, k, l;
+    DWORD i;
     DWORD b;
-    TCHAR *filter, *current;
+    TCHAR *filter;
+    DWORD current_len, name_len, pattern_len;
 
-    filter = lib_malloc(UILIB_FILTER_LENGTH_MAX * sizeof(TCHAR));
+    filter = lib_malloc(sizeof(TCHAR));
 
-    current = filter;
+    *filter = TEXT('\0');
 
-    last_filterlist = filterlist;
-
-    *filterindex = 0;
+    current_len = 1;
 
     /* create the strings for the file filters */
     for (i = 0, b = 1; uilib_filefilter[i].name != 0; i++, b <<= 1) {
         if (filterlist & b) {
-            j = _tcslen(translate_text(uilib_filefilter[i].name)) + 1;
-            memcpy(current, translate_text(uilib_filefilter[i].name), j * sizeof(TCHAR));
-            current += j;
-
-            j = _tcslen(uilib_filefilter[i].pattern) + 1;
-            memcpy(current, uilib_filefilter[i].pattern, j * sizeof(TCHAR));
-            current += j;
+            name_len = (_tcslen(translate_text(uilib_filefilter[i].name)) + 1) * sizeof(TCHAR);
+            pattern_len = (_tcslen(uilib_filefilter[i].pattern) + 1) * sizeof(TCHAR);
+            filter = lib_realloc(filter, current_len + name_len + pattern_len);
+            memmove(filter + name_len + pattern_len, filter, current_len);
+            memcpy(filter, translate_text(uilib_filefilter[i].name), name_len);
+            memcpy(filter + name_len, uilib_filefilter[i].pattern, pattern_len);
+            current_len += name_len + pattern_len;
         }
     }
 
-    *current = TEXT('\0');
-
     /* search for the most recent file filter */
-    for (k = 1; k <= UI_LIB_FILTER_HISTORY_LENGTH && *filterindex == 0; k++) {
-        l = (filter_history_current - k) % UI_LIB_FILTER_HISTORY_LENGTH;
-        if (filter_history[l] & filterlist)
-            *filterindex = get_index_from_filterbit(filter_history[l],
-                                                    filterlist);
-    }
+    *filterindex = get_last_active_filter(filterlist);
+
     if (*filterindex == 0)
         *filterindex = 1;    /* not in history: choose first filter */
 
@@ -695,7 +695,7 @@ TCHAR *uilib_select_file_autostart(HWND hwnd, const TCHAR *title,
     else
         result = GetOpenFileName(&ofn);
 
-    update_filter_history(ofn.nFilterIndex);
+    update_filter_history(ofn.nFilterIndex, filterlist);
 
     if (result) {
         char *tmpdir, *tmpfile;
@@ -896,12 +896,21 @@ void uilib_show_options(HWND param)
 void uilib_shutdown(void)
 {
     int i;
+    filter_per_list_t *f1, *f2;
 
     for (i = 0; i < UILIB_SELECTOR_STYLES_NUM; i++)
         if (ui_file_selector_initialfile[i] != NULL)
             lib_free(ui_file_selector_initialfile[i]);
 
     lib_free(fontfile);
+
+    f1 = filter_history.next;
+
+    while (f1) {
+        f2 = f1;
+        f1 = f1->next;
+        lib_free(f2);
+    }
 }
 
 static uilib_dialogbox_param_t *uilib_dialogbox_param;
@@ -1085,12 +1094,11 @@ HWND element;
 
     while (param->idc || param->ids) {
         if (param->element_type == -1) {
-            SetWindowText(hwnd, intl_translate_text_new(param->ids));
+            SetWindowText(hwnd, translate_text(param->ids));
         } else if (param->element_type == 0) {
             element = GetDlgItem(hwnd, param->idc);
-            SetWindowText(element, intl_translate_text_new(param->ids));
+            SetWindowText(element, translate_text(param->ids));
         }
         param++;
     }
 }
-
