@@ -34,6 +34,7 @@
 #include <commctrl.h>
 
 #include "console.h"
+#include "debug.h"
 #include "fullscrn.h"
 #include "lib.h"
 #include "mon_register.h"
@@ -669,7 +670,7 @@ WindowType GetNextMonitorDimensions( PWindowDimensions pwd )
     {
         ret = GetByte(&(pwd->pMonitorDimensions),&pwd->MonitorLen);
 
-        if (pwd->MonitorLen < sizeof(WINDOWPLACEMENT))
+        if (pwd->MonitorLen < (int)sizeof(WINDOWPLACEMENT))
         {
             ret = WT_END;
 
@@ -1153,7 +1154,7 @@ long CALLBACK mon_window_proc(HWND hwnd,
         hwndToolbar = CreateAToolbar(hwnd);
 
         EnableCommands(GetMenu(hwnd),hwndToolbar);
-
+        ui_translate_monitor_menu(GetMenu(hwnd));
         {
             CLIENTCREATESTRUCT ccs;
             ccs.hWindowMenu  = GetSubMenu(GetMenu(hwnd),3);
@@ -2011,7 +2012,7 @@ void uimon_init( void )
         wc.hIcon         = LoadIcon(winmain_instance, MAKEINTRESOURCE(IDI_ICON1));
         wc.hCursor       = LoadCursor(NULL, IDC_ARROW);
         wc.hbrBackground = (HBRUSH)CreateSolidBrush(RGB(0xc0, 0xc0, 0xc0));
-        wc.lpszMenuName  = MAKEINTRESOURCE(translate_res(IDR_MENUMONITOR));
+        wc.lpszMenuName  = MAKEINTRESOURCE(IDR_MENUMONITOR);
         wc.lpszClassName = MONITOR_CLASS;
         wc.hIconSm       = NULL;
 
