@@ -32,6 +32,7 @@
 #include <windows.h>
 #include <tchar.h>
 
+#include "intl.h"
 #include "res.h"
 #include "resources.h"
 #include "system.h"
@@ -39,7 +40,6 @@
 #include "uilib.h"
 #include "uipetreu.h"
 #include "winmain.h"
-#include "intl.h"
 
 
 #define NUM_OF_PETREU_SIZE 4
@@ -144,7 +144,7 @@ static void end_petreu_dialog(HWND hwnd)
 
 static void browse_petreu_file(HWND hwnd)
 {
-    uilib_select_browse(hwnd, intl_translate_text_new(IDS_PETREU_SELECT_FILE),
+    uilib_select_browse(hwnd, translate_text(IDS_PETREU_SELECT_FILE),
                         UILIB_FILTER_ALL, UILIB_SELECTOR_TYPE_FILE_SAVE,
                         IDC_PETREU_FILE);
 }
