@@ -27,9 +27,8 @@
 #ifndef _UISNAPSHOT_H
 #define _UISNAPSHOT_H
 
-extern void ui_snapshot_load_dialog(HWND hwnd);
-extern void ui_snapshot_save_dialog(HWND hwnd);
-extern char *ui_save_snapshot(const char *title, const char *filter, 
-                              HWND hwnd, int dialog_template);
+extern void ui_snapshot_load(HWND hwnd);
+extern void ui_snapshot_save(HWND hwnd);
 
 #endif
+
