@@ -40,6 +40,7 @@
 #define DUMMYUNIONNAME  u1
 #endif
 
+#include "intl.h"
 #include "lib.h"
 #include "res.h"
 #include "resources.h"
@@ -118,13 +119,6 @@ static Chip_Parameters chip_param_table[] =
       UI_VIDEO_PAL, "TED Palette"},
 };
 
-static char *modes[5]=
-{
-    "Fast PAL",
-    "PAL Emulation",
-    NULL
-};
-
 /*
 static void enable_controls_for_video_settings(HWND hwnd, int type)
 {
@@ -158,6 +152,29 @@ static void init_color_dialog(HWND hwnd)
 
 }
 
+static void init_new_pal_dialog(HWND hwnd)
+{
+    int val;
+    double fval;
+    TCHAR newval[64];
+
+    resources_get_int("ColorTint", &val);
+                      fval = ((double)val) / 1000.0;
+                      _stprintf(newval, TEXT("%.3f"), (float)fval);
+    SetDlgItemText(hwnd, IDC_VIDEO_NEW_PAL_TINT, newval);
+
+    resources_get_int("PALOddLinePhase", &val);
+                      fval = ((double)val) / 1000.0;
+                      _stprintf(newval, TEXT("%.3f"), (float)fval);
+    SetDlgItemText(hwnd, IDC_VIDEO_NEW_PAL_PHASE, newval);
+
+    resources_get_int("PALOddLineOffset", &val);
+                      fval = ((double)val) / 1000.0;
+                      _stprintf(newval, TEXT("%.3f"), (float)fval);
+    SetDlgItemText(hwnd, IDC_VIDEO_NEW_PAL_OFFSET, newval);
+
+}
+
 static Chip_Parameters *current_chip;
 static Chip_Parameters *current_chip2;
 
@@ -190,16 +207,6 @@ static void init_advanced_dialog(HWND hwnd, Chip_Parameters *chip_type)
                         _stprintf(newval, TEXT("%.3f"), (float)fval);
     SetDlgItemText(hwnd, IDC_VIDEO_ADVANCED_BLUR, newval);
 
-    filename_hwnd = GetDlgItem(hwnd, IDC_VIDEO_ADVANCED_MODE);
-    SendMessage(filename_hwnd, CB_RESETCONTENT, 0, 0);
-    n = 0;
-    while (modes[n] != NULL) {
-        SendMessage(filename_hwnd, CB_ADDSTRING, 0, (LPARAM)modes[n]);
-        n++;
-    }
-    resources_get_int("PALMode", &val);
-    SendMessage(filename_hwnd, CB_SETCURSEL, (WPARAM)val, 0);
-
     if (chip_type->res_ExternalPalette_name) {
         resources_get_int(chip_type->res_ExternalPalette_name, &n);
         CheckDlgButton(hwnd, IDC_TOGGLE_VIDEO_EXTPALETTE, n
@@ -274,7 +281,7 @@ static BOOL CALLBACK dialog_color_proc(HWND hwnd, UINT msg,
 
     switch (msg) {
       case WM_NOTIFY:
-        if (((NMHDR FAR *)lparam)->code == PSN_APPLY) {
+        if (((NMHDR FAR *)lparam)->code == (UINT)PSN_APPLY) {
             GetDlgItemText(hwnd, IDC_VIDEO_COLORS_SAT, s, 100);
             _stscanf(s, TEXT("%f"), &tf);
             ival = (int)(tf * 1000.0 + 0.5);
@@ -308,6 +315,50 @@ static BOOL CALLBACK dialog_color_proc(HWND hwnd, UINT msg,
     return FALSE;
 }
 
+static BOOL CALLBACK dialog_new_pal_proc(HWND hwnd, UINT msg,
+                                       WPARAM wparam, LPARAM lparam)
+{
+    int type, ival;
+    float tf;
+    TCHAR s[100];
+    extern int querynewpalette;
+
+    switch (msg) {
+      case WM_NOTIFY:
+        if (((NMHDR FAR *)lparam)->code == PSN_APPLY) {
+            GetDlgItemText(hwnd, IDC_VIDEO_NEW_PAL_TINT, s, 100);
+            _stscanf(s, TEXT("%f"), &tf);
+            ival = (int)(tf * 1000.0 + 0.5);
+            resources_set_int("ColorTint", ival);
+            GetDlgItemText(hwnd, IDC_VIDEO_NEW_PAL_PHASE, s, 100);
+            _stscanf(s, TEXT("%f"), &tf);
+            ival = (int)(tf * 1000.0 + 0.5);
+            resources_set_int("PALOddLinePhase", ival);
+            GetDlgItemText(hwnd, IDC_VIDEO_NEW_PAL_OFFSET, s, 100);
+            _stscanf(s, TEXT("%f"), &tf);
+            ival = (int)(tf * 1000.0 + 0.5);
+            resources_set_int("PALOddLineOffset", ival);
+            querynewpalette = 1;
+            SetWindowLong(hwnd, DWL_MSGRESULT, FALSE);
+            return TRUE;
+        }
+        return FALSE;
+      case WM_INITDIALOG:
+        init_new_pal_dialog(hwnd);
+        return TRUE;
+      case WM_COMMAND:
+        type = LOWORD(wparam);
+        switch (type) {
+          case IDC_VIDEO_NEW_PAL_TINT:
+          case IDC_VIDEO_NEW_PAL_PHASE:
+          case IDC_VIDEO_NEW_PAL_OFFSET:
+            break;
+        }
+        return TRUE;
+    }
+    return FALSE;
+}
+
 static BOOL CALLBACK dialog_advanced_proc(HWND hwnd, UINT msg,
                                           WPARAM wparam, LPARAM lparam)
 {
@@ -318,7 +369,7 @@ static BOOL CALLBACK dialog_advanced_proc(HWND hwnd, UINT msg,
 
     switch (msg) {
       case WM_NOTIFY:
-        if (((NMHDR FAR *)lparam)->code == PSN_APPLY) {
+        if (((NMHDR FAR *)lparam)->code == (UINT)PSN_APPLY) {
             GetDlgItemText(hwnd, IDC_VIDEO_COLORS_GAM, s, 100);
             _stscanf(s, TEXT("%f"), &tf);
             ival = (int)(tf * 1000.0 + 0.5);
@@ -337,10 +388,6 @@ static BOOL CALLBACK dialog_advanced_proc(HWND hwnd, UINT msg,
             ival = (int)(tf * 1000.0 + 0.5);
             resources_set_int("PALBlur", ival);
 
-            ival = SendMessage(GetDlgItem(hwnd, IDC_VIDEO_ADVANCED_MODE),
-                               CB_GETCURSEL, 0, 0);
-            resources_set_int("PALMode", ival);
-
             querynewpalette = 1;
             if (resources_set_string(current_chip->res_PaletteFile_name,
                 palette_file) < 0) {
@@ -423,7 +470,7 @@ static BOOL CALLBACK dialog_palette_proc(HWND hwnd, UINT msg,
 
     switch (msg) {
       case WM_NOTIFY:
-        if (((NMHDR FAR *)lparam)->code == PSN_APPLY) {
+        if (((NMHDR FAR *)lparam)->code == (UINT)PSN_APPLY) {
             querynewpalette = 1;
             if (resources_set_string(current_chip2->res_PaletteFile_name,
                 palette_file2) < 0) {
@@ -482,12 +529,12 @@ static BOOL CALLBACK dialog_palette_proc(HWND hwnd, UINT msg,
 
 void ui_video_settings_dialog(HWND hwnd, int chip_type1, int chip_type2)
 {
-    PROPSHEETPAGE psp[4];
+    PROPSHEETPAGE psp[5];
     PROPSHEETHEADER psh;
     int i;
     Chip_Parameters *chip_param;
 
-    for (i = 0; i < 4; i++) {
+    for (i = 0; i < 5; i++) {
         psp[i].dwSize = sizeof(PROPSHEETPAGE);
         psp[i].dwFlags = PSP_USETITLE /*| PSP_HASHELP*/ ;
         psp[i].hInstance = winmain_instance;
@@ -508,23 +555,28 @@ void ui_video_settings_dialog(HWND hwnd, int chip_type1, int chip_type2)
         psp[1].pfnDlgProc = dialog_advanced_proc;
         psp[1].pszTitle = system_mbstowcs_alloc(chip_param->page_title);
         psp[1].lParam = (LPARAM)chip_param;
-        psp[2].pfnDlgProc = dialog_color_proc;
-        psp[2].pszTitle = translate_text(IDS_COLORS);
+        psp[2].pfnDlgProc = dialog_new_pal_proc;
+        psp[2].pszTitle = translate_text(IDS_NEW_PAL);
+        psp[3].pfnDlgProc = dialog_color_proc;
+        psp[3].pszTitle = translate_text(IDS_COLORS);
 
 #ifdef _ANONYMOUS_UNION
         psp[0].pszTemplate
             = MAKEINTRESOURCE(translate_res(IDD_FULLSCREEN_SETTINGS_DIALOG));
         psp[1].pszTemplate = MAKEINTRESOURCE(translate_res(IDD_VIDEO_ADVANCED_DIALOG));
-        psp[2].pszTemplate = MAKEINTRESOURCE(translate_res(IDD_VIDEO_COLORS_DIALOG));
+        psp[2].pszTemplate = MAKEINTRESOURCE(translate_res(IDD_VIDEO_NEW_PAL_DIALOG));
+        psp[3].pszTemplate = MAKEINTRESOURCE(translate_res(IDD_VIDEO_COLORS_DIALOG));
 #else
         psp[0].DUMMYUNIONNAME.pszTemplate
             = MAKEINTRESOURCE(translate_res(IDD_FULLSCREEN_SETTINGS_DIALOG));
         psp[1].DUMMYUNIONNAME.pszTemplate
             = MAKEINTRESOURCE(translate_res(IDD_VIDEO_ADVANCED_DIALOG));
         psp[2].DUMMYUNIONNAME.pszTemplate
+            = MAKEINTRESOURCE(translate_res(IDD_VIDEO_NEW_PAL_DIALOG));
+        psp[3].DUMMYUNIONNAME.pszTemplate
             = MAKEINTRESOURCE(translate_res(IDD_VIDEO_COLORS_DIALOG));
 #endif
-        psh.nPages = 3;
+        psh.nPages = 4;
     } else {
         psp[0].pfnDlgProc = dialog_fullscreen_proc;
         psp[0].pszTitle = translate_text(IDS_FULLSCREEN);
