@@ -44,9 +44,7 @@
 #include "resources.h"
 #include "serial.h"
 #include "snapshot.h"
-#ifdef HAS_TRANSLATION
 #include "translate.h"
-#endif
 #include "types.h"
 #include "ui.h"
 #include "vdrive-bam.h"
@@ -117,87 +115,69 @@ int file_system_resources_init(void)
 
 /* ------------------------------------------------------------------------- */
 
-#ifdef HAS_TRANSLATION
 static const cmdline_option_t cmdline_options[] = {
-    { "-device8", SET_RESOURCE, 1, NULL, NULL, "FileSystemDevice8",
-      (void *)ATTACH_DEVICE_FS, IDCLS_P_TYPE,
-      IDCLS_SET_DEVICE_TYPE_8 },
-    { "-device9", SET_RESOURCE, 1, NULL, NULL, "FileSystemDevice9",
-      (void *)ATTACH_DEVICE_FS, IDCLS_P_TYPE,
-      IDCLS_SET_DEVICE_TYPE_9 },
-    { "-device10", SET_RESOURCE, 1, NULL, NULL, "FileSystemDevice10",
-      (void *)ATTACH_DEVICE_FS, IDCLS_P_TYPE,
-      IDCLS_SET_DEVICE_TYPE_10 },
-    { "-device11", SET_RESOURCE, 1, NULL, NULL, "FileSystemDevice11",
-      (void *)ATTACH_DEVICE_FS, IDCLS_P_TYPE,
-      IDCLS_SET_DEVICE_TYPE_11 },
-    { "-attach8ro", SET_RESOURCE, 0, NULL, NULL, "AttachDevice8Readonly",
-      (resource_value_t)1,
-      0, IDCLS_ATTACH_READ_ONLY_8 },
-    { "-attach8rw", SET_RESOURCE, 0, NULL, NULL, "AttachDevice8Readonly",
-      (resource_value_t)0,
-      0, IDCLS_ATTACH_READ_WRITE_8 },
-    { "-attach9ro", SET_RESOURCE, 0, NULL, NULL, "AttachDevice9Readonly",
-      (resource_value_t)1,
-      0, IDCLS_ATTACH_READ_ONLY_9 },
-    { "-attach9rw", SET_RESOURCE, 0, NULL, NULL, "AttachDevice9Readonly",
-      (resource_value_t)0,
-      0, IDCLS_ATTACH_READ_WRITE_9 },
-    { "-attach10ro", SET_RESOURCE, 0, NULL, NULL, "AttachDevice10Readonly",
-      (resource_value_t)1,
-      0, IDCLS_ATTACH_READ_ONLY_10 },
-    { "-attach10rw", SET_RESOURCE, 0, NULL, NULL, "AttachDevice10Readonly",
-      (resource_value_t)0,
-      0, IDCLS_ATTACH_READ_WRITE_10 },
-    { "-attach11ro", SET_RESOURCE, 0, NULL, NULL, "AttachDevice11Readonly",
-      (resource_value_t)1,
-      0, IDCLS_ATTACH_READ_ONLY_11 },
-    { "-attach11rw", SET_RESOURCE, 0, NULL, NULL, "AttachDevice11Readonly",
-      (resource_value_t)0,
-      0, IDCLS_ATTACH_READ_WRITE_11 },
+    { "-device8", SET_RESOURCE, 1, 
+      NULL, NULL, "FileSystemDevice8", (void *)ATTACH_DEVICE_FS,
+      USE_PARAM_ID, USE_DESCRIPTION_ID,
+      IDCLS_P_TYPE, IDCLS_SET_DEVICE_TYPE_8,
+      NULL, NULL },
+    { "-device9", SET_RESOURCE, 1,
+      NULL, NULL, "FileSystemDevice9", (void *)ATTACH_DEVICE_FS,
+      USE_PARAM_ID, USE_DESCRIPTION_ID,
+      IDCLS_P_TYPE, IDCLS_SET_DEVICE_TYPE_9,
+      NULL, NULL },
+    { "-device10", SET_RESOURCE, 1,
+      NULL, NULL, "FileSystemDevice10", (void *)ATTACH_DEVICE_FS,
+      USE_PARAM_ID, USE_DESCRIPTION_ID,
+      IDCLS_P_TYPE, IDCLS_SET_DEVICE_TYPE_10,
+      NULL, NULL },
+    { "-device11", SET_RESOURCE, 1,
+      NULL, NULL, "FileSystemDevice11", (void *)ATTACH_DEVICE_FS,
+      USE_PARAM_ID, USE_DESCRIPTION_ID,
+      IDCLS_P_TYPE, IDCLS_SET_DEVICE_TYPE_11,
+      NULL, NULL },
+    { "-attach8ro", SET_RESOURCE, 0,
+      NULL, NULL, "AttachDevice8Readonly", (resource_value_t)1,
+      USE_PARAM_STRING, USE_DESCRIPTION_ID,
+      IDCLS_UNUSED, IDCLS_ATTACH_READ_ONLY_8,
+      NULL, NULL },
+    { "-attach8rw", SET_RESOURCE, 0,
+      NULL, NULL, "AttachDevice8Readonly", (resource_value_t)0,
+      USE_PARAM_STRING, USE_DESCRIPTION_ID,
+      IDCLS_UNUSED, IDCLS_ATTACH_READ_WRITE_8,
+      NULL, NULL },
+    { "-attach9ro", SET_RESOURCE, 0,
+      NULL, NULL, "AttachDevice9Readonly", (resource_value_t)1,
+      USE_PARAM_STRING, USE_DESCRIPTION_ID,
+      IDCLS_UNUSED, IDCLS_ATTACH_READ_ONLY_9,
+      NULL, NULL },
+    { "-attach9rw", SET_RESOURCE, 0,
+      NULL, NULL, "AttachDevice9Readonly", (resource_value_t)0,
+      USE_PARAM_STRING, USE_DESCRIPTION_ID,
+      IDCLS_UNUSED, IDCLS_ATTACH_READ_WRITE_9,
+      NULL, NULL },
+    { "-attach10ro", SET_RESOURCE, 0,
+      NULL, NULL, "AttachDevice10Readonly", (resource_value_t)1,
+      USE_PARAM_STRING, USE_DESCRIPTION_ID,
+      IDCLS_UNUSED, IDCLS_ATTACH_READ_ONLY_10,
+      NULL, NULL },
+    { "-attach10rw", SET_RESOURCE, 0,
+      NULL, NULL, "AttachDevice10Readonly", (resource_value_t)0,
+      USE_PARAM_STRING, USE_DESCRIPTION_ID,
+      IDCLS_UNUSED, IDCLS_ATTACH_READ_WRITE_10,
+      NULL, NULL },
+    { "-attach11ro", SET_RESOURCE, 0,
+      NULL, NULL, "AttachDevice11Readonly", (resource_value_t)1,
+      USE_PARAM_STRING, USE_DESCRIPTION_ID,
+      IDCLS_UNUSED, IDCLS_ATTACH_READ_ONLY_11,
+      NULL, NULL },
+    { "-attach11rw", SET_RESOURCE, 0,
+      NULL, NULL, "AttachDevice11Readonly", (resource_value_t)0,
+      USE_PARAM_STRING, USE_DESCRIPTION_ID,
+      IDCLS_UNUSED, IDCLS_ATTACH_READ_WRITE_11,
+      NULL, NULL },
     { NULL }
 };
-#else
-static const cmdline_option_t cmdline_options[] = {
-    { "-device8", SET_RESOURCE, 1, NULL, NULL, "FileSystemDevice8",
-      (void *)ATTACH_DEVICE_FS, N_("<type>"),
-      N_("Set device type for device #8 (0: NONE, 1: FS, 2: REAL, 3: RAW)") },
-    { "-device9", SET_RESOURCE, 1, NULL, NULL, "FileSystemDevice9",
-      (void *)ATTACH_DEVICE_FS, N_("<type>"),
-      N_("Set device type for device #9 (0: NONE, 1: FS, 2: REAL, 3: RAW)") },
-    { "-device10", SET_RESOURCE, 1, NULL, NULL, "FileSystemDevice10",
-      (void *)ATTACH_DEVICE_FS, N_("<type>"),
-      N_("Set device type for device #10 (0: NONE, 1: FS, 2: REAL, 3: RAW)") },
-    { "-device11", SET_RESOURCE, 1, NULL, NULL, "FileSystemDevice11",
-      (void *)ATTACH_DEVICE_FS, N_("<type>"),
-      N_("Set device type for device #11 (0: NONE, 1: FS, 2: REAL, 3: RAW)") },
-    { "-attach8ro", SET_RESOURCE, 0, NULL, NULL, "AttachDevice8Readonly",
-      (resource_value_t)1,
-      NULL, N_("Attach disk image for drive #8 read only") },
-    { "-attach8rw", SET_RESOURCE, 0, NULL, NULL, "AttachDevice8Readonly",
-      (resource_value_t)0,
-      NULL, N_("Attach disk image for drive #8 read write (if possible)") },
-    { "-attach9ro", SET_RESOURCE, 0, NULL, NULL, "AttachDevice9Readonly",
-      (resource_value_t)1,
-      NULL, N_("Attach disk image for drive #9 read only") },
-    { "-attach9rw", SET_RESOURCE, 0, NULL, NULL, "AttachDevice9Readonly",
-      (resource_value_t)0,
-      NULL, N_("Attach disk image for drive #9 read write (if possible)") },
-    { "-attach10ro", SET_RESOURCE, 0, NULL, NULL, "AttachDevice10Readonly",
-      (resource_value_t)1,
-      NULL, N_("Attach disk image for drive #10 read only") },
-    { "-attach10rw", SET_RESOURCE, 0, NULL, NULL, "AttachDevice10Readonly",
-      (resource_value_t)0,
-      NULL, N_("Attach disk image for drive #10 read write (if possible)") },
-    { "-attach11ro", SET_RESOURCE, 0, NULL, NULL, "AttachDevice11Readonly",
-      (resource_value_t)1,
-      NULL, N_("Attach disk image for drive #11 read only") },
-    { "-attach11rw", SET_RESOURCE, 0, NULL, NULL, "AttachDevice11Readonly",
-      (resource_value_t)0,
-      NULL, N_("Attach disk image for drive #11 read write (if possible)") },
-    { NULL }
-};
-#endif
 
 int file_system_cmdline_options_init(void)
 {
@@ -590,11 +570,12 @@ static void file_system_detach_disk_single(unsigned int unit)
     vdrive_t *vdrive;
 
     vdrive = file_system_get_vdrive(unit);
-    if (vdrive != NULL)
+    if (vdrive != NULL && vdrive->image != NULL) {
         detach_disk_image_and_free(vdrive->image, vdrive, (unsigned int)unit);
+        ui_display_drive_current_image(unit - 8, "");
+    }
 
     set_file_system_device(file_system_device_enabled[unit - 8], (void *)unit);
-    ui_display_drive_current_image(unit - 8, "");
 }
 
 static void file_system_detach_disk_internal(int unit)
