@@ -26,14 +26,17 @@
  *
  */
 
-#ifndef _AUTOSTART_H
-#define _AUTOSTART_H
+#ifndef VICE_AUTOSTART_H
+#define VICE_AUTOSTART_H
 
 #include "types.h"
 
 #define AUTOSTART_MODE_RUN  0
 #define AUTOSTART_MODE_LOAD 1
 
+extern int autostart_resources_init(void);
+extern int autostart_cmdline_options_init(void);
+
 extern int autostart_init(CLOCK min_cycles, int handle_drive_true_emulation,
                           int blnsw, int pnt, int pntr, int lnmx);
 extern void autostart_shutdown(void);
@@ -50,6 +53,7 @@ extern int autostart_disk(const char *file_name, const char *program_name,
 extern int autostart_tape(const char *file_name, const char *program_name,
                           unsigned int program_number, unsigned int runmode);
 extern int autostart_prg(const char *file_name, unsigned int runmode);
+extern int autostart_snapshot(const char *file_name, const char *program_name);
 
 extern void autostart_disable(void);
 extern void autostart_advance(void);
