@@ -121,7 +121,6 @@ int acia_d7_enabled;
 #endif
 #endif
 
-
 static int set_machine_type(int val, void *param)
 {
     unsigned int type = (unsigned int)val;
@@ -320,7 +319,7 @@ static int set_kernal64_rom_name(const char *val, void *param)
     if (util_string_set(&kernal64_rom_name, val))
         return 0;
 
-    return c128rom_load_kernal64(kernal64_rom_name);
+    return c128rom_load_kernal64(kernal64_rom_name, NULL);
 }
 
 static int set_basic64_rom_name(const char *val, void *param)
