@@ -43,6 +43,7 @@
 #include "c128memrom.h"
 #include "c128mmu.h"
 #include "c128ui.h"
+#include "c64-midi.h"
 #include "c64acia.h"
 #include "c64cia.h"
 #include "c64export.h"
@@ -66,6 +67,7 @@
 #include "kbdbuf.h"
 #include "keyboard.h"
 #include "log.h"
+#include "resources.h"
 #include "machine-drive.h"
 #include "machine-printer.h"
 #include "machine-video.h"
@@ -391,7 +393,6 @@ int machine_resources_init(void)
         || sound_resources_init() < 0
         || sid_resources_init() < 0
         || acia1_resources_init() < 0
-        || acia1_mode_resources_init() < 0
         || rs232drv_resources_init() < 0
         || rsuser_resources_init() < 0
         || serial_resources_init() < 0
@@ -405,6 +406,9 @@ int machine_resources_init(void)
         || drive_resources_init() < 0
         || datasette_resources_init() < 0
         || cartridge_resources_init() < 0
+#ifdef HAVE_MIDI
+        || c64_midi_resources_init() < 0
+#endif
         || mmu_resources_init() < 0
         || z80mem_resources_init() < 0
         || functionrom_resources_init() < 0)
@@ -427,6 +431,9 @@ void machine_resources_shutdown(void)
     printer_resources_shutdown();
     drive_resources_shutdown();
     cartridge_resources_shutdown();
+#ifdef HAVE_MIDI
+    midi_resources_shutdown();
+#endif
     functionrom_resources_shutdown();
 }
 
@@ -463,6 +470,9 @@ int machine_cmdline_options_init(void)
         || drive_cmdline_options_init() < 0
         || datasette_cmdline_options_init() < 0
         || cartridge_cmdline_options_init() < 0
+#ifdef HAVE_MIDI
+        || c64_midi_cmdline_options_init() < 0
+#endif
         || mmu_cmdline_options_init() < 0
         || functionrom_cmdline_options_init() < 0
         || z80mem_cmdline_options_init() < 0)
@@ -609,9 +619,30 @@ int machine_specific_init(void)
 
     cartridge_init();
 
+#ifdef HAVE_MIDI
+    midi_init();
+#endif
+
     mmu_init();
 
     machine_drive_stub();
+#if defined (USE_XF86_EXTENSIONS) && \
+    (defined(USE_XF86_VIDMODE_EXT) || defined (HAVE_XRANDR))
+    {
+	/* set fullscreen if user used `-fullscreen' on cmdline 
+	   use VICII as default */
+	int fs;
+	resources_get_int("UseFullscreen", &fs);
+	if (fs)
+	{
+	    resources_get_int("40/80ColumnKey", &fs);
+	    if (fs == 1)
+		resources_set_int("VICIIFullscreen", 1);
+	    else
+		resources_set_int("VDCFullscreen", 1);
+	}
+    }
+#endif
 
     return 0;
 }
@@ -645,6 +676,10 @@ void machine_specific_reset(void)
     ramcart_reset();
     mmc64_reset();
 
+#ifdef HAVE_MIDI
+    midi_reset();
+#endif
+
     z80mem_initialize();
     z80_reset();
 }
