@@ -31,7 +31,12 @@
 #ifndef _C128MEM_H
 #define _C128MEM_H
 
+#ifdef WATCOM_COMPILE
+#include "../mem.h"
+#else
 #include "mem.h"
+#endif
+
 #include "types.h"
 
 #define C128_RAM_SIZE                   0x20000
