@@ -54,6 +54,10 @@
 #include <fcntl.h>
 #endif
 
+#ifdef HAVE_STRINGS_H
+#include <strings.h>
+#endif
+
 #include "archdep.h"
 #include "cbmdos.h"
 #include "cbmimage.h"
@@ -168,12 +172,10 @@ int network_connected(void)
   return 0;
 }
 
-#ifdef HAVE_NETWORK
 int network_get_mode(void)
 {
   return NETWORK_IDLE;
 }
-#endif
 
 void network_event_record(unsigned int type, void *data, unsigned int size)
 {
@@ -2006,7 +2008,6 @@ static int internal_write_geos_file(int unit, FILE* f)
                                 block[n++] = 0x00;
                             break;
                         }
-                        block[n] = c;
                     }
                     if (numBlks == 1) { /* last block */
                         block[0] = 0;
