@@ -2,7 +2,7 @@
  * c64-resources.h
  *
  * Written by
- *  Andreas Boose <boose@linux.rz.fh-hannover.de>
+ *  Andreas Boose <viceteam@t-online.de>
  *
  * This file is part of VICE, the Versatile Commodore Emulator.
  * See README for copyright notice.
@@ -28,6 +28,7 @@
 #define _C64_RESOURCES_H
 
 extern int c64_resources_init(void);
+extern void c64_resources_shutdown(void);
 
 extern int emu_id_enabled;
 extern int acia_de_enabled;
