@@ -45,9 +45,7 @@
 #include "resources.h"
 #include "reu.h"
 #include "snapshot.h"
-#ifdef HAS_TRANSLATION
 #include "translate.h"
-#endif
 #include "types.h"
 #include "uiapi.h"
 #include "util.h"
@@ -97,11 +95,7 @@ static int set_c64_256k_enabled(int val, void *param)
         return 0;
     } else {
         if (plus60k_enabled || plus256k_enabled) {
-#ifdef HAS_TRANSLATION
             ui_error(translate_text(IDGS_RESOURCE_S_BLOCKED_BY_S),"CPU-LINES", (plus60k_enabled) ? "PLUS60K" : "PLUS256K");
-#else
-            ui_error(_("Resource %s blocked by %s."),"CPU-LINES", (plus60k_enabled) ? "PLUS60K" : "PLUS256K");
-#endif
             return -1;
         } else {
             if (c64_256k_activate() < 0) {
@@ -186,33 +180,30 @@ void c64_256k_resources_shutdown(void)
 
 /* ------------------------------------------------------------------------- */
 
-#ifdef HAS_TRANSLATION
 static const cmdline_option_t cmdline_options[] =
 {
-    { "-256k", SET_RESOURCE, 0, NULL, NULL, "C64_256K", (resource_value_t)1,
-      0, IDCLS_ENABLE_C64_256K_EXPANSION },
-    { "+256k", SET_RESOURCE, 0, NULL, NULL, "C64_256K", (resource_value_t)0,
-      0, IDCLS_DISABLE_C64_256K_EXPANSION },
-    { "-256kimage", SET_RESOURCE, 1, NULL, NULL, "C64_256Kfilename", NULL,
-      IDCLS_P_NAME, IDCLS_SPECIFY_C64_256K_NAME },
-    { "-256kbase", SET_RESOURCE, 1, NULL, NULL, "C64_256Kbase", NULL,
-      IDCLS_P_BASE_ADDRESS, IDCLS_C64_256K_BASE },
+    { "-256k", SET_RESOURCE, 0,
+      NULL, NULL, "C64_256K", (resource_value_t)1,
+      USE_PARAM_STRING, USE_DESCRIPTION_ID,
+      IDCLS_UNUSED, IDCLS_ENABLE_C64_256K_EXPANSION,
+      NULL, NULL },
+    { "+256k", SET_RESOURCE, 0,
+      NULL, NULL, "C64_256K", (resource_value_t)0,
+      USE_PARAM_STRING, USE_DESCRIPTION_ID,
+      IDCLS_UNUSED, IDCLS_DISABLE_C64_256K_EXPANSION,
+      NULL, NULL },
+    { "-256kimage", SET_RESOURCE, 1,
+      NULL, NULL, "C64_256Kfilename", NULL,
+      USE_PARAM_ID, USE_DESCRIPTION_ID,
+      IDCLS_P_NAME, IDCLS_SPECIFY_C64_256K_NAME,
+      NULL, NULL },
+    { "-256kbase", SET_RESOURCE, 1,
+      NULL, NULL, "C64_256Kbase", NULL,
+      USE_PARAM_ID, USE_DESCRIPTION_ID,
+      IDCLS_P_BASE_ADDRESS, IDCLS_C64_256K_BASE,
+      NULL, NULL },
     { NULL }
 };
-#else
-static const cmdline_option_t cmdline_options[] =
-{
-    { "-256k", SET_RESOURCE, 0, NULL, NULL, "C64_256K", (resource_value_t)1,
-      NULL, N_("Enable the 256K RAM expansion") },
-    { "+256k", SET_RESOURCE, 0, NULL, NULL, "C64_256K", (resource_value_t)0,
-      NULL, N_("Disable the 256K RAM expansion") },
-    { "-256kimage", SET_RESOURCE, 1, NULL, NULL, "C64_256Kfilename", NULL,
-      N_("<name>"), N_("Specify name of 256K image") },
-    { "-256kbase", SET_RESOURCE, 1, NULL, NULL, "C64_256Kbase", NULL,
-      N_("<base address>"), N_("Base address of the 256K expansion") },
-    { NULL }
-};
-#endif
 
 int c64_256k_cmdline_options_init(void)
 {
