@@ -31,6 +31,8 @@
 #include <stdlib.h>
 #include <string.h>
 
+#include "alarm.h"
+#include "c64.h"
 #include "c64-resources.h"
 #include "c64_256k.h"
 #include "c64cart.h"
@@ -43,6 +45,8 @@
 #include "c64pla.h"
 #include "cart/c64cartmem.h"
 #include "cartridge.h"
+#include "clkguard.h"
+#include "dqbb.h"
 #include "machine.h"
 #include "maincpu.h"
 #include "mem.h"
@@ -139,6 +143,52 @@ void mem_toggle_watchpoints(int flag, void *context)
 
 /* ------------------------------------------------------------------------- */
 
+static void clk_overflow_callback(CLOCK sub, void *unused_data)
+{
+    if (pport.data_falloff_bit6)
+    {
+        pport.data_falloff_bit6++;
+        if (pport.data_falloff_bit6==3)
+        {
+            pport.data_set_bit6 = 0;
+            pport.data_falloff_bit6 = 0;
+        }
+    }
+
+    if (pport.data_falloff_bit7)
+    {
+        pport.data_falloff_bit7++;
+        if (pport.data_falloff_bit7==3)
+        {
+            pport.data_set_bit7 = 0;
+            pport.data_falloff_bit7 = 0;
+        }
+    }
+
+    pport.data_set_clk_bit6 -= sub;
+    pport.data_set_clk_bit7 -= sub;
+}
+
+static void check_data_set_alarm(void)
+{
+    if (pport.data_set_clk_bit6 < maincpu_clk)
+    {
+        pport.data_falloff_bit6 = 0;
+        pport.data_set_bit6 = 0;
+    }
+
+    if (pport.data_set_clk_bit7 < maincpu_clk)
+    {
+        pport.data_set_bit7 = 0;
+        pport.data_falloff_bit7 = 0;
+    }
+}
+
+void c64_mem_init(void)
+{
+    clk_guard_add_callback(maincpu_clk_guard, clk_overflow_callback, NULL);
+}
+
 void mem_pla_config_changed(void)
 {
     mem_config = (((~pport.dir | pport.data) & 0x7) | (export.exrom << 3)
@@ -169,12 +219,20 @@ void mem_pla_config_changed(void)
 BYTE REGPARM1 zero_read(WORD addr)
 {
     addr &= 0xff;
-
+#ifdef FEATURE_CPUMEMHISTORY
+    if(!(memmap_state & MEMMAP_STATE_IGNORE)) {
+        monitor_memmap_store(addr, (memmap_state&MEMMAP_STATE_OPCODE)?MEMMAP_RAM_X:(memmap_state&MEMMAP_STATE_INSTR)?0:MEMMAP_RAM_R);
+        memmap_state &= ~(MEMMAP_STATE_OPCODE);
+    }
+#endif
     switch ((BYTE)addr) {
       case 0:
         return pport.dir_read;
       case 1:
-        return pport.data_read;
+        if (pport.data_falloff_bit6 || pport.data_falloff_bit7)
+            check_data_set_alarm();
+
+        return (pport.data_read & (0xff - (((!pport.data_set_bit6)<<6)+((!pport.data_set_bit7)<<7))));
     }
 
     if (c64_256k_enabled)
@@ -190,7 +248,9 @@ BYTE REGPARM1 zero_read(WORD addr)
 void REGPARM2 zero_store(WORD addr, BYTE value)
 {
     addr &= 0xff;
-
+#ifdef FEATURE_CPUMEMHISTORY
+    monitor_memmap_store(addr, MEMMAP_RAM_W);
+#endif
     switch ((BYTE)addr) {
       case 0:
         if (vbank == 0) {
@@ -206,6 +266,24 @@ void REGPARM2 zero_store(WORD addr, BYTE value)
             mem_ram[0] = vicii_read_phi1_lowlevel();
             machine_handle_pending_alarms(maincpu_rmw_flag + 1);
         }
+        if (pport.data_set_bit7 && ((value & 0x80) == 0) && pport.data_falloff_bit7 == 0)
+        {
+            pport.data_falloff_bit7 = 1;
+            pport.data_set_clk_bit7 = maincpu_clk + C64_CPU_DATA_PORT_FALL_OFF_CYCLES;
+        }
+        if (pport.data_set_bit6 && ((value & 0x40) == 0) && pport.data_falloff_bit6 == 0)
+        {
+            pport.data_falloff_bit6 = 1;
+            pport.data_set_clk_bit6 = maincpu_clk + C64_CPU_DATA_PORT_FALL_OFF_CYCLES;
+        }
+        if (pport.data_set_bit7 && (value & 0x80) && pport.data_falloff_bit7)
+        {
+            pport.data_falloff_bit7 = 0;
+        }
+        if (pport.data_set_bit6 && (value & 0x40) && pport.data_falloff_bit6)
+        {
+            pport.data_falloff_bit6 = 0;
+        }
         if (pport.dir != value) {
             pport.dir = value;
             mem_pla_config_changed();
@@ -225,6 +303,15 @@ void REGPARM2 zero_store(WORD addr, BYTE value)
             mem_ram[1] = vicii_read_phi1_lowlevel();
             machine_handle_pending_alarms(maincpu_rmw_flag + 1);
         }
+        if ((pport.dir & 0x80) && (value & 0x80))
+        {
+            pport.data_set_bit7 = 1;
+        }
+        if ((pport.dir & 0x40) && (value & 0x40))
+        {
+            pport.data_set_bit6 = 1;
+        }
+
         if (pport.data != value) {
             pport.data = value;
             mem_pla_config_changed();
@@ -311,6 +398,16 @@ BYTE REGPARM1 mem_read_without_ultimax(WORD addr)
     return read_tab_ptr[addr >> 8](addr);
 }
 
+void REGPARM2 mem_store_without_romlh(WORD addr, BYTE value)
+{
+    store_func_ptr_t *write_tab_ptr;
+
+    write_tab_ptr = mem_write_tab[vbank][0];
+
+    write_tab_ptr[addr >> 8](addr, value);
+}
+
+
 /* ------------------------------------------------------------------------- */
 
 void REGPARM2 colorram_store(WORD addr, BYTE value)
@@ -671,6 +768,7 @@ void mem_initialize_memory(void)
     plus256k_init_config();
     c64_256k_init_config();
     mmc64_init_config();
+    dqbb_init_config();
 }
 
 /* ------------------------------------------------------------------------- */
@@ -974,12 +1072,13 @@ mem_ioreg_list_t *mem_ioreg_list_get(void *context)
     return mem_ioreg_list;
 }
 
-void mem_get_screen_parameter(WORD *base, BYTE *rows, BYTE *columns)
+void mem_get_screen_parameter(WORD *base, BYTE *rows, BYTE *columns, int *bank)
 {
     *base = ((vicii_peek(0xd018) & 0xf0) << 6)
             | ((~cia2_peek(0xdd00) & 0x03) << 14);
     *rows = 25;
     *columns = 40;
+    *bank = 0;
 }
 
 /* ------------------------------------------------------------------------- */
