@@ -29,9 +29,16 @@
 #define _C64MEM_H
 
 #include "types.h"
-#include "mem.h"
 
+#ifdef WATCOM_COMPILE
+#include "../mem.h"
+#else
+#include "mem.h"
+#endif
+
+#ifndef C64_RAM_SIZE
 #define C64_RAM_SIZE                    0x10000
+#endif
 #define C64_KERNAL_ROM_SIZE             0x2000
 #define C64_BASIC_ROM_SIZE              0x2000
 #define C64_CHARGEN_ROM_SIZE            0x1000
@@ -72,9 +79,12 @@ extern void mem_read_base_set(unsigned int base, unsigned int index,
 
 extern void REGPARM2 mem_store_without_ultimax(WORD addr, BYTE value);
 extern BYTE REGPARM1 mem_read_without_ultimax(WORD addr);
+extern void REGPARM2 mem_store_without_romlh(WORD addr, BYTE value);
 
 extern void REGPARM2 store_bank_io(WORD addr, BYTE byte);
 extern BYTE REGPARM1 read_bank_io(WORD addr);
 
+extern void c64_mem_init(void);
+
 #endif
 
