@@ -31,6 +31,7 @@
 #include <string.h>
 
 #include "actionreplay3.h"
+#include "actionreplay4.h"
 #include "actionreplay.h"
 #include "atomicpower.h"
 #include "alarm.h"
@@ -43,16 +44,17 @@
 #include "generic.h"
 #include "ide64.h"
 #include "interrupt.h"
+#include "isepic.h"
 #include "lib.h"
 #include "maincpu.h"
 #include "mem.h"
+#include "monitor.h"
 #include "resources.h"
 #include "retroreplay.h"
+#include "stardos.h"
 #include "stb.h"
 #include "supersnapshot.h"
-#ifdef HAS_TRANSLATION
 #include "translate.h"
-#endif
 #include "util.h"
 
 
@@ -72,6 +74,7 @@ static alarm_t *cartridge_alarm = NULL;
 
 static unsigned int cartridge_int_num;
 
+static int trying_cart = 0;
 
 int try_cartridge_init(int c)
 {
@@ -80,6 +83,7 @@ int try_cartridge_init(int c)
     if (cartres)
         return 0;
 
+    trying_cart = 1;
     return cartridge_attach_image(c64cart_type, cartfile);
 }
 
@@ -162,125 +166,126 @@ void cartridge_resources_shutdown(void)
 
 static int attach_cartridge_cmdline(const char *param, void *extra_param)
 {
+    /* patch: iAN CooG */
+    if (!param)
+    {
+        cartridge_detach_image();
+        return 0;
+    }
     return cartridge_attach_image((int)extra_param, param);
 }
 
-#ifdef HAS_TRANSLATION
 static const cmdline_option_t cmdline_options[] =
 {
-    { "-cartreset", SET_RESOURCE, 0, NULL, NULL, "CartridgeReset",
-      (void *)1, 0,
-      IDCLS_CART_ATTACH_DETACH_RESET },
-    { "+cartreset", SET_RESOURCE, 0, NULL, NULL, "CartridgeReset",
-      (void *)0, 0,
-      IDCLS_CART_ATTACH_DETACH_NO_RESET },
-    { "-cartcrt", CALL_FUNCTION, 1, attach_cartridge_cmdline,
-      (void *)CARTRIDGE_CRT, NULL, NULL,
-      IDCLS_P_NAME, IDCLS_ATTACH_CRT_CART },
-    { "-cart8", CALL_FUNCTION, 1, attach_cartridge_cmdline,
-      (void *)CARTRIDGE_GENERIC_8KB, NULL, NULL,
-      IDCLS_P_NAME, IDCLS_ATTACH_GENERIC_8KB_CART },
-    { "-cart16", CALL_FUNCTION, 1, attach_cartridge_cmdline,
-      (void *)CARTRIDGE_GENERIC_16KB, NULL, NULL,
-      IDCLS_P_NAME, IDCLS_ATTACH_GENERIC_16KB_CART },
-    { "-cartar", CALL_FUNCTION, 1, attach_cartridge_cmdline,
-      (void *)CARTRIDGE_ACTION_REPLAY, NULL, NULL,
+    { "-cartreset", SET_RESOURCE, 0,
+      NULL, NULL, "CartridgeReset", (void *)1,
+      USE_PARAM_STRING, USE_DESCRIPTION_ID,
+      IDCLS_UNUSED, IDCLS_CART_ATTACH_DETACH_RESET,
+      NULL, NULL },
+    { "+cartreset", SET_RESOURCE, 0,
+      NULL, NULL, "CartridgeReset", (void *)0,
+      USE_PARAM_STRING, USE_DESCRIPTION_ID,
+      IDCLS_UNUSED, IDCLS_CART_ATTACH_DETACH_NO_RESET,
+      NULL, NULL },
+    { "-cartcrt", CALL_FUNCTION, 1,
+      attach_cartridge_cmdline, (void *)CARTRIDGE_CRT, NULL, NULL,
+      USE_PARAM_ID, USE_DESCRIPTION_ID,
+      IDCLS_P_NAME, IDCLS_ATTACH_CRT_CART,
+      NULL, NULL },
+    { "-cart8", CALL_FUNCTION, 1,
+      attach_cartridge_cmdline, (void *)CARTRIDGE_GENERIC_8KB, NULL, NULL,
+      USE_PARAM_ID, USE_DESCRIPTION_ID,
+      IDCLS_P_NAME, IDCLS_ATTACH_GENERIC_8KB_CART,
+      NULL, NULL },
+    { "-cart16", CALL_FUNCTION, 1,
+      attach_cartridge_cmdline, (void *)CARTRIDGE_GENERIC_16KB, NULL, NULL,
+      USE_PARAM_ID, USE_DESCRIPTION_ID,
+      IDCLS_P_NAME, IDCLS_ATTACH_GENERIC_16KB_CART,
+      NULL, NULL },
+    { "-cartar", CALL_FUNCTION, 1,
+      attach_cartridge_cmdline, (void *)CARTRIDGE_ACTION_REPLAY, NULL, NULL,
+      USE_PARAM_ID, USE_DESCRIPTION_ID,
       IDCLS_P_NAME, IDCLS_ATTACH_RAW_ACTION_REPLAY_CART },
-    { "-cartar3", CALL_FUNCTION, 1, attach_cartridge_cmdline,
-      (void *)CARTRIDGE_ACTION_REPLAY3, NULL, NULL,
-      IDCLS_P_NAME, IDCLS_ATTACH_RAW_ACTION_REPLAY3_CART },
-    { "-cartrr", CALL_FUNCTION, 1, attach_cartridge_cmdline,
-      (void *)CARTRIDGE_RETRO_REPLAY, NULL, NULL,
-      IDCLS_P_NAME, IDCLS_ATTACH_RAW_RETRO_REPLAY_CART },
-    { "-cartide", CALL_FUNCTION, 1, attach_cartridge_cmdline,
-      (void *)CARTRIDGE_IDE64, NULL, NULL,
-      IDCLS_P_NAME, IDCLS_ATTACH_RAW_IDE64_CART },
-    { "-cartap", CALL_FUNCTION, 1, attach_cartridge_cmdline,
-      (void *)CARTRIDGE_ATOMIC_POWER, NULL, NULL,
-      IDCLS_P_NAME, IDCLS_ATTACH_RAW_ATOMIC_POWER_CART },
-    { "-cartepyx", CALL_FUNCTION, 1, attach_cartridge_cmdline,
-      (void *)CARTRIDGE_EPYX_FASTLOAD, NULL, NULL,
-      IDCLS_P_NAME, IDCLS_ATTACH_RAW_EPYX_FASTLOAD_CART },
-    { "-cartss4", CALL_FUNCTION, 1, attach_cartridge_cmdline,
-      (void *)CARTRIDGE_SUPER_SNAPSHOT, NULL, NULL,
-      IDCLS_P_NAME, IDCLS_ATTACH_RAW_SS4_CART },
-    { "-cartss5", CALL_FUNCTION, 1, attach_cartridge_cmdline,
-      (void *)CARTRIDGE_SUPER_SNAPSHOT_V5, NULL, NULL,
-      IDCLS_P_NAME, IDCLS_ATTACH_RAW_SS5_CART },
-    { "-cartieee488", CALL_FUNCTION, 1, attach_cartridge_cmdline,
-      (void *)CARTRIDGE_IEEE488, NULL, NULL,
-      IDCLS_P_NAME, IDCLS_ATTACH_CBM_IEEE488_CART },
-    { "-cartwestermann", CALL_FUNCTION, 1, attach_cartridge_cmdline,
-      (void *)CARTRIDGE_WESTERMANN, NULL, NULL,
-      IDCLS_P_NAME, IDCLS_ATTACH_RAW_WESTERMANN_CART },
-    { "-cartstb", CALL_FUNCTION, 1, attach_cartridge_cmdline,
-      (void *)CARTRIDGE_STRUCTURED_BASIC, NULL, NULL,
-      IDCLS_P_NAME, IDCLS_ATTACH_RAW_STB_CART },
-    { "-cartexpert", CALL_FUNCTION, 0, attach_cartridge_cmdline,
-      (void *)CARTRIDGE_EXPERT, NULL, NULL,
-      0, IDCLS_ENABLE_EXPERT_CART },
+    { "-cartar3", CALL_FUNCTION, 1,
+      attach_cartridge_cmdline, (void *)CARTRIDGE_ACTION_REPLAY3, NULL, NULL,
+      USE_PARAM_ID, USE_DESCRIPTION_ID,
+      IDCLS_P_NAME, IDCLS_ATTACH_RAW_ACTION_REPLAY3_CART,
+      NULL, NULL },
+    { "-cartar4", CALL_FUNCTION, 1,
+      attach_cartridge_cmdline, (void *)CARTRIDGE_ACTION_REPLAY4, NULL, NULL,
+      USE_PARAM_ID, USE_DESCRIPTION_ID,
+      IDCLS_P_NAME, IDCLS_ATTACH_RAW_ACTION_REPLAY4_CART,
+      NULL, NULL },
+    { "-cartrr", CALL_FUNCTION, 1,
+      attach_cartridge_cmdline, (void *)CARTRIDGE_RETRO_REPLAY, NULL, NULL,
+      USE_PARAM_ID, USE_DESCRIPTION_ID,
+      IDCLS_P_NAME, IDCLS_ATTACH_RAW_RETRO_REPLAY_CART,
+      NULL, NULL },
+    { "-cartide", CALL_FUNCTION, 1,
+      attach_cartridge_cmdline, (void *)CARTRIDGE_IDE64, NULL, NULL,
+      USE_PARAM_ID, USE_DESCRIPTION_ID,
+      IDCLS_P_NAME, IDCLS_ATTACH_RAW_IDE64_CART,
+      NULL, NULL },
+    { "-cartap", CALL_FUNCTION, 1,
+      attach_cartridge_cmdline, (void *)CARTRIDGE_ATOMIC_POWER, NULL, NULL,
+      USE_PARAM_ID, USE_DESCRIPTION_ID,
+      IDCLS_P_NAME, IDCLS_ATTACH_RAW_ATOMIC_POWER_CART,
+      NULL, NULL },
+    { "-cartepyx", CALL_FUNCTION, 1,
+      attach_cartridge_cmdline, (void *)CARTRIDGE_EPYX_FASTLOAD, NULL, NULL,
+      USE_PARAM_ID, USE_DESCRIPTION_ID,
+      IDCLS_P_NAME, IDCLS_ATTACH_RAW_EPYX_FASTLOAD_CART,
+      NULL, NULL },
+    { "-cartss4", CALL_FUNCTION, 1,
+      attach_cartridge_cmdline, (void *)CARTRIDGE_SUPER_SNAPSHOT, NULL, NULL,
+      USE_PARAM_ID, USE_DESCRIPTION_ID,
+      IDCLS_P_NAME, IDCLS_ATTACH_RAW_SS4_CART,
+      NULL, NULL },
+    { "-cartss5", CALL_FUNCTION, 1,
+      attach_cartridge_cmdline, (void *)CARTRIDGE_SUPER_SNAPSHOT_V5, NULL, NULL,
+      USE_PARAM_ID, USE_DESCRIPTION_ID,
+      IDCLS_P_NAME, IDCLS_ATTACH_RAW_SS5_CART,
+      NULL, NULL },
+    { "-cartieee488", CALL_FUNCTION, 1,
+      attach_cartridge_cmdline, (void *)CARTRIDGE_IEEE488, NULL, NULL,
+      USE_PARAM_ID, USE_DESCRIPTION_ID,
+      IDCLS_P_NAME, IDCLS_ATTACH_CBM_IEEE488_CART,
+      NULL, NULL },
+    { "-cartwestermann", CALL_FUNCTION, 1,
+      attach_cartridge_cmdline, (void *)CARTRIDGE_WESTERMANN, NULL, NULL,
+      USE_PARAM_ID, USE_DESCRIPTION_ID,
+      IDCLS_P_NAME, IDCLS_ATTACH_RAW_WESTERMANN_CART,
+      NULL, NULL },
+    { "-cartstb", CALL_FUNCTION, 1,
+      attach_cartridge_cmdline, (void *)CARTRIDGE_STRUCTURED_BASIC, NULL, NULL,
+      USE_PARAM_ID, USE_DESCRIPTION_ID,
+      IDCLS_P_NAME, IDCLS_ATTACH_RAW_STB_CART,
+      NULL, NULL },
+    { "-cartstardos", CALL_FUNCTION, 1,
+      attach_cartridge_cmdline, (void *)CARTRIDGE_STARDOS, NULL, NULL,
+      USE_PARAM_ID, USE_DESCRIPTION_ID,
+      IDCLS_P_NAME, IDCLS_ATTACH_RAW_STARDOS_CART,
+      NULL, NULL },
+    { "-cartexpert", CALL_FUNCTION, 0,
+      attach_cartridge_cmdline, (void *)CARTRIDGE_EXPERT, NULL, NULL,
+      USE_PARAM_STRING, USE_DESCRIPTION_ID,
+      IDCLS_UNUSED, IDCLS_ENABLE_EXPERT_CART,
+      NULL, NULL },
+    { "+cart", CALL_FUNCTION, 0,
+      attach_cartridge_cmdline, NULL, NULL, NULL,
+      USE_PARAM_STRING, USE_DESCRIPTION_ID,
+      IDCLS_UNUSED, IDCLS_DISABLE_CART,
+      NULL, NULL }, /* patch: iAN CooG */
     { NULL }
 };
-#else
-static const cmdline_option_t cmdline_options[] =
-{
-    { "-cartreset", SET_RESOURCE, 0, NULL, NULL, "CartridgeReset",
-      (void *)1, NULL,
-      N_("Reset machine if a cartridge is attached or detached") },
-    { "+cartreset", SET_RESOURCE, 0, NULL, NULL, "CartridgeReset",
-      (void *)0, NULL,
-      N_("Do not reset machine if a cartridge is attached or detached") },
-    { "-cartcrt", CALL_FUNCTION, 1, attach_cartridge_cmdline,
-      (void *)CARTRIDGE_CRT, NULL, NULL,
-      N_("<name>"), N_("Attach CRT cartridge image") },
-    { "-cart8", CALL_FUNCTION, 1, attach_cartridge_cmdline,
-      (void *)CARTRIDGE_GENERIC_8KB, NULL, NULL,
-      N_("<name>"), N_("Attach generic 8KB cartridge image") },
-    { "-cart16", CALL_FUNCTION, 1, attach_cartridge_cmdline,
-      (void *)CARTRIDGE_GENERIC_16KB, NULL, NULL,
-      N_("<name>"), N_("Attach generic 16KB cartridge image") },
-    { "-cartar", CALL_FUNCTION, 1, attach_cartridge_cmdline,
-      (void *)CARTRIDGE_ACTION_REPLAY, NULL, NULL,
-      N_("<name>"), N_("Attach raw 32KB Action Replay cartridge image") },
-    { "-cartar3", CALL_FUNCTION, 1, attach_cartridge_cmdline,
-      (void *)CARTRIDGE_ACTION_REPLAY3, NULL, NULL,
-      N_("<name>"), N_("Attach raw 16KB Action Replay III cartridge image") },
-    { "-cartrr", CALL_FUNCTION, 1, attach_cartridge_cmdline,
-      (void *)CARTRIDGE_RETRO_REPLAY, NULL, NULL,
-      N_("<name>"), N_("Attach raw 64KB Retro Replay cartridge image") },
-    { "-cartide", CALL_FUNCTION, 1, attach_cartridge_cmdline,
-      (void *)CARTRIDGE_IDE64, NULL, NULL,
-      N_("<name>"), N_("Attach raw 64KB IDE64 cartridge image") },
-    { "-cartap", CALL_FUNCTION, 1, attach_cartridge_cmdline,
-      (void *)CARTRIDGE_ATOMIC_POWER, NULL, NULL,
-      N_("<name>"), N_("Attach raw 32KB Atomic Power cartridge image") },
-    { "-cartepyx", CALL_FUNCTION, 1, attach_cartridge_cmdline,
-      (void *)CARTRIDGE_EPYX_FASTLOAD, NULL, NULL,
-      N_("<name>"), N_("Attach raw 8KB Epyx fastload cartridge image") },
-    { "-cartss4", CALL_FUNCTION, 1, attach_cartridge_cmdline,
-      (void *)CARTRIDGE_SUPER_SNAPSHOT, NULL, NULL,
-      N_("<name>"), N_("Attach raw 32KB Super Snapshot cartridge image") },
-    { "-cartss5", CALL_FUNCTION, 1, attach_cartridge_cmdline,
-      (void *)CARTRIDGE_SUPER_SNAPSHOT_V5, NULL, NULL,
-      N_("<name>"), N_("Attach raw 64KB Super Snapshot cartridge image") },
-    { "-cartieee488", CALL_FUNCTION, 1, attach_cartridge_cmdline,
-      (void *)CARTRIDGE_IEEE488, NULL, NULL,
-      N_("<name>"), N_("Attach CBM IEEE488 cartridge image") },
-    { "-cartwestermann", CALL_FUNCTION, 1, attach_cartridge_cmdline,
-      (void *)CARTRIDGE_WESTERMANN, NULL, NULL,
-      N_("<name>"), N_("Attach raw 16KB Westermann learning cartridge image") },
-    { "-cartstb", CALL_FUNCTION, 1, attach_cartridge_cmdline,
-      (void *)CARTRIDGE_STRUCTURED_BASIC, NULL, NULL,
-      N_("<name>"), N_("Attach raw Structured Basic cartridge image") },
-    { "-cartexpert", CALL_FUNCTION, 0, attach_cartridge_cmdline,
-      (void *)CARTRIDGE_EXPERT, NULL, NULL,
-      NULL, N_("Enable expert cartridge") },
-    { NULL }
-};
-#endif
 
 int cartridge_cmdline_options_init(void)
 {
+    mon_cart_cmd.cartridge_attach_image = cartridge_attach_image;
+    mon_cart_cmd.cartridge_detach_image = cartridge_detach_image;
+    mon_cart_cmd.cartridge_trigger_freeze = cartridge_trigger_freeze;
+    mon_cart_cmd.cartridge_trigger_freeze_nmi_only = cartridge_trigger_freeze_nmi_only;
+
     if (ide64_cmdline_options_init() < 0)
         return -1;
 
@@ -306,9 +311,17 @@ int cartridge_attach_image(int type, const char *filename)
     /* allocate temporary array */
     rawcart = lib_malloc(0x88000);
 
-    /* Do not detach cartridge when attaching the same cart type again.  */
-    if (type != c64cart_type)
-        cartridge_detach_image();
+/*  cart should always be detached. there is no reason for doing fancy checks
+    here, and it will cause problems incase a cart MUST be detached before
+    attaching another, or even itself. (eg for initialization reasons)
+    
+    most obvious reason: attaching a different ROM (software) for the same
+    cartridge (hardware) */
+
+    if (trying_cart == 0)
+      cartridge_detach_image();
+    else
+      trying_cart = 0;
 
     switch(type) {
       case CARTRIDGE_GENERIC_8KB:
@@ -326,6 +339,10 @@ int cartridge_attach_image(int type, const char *filename)
         if (actionreplay3_bin_attach(filename, rawcart) < 0)
             goto done;
         break;
+      case CARTRIDGE_ACTION_REPLAY4:
+        if (actionreplay4_bin_attach(filename, rawcart) < 0)
+            goto done;
+        break;
       case CARTRIDGE_ACTION_REPLAY:
         if (actionreplay_bin_attach(filename, rawcart) < 0)
             goto done;
@@ -375,6 +392,10 @@ int cartridge_attach_image(int type, const char *filename)
         if (stb_bin_attach(filename, rawcart) < 0)
             goto done;
         break;
+      case CARTRIDGE_STARDOS:
+        if (stardos_bin_attach(filename, rawcart) < 0)
+            goto done;
+        break;
       default:
         goto done;
     }
@@ -429,6 +450,7 @@ void cartridge_trigger_freeze(void)
     int type = ((c64cart_type == CARTRIDGE_CRT) ? crttype : c64cart_type);
 
     switch (type) {
+      case CARTRIDGE_ACTION_REPLAY4:
       case CARTRIDGE_ACTION_REPLAY3:
       case CARTRIDGE_ACTION_REPLAY:
       case CARTRIDGE_KCS_POWER:
@@ -447,6 +469,11 @@ void cartridge_trigger_freeze(void)
         }
         break;
     }
+    if (isepic_enabled && isepic_switch)
+    {
+        maincpu_set_nmi(cartridge_int_num, IK_NMI);
+        alarm_set(cartridge_alarm, maincpu_clk + 3);
+    }
 }
 
 void cartridge_trigger_freeze_nmi_only(void)
