@@ -31,6 +31,7 @@
 #include <string.h>
 
 #include "actionreplay3.h"
+#include "actionreplay4.h"
 #include "actionreplay.h"
 #include "atomicpower.h"
 #include "c64cart.h"
@@ -44,10 +45,13 @@
 #include "delaep256.h"
 #include "delaep64.h"
 #include "delaep7x8.h"
+#include "dqbb.h"
 #include "epyxfastload.h"
 #include "expert.h"
 #include "final.h"
 #include "generic.h"
+#include "ide64.h"
+#include "isepic.h"
 #include "kcs.h"
 #include "log.h"
 #include "machine.h"
@@ -58,9 +62,9 @@
 #include "resources.h"
 #include "retroreplay.h"
 #include "rexep256.h"
-#include "ide64.h"
 #include "ramcart.h"
 #include "ross.h"
+#include "stardos.h"
 #include "stb.h"
 #include "supergames.h"
 #include "supersnapshot.h"
@@ -124,6 +128,8 @@ BYTE REGPARM1 cartridge_read_io1(WORD addr)
     log_debug("Read IO1 %02x.", addr);
 #endif
     switch (mem_cartridge_type) {
+      case CARTRIDGE_STARDOS:
+        return stardos_io1_read(addr);
       case CARTRIDGE_ACTION_REPLAY3:
         return actionreplay3_io1_read(addr);
       case CARTRIDGE_ACTION_REPLAY:
@@ -177,6 +183,9 @@ void REGPARM2 cartridge_store_io1(WORD addr, BYTE value)
 #endif
 
     switch (mem_cartridge_type) {
+      case CARTRIDGE_ACTION_REPLAY4:
+        actionreplay4_io1_store(addr, value);
+        break;
       case CARTRIDGE_ACTION_REPLAY3:
         actionreplay3_io1_store(addr, value);
         break;
@@ -275,6 +284,10 @@ BYTE REGPARM1 cartridge_read_io2(WORD addr)
     log_debug("Read IO2 %02x.", addr);
 #endif
     switch (mem_cartridge_type) {
+      case CARTRIDGE_STARDOS:
+        return stardos_io2_read(addr);
+      case CARTRIDGE_ACTION_REPLAY4:
+        return actionreplay4_io2_read(addr);
       case CARTRIDGE_ACTION_REPLAY3:
         return actionreplay3_io2_read(addr);
       case CARTRIDGE_ACTION_REPLAY:
@@ -373,12 +386,16 @@ BYTE REGPARM1 roml_read(WORD addr)
         return ramcart_roml_read(addr);
 
     switch (mem_cartridge_type) {
+      case CARTRIDGE_STARDOS:
+        return stardos_roml_read(addr);
       case CARTRIDGE_ZAXXON:
         return zaxxon_roml_read(addr);
       case CARTRIDGE_SUPER_SNAPSHOT:
         return supersnapshot_v4_roml_read(addr);
       case CARTRIDGE_SUPER_SNAPSHOT_V5:
         return supersnapshot_v5_roml_read(addr);
+      case CARTRIDGE_ACTION_REPLAY4:
+        return actionreplay4_roml_read(addr);
       case CARTRIDGE_ACTION_REPLAY:
         return actionreplay_roml_read(addr);
       case CARTRIDGE_RETRO_REPLAY:
@@ -396,6 +413,10 @@ BYTE REGPARM1 roml_read(WORD addr)
       case CARTRIDGE_MAGIC_FORMEL:
         return magicformel_roml_read(addr);
     }
+    if (dqbb_enabled)
+    {
+        return dqbb_roml_read(addr);
+    }
 
     if (export_ram)
         return export_ram0[addr & 0x1fff];
@@ -458,6 +479,14 @@ BYTE REGPARM1 romh_read(WORD addr)
       case CARTRIDGE_IDE64:
         return romh_banks[(addr & 0x3fff) | (romh_bank << 14)];
     }
+    if (isepic_enabled && isepic_switch)
+    {
+        return isepic_romh_read(addr);
+    }
+    if (dqbb_enabled)
+    {
+        return dqbb_romh_read(addr);
+    }
     return romh_banks[(addr & 0x1fff) + (romh_bank << 13)];
 }
 
@@ -468,6 +497,31 @@ void REGPARM2 romh_store(WORD addr, BYTE value)
         magicformel_romh_store(addr, value);
         return;
     }
+    if (isepic_enabled && isepic_switch)
+    {
+        isepic_romh_store(addr, value);
+        return;
+    }
+}
+
+void REGPARM2 romh_no_ultimax_store(WORD addr, BYTE value)
+{
+    if (dqbb_enabled)
+    {
+        dqbb_romh_store(addr, value);
+        return;
+    }
+    mem_store_without_romlh(addr, value);
+}
+
+void REGPARM2 roml_no_ultimax_store(WORD addr, BYTE value)
+{
+    if (dqbb_enabled)
+    {
+        dqbb_roml_store(addr, value);
+        return;
+    }
+    mem_store_without_romlh(addr, value);
 }
 
 BYTE REGPARM1 ultimax_1000_7fff_read(WORD addr)
@@ -478,6 +532,10 @@ BYTE REGPARM1 ultimax_1000_7fff_read(WORD addr)
       case CARTRIDGE_MAGIC_FORMEL:
         return magicformel_1000_7fff_read(addr);
     }
+    if (isepic_enabled && isepic_switch)
+    {
+        return isepic_1000_7fff_read(addr);
+    }
     return vicii_read_phi1();
 }
 
@@ -491,6 +549,10 @@ void REGPARM2 ultimax_1000_7fff_store(WORD addr, BYTE value)
         magicformel_1000_7fff_store(addr, value);
         break;
     }
+    if (isepic_enabled && isepic_switch)
+    {
+        isepic_1000_7fff_store(addr, value);
+    }
 }
 
 BYTE REGPARM1 ultimax_a000_bfff_read(WORD addr)
@@ -503,6 +565,10 @@ BYTE REGPARM1 ultimax_a000_bfff_read(WORD addr)
       case CARTRIDGE_MAGIC_FORMEL:
         return magicformel_a000_bfff_read(addr);
     }
+    if (isepic_enabled && isepic_switch)
+    {
+        return isepic_a000_bfff_read(addr);
+    }
     return vicii_read_phi1();
 }
 
@@ -516,6 +582,10 @@ void REGPARM2 ultimax_a000_bfff_store(WORD addr, BYTE value)
         magicformel_a000_bfff_store(addr, value);
         break;
     }
+    if (isepic_enabled && isepic_switch)
+    {
+        isepic_a000_bfff_store(addr, value);
+    }
 }
 
 BYTE REGPARM1 ultimax_c000_cfff_read(WORD addr)
@@ -526,6 +596,10 @@ BYTE REGPARM1 ultimax_c000_cfff_read(WORD addr)
       case CARTRIDGE_MAGIC_FORMEL:
         return magicformel_c000_cfff_read(addr);
     }
+    if (isepic_enabled && isepic_switch)
+    {
+        return isepic_c000_cfff_read(addr);
+    }
     return vicii_read_phi1();
 }
 
@@ -539,6 +613,10 @@ void REGPARM2 ultimax_c000_cfff_store(WORD addr, BYTE value)
         magicformel_c000_cfff_store(addr, value);
         break;
     }
+    if (isepic_enabled && isepic_switch)
+    {
+        isepic_c000_cfff_store(addr, value);
+    }
 }
 
 BYTE REGPARM1 ultimax_d000_dfff_read(WORD addr)
@@ -569,6 +647,12 @@ void REGPARM1 cartridge_decode_address(WORD addr)
 void cartridge_init_config(void)
 {
     switch (mem_cartridge_type) {
+      case CARTRIDGE_STARDOS:
+        stardos_config_init();
+        break;
+      case CARTRIDGE_ACTION_REPLAY4:
+        actionreplay4_config_init();
+        break;
       case CARTRIDGE_ACTION_REPLAY3:
         actionreplay3_config_init();
         break;
@@ -680,6 +764,9 @@ void cartridge_init_config(void)
 void cartridge_reset(void)
 {
     switch (mem_cartridge_type) {
+      case CARTRIDGE_ACTION_REPLAY4:
+        actionreplay4_reset();
+        break;
       case CARTRIDGE_ACTION_REPLAY3:
         actionreplay3_reset();
         break;
@@ -720,6 +807,12 @@ void cartridge_attach(int type, BYTE *rawcart)
       case CARTRIDGE_FINAL_I:
         final_v1_config_setup(rawcart);
         break;
+      case CARTRIDGE_STARDOS:
+        stardos_config_setup(rawcart);
+        break;
+      case CARTRIDGE_ACTION_REPLAY4:
+        actionreplay4_config_setup(rawcart);
+        break;
       case CARTRIDGE_ACTION_REPLAY3:
         actionreplay3_config_setup(rawcart);
         break;
@@ -815,6 +908,12 @@ void cartridge_detach(int type)
     int cartridge_reset;
 
     switch (type) {
+      case CARTRIDGE_STARDOS:
+        stardos_detach();
+        break;
+      case CARTRIDGE_ACTION_REPLAY4:
+        actionreplay4_detach();
+        break;
       case CARTRIDGE_ACTION_REPLAY3:
         actionreplay3_detach();
         break;
@@ -931,6 +1030,9 @@ void cartridge_freeze(int type)
       case CARTRIDGE_SUPER_SNAPSHOT_V5:
         supersnapshot_v5_freeze();
         break;
+      case CARTRIDGE_ACTION_REPLAY4:
+        actionreplay4_freeze();
+        break;
       case CARTRIDGE_ACTION_REPLAY3:
         actionreplay3_freeze();
         break;
@@ -953,6 +1055,10 @@ void cartridge_freeze(int type)
         final_v3_freeze();
         break;
     }
+    if (isepic_enabled && isepic_switch)
+    {
+        isepic_freeze();
+    }
 }
 
 int cartridge_save_image(const char *filename)
