@@ -42,7 +42,13 @@
 #include "emuid.h"
 #include "kbdbuf.h"
 #include "machine.h"
+
+#ifdef WATCOM_COMPILE
+#include "../mem.h"
+#else
 #include "mem.h"
+#endif
+
 #include "monitor.h"
 #include "ram.h"
 #include "resources.h"
@@ -1140,12 +1146,12 @@ mem_ioreg_list_t *mem_ioreg_list_get(void *context)
     return mem_ioreg_list;
 }
 
-void mem_get_screen_parameter(WORD *base, BYTE *rows, BYTE *columns)
+void mem_get_screen_parameter(WORD *base, BYTE *rows, BYTE *columns, int *bank)
 {
-    /* FIXME */
-    *base = 0;
+    *base = 0xd000;
     *rows = 25;
-    *columns = 80;
+    *columns = (cbm2_isC500) ? 40 : 80;
+    *bank = 16;
 }
 
 void mem_color_ram_to_snapshot(BYTE *color_ram)
