@@ -43,9 +43,7 @@
 #include "resources.h"
 #include "snapshot.h"
 #include "tap.h"
-#ifdef HAS_TRANSLATION
 #include "translate.h"
-#endif
 #include "types.h"
 #include "ui.h"
 
@@ -152,40 +150,29 @@ int datasette_resources_init(void)
 
 /*---------- Commandline options --------------------------------------*/
 
-#ifdef HAS_TRANSLATION
 static const cmdline_option_t cmdline_options[] = {
-    { "-dsresetwithcpu", SET_RESOURCE, 0, NULL, NULL,
-      "DatasetteResetWithCPU", (resource_value_t)1,
-      0, IDCLS_ENABLE_AUTO_DATASETTE_RESET },
-    { "+dsresetwithcpu", SET_RESOURCE, 0, NULL, NULL,
-      "DatasetteResetWithCPU", (resource_value_t)0,
-      0, IDCLS_DISABLE_AUTO_DATASETTE_RESET },
-    { "-dszerogapdelay", SET_RESOURCE, 1, NULL, NULL,
-      "DatasetteZeroGapDelay", NULL,
-      IDCLS_P_VALUE, IDCLS_SET_ZERO_TAP_DELAY },
-    { "-dsspeedtuning", SET_RESOURCE, 1, NULL, NULL,
-      "DatasetteSpeedTuning", NULL,
-      IDCLS_P_VALUE, IDCLS_SET_CYCLES_ADDED_GAP_TAP },
+    { "-dsresetwithcpu", SET_RESOURCE, 0,
+      NULL, NULL, "DatasetteResetWithCPU", (resource_value_t)1,
+      USE_PARAM_STRING, USE_DESCRIPTION_ID,
+      IDCLS_UNUSED, IDCLS_ENABLE_AUTO_DATASETTE_RESET,
+      NULL, NULL },
+    { "+dsresetwithcpu", SET_RESOURCE, 0,
+      NULL, NULL, "DatasetteResetWithCPU", (resource_value_t)0,
+      USE_PARAM_STRING, USE_DESCRIPTION_ID,
+      IDCLS_UNUSED, IDCLS_DISABLE_AUTO_DATASETTE_RESET,
+      NULL, NULL },
+    { "-dszerogapdelay", SET_RESOURCE, 1,
+      NULL, NULL, "DatasetteZeroGapDelay", NULL,
+      USE_PARAM_ID, USE_DESCRIPTION_ID,
+      IDCLS_P_VALUE, IDCLS_SET_ZERO_TAP_DELAY,
+      NULL, NULL },
+    { "-dsspeedtuning", SET_RESOURCE, 1,
+      NULL, NULL, "DatasetteSpeedTuning", NULL,
+      USE_PARAM_ID, USE_DESCRIPTION_ID,
+      IDCLS_P_VALUE, IDCLS_SET_CYCLES_ADDED_GAP_TAP,
+      NULL, NULL },
     { NULL }
 };
-#else
-static const cmdline_option_t cmdline_options[] = {
-    { "-dsresetwithcpu", SET_RESOURCE, 0, NULL, NULL,
-      "DatasetteResetWithCPU", (resource_value_t)1,
-      NULL, N_("Enable automatic Datasette-Reset") },
-    { "+dsresetwithcpu", SET_RESOURCE, 0, NULL, NULL,
-      "DatasetteResetWithCPU", (resource_value_t)0,
-      NULL, N_("Disable automatic Datasette-Reset") },
-    { "-dszerogapdelay", SET_RESOURCE, 1, NULL, NULL,
-      "DatasetteZeroGapDelay", NULL,
-      N_("<value>"), N_("Set delay in cycles for a zero in the tap") },
-    { "-dsspeedtuning", SET_RESOURCE, 1, NULL, NULL,
-      "DatasetteSpeedTuning", NULL,
-      N_("<value>"), N_("Set number of cycles added to each gap in the tap") },
-    { NULL }
-};
-#endif
-
 
 int datasette_cmdline_options_init(void)
 {
@@ -456,7 +443,7 @@ static void datasette_read_bit(CLOCK offset, void *data)
         return;
 
     /* check for delay of motor stop */
-    if (motor_stop_clk > 0 && maincpu_clk > motor_stop_clk) {
+    if (motor_stop_clk > 0 && maincpu_clk >= motor_stop_clk) {
         motor_stop_clk = 0;
         ui_display_tape_motor_status(0);
         datasette_motor = 0;
@@ -753,12 +740,17 @@ void datasette_set_motor(int flag)
             if (!datasette_motor) {
                 last_write_clk = (CLOCK)0;
                 datasette_start_motor();
-                ui_display_tape_motor_status(flag);
+                ui_display_tape_motor_status(1);
                 datasette_motor = 1;
             }
         }
         if (!flag && datasette_motor && motor_stop_clk == 0) {
             motor_stop_clk = maincpu_clk + MOTOR_DELAY;
+            if (!datasette_alarm_pending) {
+                /* make sure that the motor will stop */
+                alarm_set(datasette_alarm, motor_stop_clk);
+                datasette_alarm_pending = 1;
+            }
         }
     }
 }
@@ -822,8 +814,6 @@ void datasette_toggle_write_bit(int write_bit)
             } else {
                 bit_write();
             }
-        } else if (maincpu_clk < motor_stop_clk) {
-            bit_write();
         }
     }
 }
