@@ -69,32 +69,6 @@
 #define DRIVE_ACTIVE_RED     0
 #define DRIVE_ACTIVE_GREEN   1
 
-#define DRIVE_EXPANSION_2000(type) (        \
-        ((type) == DRIVE_TYPE_1541)         \
-        || ((type) == DRIVE_TYPE_1541II)    \
-        )
-
-#define DRIVE_EXPANSION_4000(type) (        \
-        ((type) == DRIVE_TYPE_1541)         \
-        || ((type) == DRIVE_TYPE_1541II)    \
-        )
-
-#define DRIVE_EXPANSION_6000(type) (        \
-        ((type) == DRIVE_TYPE_1541)         \
-        || ((type) == DRIVE_TYPE_1541II)    \
-        )
-
-#define DRIVE_EXPANSION_8000(type) (        \
-        ((type) == DRIVE_TYPE_1541)         \
-        || ((type) == DRIVE_TYPE_1541II)    \
-        )
-
-#define DRIVE_EXPANSION_A000(type) (        \
-        ((type) == DRIVE_TYPE_1541)         \
-        || ((type) == DRIVE_TYPE_1541II)    \
-        )
-
-
 /* Number of cycles before an attached disk becomes visible to the R/W head.
    This is mostly to make routines that auto-detect disk changes happy.  */
 #define DRIVE_ATTACH_DELAY           (3*600000)
@@ -106,6 +80,11 @@
    detached.  */
 #define DRIVE_ATTACH_DETACH_DELAY    (3*400000)
 
+/* Parallel cables available.  */
+#define DRIVE_PC_NONE     0
+#define DRIVE_PC_STANDARD 1
+#define DRIVE_PC_DD3      2
+
 /* ------------------------------------------------------------------------- */
 
 struct gcr_s;
@@ -212,8 +191,8 @@ typedef struct drive_s {
     /* What extension policy?  */
     int extend_image_policy;
 
-    /* Flag: Do we emulate a SpeedDOS-compatible parallel cable?  */
-    int parallel_cable_enabled;
+    /* Flag: What parallel cable do we emulate?  */
+    int parallel_cable;
 
     /* If the user does not want to extend the disk image and `ask mode' is
     selected this flag gets cleared.  */
@@ -236,6 +215,9 @@ typedef struct drive_s {
     int drive_ram2_enabled, drive_ram4_enabled, drive_ram6_enabled,
         drive_ram8_enabled, drive_rama_enabled;
 
+    /* Are the Professional DOS extentions enabled?  */
+    int profdos;
+
     /* Drive ROM starts here.  */
     WORD rom_start;
 
@@ -278,9 +260,18 @@ extern void drive_set_last_read(unsigned int track, unsigned int sector,
                                 BYTE *buffer, struct drive_context_s *drv);
 
 extern int drive_check_type(unsigned int drive_type, unsigned int dnr);
-extern int drive_check_extend_policy(unsigned int drive_type);
-extern int drive_check_idle_method(unsigned int drive_type);
-extern int drive_check_parallel_cable(unsigned int drive_type);
+extern int drive_check_extend_policy(int drive_type);
+extern int drive_check_idle_method(int drive_type);
+extern int drive_check_expansion(int drive_type);
+extern int drive_check_expansion2000(int drive_type);
+extern int drive_check_expansion4000(int drive_type);
+extern int drive_check_expansion6000(int drive_type);
+extern int drive_check_expansion8000(int drive_type);
+extern int drive_check_expansionA000(int drive_type);
+extern int drive_check_parallel_cable(int drive_type);
+extern int drive_check_extend_policy(int drive_type);
+extern int drive_check_idle_method(int drive_type);
+extern int drive_check_profdos(int drive_type);
 
 extern int drive_num_leds(unsigned int dnr);
 
