@@ -40,36 +40,41 @@ static int romset_firmware[1];
 static char *dos_rom_name_1571cr = NULL;
 
 
-static int set_dos_rom_name_1571cr(resource_value_t v, void *param)
+static int set_dos_rom_name_1571cr(const char *val, void *param)
 {
-    if (util_string_set(&dos_rom_name_1571cr, (const char *)v))
+    if (util_string_set(&dos_rom_name_1571cr, val))
         return 0;
 
     return iec128dcrrom_load_1571cr();
 }
 
-static int set_romset_firmware(resource_value_t v, void *param)
+static int set_romset_firmware(int val, void *param)
 {
     unsigned int num = (unsigned int)param;
 
-    romset_firmware[num] = (int)v;
+    romset_firmware[num] = val;
 
     return 0;
 }
 
-static const resource_t resources[] = {
-    { "DosName1571cr", RES_STRING, (resource_value_t)"d1571cr",
-      RES_EVENT_NO, NULL,
-      (void *)&dos_rom_name_1571cr, set_dos_rom_name_1571cr, NULL },
-    { "RomsetDosName1571cr", RES_INTEGER, (resource_value_t)0,
-      RES_EVENT_NO, NULL,
-      (void *)&romset_firmware[0], set_romset_firmware, (void *)0 },
+static const resource_string_t resources_string[] = {
+    { "DosName1571cr", "d1571cr", RES_EVENT_NO, NULL,
+      &dos_rom_name_1571cr, set_dos_rom_name_1571cr, NULL },
+    { NULL }
+};
+
+static const resource_int_t resources_int[] = {
+    { "RomsetDosName1571cr", 0, RES_EVENT_NO, NULL,
+      &romset_firmware[0], set_romset_firmware, (void *)0 },
     { NULL }
 };
 
 int iec128dcr_resources_init(void)
 {
-    return resources_register(resources);
+    if (resources_register_string(resources_string) < 0)
+        return -1;
+
+    return resources_register_int(resources_int);
 }
 
 void iec128dcr_resources_shutdown(void)
