@@ -36,6 +36,7 @@
 #include "attach.h"
 #include "clkguard.h"
 #include "cmdline.h"
+#include "crc32.h"
 #include "datasette.h"
 #include "debug.h"
 #include "event.h"
@@ -50,9 +51,7 @@
 #include "resources.h"
 #include "snapshot.h"
 #include "tape.h"
-#ifdef HAS_TRANSLATION
 #include "translate.h"
-#endif
 #include "types.h"
 #include "ui.h"
 #include "util.h"
@@ -92,7 +91,8 @@ static char *event_snapshot_dir = NULL;
 static char *event_start_snapshot = NULL;
 static char *event_end_snapshot = NULL;
 static char *event_snapshot_path_str = NULL;
-static unsigned int event_start_mode;
+static int event_start_mode;
+static int event_image_include;
 
 
 static char *event_snapshot_path(const char *snapshot_file)
@@ -118,14 +118,18 @@ static int event_image_append(const char *filename,
     while (event_image_list_ptr->next != NULL) {
         if (strcmp(filename, event_image_list_ptr->next->orig_filename) == 0) {
             if (mapped_name != NULL) {
-                if (append == 0)
-                    *mapped_name = lib_stralloc(event_image_list_ptr->next->mapped_filename);
-                else
+                if (append == 0) {
+                    if (event_image_list_ptr->next->mapped_filename != NULL) {
+                        *mapped_name = lib_stralloc(event_image_list_ptr->next->mapped_filename);
+                    } else {
+                        return 1;
+                    }
+                } else {
                     event_image_list_ptr->next->mapped_filename = lib_stralloc(*mapped_name);
+                }
             }
             return 0;
         }
-
         event_image_list_ptr = event_image_list_ptr->next;
     }
 
@@ -136,7 +140,7 @@ static int event_image_append(const char *filename,
     event_image_list_ptr->next = NULL;
     event_image_list_ptr->orig_filename = lib_stralloc(filename);
     event_image_list_ptr->mapped_filename = NULL;
-    if (mapped_name != NULL)
+    if (mapped_name != NULL && append)
         event_image_list_ptr->mapped_filename = lib_stralloc(*mapped_name);
 
     return 1;
@@ -148,39 +152,54 @@ void event_record_attach_in_list(event_list_state_t *list, unsigned int unit,
 {
     char *event_data;
     unsigned int size;
+    char *strdir, *strfile;
 
     list->current->type = EVENT_ATTACHIMAGE;
     list->current->clk = maincpu_clk;
     list->current->next
         = (event_list_t *)lib_calloc(1, sizeof(event_list_t));
 
-    size = strlen(filename) + 3;
+    util_fname_split(filename, &strdir, &strfile);
+
+    if (event_image_include)
+        size = strlen(filename) + 3;
+    else
+        size = strlen(strfile) + sizeof(long) + 4;
 
     event_data = lib_malloc(size);
     event_data[0] = unit;
     event_data[1] = read_only;
-    strcpy(&event_data[2], filename);
 
-    if (event_image_append(filename, NULL, 0) == 1) {
-        FILE *fd;
-        size_t file_len = 0;
+    if (event_image_include) {
+        strcpy(&event_data[2], filename);
+        if (event_image_append(filename, NULL, 0) == 1) {
+            FILE *fd;
+            size_t file_len = 0;
         
-        fd = fopen(filename, MODE_READ);
+            fd = fopen(filename, MODE_READ);
 
-        if (fd != NULL) {
-            file_len = util_file_length(fd);
-            event_data = lib_realloc(event_data, size + file_len);
+            if (fd != NULL) {
+                file_len = util_file_length(fd);
+                event_data = lib_realloc(event_data, size + file_len);
 
-            if (fread(&event_data[size], file_len, 1, fd) != 1)
-                log_error(event_log, "Cannot load image file %s", filename);
+                if (fread(&event_data[size], file_len, 1, fd) != 1)
+                    log_error(event_log, "Cannot load image file %s", filename);
 
-            fclose(fd);
-        } else {
-            log_error(event_log, "Cannot open image file %s", filename);
+                fclose(fd);
+            } else {
+                log_error(event_log, "Cannot open image file %s", filename);
+            }
+            size += file_len;
         }
-        size += file_len;
+    } else {
+        strcpy(&event_data[2], "");
+        *(unsigned long *)(event_data + 3) = crc32_file(filename);
+        strcpy(&event_data[3 + sizeof(long)], strfile);
     }
 
+    lib_free(strdir);
+    lib_free(strfile);
+
     list->current->size = size;
     list->current->data = event_data;
     list->current = list->current->next;
@@ -199,62 +218,63 @@ void event_record_attach_image(unsigned int unit, const char *filename,
 static void event_playback_attach_image(void *data, unsigned int size)
 {
     unsigned int unit, read_only;
-    char *orig_filename, *filename;
+    char *orig_filename, *filename = NULL;
     size_t file_len;
-    char *str;
+    unsigned long crc_to_attach;
 
     unit = (unsigned int)((char*)data)[0];
     read_only = (unsigned int)((char*)data)[1];
     orig_filename = &((char*)data)[2];
-    file_len  = size - strlen(orig_filename) - 3;
 
-    if (file_len > 0) {
-        FILE *fd;
+    if (*orig_filename == 0) {
+        /* no image attached */
+        orig_filename = (char *) data + 3 + sizeof(long);
 
-        str = archdep_tmpnam();
-        filename = util_concat(str, FSDEV_EXT_SEP_STR,
-                                util_get_extension(orig_filename), NULL);
-        lib_free(str);
-
-        fd = fopen(filename, MODE_WRITE);
-        if (fd == NULL) {
-#ifdef HAS_TRANSLATION
-            ui_error(translate_text(IDGS_CANNOT_CREATE_IMAGE_S), filename);
-#else
-            ui_error(_("Cannot create image file %s"), filename);
-#endif
-            goto error;
-        }
-
-        if (fwrite((char*)data + strlen(orig_filename) + 3, file_len, 1, fd) != 1) {
-#ifdef HAS_TRANSLATION
-            ui_error(translate_text(IDGS_CANNOT_WRITE_IMAGE_FILE_S), filename);
-#else
-            ui_error(_("Cannot write image file %s"), filename);
-#endif
-            goto error;
-        }
-
-        fclose(fd);
-        event_image_append(orig_filename, &filename, 1);
-    } else {
         if (event_image_append(orig_filename, &filename, 0) != 0) {
-#ifdef HAS_TRANSLATION
-            ui_error(translate_text(IDGS_CANNOT_FIND_MAPPED_NAME_S), orig_filename);
-#else
-            ui_error(_("Cannot find mapped name for %s"), orig_filename);
-#endif
-            return;
+            crc_to_attach = *(unsigned long *)(((char *)data)+3);
+            do {
+                filename = ui_get_file("Please attach image %s (CRC32 checksum 0x%x)",
+                            (char *) data + 3 + sizeof(long), crc_to_attach);
+            } while (filename != NULL && crc_to_attach != crc32_file(filename));
+            if (filename == NULL) {
+                ui_error("Image wasn't attached. Playback will probably get out of sync.");
+                return;
+            }
+            event_image_append(orig_filename, &filename, 1);
+        }
+    } else {
+        file_len  = size - strlen(orig_filename) - 3;
+
+        if (file_len > 0) {
+            FILE *fd;
+
+            fd = archdep_mkstemp_fd(&filename, MODE_WRITE);
+    
+            if (fd == NULL) {
+                ui_error(translate_text(IDGS_CANNOT_CREATE_IMAGE), filename);
+                goto error;
+            }
+
+            if (fwrite((char*)data + strlen(orig_filename) + 3, file_len, 1, fd) != 1) {
+                ui_error(translate_text(IDGS_CANNOT_WRITE_IMAGE_FILE_S), filename);
+                goto error;
+            }
+
+            fclose(fd);
+            event_image_append(orig_filename, &filename, 1);
+        } else {
+            if (event_image_append(orig_filename, &filename, 0) != 0) {
+                ui_error(translate_text(IDGS_CANNOT_FIND_MAPPED_NAME_S), orig_filename);
+                return;
+            }
         }
     }
-
     /* now filename holds the name to attach    */
     /* FIXME: read_only isn't handled for tape  */
     if (unit == 1) {
         tape_image_event_playback(unit, filename);
     } else {
-        resources_set_sprintf("AttachDevice%dReadonly", 
-                                (resource_value_t) read_only, unit);
+        resources_set_int_sprintf("AttachDevice%dReadonly", read_only, unit);
         file_system_event_playback(unit, filename);
     }
     
@@ -303,6 +323,7 @@ void event_record_in_list(event_list_state_t *list, unsigned int type,
     list->current->next
         = (event_list_t *)lib_calloc(1, sizeof(event_list_t));
     list->current = list->current->next;
+    list->current->type = EVENT_LIST_END;
 }
 
 void event_record(unsigned int type, void *data, unsigned int size)
@@ -408,35 +429,35 @@ void event_playback_event_list(event_list_state_t *list)
 
     while (current->type != EVENT_LIST_END) {
         switch (current->type) {
-            case EVENT_SYNC_TEST:
-                break;
-            case EVENT_KEYBOARD_DELAY:
-                keyboard_register_delay(*(unsigned int*)current->data);
-                break;
-            case EVENT_KEYBOARD_MATRIX:
-                keyboard_event_delayed_playback(current->data);
-                break;
-            case EVENT_KEYBOARD_RESTORE:
-                keyboard_restore_event_playback(0, current->data);
-                break;
-            case EVENT_KEYBOARD_CLEAR:
-                keyboard_register_clear();
-                break;
-            case EVENT_JOYSTICK_DELAY:
-                joystick_register_delay(*(unsigned int*)current->data);
-                break;
-            case EVENT_JOYSTICK_VALUE:
-                joystick_event_delayed_playback(current->data);
-                break;
-            case EVENT_DATASETTE:
-                datasette_event_playback(0, current->data);
-                break;
-            case EVENT_RESETCPU:
-                machine_reset_event_playback(0, current->data);
-                break;
-            case EVENT_ATTACHDISK:
-            case EVENT_ATTACHTAPE:
-              {
+          case EVENT_SYNC_TEST:
+            break;
+          case EVENT_KEYBOARD_DELAY:
+            keyboard_register_delay(*(unsigned int*)current->data);
+            break;
+          case EVENT_KEYBOARD_MATRIX:
+            keyboard_event_delayed_playback(current->data);
+            break;
+          case EVENT_KEYBOARD_RESTORE:
+            keyboard_restore_event_playback(0, current->data);
+            break;
+          case EVENT_KEYBOARD_CLEAR:
+            keyboard_register_clear();
+            break;
+          case EVENT_JOYSTICK_DELAY:
+            joystick_register_delay(*(unsigned int*)current->data);
+            break;
+          case EVENT_JOYSTICK_VALUE:
+            joystick_event_delayed_playback(current->data);
+            break;
+          case EVENT_DATASETTE:
+            datasette_event_playback(0, current->data);
+            break;
+          case EVENT_RESETCPU:
+            machine_reset_event_playback(0, current->data);
+            break;
+          case EVENT_ATTACHDISK:
+          case EVENT_ATTACHTAPE:
+            {
                 /* in fact this is only for detaching */
                 unsigned int unit;
 
@@ -447,15 +468,15 @@ void event_playback_event_list(event_list_state_t *list)
                 else
                     file_system_event_playback(unit, NULL);
                 break;
-              }
-            case EVENT_ATTACHIMAGE:
-                event_playback_attach_image(current->data, current->size);
-                break;
-            case EVENT_RESOURCE:
-                resources_set_value_event(current->data, current->size);
-                break;
-            default:
-                log_error(event_log, "Unknow event type %i.", current->type);
+            }
+          case EVENT_ATTACHIMAGE:
+            event_playback_attach_image(current->data, current->size);
+            break;
+          case EVENT_RESOURCE:
+            resources_set_value_event(current->data, current->size);
+            break;
+          default:
+            log_error(event_log, "Unknow event type %i.", current->type);
         }
         current = current->next;
     }
@@ -619,11 +640,7 @@ static void event_record_start_trap(WORD addr, void *data)
       case EVENT_START_MODE_FILE_SAVE:
         if (machine_write_snapshot(event_snapshot_path(event_start_snapshot),
                                     1, 1, 0) < 0) {
-#ifdef HAS_TRANSLATION
             ui_error(translate_text(IDGS_CANT_CREATE_START_SNAP_S), 
-#else
-            ui_error(_("Could not create start snapshot file %s."), 
-#endif
                         event_snapshot_path(event_start_snapshot));
             ui_display_recording(0);
             return;
@@ -638,11 +655,7 @@ static void event_record_start_trap(WORD addr, void *data)
       case EVENT_START_MODE_FILE_LOAD:
         if (machine_read_snapshot(
                 event_snapshot_path(event_end_snapshot), 1) < 0) {
-#ifdef HAS_TRANSLATION
             ui_error(translate_text(IDGS_ERROR_READING_END_SNAP_S),
-#else
-            ui_error(_("Error reading end snapshot file %s."),
-#endif
                         event_snapshot_path(event_end_snapshot));
             return;
         }
@@ -663,6 +676,7 @@ static void event_record_start_trap(WORD addr, void *data)
       case EVENT_START_MODE_PLAYBACK:
         cut_list(event_list->current->next);
         event_list->current->next = NULL;
+        event_list->current->type = EVENT_LIST_END;
         event_destroy_image_list();
         event_write_version();
         record_active = 1;
@@ -694,7 +708,6 @@ int event_record_start(void)
     if (record_active != 0)
         return -1;
 
-
     interrupt_maincpu_trigger_trap(event_record_start_trap, (void *)0);
 
     ui_display_recording(1);
@@ -706,11 +719,7 @@ static void event_record_stop_trap(WORD addr, void *data)
 {
     if (machine_write_snapshot(
             event_snapshot_path(event_end_snapshot), 1, 1, 1) < 0) {
-#ifdef HAS_TRANSLATION
         ui_error(translate_text(IDGS_CANT_CREATE_END_SNAP_S),
-#else
-        ui_error(_("Could not create end snapshot file %s."),
-#endif
                     event_snapshot_path(event_end_snapshot));
         return;
     }
@@ -774,11 +783,7 @@ static void event_playback_start_trap(WORD addr, void *data)
         event_snapshot_path(event_end_snapshot), &major, &minor, machine_name);
 
     if (s == NULL) {
-#ifdef HAS_TRANSLATION
         ui_error(translate_text(IDGS_CANT_OPEN_END_SNAP_S), 
-#else
-        ui_error(_("Could not open end snapshot file %s."), 
-#endif
                     event_snapshot_path(event_end_snapshot));
         ui_display_playback(0, NULL);
         return;
@@ -789,11 +794,7 @@ static void event_playback_start_trap(WORD addr, void *data)
 
     if (event_snapshot_read_module(s, 1) < 0) {
         snapshot_close(s);
-#ifdef HAS_TRANSLATION
         ui_error(translate_text(IDGS_CANT_FIND_SECTION_END_SNAP));
-#else
-        ui_error(_("Could not find event section in end snapshot file."));
-#endif
         ui_display_playback(0, NULL);
         return;
     }
@@ -813,11 +814,7 @@ static void event_playback_start_trap(WORD addr, void *data)
                     event_snapshot_path(event_start_snapshot), 0) < 0)
             {
                 char *st = lib_stralloc(event_snapshot_path((char *)(&data[1])));
-#ifdef HAS_TRANSLATION
                 ui_error(translate_text(IDGS_ERROR_READING_START_SNAP_TRIED),
-#else
-                ui_error(_("Error reading start snapshot file. Tried %s and %s"),
-#endif
                             st, event_snapshot_path(event_start_snapshot));
                 lib_free(st);
                 ui_display_playback(0, NULL);
@@ -843,11 +840,7 @@ static void event_playback_start_trap(WORD addr, void *data)
     } else {
         if (machine_read_snapshot(
                 event_snapshot_path(event_start_snapshot), 0) < 0) {
-#ifdef HAS_TRANSLATION
             ui_error(translate_text(IDGS_ERROR_READING_START_SNAP));
-#else
-            ui_error(_("Error reading start snapshot file."));
-#endif
             ui_display_playback(0, NULL);
             return;
         }
@@ -900,11 +893,7 @@ static void event_record_set_milestone_trap(WORD addr, void *data)
 {
     if (machine_write_snapshot(
         event_snapshot_path(event_end_snapshot), 1, 1, 1) < 0) {
-#ifdef HAS_TRANSLATION
             ui_error(translate_text(IDGS_CANT_CREATE_END_SNAP_S),
-#else
-            ui_error(_("Could not create end snapshot file %s."),
-#endif
                         event_snapshot_path(event_end_snapshot));
     } else {
         milestone_timestamp_alarm = next_timestamp_clk;
@@ -933,11 +922,7 @@ static void event_record_reset_milestone_trap(WORD addr, void *data)
 
     if (machine_read_snapshot(
             event_snapshot_path(event_end_snapshot), 1) < 0) {
-#ifdef HAS_TRANSLATION
         ui_error(translate_text(IDGS_ERROR_READING_END_SNAP_S),
-#else
-        ui_error(_("Error reading end snapshot file %s."),
-#endif
                     event_snapshot_path(event_end_snapshot));
         return;
     }
@@ -1023,7 +1008,7 @@ int event_snapshot_read_module(struct snapshot_s *s, int event_mode)
             1.14.x so there might exist history files with TIMESTAMP events)
         */
         do {
-            if (SMR_DW_INT(m, (int*)&(type)) < 0) {
+            if (SMR_DW_UINT(m, &(type)) < 0) {
                 snapshot_module_close(m);
                 return -1;
             }
@@ -1033,7 +1018,7 @@ int event_snapshot_read_module(struct snapshot_s *s, int event_mode)
                 return -1;
             }
 
-            if (SMR_DW_INT(m, (int*)&(size)) < 0) {
+            if (SMR_DW_UINT(m, &(size)) < 0) {
                 snapshot_module_close(m);
                 return -1;
             }
@@ -1133,9 +1118,9 @@ int event_snapshot_write_module(struct snapshot_s *s, int event_mode)
 
 /*-----------------------------------------------------------------------*/
 
-static int set_event_snapshot_dir(resource_value_t v, void *param)
+static int set_event_snapshot_dir(const char *val, void *param)
 {
-    const char *s = (const char *)v;
+    const char *s = val;
 
     /* Make sure that the string ends with FSDEV_DIR_SEP_STR */
     if (s[strlen(s) - 1] == FSDEV_DIR_SEP_CHR) {
@@ -1149,28 +1134,24 @@ static int set_event_snapshot_dir(resource_value_t v, void *param)
     return 0;
 }
 
-static int set_event_start_snapshot(resource_value_t v, void *param)
+static int set_event_start_snapshot(const char *val, void *param)
 {
-    if (util_string_set(&event_start_snapshot, (const char *)v))
+    if (util_string_set(&event_start_snapshot, val))
         return 0;
 
     return 0;
 }
 
-static int set_event_end_snapshot(resource_value_t v, void *param)
+static int set_event_end_snapshot(const char *val, void *param)
 {
-    if (util_string_set(&event_end_snapshot, (const char *)v))
+    if (util_string_set(&event_end_snapshot, val))
         return 0;
 
     return 0;
 }
 
-static int set_event_start_mode(resource_value_t v, void *param)
+static int set_event_start_mode(int mode, void *param)
 {
-    unsigned int mode;
-
-    mode = (unsigned int)v;
-
     if (mode != EVENT_START_MODE_FILE_SAVE
         && mode != EVENT_START_MODE_FILE_LOAD
         && mode != EVENT_START_MODE_RESET
@@ -1182,27 +1163,37 @@ static int set_event_start_mode(resource_value_t v, void *param)
     return 0;
 }
 
-static const resource_t resources[] = {
-    { "EventSnapshotDir", RES_STRING, 
-      (resource_value_t)FSDEVICE_DEFAULT_DIR FSDEV_DIR_SEP_STR,
-      RES_EVENT_NO, NULL,
-      (void *)&event_snapshot_dir, set_event_snapshot_dir, NULL },
-    { "EventStartSnapshot", RES_STRING, (resource_value_t)EVENT_START_SNAPSHOT,
-      RES_EVENT_NO, NULL,
-      (void *)&event_start_snapshot, set_event_start_snapshot, NULL },
-    { "EventEndSnapshot", RES_STRING, (resource_value_t)EVENT_END_SNAPSHOT,
-      RES_EVENT_NO, NULL,
-      (void *)&event_end_snapshot, set_event_end_snapshot, NULL },
-    { "EventStartMode", RES_INTEGER,
-      (resource_value_t)EVENT_START_MODE_FILE_SAVE,
-      RES_EVENT_NO, NULL,
-      (void *)&event_start_mode, set_event_start_mode, NULL },
+static int set_event_image_include(int enable, void *param)
+{
+    event_image_include = enable;
+    return 0;
+}
+
+static const resource_string_t resources_string[] = {
+    { "EventSnapshotDir", 
+      FSDEVICE_DEFAULT_DIR FSDEV_DIR_SEP_STR, RES_EVENT_NO, NULL,
+      &event_snapshot_dir, set_event_snapshot_dir, NULL },
+    { "EventStartSnapshot", EVENT_START_SNAPSHOT, RES_EVENT_NO, NULL,
+      &event_start_snapshot, set_event_start_snapshot, NULL },
+    { "EventEndSnapshot", EVENT_END_SNAPSHOT, RES_EVENT_NO, NULL,
+      &event_end_snapshot, set_event_end_snapshot, NULL },
+    { NULL }
+};
+
+static const resource_int_t resources_int[] = {
+    { "EventStartMode", EVENT_START_MODE_FILE_SAVE, RES_EVENT_NO, NULL,
+      &event_start_mode, set_event_start_mode, NULL },
+    { "EventImageInclude", 1, RES_EVENT_NO, NULL,
+      &event_image_include, set_event_image_include, NULL },
     { NULL }
 };
 
 int event_resources_init(void)
 {
-    return resources_register(resources);
+    if (resources_register_string(resources_string) < 0)
+        return -1;
+
+    return resources_register_int(resources_int);
 }
 
 void event_shutdown(void)
@@ -1222,19 +1213,14 @@ static int cmdline_help(const char *param, void *extra_param)
     return event_playback_start();
 }
 
-#ifdef HAS_TRANSLATION
 static const cmdline_option_t cmdline_options[] = {
-    { "-playback", CALL_FUNCTION, 0, cmdline_help, NULL, NULL, NULL,
-      0, IDCLS_PLAYBACK_RECORDED_EVENTS },
+    { "-playback", CALL_FUNCTION, 0,
+      cmdline_help, NULL, NULL, NULL,
+      USE_PARAM_STRING, USE_DESCRIPTION_ID,
+      IDCLS_UNUSED, IDCLS_PLAYBACK_RECORDED_EVENTS,
+      NULL, NULL },
     { NULL }
 };
-#else
-static const cmdline_option_t cmdline_options[] = {
-    { "-playback", CALL_FUNCTION, 0, cmdline_help, NULL, NULL, NULL,
-      NULL, N_("Playback recorded events") },
-    { NULL }
-};
-#endif
 
 int event_cmdline_options_init(void)
 {
