@@ -39,9 +39,7 @@
 #include "palette.h"
 #include "resources.h"
 #include "screenshot.h"
-#ifdef HAS_TRANSLATION
 #include "translate.h"
-#endif
 #include "ui.h"
 #include "util.h"
 #include "vsync.h"
@@ -49,6 +47,7 @@
 static ffmpegdrv_codec_t avi_audio_codeclist[] = { 
     { CODEC_ID_MP2, "MP2" },
     { CODEC_ID_MP3, "MP3" },
+    { CODEC_ID_PCM_S16LE, "PCM uncompressed" },
     { 0, NULL }
 };
 
@@ -183,27 +182,19 @@ int ffmpegdrv_resources_init(void)
 
 /*---------- Commandline options --------------------------------------*/
 
-#ifdef HAS_TRANSLATION
 static const cmdline_option_t cmdline_options[] = {
-    { "-ffmpegaudiobitrate", SET_RESOURCE, 1, NULL, NULL,
-      "FFMPEGAudioBitrate", NULL,
-      IDCLS_P_VALUE, IDCLS_SET_AUDIO_STREAM_BITRATE },
-    { "-ffmpegvideobitrate", SET_RESOURCE, 1, NULL, NULL,
-      "FFMPEGVideoBitrate", NULL,
-      IDCLS_P_VALUE, IDCLS_SET_VIDEO_STREAM_BITRATE },
+    { "-ffmpegaudiobitrate", SET_RESOURCE, 1,
+      NULL, NULL, "FFMPEGAudioBitrate", NULL,
+      USE_PARAM_ID, USE_DESCRIPTION_ID,
+      IDCLS_P_VALUE, IDCLS_SET_AUDIO_STREAM_BITRATE,
+      NULL, NULL },
+    { "-ffmpegvideobitrate", SET_RESOURCE, 1,
+      NULL, NULL, "FFMPEGVideoBitrate", NULL,
+      USE_PARAM_ID, USE_DESCRIPTION_ID,
+      IDCLS_P_VALUE, IDCLS_SET_VIDEO_STREAM_BITRATE,
+      NULL, NULL },
     { NULL }
 };
-#else
-static const cmdline_option_t cmdline_options[] = {
-    { "-ffmpegaudiobitrate", SET_RESOURCE, 1, NULL, NULL,
-      "FFMPEGAudioBitrate", NULL,
-      N_("<value>"), N_("Set bitrate for audio stream in media file") },
-    { "-ffmpegvideobitrate", SET_RESOURCE, 1, NULL, NULL,
-      "FFMPEGVideoBitrate", NULL,
-      N_("<value>"), N_("Set bitrate for video stream in media file") },
-    { NULL }
-};
-#endif
 
 int ffmpegdrv_cmdline_options_init(void)
 {
@@ -536,8 +527,10 @@ static void ffmpegdrv_init_video(screenshot_t *screenshot)
     c->pix_fmt = PIX_FMT_YUV420P;
 
     /* FFV1 isn't strict standard compliant */
-    if (c->codec_id == CODEC_ID_FFV1)
+    if (c->codec_id == CODEC_ID_FFV1) {
         c->strict_std_compliance = -1;
+        c->pix_fmt = PIX_FMT_RGBA32;
+    }
 
     video_st = st;
     video_pts = 0;
@@ -560,20 +553,12 @@ static int ffmpegdrv_init_file(void)
     (*ffmpeglib.p_dump_format)(ffmpegdrv_oc, 0, ffmpegdrv_oc->filename, 1);
 
     if (video_st && (ffmpegdrv_open_video(ffmpegdrv_oc, video_st) < 0)) {
-#ifdef HAS_TRANSLATION
         ui_error(translate_text(IDGS_FFMPEG_CANNOT_OPEN_VSTREAM));
-#else
-        ui_error(_("ffmpegdrv: Cannot open video stream"));
-#endif
         screenshot_stop_recording();
         return -1;
     }
     if (audio_st && (ffmpegdrv_open_audio(ffmpegdrv_oc, audio_st) < 0)) {
-#ifdef HAS_TRANSLATION
         ui_error(translate_text(IDGS_FFMPEG_CANNOT_OPEN_ASTREAM));
-#else
-        ui_error(_("ffmpegdrv: Cannot open audio stream"));
-#endif
         screenshot_stop_recording();
         return -1;
     }
@@ -582,11 +567,7 @@ static int ffmpegdrv_init_file(void)
         if ((*ffmpeglib.p_url_fopen)(&ffmpegdrv_oc->pb, ffmpegdrv_oc->filename,
                             URL_WRONLY) < 0) 
         {
-#ifdef HAS_TRANSLATION
             ui_error(translate_text(IDGS_FFMPEG_CANNOT_OPEN_S), ffmpegdrv_oc->filename);
-#else
-            ui_error(_("ffmpegdrv: Cannot open %s"), ffmpegdrv_oc->filename);
-#endif
             screenshot_stop_recording();
             return -1;
         }
@@ -799,7 +780,12 @@ static gfxoutputdrv_t ffmpeg_drv[] = {
         ffmpegdrv_close,
         ffmpegdrv_write,
         ffmpegdrv_save,
+#ifdef FEATURE_CPUMEMHISTORY
+        ffmpegdrv_record,
+        NULL
+#else
         ffmpegdrv_record
+#endif
     },
 /*
 {
@@ -833,7 +819,11 @@ static gfxoutputdrv_t ffmpeg_drv[] = {
         ffmpegdrv_record
     },
 */
-    { NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL }
+    { NULL, NULL, NULL, NULL, NULL, NULL, NULL, 
+#ifdef FEATURE_CPUMEMHISTORY
+      NULL,
+#endif
+      NULL }
 };
 
 void gfxoutput_init_ffmpeg(void)
