@@ -69,7 +69,7 @@ static int jpegdrv_open(screenshot_t *screenshot, const char *filename)
   screenshot->gfxoutputdrv_data = sdata;
   sdata->line = 0;
   sdata->ext_filename=util_add_extension_const(filename, jpeg_drv.default_extension);
-  sdata->fd = fopen(filename, "wb");
+  sdata->fd = fopen(sdata->ext_filename, "wb");
   if (sdata->fd==NULL)
   {
     jpeg_destroy_compress(&cinfo);
@@ -135,6 +135,84 @@ static int jpegdrv_save(screenshot_t *screenshot, const char *filename)
   return 0;
 }
 
+#ifdef FEATURE_CPUMEMHISTORY
+static FILE *jpegdrv_memmap_fd;
+static char *jpegdrv_memmap_ext_filename;
+static BYTE *jpegdrv_memmap_data;
+
+static int jpegdrv_close_memmap(void)
+{
+  jpeg_finish_compress(&cinfo);
+  fclose(jpegdrv_memmap_fd);
+  jpeg_destroy_compress(&cinfo);
+  lib_free(jpegdrv_memmap_data);
+  lib_free(jpegdrv_memmap_ext_filename);
+
+  return 0;
+}
+
+static int jpegdrv_write_memmap(int line, int x_size, BYTE *gfx, BYTE *palette)
+{
+  int i;
+  BYTE pixval;
+  JSAMPROW rowpointer[1];
+
+  for (i=0; i<x_size; i++)
+  {
+    pixval = gfx[(line*x_size)+i];
+    jpegdrv_memmap_data[i*3]=palette[pixval*3];
+    jpegdrv_memmap_data[(i*3)+1]=palette[(pixval*3)+1];
+    jpegdrv_memmap_data[(i*3)+2]=palette[(pixval*3)+2];
+  }
+  rowpointer[0]=jpegdrv_memmap_data;
+  jpeg_write_scanlines(&cinfo, rowpointer, 1);
+
+  return 0;
+}
+
+static int jpegdrv_open_memmap(const char *filename, int x_size, int y_size)
+{
+  cinfo.err = jpeg_std_error(&jerr);
+  jpeg_create_compress(&cinfo);
+  jpegdrv_memmap_ext_filename=util_add_extension_const(filename, jpeg_drv.default_extension);
+  jpegdrv_memmap_fd = fopen(jpegdrv_memmap_ext_filename, "wb");
+  if (jpegdrv_memmap_fd==NULL)
+  {
+    jpeg_destroy_compress(&cinfo);
+    lib_free(jpegdrv_memmap_ext_filename);
+    return -1;
+  }
+  jpeg_stdio_dest(&cinfo, jpegdrv_memmap_fd);
+  jpegdrv_memmap_data = (BYTE *)lib_malloc(x_size*3);
+  cinfo.image_width = x_size;
+  cinfo.image_height = y_size;
+  cinfo.input_components = 3;
+  cinfo.in_color_space = JCS_RGB;
+  jpeg_set_defaults(&cinfo);
+  jpeg_start_compress(&cinfo, TRUE);
+
+  return 0;
+}
+
+static int jpegdrv_save_memmap(const char *filename, int x_size, int y_size, BYTE *gfx, BYTE *palette)
+{
+  int line;
+
+  if (jpegdrv_open_memmap(filename, x_size, y_size) < 0)
+    return -1;
+
+  for (line = 0; line < y_size; line++)
+  {
+    jpegdrv_write_memmap(line, x_size, gfx, palette);
+  }
+
+  if (jpegdrv_close_memmap() < 0)
+    return -1;
+
+  return 0;
+}
+#endif
+
 static gfxoutputdrv_t jpeg_drv =
 {
     "JPEG",
@@ -144,7 +222,12 @@ static gfxoutputdrv_t jpeg_drv =
     jpegdrv_close,
     jpegdrv_write,
     jpegdrv_save,
+#ifdef FEATURE_CPUMEMHISTORY
+    NULL,
+    jpegdrv_save_memmap
+#else
     NULL
+#endif
 };
 
 void gfxoutput_init_jpeg(void)
