@@ -370,18 +370,22 @@ const char info_contrib_text[] =
 "  in the Win32 and MSDOS port. He also wrote the BeOS port and\n"
 "  implemented video/audio capture support.\n"
 "  Improved history recording/playback and implented support for\n"
-"  video recording and netlink feature. Various bug(fixe)s. ;-)\n"
+"  video recording and netlink feature. Made the win32 user\n"
+"  changable keyboard shortcut system. Various bug(fixe)s. ;-)\n"
 "\n"
 "  Martin Pottendorfer <Martin.Pottendorfer@aut.alcatel.at>\n"
 "  Implemented Gnome Port based on Oliver Schaertels GTK+ port\n"
 "  Added support code for internationalization based on gettext\n"
+"  Improved the *nix fullscreen support\n"
 "  Translated the UI to German\n"
 "  Implemented the fliplists + ui (unix).\n"
 "\n"
 "  Spiro Trikaliotis <Spiro.Trikaliotis@gmx.de> wrote the Win32\n"
 "  console implementation for the built-in monitor, corrected some\n"
-"  REU related bugs, added support for the TFE and RR-Net\n"
-"  (cs8900a), and wrote some further patches.\n"
+"  REU related bugs, improved the CIA emulation, added com-port CIA\n"
+"  support to the win32 port, added text copy and paste support to\n"
+"  the win32 port, added support for the TFE and RR-Net (cs8900a),\n"
+"  and wrote some further patches.\n"
 "\n"
 "  David Hansel <david@hansels.net> wrote the Star NL10 printer\n"
 "  driver, implemented IEC devices and improved the tape emulation.\n"
@@ -395,12 +399,14 @@ const char info_contrib_text[] =
 "  Wrote the c64 +60K, +256K and 256K memory expansions code. Wrote\n"
 "  the pet REU code. Wrote the plus4 memory expansions code.\n"
 "  Made the ethernet support for the Msdos port. Maintains the\n"
-"  RiscOS, QNX 6.x, Solaris, GP2X, Minix 3.x, Amiga, ppc-BeOS and\n"
-"  newly resurrected OS/2 binary ports. Added new .crt support. Added\n"
-"  new screenshot formats. Added new sound recording support. Added\n"
-"  SIDcart support for pet, plus4 and vic20. Improved the MMC64\n"
-"  emulation. Added 2 MHz mode for x128. And lots of other fixes\n"
-"  and improvements.\n"
+"  RiscOS, QNX 4.x, QNX 6.x, SkyOS, Solaris, Openserver, Unixware,\n"
+"  HPUX, GP2X, Minix 3.x, Amiga, ppc-BeOS and newly resurrected OS/2\n"
+"  binary ports. Added new .crt support. Added new screenshot formats.\n"
+"  Added new sound recording support. Added SIDcart support for pet,\n"
+"  plus4 and vic20. Improved the MMC64 emulation. Added 2 MHz mode for\n"
+"  x128. Added the Hummer userport joystick emulation. Added text copy\n"
+"  and paste support to the amiga and beos ports. Added DQBB and Isepic\n"
+"  cartridge support. And lots of other fixes and improvements.\n"
 "\n"
 "  Christian Vogelgsang <chris@vogelgsang.org> maintains the\n"
 "  Mac OS X port. Added Intel Mac support and universal binary\n"
@@ -408,6 +414,29 @@ const char info_contrib_text[] =
 "  and the bindist bundle tool. Improved the TFE chip emulation.\n"
 "  Added some Gtk+ fixes.\n"
 "\n"
+"  Fabrizio Gennari <fabrizio.ge@tiscalinet.it> added some\n"
+"  improvements to the MSDOS- and GTK port.\n"
+"\n"
+"  Hannu Nuotio <<hannu.nuotio@tut.fi> implemented DTV flash\n"
+"  emulation, DTV support in the monitor, large parts of the\n"
+"  DTV VIC emulation, burst mode and skip cycle emulation\n"
+"  as well as many other things. Added experimental NEOS\n"
+"  and Amiga mouse support. Fixed mouse support for single size in\n"
+"  unix. Fixed mouse grab and menu popup for xaw. Added new monitor\n"
+"  commands and features. Added the memmap feature. Made MIDI\n"
+"  support and MIDI driver code for *nix.\n"
+"\n"
+"  M. Kiesel <mayne@users.sourceforge.net> started implementing\n"
+"  x64dtv. The C64DTV memory model and early versions of the\n"
+"  DMA and Blitter engine have been implemented by him. Added new\n"
+"  monitor commands and features.\n"
+"\n"
+"  Daniel Kahlin <daniel@kahlin.net> Worked on DTV VIC emulation,\n"
+"  palette, DTV SID support in resid, better DMA/Blitter support\n"
+"  and did lots of refactoring. Added new monitor commands and\n"
+"  features. Improved the VIC emulation for xvic. Made MIDI driver\n"
+"  code for win32.\n"
+"\n"
 "Former team members:\n"
 "\n"
 "  Thomas Bretz <tbretz@ph.tum.de>\n"
@@ -562,7 +591,7 @@ const char info_contrib_text[] =
 "  Manfred Spraul <manfreds@colorfullife.com> wrote the MS-Windows\n"
 "  text lister.\n"
 "\n"
-"  Peter Karlsson <peter@softwolves.pp.se> provided the swedish\n"
+"  Peter Krefting <peter@softwolves.pp.se> provided the swedish\n"
 "  UI translations.\n"
 "\n"
 "  Czirkos Zoltan <cirix@fw.hu> and Karai Csaba <cskarai@freemail.hu>\n"
@@ -610,9 +639,6 @@ const char info_contrib_text[] =
 "\n"
 "  ck! <pixelite@lycos.de> provided a win32 cbm character font.\n"
 "\n"
-"  Fabrizio Gennari <fabrizio.ge@tiscalinet.it> added some\n"
-"  improvements to the MSDOS- and GTK port.\n"
-"\n"
 "  Dirk Jagdmann <doj@cubic.org> wrote the Catweasel sound driver.\n"
 "\n"
 "  Maciej Witkowiak <ytm@elysium.pl> did some IDE64 and C1541\n"
@@ -623,7 +649,8 @@ const char info_contrib_text[] =
 "\n"
 "  Rami Rasanen <raipe@neutech.fi> rewrote the VIC20 sound code.\n"
 "\n"
-"  iAN CooG <ian7102@libero.it> contributed various small patches.\n"
+"  iAN CooG <ian7102@libero.it> Added win32 vsid GUI and contributed\n"
+"  various small patches.\n"
 "\n"
 "  Mike Dawson <mike@gp2x.org> provided the GP2X port, and is the\n"
 "  co-maintainer of the GP2X port.\n"
@@ -644,10 +671,9 @@ const char info_contrib_text[] =
 "  routines for the cybergraphics support for the Amiga ports.\n"
 "\n"
 "  Wolfgang Moser <womo@d81.de> provided small optimization fixes\n"
-"  to the GCR code.\n"
-"\n"
-"  Christian Vogelgsang <chris@vogelgsang.org> resurrected the Mac\n"
-"  OSX X11 port and added support for an Intel build.\n"
+"  to the GCR code, provided an excellent REU test suite and added\n"
+"  REU fixes, and is always the good guy reviewing and commenting\n"
+"  changes in the background.\n"
 "\n"
 "  Dr.-Ing. Ingo D. Rullhusen <d01c@uni-bremen.de> wrote some small\n"
 "  XAW dialog fix.\n"
@@ -665,6 +691,33 @@ const char info_contrib_text[] =
 "  Gunnar Ruthenberg <Krill.Plush@gmail.com> provided some VIC-II\n"
 "  enhancements and improved the win32 port.\n"
 "\n"
+"  Groepaz/Hitmen <groepaz@gmx.net> Added new more precise PAL emulation.\n"
+"  Added support for the Action Replay 4 and StarDos cartridges. Provided\n"
+"  several fixes.\n"
+"\n"
+"  Ingo Korb <ingo@akana.de> Corrected block allocation and interleave\n"
+"  for c1541/vdrive."
+"\n"
+"  Georg Feil <georg@sgl.sci.yorku.ca> Added support for toggling\n"
+"  CB2 sound output line in the PET emulator.\n"
+"\n"
+"  Greg King <greg.king4@verizon.net> Added a working RTC to the\n"
+"  emulation of the IDE64 cartridge.\n"
+"\n"
+"  Thomas Giesel <skoe@directbox.com> Added new monitor commands and\n"
+"  features.\n"
+"\n"
+"  Marcus Sutton <loggedoubt@gmail.com> Made some console, dialog and\n"
+"  joystick fixes for the BeOS port.\n"
+"\n"
+"  Antti Lankila <alankila@bel.fi> Made the ReSID-fp engine and rewrote\n"
+"  the PAL emulation code.\n"
+"\n"
+"  Mustafa 'GnoStiC' Tufan <mtufan@gmail.com> Made improvements to the\n"
+"  gp2x port.\n"
+"\n"
+"  Ville-Matias Heikkila <viznut@iki.fi> Rewrote the vic20 sound code.\n"
+"\n"
 "(We hope we have not forgotten anybody; if you think we have,\n"
 "please tell us.)\n"
 "\n"
