@@ -29,6 +29,7 @@
 
 #include "archdep.h"
 #include "attach.h"
+#include "autostart.h"
 #include "cmdline.h"
 #include "console.h"
 #include "debug.h"
@@ -47,6 +48,7 @@
 #include "log.h"
 #include "machine-bus.h"
 #include "machine.h"
+#include "monitor.h"
 #include "maincpu.h"
 #include "network.h"
 #include "palette.h"
@@ -80,6 +82,10 @@ int init_resources(void)
         init_resource_fail("system file locator");
         return -1;
     }
+    if (autostart_resources_init() < 0) {
+        init_resource_fail("autostart");
+        return -1;
+    }
     if (romset_resources_init() < 0) {
         init_resource_fail("romset");
         return -1;
@@ -165,6 +171,10 @@ int init_cmdline_options(void)
         init_cmdline_options_fail("UI");
         return -1;
     }
+    if (autostart_cmdline_options_init() < 0) {
+        init_resource_fail("autostart");
+        return -1;
+    }
     if (fliplist_cmdline_options_init() < 0) {
         init_cmdline_options_fail("flip list");
         return -1;
@@ -181,6 +191,10 @@ int init_cmdline_options(void)
         init_cmdline_options_fail("event");
         return -1;
     }
+    if (monitor_cmdline_options_init() < 0) {
+        init_cmdline_options_fail("monitor");
+        return -1;
+    }
 #ifdef DEBUG
     if (debug_cmdline_options_init() < 0) {
         init_cmdline_options_fail("debug");
