@@ -43,9 +43,7 @@
 #include "machine.h"
 #include "resources.h"
 #include "tape.h"
-#ifdef HAS_TRANSLATION
 #include "translate.h"
-#endif
 #include "util.h"
 
 
@@ -70,6 +68,14 @@ static int cmdline_help(const char *param, void *extra_param)
     return 0;   /* OSF1 cc complains */
 }
 
+static int cmdline_config(const char *param, void *extra_param)
+{
+    /* "-config" needs to be handled before this gets called
+       but it also needs to be registered as a cmdline option,
+       hence this kludge. */
+    return 0;
+}
+
 static int cmdline_default(const char *param, void *extra_param)
 {
     return resources_set_defaults();
@@ -91,7 +97,7 @@ static int cmdline_autoload(const char *param, void *extra_param)
     return 0;
 }
 
-#ifndef __OS2__
+#if !defined(__OS2__) && !defined(__BEOS__)
 static int cmdline_console(const char *param, void *extra_param)
 {
     console_mode = 1;
@@ -126,53 +132,52 @@ static int cmdline_attach(const char *param, void *extra_param)
     return 0;
 }
 
-#ifdef HAS_TRANSLATION
 static const cmdline_option_t common_cmdline_options[] = {
-    { "-help", CALL_FUNCTION, 0, cmdline_help, NULL, NULL, NULL,
-      0, IDCLS_SHOW_COMMAND_LINE_OPTIONS },
-    { "-?", CALL_FUNCTION, 0, cmdline_help, NULL, NULL, NULL,
-      0, IDCLS_SHOW_COMMAND_LINE_OPTIONS },
-    { "-h", CALL_FUNCTION, 0, cmdline_help, NULL, NULL, NULL,
-      0, IDCLS_SHOW_COMMAND_LINE_OPTIONS },
+    { "-help", CALL_FUNCTION, 0,
+      cmdline_help, NULL, NULL, NULL,
+      USE_PARAM_STRING, USE_DESCRIPTION_ID,
+      IDCLS_UNUSED, IDCLS_SHOW_COMMAND_LINE_OPTIONS,
+      NULL, NULL },
+    { "-?", CALL_FUNCTION, 0,
+      cmdline_help, NULL, NULL, NULL,
+      USE_PARAM_STRING, USE_DESCRIPTION_ID,
+      IDCLS_UNUSED, IDCLS_SHOW_COMMAND_LINE_OPTIONS,
+      NULL, NULL },
+    { "-h", CALL_FUNCTION, 0,
+      cmdline_help, NULL, NULL, NULL,
+      USE_PARAM_STRING, USE_DESCRIPTION_ID,
+      IDCLS_UNUSED, IDCLS_SHOW_COMMAND_LINE_OPTIONS,
+      NULL, NULL },
 #if (!defined  __OS2__ && !defined __BEOS__)
-    { "-console", CALL_FUNCTION, 0, cmdline_console, NULL, NULL, NULL,
-      0, IDCLS_CONSOLE_MODE },
-    { "-core", SET_RESOURCE, 0, NULL, NULL, "DoCoreDump", (resource_value_t)1,
-      0, IDCLS_ALLOW_CORE_DUMPS },
-    { "+core", SET_RESOURCE, 0, NULL, NULL, "DoCoreDump", (resource_value_t)0,
-      0, IDCLS_DONT_ALLOW_CORE_DUMPS },
+    { "-console", CALL_FUNCTION, 0,
+      cmdline_console, NULL, NULL, NULL,
+      USE_PARAM_STRING, USE_DESCRIPTION_ID,
+      IDCLS_UNUSED, IDCLS_CONSOLE_MODE,
+      NULL, NULL },
+    { "-core", SET_RESOURCE, 0,
+      NULL, NULL, "DoCoreDump", (resource_value_t)1,
+      USE_PARAM_STRING, USE_DESCRIPTION_ID,
+      IDCLS_UNUSED, IDCLS_ALLOW_CORE_DUMPS,
+      NULL, NULL },
+    { "+core", SET_RESOURCE, 0,
+      NULL, NULL, "DoCoreDump", (resource_value_t)0,
+      USE_PARAM_STRING, USE_DESCRIPTION_ID,
+      IDCLS_UNUSED, IDCLS_DONT_ALLOW_CORE_DUMPS,
+      NULL, NULL },
 #else
-    { "-debug", SET_RESOURCE, 0, NULL, NULL, "DoCoreDump", (resource_value_t)1,
-      0, IDCLS_DONT_CALL_EXCEPTION_HANDLER },
-    { "+debug", SET_RESOURCE, 0, NULL, NULL, "DoCoreDump", (resource_value_t)0,
-      0, IDCLS_CALL_EXCEPTION_HANDLER },
+    { "-debug", SET_RESOURCE, 0,
+      NULL, NULL, "DoCoreDump", (resource_value_t)1,
+      USE_PARAM_STRING, USE_DESCRIPTION_ID,
+      IDCLS_UNUSED, IDCLS_DONT_CALL_EXCEPTION_HANDLER,
+      NULL, NULL },
+    { "+debug", SET_RESOURCE, 0,
+      NULL, NULL, "DoCoreDump", (resource_value_t)0,
+      USE_PARAM_STRING, USE_DESCRIPTION_ID,
+      IDCLS_UNUSED, IDCLS_CALL_EXCEPTION_HANDLER,
+      NULL, NULL },
 #endif
     { NULL }
 };
-#else
-static const cmdline_option_t common_cmdline_options[] = {
-    { "-help", CALL_FUNCTION, 0, cmdline_help, NULL, NULL, NULL,
-      NULL, N_("Show a list of the available options and exit normally") },
-    { "-?", CALL_FUNCTION, 0, cmdline_help, NULL, NULL, NULL,
-      NULL, N_("Show a list of the available options and exit normally") },
-    { "-h", CALL_FUNCTION, 0, cmdline_help, NULL, NULL, NULL,
-      NULL, N_("Show a list of the available options and exit normally") },
-#if (!defined  __OS2__ && !defined __BEOS__)
-    { "-console", CALL_FUNCTION, 0, cmdline_console, NULL, NULL, NULL,
-      NULL, N_("Console mode (for music playback)") },
-    { "-core", SET_RESOURCE, 0, NULL, NULL, "DoCoreDump", (resource_value_t)1,
-      NULL, N_("Allow production of core dumps") },
-    { "+core", SET_RESOURCE, 0, NULL, NULL, "DoCoreDump", (resource_value_t)0,
-      NULL, N_("Do not produce core dumps") },
-#else
-    { "-debug", SET_RESOURCE, 0, NULL, NULL, "DoCoreDump", (resource_value_t)1,
-      NULL, N_("Don't call exception handler") },
-    { "+debug", SET_RESOURCE, 0, NULL, NULL, "DoCoreDump", (resource_value_t)0,
-      NULL, N_("Call exception handler (default)") },
-#endif
-    { NULL }
-};
-#endif
 
 static const cmdline_option_t vsid_cmdline_options[] = {
     { NULL }
@@ -180,47 +185,54 @@ static const cmdline_option_t vsid_cmdline_options[] = {
 
 /* These are the command-line options for the initialization sequence.  */
 
-#ifdef HAS_TRANSLATION
 static const cmdline_option_t cmdline_options[] = {
-    { "-default", CALL_FUNCTION, 0, cmdline_default, NULL, NULL, NULL,
-      0, IDCLS_RESTORE_DEFAULT_SETTINGS },
-    { "-autostart", CALL_FUNCTION, 1, cmdline_autostart, NULL, NULL, NULL,
-      IDCLS_P_NAME, IDCLS_ATTACH_AND_AUTOSTART },
-    { "-autoload", CALL_FUNCTION, 1, cmdline_autoload, NULL, NULL, NULL,
-      IDCLS_P_NAME, IDCLS_ATTACH_AND_AUTOLOAD },
-    { "-1", CALL_FUNCTION, 1, cmdline_attach, (void *)1, NULL, NULL,
-      IDCLS_P_NAME, IDCLS_ATTACH_AS_TAPE },
-    { "-8", CALL_FUNCTION, 1, cmdline_attach, (void *)8, NULL, NULL,
-      IDCLS_P_NAME, IDCLS_ATTACH_AS_DISK_8 },
-    { "-9", CALL_FUNCTION, 1, cmdline_attach, (void *)9, NULL, NULL,
-      IDCLS_P_NAME, IDCLS_ATTACH_AS_DISK_9 },
-    { "-10", CALL_FUNCTION, 1, cmdline_attach, (void *)10, NULL, NULL,
-      IDCLS_P_NAME, IDCLS_ATTACH_AS_DISK_10 },
-    { "-11", CALL_FUNCTION, 1, cmdline_attach, (void *)11, NULL, NULL,
-      IDCLS_P_NAME, IDCLS_ATTACH_AS_DISK_11 },
+    { "-default", CALL_FUNCTION, 0,
+      cmdline_default, NULL, NULL, NULL,
+      USE_PARAM_STRING, USE_DESCRIPTION_ID,
+      IDCLS_UNUSED, IDCLS_RESTORE_DEFAULT_SETTINGS,
+      NULL, NULL },
+    { "-config", CALL_FUNCTION, 1,
+      cmdline_config, NULL, NULL, NULL,
+      USE_PARAM_ID, USE_DESCRIPTION_ID,
+      IDCLS_P_FILE, IDCLS_SPECIFY_CONFIG_FILE,
+      NULL, NULL },
+    { "-autostart", CALL_FUNCTION, 1,
+      cmdline_autostart, NULL, NULL, NULL,
+      USE_PARAM_ID, USE_DESCRIPTION_ID,
+      IDCLS_P_NAME, IDCLS_ATTACH_AND_AUTOSTART,
+      NULL, NULL },
+    { "-autoload", CALL_FUNCTION, 1,
+      cmdline_autoload, NULL, NULL, NULL,
+      USE_PARAM_ID, USE_DESCRIPTION_ID,
+      IDCLS_P_NAME, IDCLS_ATTACH_AND_AUTOLOAD,
+      NULL, NULL },
+    { "-1", CALL_FUNCTION, 1,
+      cmdline_attach, (void *)1, NULL, NULL,
+      USE_PARAM_ID, USE_DESCRIPTION_ID,
+      IDCLS_P_NAME, IDCLS_ATTACH_AS_TAPE,
+      NULL, NULL },
+    { "-8", CALL_FUNCTION, 1,
+      cmdline_attach, (void *)8, NULL, NULL,
+      USE_PARAM_ID, USE_DESCRIPTION_ID,
+      IDCLS_P_NAME, IDCLS_ATTACH_AS_DISK_8,
+      NULL, NULL },
+    { "-9", CALL_FUNCTION, 1,
+      cmdline_attach, (void *)9, NULL, NULL,
+      USE_PARAM_ID, USE_DESCRIPTION_ID,
+      IDCLS_P_NAME, IDCLS_ATTACH_AS_DISK_9,
+      NULL, NULL },
+    { "-10", CALL_FUNCTION, 1,
+      cmdline_attach, (void *)10, NULL, NULL,
+      USE_PARAM_ID, USE_DESCRIPTION_ID,
+      IDCLS_P_NAME, IDCLS_ATTACH_AS_DISK_10,
+      NULL, NULL },
+    { "-11", CALL_FUNCTION, 1,
+      cmdline_attach, (void *)11, NULL, NULL,
+      USE_PARAM_ID, USE_DESCRIPTION_ID,
+      IDCLS_P_NAME, IDCLS_ATTACH_AS_DISK_11,
+      NULL, NULL },
     { NULL }
 };
-#else
-static const cmdline_option_t cmdline_options[] = {
-    { "-default", CALL_FUNCTION, 0, cmdline_default, NULL, NULL, NULL,
-      NULL, N_("Restore default (factory) settings") },
-    { "-autostart", CALL_FUNCTION, 1, cmdline_autostart, NULL, NULL, NULL,
-      N_("<name>"), N_("Attach and autostart tape/disk image <name>") },
-    { "-autoload", CALL_FUNCTION, 1, cmdline_autoload, NULL, NULL, NULL,
-      N_("<name>"), N_("Attach and autoload tape/disk image <name>") },
-    { "-1", CALL_FUNCTION, 1, cmdline_attach, (void *)1, NULL, NULL,
-      N_("<name>"), N_("Attach <name> as a tape image") },
-    { "-8", CALL_FUNCTION, 1, cmdline_attach, (void *)8, NULL, NULL,
-      N_("<name>"), N_("Attach <name> as a disk image in drive #8") },
-    { "-9", CALL_FUNCTION, 1, cmdline_attach, (void *)9, NULL, NULL,
-      N_("<name>"), N_("Attach <name> as a disk image in drive #9") },
-    { "-10", CALL_FUNCTION, 1, cmdline_attach, (void *)10, NULL, NULL,
-      N_("<name>"), N_("Attach <name> as a disk image in drive #10") },
-    { "-11", CALL_FUNCTION, 1, cmdline_attach, (void *)11, NULL, NULL,
-      N_("<name>"), N_("Attach <name> as a disk image in drive #11") },
-    { NULL }
-};
-#endif
 
 int initcmdline_init(void)
 {
