@@ -68,7 +68,9 @@ static alarm_t *joystick_alarm = NULL;
 
 static CLOCK joystick_delay;
 
+#ifdef COMMON_KBD
 static int joykeys[3][9];
+#endif
 
 static void joystick_latch_matrix(CLOCK offset)
 {
@@ -81,11 +83,7 @@ static void joystick_latch_matrix(CLOCK offset)
         else
             memcpy(joystick_value, network_joystick_value, sizeof(joystick_value));
     } else {
-        idx = latch_joystick_value[0];
-        if (idx > 0)
-            joystick_value[idx] = latch_joystick_value[idx];
-        else
-            memcpy(joystick_value, latch_joystick_value, sizeof(joystick_value));
+        memcpy(joystick_value, latch_joystick_value, sizeof(joystick_value));
     }
     ui_display_joyport(joystick_value);
 }
@@ -237,6 +235,16 @@ static int joyreleaseval(int column, int *status)
     return ~val;
 }
 
+/* toggle keyset joystick. 
+   this disables any active key-based joystick and is useful for typing. */
+static int joykeys_enable = 0;
+
+static int set_joykeys_enable(int val, void *param)
+{
+  joykeys_enable = val;
+  return 0;
+}
+
 #define DEFINE_SET_KEYSET(num)                       \
     static int set_keyset##num(int val, void *param) \
     {                                                \
@@ -285,6 +293,8 @@ static const resource_int_t resources_int[] = {
       &joykeys[2][KEYSET_W], set_keyset2, (void *)KEYSET_W },
     { "KeySet2Fire", 0, RES_EVENT_NO, NULL,
       &joykeys[2][KEYSET_FIRE], set_keyset2, (void *)KEYSET_FIRE },
+    { "KeySetEnable", 1, RES_EVENT_NO, NULL,
+      &joykeys_enable, set_joykeys_enable, NULL },
     { NULL }
 };
 
@@ -292,6 +302,10 @@ int joystick_check_set(signed long key, int keysetnum, unsigned int joyport)
 {
     int column;
 
+    /* if joykeys are disabled then ignore key sets */
+    if(!joykeys_enable)
+      return 0;
+
     for (column = 0; column < 9; column++) {
         if (key == joykeys[keysetnum][column]) {
             if (joypad_bits[column]) {
@@ -313,6 +327,10 @@ int joystick_check_clr(signed long key, int keysetnum, unsigned int joyport)
 {
     int column;
 
+    /* if joykeys are disabled then ignore key sets */
+    if(!joykeys_enable)
+      return 0;
+
     for (column = 0; column < 9; column++) {
         if (key == joykeys[keysetnum][column]) {
             /*joystick_value[joyport] &= joyreleaseval(column,
