@@ -396,6 +396,10 @@ void *lib_malloc(size_t size)
     lib_debug_alloc(ptr, size, 3);
 #endif
 
+    if (ptr) {
+        memset(ptr, 0, size);
+    }
+
     return ptr;
 }
 
@@ -490,8 +494,9 @@ void *lib_realloc(void *ptr, size_t size)
     return new_ptr;
 }
 
-void lib_free(void *ptr)
+void lib_free(const void *constptr)
 {
+    void * ptr = (void*) constptr;
 #ifdef LIB_DEBUG
     lib_debug_free(ptr, 1, 1);
 #endif
