@@ -71,7 +71,7 @@
 #include "joy.h"
 #endif
 
-
+static int ignore_jam;
 int machine_keymap_index;
 
 
@@ -81,6 +81,9 @@ unsigned int machine_jam(const char *format, ...)
     va_list ap;
     ui_jam_action_t ret;
 
+    if (ignore_jam > 0)
+        return JAM_NONE;
+
     va_start(ap, format);
 
     str = lib_mvsprintf(format, ap);
@@ -94,13 +97,18 @@ unsigned int machine_jam(const char *format, ...)
         return JAM_HARD_RESET;
       case UI_JAM_MONITOR:
         return JAM_MONITOR;
+      default:
+        break;
     }
 
+    ignore_jam = 1;
     return JAM_NONE;
 }
 
 static void machine_trigger_reset_internal(const unsigned int mode)
 {
+    ignore_jam = 0;
+
     switch (mode) {
       case MACHINE_RESET_MODE_HARD:
         vsync_frame_counter = 0;
