@@ -2,7 +2,7 @@
  * asmz80.c - Z80 Assembler-related utility functions.
  *
  * Written by
- *  Andreas Boose <boose@linux.rz.fh-hannover.de>
+ *  Andreas Boose <viceteam@t-online.de>
  *
  * This file is part of VICE, the Versatile Commodore Emulator.
  * See README for copyright notice.
@@ -32,7 +32,7 @@
 #include "montypes.h"
 #include "types.h"
 
-static int addr_mode_size[] = {
+static const int addr_mode_size[] = {
     1, /* ASM_ADDR_MODE_IMPLIED */
     1, /* ASM_ADDR_MODE_ACCUMULATOR */
     2, /* ASM_ADDR_MODE_IMMEDIATE */
@@ -77,7 +77,7 @@ static int addr_mode_size[] = {
     1  /* ASM_ADDR_MODE_REG_IND_SP */
 };
 
-static asm_opcode_info_t opcode_list[] = {
+static const asm_opcode_info_t opcode_list[] = {
     /* 00 */ { "NOP",        ASM_ADDR_MODE_IMPLIED },
     /* 01 */ { "LD BC,",     ASM_ADDR_MODE_IMMEDIATE_16 },
     /* 02 */ { "LD (BC),A",  ASM_ADDR_MODE_IMPLIED },
@@ -336,7 +336,7 @@ static asm_opcode_info_t opcode_list[] = {
     /* ff */ { "RST 38",     ASM_ADDR_MODE_IMPLIED }
 };
 
-static asm_opcode_info_t opcode_list_cb[] = {
+static const asm_opcode_info_t opcode_list_cb[] = {
     /* 00 */ { "RLC",        ASM_ADDR_MODE_REG_B },
     /* 01 */ { "RLC",        ASM_ADDR_MODE_REG_C },
     /* 02 */ { "RLC",        ASM_ADDR_MODE_REG_D },
@@ -595,7 +595,7 @@ static asm_opcode_info_t opcode_list_cb[] = {
     /* ff */ { "SET 7,",     ASM_ADDR_MODE_ACCUMULATOR }
 };
 
-static asm_opcode_info_t opcode_list_dd[] = {
+static const asm_opcode_info_t opcode_list_dd[] = {
     /* 00 */ { "NOP",        ASM_ADDR_MODE_IMPLIED },
     /* 01 */ { "LD BC,",     ASM_ADDR_MODE_IMMEDIATE_16 },
     /* 02 */ { "LD (BC),A",  ASM_ADDR_MODE_IMPLIED },
@@ -854,7 +854,7 @@ static asm_opcode_info_t opcode_list_dd[] = {
     /* ff */ { "RST 38",     ASM_ADDR_MODE_IMPLIED }
 };
 
-static asm_opcode_info_t opcode_list_ed[] = {
+static const asm_opcode_info_t opcode_list_ed[] = {
     /* 00 */ { "",           ASM_ADDR_MODE_IMPLIED },
     /* 01 */ { "",           ASM_ADDR_MODE_IMPLIED },
     /* 02 */ { "",           ASM_ADDR_MODE_IMPLIED },
@@ -1017,32 +1017,32 @@ static asm_opcode_info_t opcode_list_ed[] = {
     /* 9f */ { "",           ASM_ADDR_MODE_IMPLIED },
     /* a0 */ { "LDI",        ASM_ADDR_MODE_IMPLIED },
     /* a1 */ { "CPI",        ASM_ADDR_MODE_IMPLIED },
-    /* a2 */ { "",           ASM_ADDR_MODE_IMPLIED },
-    /* a3 */ { "",           ASM_ADDR_MODE_IMPLIED },
+    /* a2 */ { "INI",        ASM_ADDR_MODE_IMPLIED },
+    /* a3 */ { "OUTI",       ASM_ADDR_MODE_IMPLIED },
     /* a4 */ { "",           ASM_ADDR_MODE_IMPLIED },
     /* a5 */ { "",           ASM_ADDR_MODE_IMPLIED },
     /* a6 */ { "",           ASM_ADDR_MODE_IMPLIED },
     /* a7 */ { "",           ASM_ADDR_MODE_IMPLIED },
     /* a8 */ { "LDD",        ASM_ADDR_MODE_IMPLIED },
     /* a9 */ { "CPD",        ASM_ADDR_MODE_IMPLIED },
-    /* aa */ { "",           ASM_ADDR_MODE_IMPLIED },
-    /* ab */ { "",           ASM_ADDR_MODE_IMPLIED },
+    /* aa */ { "IND",        ASM_ADDR_MODE_IMPLIED },
+    /* ab */ { "OUTD",       ASM_ADDR_MODE_IMPLIED },
     /* ac */ { "",           ASM_ADDR_MODE_IMPLIED },
     /* ad */ { "",           ASM_ADDR_MODE_IMPLIED },
     /* ae */ { "",           ASM_ADDR_MODE_IMPLIED },
     /* af */ { "",           ASM_ADDR_MODE_IMPLIED },
     /* b0 */ { "LDIR",       ASM_ADDR_MODE_IMPLIED },
     /* b1 */ { "CPIR",       ASM_ADDR_MODE_IMPLIED },
-    /* b2 */ { "",           ASM_ADDR_MODE_IMPLIED },
-    /* b3 */ { "",           ASM_ADDR_MODE_IMPLIED },
+    /* b2 */ { "INIR",       ASM_ADDR_MODE_IMPLIED },
+    /* b3 */ { "OTIR",       ASM_ADDR_MODE_IMPLIED },
     /* b4 */ { "",           ASM_ADDR_MODE_IMPLIED },
     /* b5 */ { "",           ASM_ADDR_MODE_IMPLIED },
     /* b6 */ { "",           ASM_ADDR_MODE_IMPLIED },
     /* b7 */ { "",           ASM_ADDR_MODE_IMPLIED },
     /* b8 */ { "LDDR",       ASM_ADDR_MODE_IMPLIED },
     /* b9 */ { "CPDR",       ASM_ADDR_MODE_IMPLIED },
-    /* ba */ { "",           ASM_ADDR_MODE_IMPLIED },
-    /* bb */ { "",           ASM_ADDR_MODE_IMPLIED },
+    /* ba */ { "INDR",       ASM_ADDR_MODE_IMPLIED },
+    /* bb */ { "OTDR",       ASM_ADDR_MODE_IMPLIED },
     /* bc */ { "",           ASM_ADDR_MODE_IMPLIED },
     /* bd */ { "",           ASM_ADDR_MODE_IMPLIED },
     /* be */ { "",           ASM_ADDR_MODE_IMPLIED },
@@ -1113,7 +1113,7 @@ static asm_opcode_info_t opcode_list_ed[] = {
     /* ff */ { "",           ASM_ADDR_MODE_IMPLIED }
 };
 
-static asm_opcode_info_t opcode_list_fd[] = {
+static const asm_opcode_info_t opcode_list_fd[] = {
     /* 00 */ { "NOP",        ASM_ADDR_MODE_IMPLIED },
     /* 01 */ { "LD BC,",     ASM_ADDR_MODE_IMMEDIATE_16 },
     /* 02 */ { "LD (BC),A",  ASM_ADDR_MODE_IMPLIED },
@@ -1372,7 +1372,7 @@ static asm_opcode_info_t opcode_list_fd[] = {
     /* ff */ { "RST 38",     ASM_ADDR_MODE_IMPLIED }
 };
 
-static asm_opcode_info_t *asm_opcode_info_get(BYTE p0, BYTE p1, BYTE p2)
+static const asm_opcode_info_t *asm_opcode_info_get(BYTE p0, BYTE p1, BYTE p2)
 {
     if (p0 == 0xcb)
         return opcode_list_cb + (unsigned int)p1;
@@ -1385,8 +1385,7 @@ static asm_opcode_info_t *asm_opcode_info_get(BYTE p0, BYTE p1, BYTE p2)
     return opcode_list + (unsigned int)p0;
 }
 
-static unsigned int asm_addr_mode_get_size(unsigned int mode, BYTE p0,
-                                           BYTE p1)
+static unsigned int asm_addr_mode_get_size(unsigned int mode, BYTE p0, BYTE p1)
 {
     if (p0 == 0xcb)
         return addr_mode_size[mode] + 1;
