@@ -30,6 +30,10 @@
 
 #include <string.h>
 
+#ifdef HAVE_STRINGS_H
+#include <strings.h>
+#endif
+
 #include "asm.h"
 #include "montypes.h"
 #include "mon_assemble.h"
