@@ -32,6 +32,11 @@
 #include "monitor.h"
 #include "types.h"
 
+#if 0
+/* set this to enable experimental 24-bit address space support */
+#define HAVE_MEMSPACE24
+#endif
+
 /* Types */
 
 typedef int bool;
@@ -54,7 +59,23 @@ enum t_reg_id {
    e_AF2,
    e_BC2,
    e_DE2,
-   e_HL2
+   e_HL2,
+/* New C64DTV regs */
+   e_R3,
+   e_R4,
+   e_R5,
+   e_R6,
+   e_R7,
+   e_R8,
+   e_R9,
+   e_R10,
+   e_R11,
+   e_R12,
+   e_R13,
+   e_R14,
+   e_R15,
+   e_ACM,
+   e_XYM
 };
 typedef enum t_reg_id REG_ID;
 
@@ -110,6 +131,14 @@ typedef struct cond_node_s cond_node_t;
 
 typedef void monitor_toggle_func_t(int value);
 
+struct cpuhistory_s {
+   WORD addr;
+   BYTE op;
+   BYTE p1;
+   BYTE p2;
+};
+typedef struct cpuhistory_s cpuhistory_t;
+
 /* Defines */
 #ifndef TRUE
 #define TRUE 1
@@ -124,6 +153,13 @@ typedef void monitor_toggle_func_t(int value);
 #define LO16_TO_HI16(x) (((x)&0xffff)<<16)
 #define HI16_TO_LO16(x) (((x)>>16)&0xffff)
 
+#ifdef HAVE_MEMSPACE24
+#define HI8(x) ((x)&0xff000000)
+#define LO24(x) ((x)&0xffffff)
+#define LO8_TO_HI8(x) (((x)&0xff)<<24)
+#define HI8_TO_LO8(x) (((x)>>24)&0xff)
+#endif
+
 #define STATE_INITIAL  0
 #define STATE_FNAME    1
 #define STATE_REG_ASGN 2
@@ -140,13 +176,33 @@ typedef void monitor_toggle_func_t(int value);
 #define any_watchpoints_store(mem) (watchpoints_store[(mem)] != NULL)
 
 #define new_cond ((cond_node_t *)(lib_malloc(sizeof(cond_node_t))))
+#ifndef HAVE_MEMSPACE24
 #define addr_memspace(ma) (HI16_TO_LO16(ma))
 #define addr_location(ma) (LO16(ma))
+#define addr_mask(l) (LO16(l))
 #define new_addr(m, l) (LO16_TO_HI16(m) | (l))
+#else
+#define addr_memspace(ma) (HI8_TO_LO8(ma))
+#define addr_location(ma) (LO24(ma))
+#define addr_mask(l) (LO24(l))
+#define new_addr(m, l) (LO8_TO_HI8(m) | (l))
+#endif
 #define new_reg(m, r) (LO16_TO_HI16(m) | (r))
 #define reg_memspace(mr) (HI16_TO_LO16(mr))
 #define reg_regid(mr) (LO16(mr))
 
+#define CPUHISTORY_SIZE 64
+
+#ifdef FEATURE_CPUMEMHISTORY
+#define MEMMAP_SIZE 0x10000
+#define MEMMAP_PICX 0x100
+#define MEMMAP_PICY 0x100
+#else
+#define MEMMAP_SIZE 1
+#define MEMMAP_PICX 1
+#define MEMMAP_PICY 1
+#endif
+
 /* Global variables */
 
 extern const char *_mon_space_strings[];
@@ -161,8 +217,6 @@ extern int mon_console_close_on_leaving;
 extern RADIXTYPE default_radix;
 extern MEMSPACE default_memspace;
 extern bool asm_mode;
-extern char *playback_name;
-extern bool playback;
 extern MON_ADDR asm_mode_addr;
 extern struct monitor_cpu_type_s monitor_cpu_type;
 extern MON_ADDR dot_addr[NUM_MEMSPACES];
@@ -171,11 +225,32 @@ extern int mon_stop_output;
 extern monitor_interface_t *mon_interfaces[NUM_MEMSPACES];
 extern bool force_array[NUM_MEMSPACES];
 extern unsigned char data_buf[256];
+extern unsigned char data_mask_buf[256];
 extern unsigned int data_buf_len;
+extern cpuhistory_t cpuhistory[CPUHISTORY_SIZE];
+extern int cpuhistory_i;
+extern BYTE *mon_memmap;
+extern int mon_memmap_size;
+extern int mon_memmap_pic_x;
+extern int mon_memmap_pic_y;
 
 /* Function declarations */
 extern void mon_add_number_to_buffer(int number);
+extern void mon_add_number_masked_to_buffer(int number, int mask);
 extern void mon_add_string_to_buffer(char *str);
+extern void mon_backtrace(void);
+extern void mon_cart_freeze(void);
+extern void mon_cpuhistory(int count);
+extern void mon_memmap_zap(void);
+extern void mon_memmap_show(int mask, MON_ADDR start_addr, MON_ADDR end_addr);
+extern void mon_memmap_save(const char* filename, int format);
+extern void mon_reset_machine(int type);
+extern void mon_resource_get(const char *name);
+extern void mon_resource_set(const char *name, const char* value);
+extern void mon_screenshot_save(const char* filename, int format);
+extern void mon_show_dir(const char *path);
+extern void mon_show_pwd(void);
+extern void mon_tape_ctrl(int command);
 extern void mon_display_screen(void);
 extern void mon_instructions_step(int count);
 extern void mon_instructions_next(int count);
@@ -207,6 +282,7 @@ extern void mon_jump(MON_ADDR addr);
 extern void mon_keyboard_feed(const char *string);
 extern char *mon_symbol_table_lookup_name(MEMSPACE mem, WORD addr);
 extern int mon_symbol_table_lookup_addr(MEMSPACE mem, char *name);
+extern char* mon_prepend_dot_to_name(char *name);
 extern void mon_add_name_to_symbol_table(MON_ADDR addr, char *name);
 extern void mon_remove_name_from_symbol_table(MEMSPACE mem, char *name);
 extern void mon_print_symbol_table(MEMSPACE mem);
@@ -215,6 +291,7 @@ extern void mon_save_symbols(MEMSPACE mem, const char *filename);
 
 extern void mon_record_commands(char *filename);
 extern void mon_end_recording(void);
+extern void mon_playback_init(const char* filename);
+extern void monitor_change_device(MEMSPACE mem);
 
 #endif
-
