@@ -30,9 +30,14 @@
 #ifdef HAVE_NETWORK
 
 #ifdef MINIX_SUPPORT
-#define _POSIX_SOURCE
 #include <limits.h>
 #define PF_INET AF_INET
+
+#ifndef MINIX_HAS_RECV_SEND
+extern ssize_t recv(int socket, void *buffer, size_t length, int flags);
+extern ssize_t send(int socket, const void *buffer, size_t length, int flags);
+#endif
+
 #endif
 
 #include <assert.h>
@@ -40,6 +45,9 @@
 #include <stdlib.h>
 #include <string.h>
 
+#ifdef HAVE_STRINGS_H
+#include <strings.h>
+#endif
 
 #ifdef AMIGA_SUPPORT
 #ifndef AMIGA_OS4
@@ -56,7 +64,7 @@ struct Library *SocketBase;
 #define __USE_INLINE__
 #include <proto/bsdsocket.h>
 #endif
-#ifndef AMIGA_AROS
+#if !defined(AMIGA_AROS) && !defined(AMIGA_MORPHOS)
 #define select(nfds, read_fds, write_fds, except_fds, timeout) \
         WaitSelect(nfds, read_fds, write_fds, except_fds, timeout, NULL)
 #endif
@@ -92,12 +100,18 @@ typedef struct timeval TIMEVAL;
 #include <netdb.h>
 #ifndef __MSDOS__
 #include <sys/time.h>
-#ifndef AMIGA_SUPPORT
+#if !defined(AMIGA_SUPPORT) && !defined(VMS)
 #include <sys/select.h>
 #endif
+#endif
 #if !defined(AMIGA_M68K) && !defined(AMIGA_AROS)
 #include <unistd.h>
 #endif
+
+#ifdef __minix
+#define recv(socket, buffer, length, flags) \
+        recvfrom(socket, buffer, length, flags, NULL, NULL)
+extern ssize_t send(int socket, const void *buffer, size_t length, int flags);
 #endif
 
 typedef unsigned int SOCKET;
@@ -129,9 +143,7 @@ typedef struct timeval TIMEVAL;
 #include "mos6510.h"
 #include "network.h"
 #include "resources.h"
-#ifdef HAS_TRANSLATION
 #include "translate.h"
-#endif
 #include "types.h"
 #include "ui.h"
 #include "uiapi.h"
@@ -167,6 +179,7 @@ static int netplay_ipv6 = 0;
 #endif
 
 #ifndef HAVE_HTONL
+#ifndef htonl
 static unsigned int htonl(unsigned int ip)
 {
 #ifdef WORDS_BIGENDIAN
@@ -179,8 +192,10 @@ static unsigned int htonl(unsigned int ip)
 #endif
 }
 #endif
+#endif
 
 #ifndef HAVE_HTONS
+#ifndef htons
 static unsigned short htons(unsigned short ip)
 {
 #ifdef WORDS_BIGENDIAN
@@ -193,6 +208,7 @@ static unsigned short htons(unsigned short ip)
 #endif
 }
 #endif
+#endif
 
 static int set_server_name(const char *val, void *param)
 {
@@ -245,11 +261,7 @@ static int set_netplay_ipv6(int val, void *param)
         return -1;
 
     if (network_mode!=NETWORK_IDLE) {
-#ifdef HAS_TRANSLATION
         ui_error(translate_text(IDGS_CANNOT_SWITCH_IPV4_IPV6));
-#else
-        ui_error(_("Cannot switch IPV4/IPV6 while netplay is active."));
-#endif
         return -1;
     }
     netplay_ipv6 = val;
@@ -470,11 +482,7 @@ static void network_test_delay(void)
 
     vsyncarch_init();
 
-#ifdef HAS_TRANSLATION
     ui_display_statustext(translate_text(IDGS_TESTING_BEST_FRAME_DELAY), 0);
-#else
-    ui_display_statustext(_("Testing best frame delay..."), 0);
-#endif
 
     if (network_mode == NETWORK_SERVER_CONNECTED) {
         for (i = 0; i < NUM_OF_TESTPACKETS; i++) {
@@ -520,11 +528,7 @@ static void network_test_delay(void)
     network_free_frame_event_list();
     frame_delta = new_frame_delta;
     network_init_frame_event_list();
-#ifdef HAS_TRANSLATION
     sprintf(st, translate_text(IDGS_USING_D_FRAMES_DELAY), frame_delta);
-#else
-    sprintf(st, _("Using %d frames delay."), frame_delta);
-#endif
     log_debug("netplay connected with %d frames delta.", frame_delta);
     ui_display_statustext(st, 1);
 }
@@ -545,11 +549,7 @@ static void network_server_connect_trap(WORD addr, void *data)
     if (machine_write_snapshot(snapshotfilename, 1, 1, 0) == 0) {
         f = fopen(snapshotfilename, MODE_READ);
         if (f == NULL) {
-#ifdef HAS_TRANSLATION
             ui_error(translate_text(IDGS_CANNOT_LOAD_SNAPSHOT_TRANSFER));
-#else
-            ui_error(_("Cannot load snapshot file for transfer"));
-#endif
             lib_free(snapshotfilename);
             return;
         }
@@ -558,21 +558,13 @@ static void network_server_connect_trap(WORD addr, void *data)
         fread(buf, 1, buf_size, f);
         fclose(f);
 
-#ifdef HAS_TRANSLATION
         ui_display_statustext(translate_text(IDGS_SENDING_SNAPSHOT_TO_CLIENT), 0);
-#else
-        ui_display_statustext(_("Sending snapshot to client..."), 0);
-#endif
         util_int_to_le_buf4(send_size4, (int)buf_size);
         network_send_buffer(network_socket, send_size4, 4);
         i = network_send_buffer(network_socket, buf, (int)buf_size);
         lib_free(buf);
         if (i < 0) {
-#ifdef HAS_TRANSLATION
             ui_error(translate_text(IDGS_CANNOT_SEND_SNAPSHOT_TO_CLIENT));
-#else
-            ui_error(_("Cannot send snapshot to client"));
-#endif
             ui_display_statustext("", 0);
             lib_free(snapshotfilename);
             return;
@@ -598,11 +590,7 @@ static void network_server_connect_trap(WORD addr, void *data)
 
         network_test_delay();
     } else {
-#ifdef HAS_TRANSLATION
         ui_error(translate_text(IDGS_CANNOT_CREATE_SNAPSHOT_FILE_S), snapshotfilename);
-#else
-        ui_error(_("Cannot create snapshot file %s"), snapshotfilename);
-#endif
     }
     lib_free(snapshotfilename);
 }
@@ -638,11 +626,7 @@ static void network_client_connect_trap(WORD addr, void *data)
 
     /* read the snapshot */
     if (machine_read_snapshot(snapshotfilename, 0) != 0) {
-#ifdef HAS_TRANSLATION
         ui_error(translate_text(IDGS_CANNOT_OPEN_SNAPSHOT_FILE_S), snapshotfilename);
-#else
-        ui_error(_("Cannot open snapshot file %s"), snapshotfilename);
-#endif
         lib_free(snapshotfilename);
         return;
     }
@@ -788,11 +772,7 @@ int network_start_server(void)
     network_mode = NETWORK_SERVER;
 
     vsync_suspend_speed_eval();
-#ifdef HAS_TRANSLATION
     ui_display_statustext(translate_text(IDGS_SERVER_IS_WAITING_FOR_CLIENT), 1);
-#else
-    ui_display_statustext(_("Server is waiting for a client..."), 1);
-#endif
     return 0;
 } 
 
@@ -825,11 +805,7 @@ int network_connect_client(void)
 
     f = archdep_mkstemp_fd(&snapshotfilename, MODE_WRITE);
     if (f == NULL) {
-#ifdef HAS_TRANSLATION
         ui_error(translate_text(IDGS_CANNOT_CREATE_SNAPSHOT_S_SELECT));
-#else
-        ui_error(_("Cannot create snapshot file. Select different history directory!"));
-#endif
         return -1;
     }
 
@@ -844,11 +820,7 @@ int network_connect_client(void)
 #endif
     server_hostent = gethostbyname(server_name);
     if (server_hostent == NULL) {
-#ifdef HAS_TRANSLATION
         ui_error(translate_text(IDGS_CANNOT_RESOLVE_S), server_name);
-#else
-        ui_error(_("Cannot resolve %s"), server_name);
-#endif
         return -1;
     }
 #ifdef HAVE_IPV6
@@ -888,13 +860,8 @@ int network_connect_client(void)
         sizeof(server_addr));
     if (return_value < 0) {
         closesocket(network_socket);
-#ifdef HAS_TRANSLATION
         ui_error(translate_text(IDGS_CANNOT_CONNECT_TO_S),
                     server_name, server_port);
-#else
-        ui_error(_("Cannot connect to %s (no server running on port %d)."),
-                    server_name, server_port);
-#endif
         lib_free(snapshotfilename);
 #if defined(HAVE_IPV6) && !defined(HAVE_GETHOSTBYNAME2)
         if (netplay_ipv6)
@@ -903,11 +870,7 @@ int network_connect_client(void)
         return -1;
     }
 
-#ifdef HAS_TRANSLATION
     ui_display_statustext(translate_text(IDGS_RECEIVING_SNAPSHOT_SERVER), 0);
-#else
-    ui_display_statustext(_("Receiving snapshot from server..."), 0);
-#endif
     if (network_recv_buffer(network_socket, recv_buf4, 4) < 0) {
         lib_free(snapshotfilename);
         closesocket(network_socket);
@@ -990,11 +953,7 @@ static void network_hook_connected_send(void)
     util_int_to_le_buf4(send_len4, (int)send_len);
     if (network_send_buffer(network_socket, send_len4, 4) < 0
         || network_send_buffer(network_socket, local_event_buf, send_len) < 0) {
-#ifdef HAS_TRANSLATION
         ui_display_statustext(translate_text(IDGS_REMOTE_HOST_DISCONNECTED), 1);
-#else
-        ui_display_statustext(_("Remote host disconnected."), 1);
-#endif
         network_disconnect();
     }
 #ifdef NETWORK_DEBUG
@@ -1020,11 +979,7 @@ static void network_hook_connected_receive(void)
     if (frame_buffer_full) {
         do {
             if (network_recv_buffer(network_socket, recv_len4, 4) < 0) {
-#ifdef HAS_TRANSLATION
                 ui_display_statustext(translate_text(IDGS_REMOTE_HOST_DISCONNECTED), 1);
-#else
-                ui_display_statustext(_("Remote host disconnected."), 1);
-#endif
                 network_disconnect();
                 return;
             }
@@ -1032,11 +987,7 @@ static void network_hook_connected_receive(void)
             recv_len = util_le_buf4_to_int(recv_len4);
             if (recv_len == 0 && suspended == 0) {
                 /* remote host suspended emulation */
-#ifdef HAS_TRANSLATION
                 ui_display_statustext(translate_text(IDGS_REMOTE_HOST_SUSPENDING), 0);
-#else
-                ui_display_statustext(_("Remote host suspending..."), 0);
-#endif
                 suspended = 1;
                 vsync_suspend_speed_eval();
             }
@@ -1076,11 +1027,7 @@ static void network_hook_connected_receive(void)
             for (i = 0; i < 5; i++) {
                 if (((DWORD *)client_event_list->base->data)[i]
                     != ((DWORD *)server_event_list->base->data)[i]) {
-#ifdef HAS_TRANSLATION
                     ui_error(translate_text(IDGS_NETWORK_OUT_OF_SYNC));
-#else
-                    ui_error(_("Network out of sync - disconnecting."));
-#endif
                     network_disconnect();
                     /* shouldn't happen but resyncing would be nicer */
                     break;
@@ -1199,5 +1146,9 @@ void network_hook(void)
 void network_shutdown(void)
 {
 }
-#endif
 
+int network_get_mode(void)
+{
+    return NETWORK_IDLE;
+}
+#endif
