@@ -74,10 +74,9 @@ static void set_cb2(int state)
 }
 
 static void set_int(via_context_t *via_context, unsigned int int_num,
-                    int value)
+                    int value, CLOCK rclk)
 {
-    interrupt_set_irq(maincpu_int_status, int_num, value,
-                      *(via_context->clk_ptr));
+    interrupt_set_irq(maincpu_int_status, int_num, value, rclk);
 }
 
 static void restore_int(via_context_t *via_context, unsigned int int_num,
@@ -129,6 +128,7 @@ static void undump_pcr(via_context_t *via_context, BYTE byte)
     crtc_set_char(byte & 2); /* switching PET charrom with CA2 */
                              /* switching userport strobe with CB2 */
 #endif
+    petsound_store_manual((byte & 0xe0) == 0xe0);   /* Manual control of CB2 sound */
 }
 
 static BYTE store_pcr(via_context_t *via_context, BYTE byte, WORD addr)
@@ -146,6 +146,7 @@ static BYTE store_pcr(via_context_t *via_context, BYTE byte, WORD addr)
         printer_userport_write_strobe(byte & 0x20);
     }
 #endif
+    petsound_store_manual((byte & 0xe0) == 0xe0);   /* Manual control of CB2 sound */
     return byte;
 }
 
