@@ -71,7 +71,7 @@
 #include "types.h"
 
 
-#define PETCATVERSION   2.16
+#define PETCATVERSION   2.17
 #define PETCATLEVEL     1
 
 #define B_1              1
@@ -104,6 +104,8 @@
 #define B_BLARG         26
 #define B_VIC4          27
 #define B_VIC5          28
+#define B_WSF           29
+#define B_GB            30
 
 /* Limits */
 
@@ -138,6 +140,8 @@
 #define NUM_BASLCC      51      /* Basic Lightning (c64) */
 #define NUM_MAGICCC     50      /* Magic Basic (c64) */
 #define NUM_EASYCC      51      /* Easy Basic (vic20) */
+#define NUM_WSFCC       51      /* WS basic final (c64) */
+#define NUM_GBCC        29
 
 #define NUM_BLARGE0     11      /* Blarg (c64) */
 
@@ -166,6 +170,8 @@
 #define MAX_BASLCC      0xFE    /* Basic Lightning (c64) */
 #define MAX_MAGICCC     0xFD    /* Magic Basic (c64) */
 #define MAX_EASYCC      0xFE    /* Easy Basic (vic20) */
+#define MAX_WSFCC       0xFE    /* WS basic final (c64) */
+#define MAX_GBCC        0xE8    /* Game Basic (c64) */
 
 #define MAX_BLARGE0     0xEA    /* Blarg (c64) */
 
@@ -270,7 +276,7 @@ static const char *a_cbmkeys[] = {
 	"","","","","","","CBM-^",""
 };
 
-#define NUM_VERSIONS  28
+#define NUM_VERSIONS  30
 
 const char *VersNames[] = {
     "Basic 1.0",
@@ -306,6 +312,8 @@ const char *VersNames[] = {
     "Basic 2.0 with Blarg",
     "Basic 4.0 extension for VIC20",
     "Basic 5.0 extension for VIC20",
+    "Basic 2.0 with WS basic final",
+    "Basic 2.0 with Game Basic",
     ""
 };
 
@@ -532,8 +540,7 @@ const char *graphicsbasickwcc[] = {
 };
 
 
-/* WS (WohnzimmerSoft) basic (c64) Keywords (Tokens CC - FE) -- Marco van den
-                                                                Heuvel */
+/* WS (WohnzimmerSoft) basic (c64) Keywords (Tokens CC - FE) -- Marco van den Heuvel */
 
 const char *wsbasickwcc[] = {
     "copy",   "old",    "port",  "doke",  "vpoke",  "fill",   "error",
@@ -547,6 +554,20 @@ const char *wsbasickwcc[] = {
 };
 
 
+/* WS (WohnzimmerSoft) basic final (c64) Keywords (Tokens CC - FE) -- Marco van den Heuvel */
+
+const char *wsfbasickwcc[] = {
+    "copy",   "bank",   "old",   "doke",  "display", "fill",   "error",
+    "send",   "call",   "bit",   "dir",   "bload",   "bsave",  "find",
+    "speed",  "pitch",  "say",   "fast",  "slow",    "talk",   "shutup",
+    "stash",  "fetch",  "swap",  "off",   "mode",    "device", "object",
+    "vstash", "vfetch", "latch", "color", "cls",     "curpos", "monitor",
+    "subend", "do",     "loop",  "exit",  "deek",    "col",    "rsm",
+    "dec",    "hex$",   "hi",    "lo",    "ds$",     "line",   "bnk",
+    "ypos",   "joy"
+};
+
+
 /* Pegasus basic 4.0 (c64) Keywords (Tokens CC - EC) -- Marco van den Heuvel */
  
 const char *pegbasickwcc[] = {
@@ -611,6 +632,16 @@ const char *magickwcc[] = {
     "replace",   "lrun"
 };
 
+/* Game Basic (c64) Keywords (Tokens CC - E8) -- Marco van den Heuvel */
+
+const char *gbkwcc[] = {
+    "window", "bfile",   "upper",   "lower",   "cls",    "screen", "parse",
+    "proc",   "else",    "scratch", "replace", "device", "dir",    "repeat",
+    "until",  "disk",    "fetch#",  "put#",    "prompt", "pop",    "help",
+    "exit",   "disable", "enter",   "reset",   "warm",   "num",    "type",
+    "text$"
+};
+
 /* Simon's Basic Keywords */
 
 const char *simonskw[] = {
@@ -670,12 +701,10 @@ int network_connected(void)
   return 0;
 }
 
-#ifdef HAVE_NETWORK
 int network_get_mode(void)
 {
   return NETWORK_IDLE;
 }
-#endif
 
 void network_event_record(unsigned int type, void *data, unsigned int size)
 {
@@ -822,6 +851,7 @@ int main(int argc, char **argv)
                 "\tultra\tBasic v2.0 with Ultrabasic-64 (C64)\n"
                 "\tgraph\tBasic v2.0 with Graphics basic (C64)\n"
                 "\tWSB\tBasic v2.0 with WS basic (C64)\n"
+                "\tWSBF\tBasic v2.0 with WS basic final (C64)\n"
                 "\tPegasus\tBasic v2.0 with Pegasus basic 4.0 (C64)\n"
                 "\tXbasic\tBasic v2.0 with Xbasic (C64)\n"
                 "\tDrago\tBasic v2.0 with Drago basic 2.2 (C64)\n"
@@ -830,6 +860,7 @@ int main(int argc, char **argv)
                 "\tmagic\tBasic v2.0 with Magic Basic (C64)\n"
                 "\teasy\tBasic v2.0 with Easy Basic (VIC20)\n"
                 "\tblarg\tBasic v2.0 with Blarg (C64)\n"
+                "\tGame\tBasic v2.0 with Game Basic (C64)\n"
                 "\t4 -w4e\tPET Basic v4.0 program (PET/C64)\n"
                 "\t3\tBasic v3.5 program (C16)\n"
                 "\t4v\tBasic 2.0 with Basic 4.0 extensions (VIC20)\n"
@@ -1123,11 +1154,42 @@ static int parse_version(char *str)
         break;
 
       case 'G':
-        version = B_GRAPH;
+        switch (str[1]) {
+          case 'R':
+            version = B_GRAPH;
+            break;
+          case 'A':
+            version = B_GB;
+            break;
+          default:
+            fprintf (stderr,
+                "Please, select one of the following: 70, 71\n");
+        }
         break;
 
       case 'W':
-        version = B_WS;
+        if (str[1]!='S')
+        {
+          fprintf(stderr, "Please, select one of the following: WSB, WSBF\n");
+        }
+        else
+        {
+          if (str[2]!='B')
+          {
+            fprintf(stderr, "Please, select one of the following: WSB, WSBF\n");
+          }
+          else
+          {
+            if (str[3]=='F')
+            {
+              version = B_WSF;
+            }
+            else
+            {
+              version = B_WS;
+            }
+          }
+        }
         break;
 
       case 'M':
@@ -1251,6 +1313,11 @@ static void list_keywords(int version)
             printf("%s\t", blargkwe0[n] /*, n + 0xe0*/);
         break;
 
+      case B_GB:
+        for (n = 0; n < NUM_GBCC; n++)
+            printf("%s\t", gbkwcc[n] /*, n + 0xcc*/);
+        break;
+
       case B_4:
       case B_4E:
         for (n = 0; n < ((version == B_4) ? NUM_V4CC : NUM_4ECC); n++)
@@ -1297,6 +1364,11 @@ static void list_keywords(int version)
             printf("%s\t", wsbasickwcc[n] /*, n + 0xcc*/);
         break;
 
+      case B_WSF:
+        for (n = 0; n < NUM_WSFCC; n++)
+            printf("%s\t", wsfbasickwcc[n] /*, n + 0xcc*/);
+        break;
+
       case B_PEG:
         for (n = 0; n < NUM_PEGCC; n++)
             printf("%s\t", pegbasickwcc[n] /*, n + 0xcc*/);
@@ -1528,6 +1600,11 @@ static int p_expand(int version, int addr, int ctrls)
                         fprintf(dest, "%s", easykwcc[c - 0xe0]);
                     break;
 
+                  case B_GB:
+                    if (c >= 0xcc && c <= MAX_GBCC)
+                        fprintf(dest, "%s", gbkwcc[c - 0xcc]);
+                    break;
+
                   case B_SPEECH:        /* C64 Speech basic */
                     if (c >= 0xcc && c <= MAX_SPECC)
                         fprintf(dest, "%s", speechkwcc[c - 0xcc]);
@@ -1558,6 +1635,11 @@ static int p_expand(int version, int addr, int ctrls)
                         fprintf(dest, "%s", wsbasickwcc[c - 0xcc]);
                     break;
 
+                  case B_WSF:
+                    if (c >= 0xcc && c <= MAX_WSFCC)
+                        fprintf(dest, "%s", wsfbasickwcc[c - 0xcc]);
+                    break;
+
                   case B_PEG:
                     if (c >= 0xcc && c <= MAX_PEGCC)
                         fprintf(dest, "%s", pegbasickwcc[c - 0xcc]);
@@ -1847,6 +1929,14 @@ static void p_tokenize(int version, unsigned int addr, int ctrls)
                     }
                     break;
 
+                  case B_GB:
+                    if ((c = sstrcmp(p2, gbkwcc, 0, NUM_GBCC)) !=KW_NONE) {
+                        *p1++ = c + 0xcc;
+                        p1 += kwlen;
+                        match++;
+                    }
+                    break;
+
                   case B_MIGHTY:
                     if ((c = sstrcmp(p2, mightykwcc, 0, NUM_MIGHTYCC)) !=KW_NONE) {
                         *p1++ = c + 0xcc;
@@ -1947,6 +2037,14 @@ static void p_tokenize(int version, unsigned int addr, int ctrls)
                     }
                     break;
 
+                  case B_WSF:
+                    if ((c = sstrcmp(p2 , wsfbasickwcc, 0, NUM_WSCC)) !=KW_NONE) {
+                        *p1++ = c + 0xcc;
+                        p2 += kwlen;
+                        match++;
+                    }
+                    break;
+
                   case B_PEG:
                     if ((c = sstrcmp(p2 , pegbasickwcc, 0, NUM_PEGCC)) !=KW_NONE) {
                         *p1++ = c + 0xcc;
