@@ -41,6 +41,7 @@
 #include "kbdbuf.h"
 #include "keyboard.h"
 #include "log.h"
+#include "resources.h"
 #include "machine-drive.h"
 #include "machine-printer.h"
 #include "machine-video.h"
@@ -391,6 +392,16 @@ int machine_specific_init(void)
 
     machine_drive_stub();
 
+#if defined (USE_XF86_EXTENSIONS) && \
+    (defined(USE_XF86_VIDMODE_EXT) || defined (HAVE_XRANDR))
+    {
+	/* set fullscreen if user used `-fullscreen' on cmdline */
+	int fs;
+	resources_get_int("UseFullscreen", &fs);
+	if (fs)
+	    resources_set_int("TEDFullscreen", 1);
+    }
+#endif
     return 0;
 }
 
