@@ -37,7 +37,13 @@
 #include "keyboard.h"
 #include "log.h"
 #include "maincpu.h"
+
+#ifdef WATCOM_COMPILE
+#include "../mem.h"
+#else
 #include "mem.h"
+#endif
+
 #include "plus4mem.h"
 #include "plus4pio2.h"
 #include "ted-badline.h"
@@ -936,11 +942,9 @@ inline static BYTE ted09_peek(void)
             return ted.irq_status | 0xa3;
         else
             return ted.irq_status | 0x23;
-    } else {
-        return ted.irq_status | 0x21;
     }
 
-    return ted.irq_status;
+    return ted.irq_status | 0x21;
 }
 
 BYTE REGPARM1 ted_peek(WORD addr)
