@@ -2,7 +2,7 @@
  * drv-mps803.h - MPS803 printer driver.
  *
  * Written by
- *  Andreas Boose <boose@linux.rz.fh-hannover.de>
+ *  Andreas Boose <viceteam@t-online.de>
  *
  * This file is part of VICE, the Versatile Commodore Emulator.
  * See README for copyright notice.
@@ -31,6 +31,7 @@
 
 extern int drv_mps803_init_resources(void);
 extern int drv_mps803_init(void);
+extern void drv_mps803_shutdown(void);
 
 #endif
 
