@@ -2,7 +2,7 @@
  * interface-userport.h - Userport printer interface.
  *
  * Written by
- *  Andreas Boose <boose@linux.rz.fh-hannover.de>
+ *  Andreas Boose <viceteam@t-online.de>
  *
  * This file is part of VICE, the Versatile Commodore Emulator.
  * See README for copyright notice.
@@ -27,8 +27,13 @@
 #ifndef _INTERFACE_USERPORT_H
 #define _INTERFACE_USERPORT_H
 
+#include "types.h"
+
 extern int interface_userport_init_resources(void);
 extern int interface_userport_init_cmdline_options(void);
+extern void interface_userport_write_data(BYTE b);
+extern void interface_userport_write_strobe(int s);
+extern void interface_userport_init(void (*set_busy)(unsigned int));
 
 #endif
 
