@@ -37,13 +37,10 @@
 #include "output-text.h"
 #include "output.h"
 #include "resources.h"
-#ifdef HAS_TRANSLATION
 #include "translate.h"
-#endif
 #include "types.h"
 #include "util.h"
 
-
 static char *PrinterDev[3] = { NULL, NULL, NULL };
 static int printer_device[3];
 static FILE *output_fd[3] = { NULL, NULL, NULL };
@@ -86,47 +83,40 @@ static const resource_int_t resources_int[] = {
     { NULL }
 };
 
-#ifdef HAS_TRANSLATION
 static const cmdline_option_t cmdline_options[] =
 {
-    { "-prtxtdev1", SET_RESOURCE, 1, NULL, NULL, "PrinterTextDevice1", NULL,
-     IDCLS_P_NAME, IDCLS_SPECIFY_TEXT_DEVICE_DUMP_NAME },
-    { "-prtxtdev2", SET_RESOURCE, 1, NULL, NULL, "PrinterTextDevice2", NULL,
-     IDCLS_P_NAME, IDCLS_SPECIFY_TEXT_DEVICE_DUMP_NAME },
-    { "-prtxtdev3", SET_RESOURCE, 1, NULL, NULL, "PrinterTextDevice3", NULL,
-     IDCLS_P_NAME, IDCLS_SPECIFY_TEXT_DEVICE_DUMP_NAME },
-    { "-pr4txtdev", SET_RESOURCE, 1, NULL, NULL, "Printer4TextDevice",
-      (resource_value_t)0,
-      IDCLS_P_0_2, IDCLS_SPECIFY_TEXT_DEVICE_4 },
-    { "-pr5txtdev", SET_RESOURCE, 1, NULL, NULL, "Printer5TextDevice",
-      (resource_value_t)0,
-      IDCLS_P_0_2, IDCLS_SPECIFY_TEXT_DEVICE_5 },
-    { "-prusertxtdev", SET_RESOURCE, 1, NULL, NULL, "PrinterUserportTextDevice",
-      (resource_value_t)0,
-      IDCLS_P_0_2, IDCLS_SPECIFY_TEXT_USERPORT },
+    { "-prtxtdev1", SET_RESOURCE, 1,
+      NULL, NULL, "PrinterTextDevice1", NULL,
+      USE_PARAM_ID, USE_DESCRIPTION_ID,
+      IDCLS_P_NAME, IDCLS_SPECIFY_TEXT_DEVICE_DUMP_NAME,
+      NULL, NULL },
+    { "-prtxtdev2", SET_RESOURCE, 1,
+      NULL, NULL, "PrinterTextDevice2", NULL,
+      USE_PARAM_ID, USE_DESCRIPTION_ID,
+      IDCLS_P_NAME, IDCLS_SPECIFY_TEXT_DEVICE_DUMP_NAME,
+      NULL, NULL },
+    { "-prtxtdev3", SET_RESOURCE, 1,
+      NULL, NULL, "PrinterTextDevice3", NULL,
+      USE_PARAM_ID, USE_DESCRIPTION_ID,
+      IDCLS_P_NAME, IDCLS_SPECIFY_TEXT_DEVICE_DUMP_NAME,
+      NULL, NULL },
+    { "-pr4txtdev", SET_RESOURCE, 1,
+      NULL, NULL, "Printer4TextDevice", (resource_value_t)0,
+      USE_PARAM_STRING, USE_DESCRIPTION_ID,
+      IDCLS_UNUSED, IDCLS_SPECIFY_TEXT_DEVICE_4,
+      "<0-2>", NULL },
+    { "-pr5txtdev", SET_RESOURCE, 1,
+      NULL, NULL, "Printer5TextDevice", (resource_value_t)0,
+      USE_PARAM_STRING, USE_DESCRIPTION_ID,
+      IDCLS_UNUSED, IDCLS_SPECIFY_TEXT_DEVICE_5,
+      "<0-2>", NULL },
+    { "-prusertxtdev", SET_RESOURCE, 1,
+      NULL, NULL, "PrinterUserportTextDevice", (resource_value_t)0,
+      USE_PARAM_STRING, USE_DESCRIPTION_ID,
+      IDCLS_UNUSED, IDCLS_SPECIFY_TEXT_USERPORT,
+      "<0-2>", NULL },
     { NULL }
 };
-#else
-static const cmdline_option_t cmdline_options[] =
-{
-    { "-prtxtdev1", SET_RESOURCE, 1, NULL, NULL, "PrinterTextDevice1", NULL,
-     N_("<name>"), N_("Specify name of printer text device or dump file") },
-    { "-prtxtdev2", SET_RESOURCE, 1, NULL, NULL, "PrinterTextDevice2", NULL,
-     N_("<name>"), N_("Specify name of printer text device or dump file") },
-    { "-prtxtdev3", SET_RESOURCE, 1, NULL, NULL, "PrinterTextDevice3", NULL,
-     N_("<name>"), N_("Specify name of printer text device or dump file") },
-    { "-pr4txtdev", SET_RESOURCE, 1, NULL, NULL, "Printer4TextDevice",
-      (resource_value_t)0,
-      "<0-2>", N_("Specify printer text output device for IEC printer #4") },
-    { "-pr5txtdev", SET_RESOURCE, 1, NULL, NULL, "Printer5TextDevice",
-      (resource_value_t)0,
-      "<0-2>", N_("Specify printer text output device for IEC printer #5") },
-    { "-prusertxtdev", SET_RESOURCE, 1, NULL, NULL, "PrinterUserportTextDevice",
-      (resource_value_t)0,
-      "<0-2>", N_("Specify printer text output device for userport printer") },
-    { NULL }
-};
-#endif
 
 int output_text_init_cmdline_options(void)
 {
@@ -227,4 +217,3 @@ void output_text_shutdown_resources(void)
     lib_free(PrinterDev[1]);
     lib_free(PrinterDev[2]);
 }
-
