@@ -61,11 +61,22 @@ inline static void refresh_canvas(raster_t *raster)
     h = update_area->ye - update_area->ys + 1;
 
     if (video_render_get_fake_pal_state()) {
-        /* if pal emu is activated, more pixels have to be updated */
+        /* if pal emu is activated, more pixels have to be updated: around,
+         * above and below, because of blurring and scanline effects.
+         *
+         * 1 line above and 1 lines below are required because the update on
+         * any line affects the scanlines both above and below, so both must
+         * be included in the full update rectangle.
+         *
+         * These coordinates are also passed to the graphics driver as the
+         * updated region, so the area here must be at least as large as the
+         * updated region. */
         x -= 4;
         xx -= 4;
         w += 8;
-        h ++;
+        y --;
+        yy --;
+        h += 2;
     }
 
     if (xx < 0) {
