@@ -5,6 +5,9 @@
  *  Ettore Perazzoli <ettore@comm2000.it>
  *  Andreas Boose <viceteam@t-online.de>
  *
+ * DTV sections written by
+ *  Daniel Kahlin <daniel@kahlin.net>
+ *
  * This file is part of VICE, the Versatile Commodore Emulator.
  * See README for copyright notice.
  *
@@ -204,6 +207,8 @@ inline static void draw_blank(raster_t *raster,
            raster->border_color, end - start + 1);
 }
 
+/* seemingly dead code */
+#if 0
 /* Draw the borders.  */
 inline static void draw_borders(raster_t *raster)
 {
@@ -214,6 +219,7 @@ inline static void draw_borders(raster_t *raster)
                    raster->display_xstop,
                    raster->geometry->screen_size.width - 1);
 }
+#endif
 
 int raster_init(raster_t *raster,
                 unsigned int num_modes)
@@ -237,6 +243,9 @@ int raster_init(raster_t *raster,
 
     raster->fake_draw_buffer_line = NULL;
 
+    raster->can_disable_border = 0;
+    raster->border_disable = 0;
+
     raster->border_color = 0;
     raster->background_color = 0;
     raster->idle_background_color = 0;
@@ -265,8 +274,10 @@ void raster_reset(raster_t *raster)
     raster->current_line = 0;
 
     raster->xsmooth = raster->ysmooth = 0;
+    raster->sprite_xsmooth = 0;
     raster->xsmooth_shift_left = 0;
     raster->xsmooth_shift_right = 0;
+    raster->sprite_xsmooth_shift_right = 0;
     raster->skip_frame = 0;
 
     raster->blank_off = 0;
@@ -274,11 +285,13 @@ void raster_reset(raster_t *raster)
     raster->blank_this_line = 0;
     raster->open_right_border = 0;
     raster->open_left_border = 0;
+    raster->border_disable = 0;
     raster->blank = 0;
 
     raster->draw_idle_state = 0;
     raster->ycounter = 0;
     raster->video_mode = 0;
+    raster->last_video_mode = -1;
 }
 
 typedef struct raster_list_t {
