@@ -5,6 +5,9 @@
  *  Ettore Perazzoli <ettore@comm2000.it>
  *  Andreas Boose <viceteam@t-online.de>
  *
+ * DTV sections written by
+ *  Daniel Kahlin <daniel@kahlin.net>
+ *
  * This file is part of VICE, the Versatile Commodore Emulator.
  * See README for copyright notice.
  *
@@ -84,13 +87,13 @@ struct raster_s {
     BYTE *fake_draw_buffer_line;
 
     /* Smooth scroll values for the graphics (not the whole screen).  */
-    int xsmooth, ysmooth;
+    int xsmooth, ysmooth, sprite_xsmooth;
 
     /* Number of pixels at a xsmooth shift to the left.  */
     int xsmooth_shift_left;
 
     /* Number of pixels at a xsmooth shift to the right.  */
-    int xsmooth_shift_right;
+    int xsmooth_shift_right, sprite_xsmooth_shift_right;
 
     /* If nonzero, we should skip the next frame. (used for automatic refresh
        rate setting) */
@@ -119,6 +122,7 @@ struct raster_s {
 
     /* Open border flags.  */
     int open_right_border, open_left_border;
+    int can_disable_border, border_disable;
 
     /*  Overrides the blank flag when forced DMA switches on screen and the
         store that forced DMA sets the blank flag.  The flag should be cleared
@@ -142,6 +146,9 @@ struct raster_s {
     /* Current video mode.  */
     int video_mode;
 
+    /* Last video mode.  */
+    int last_video_mode;
+
     /* Cache.  */
     struct raster_cache_s *cache;
     int cache_enabled;          /* FIXME: Method to toggle it. */
@@ -324,7 +331,7 @@ inline static void raster_changes_sprites_add_int(raster_t *raster,
         *ptr = new_value;
     else if (raster_x < (int)(raster->geometry->screen_size.width 
                         + raster->geometry->extra_offscreen_border_right)) {
-        raster_changes_add_int(raster->changes->sprites,
+        raster_changes_add_sorted_int(raster->changes->sprites,
                                raster_x, ptr, new_value);
         raster->changes->have_on_this_line = 1;
     } else {
