@@ -1,6 +1,6 @@
 //  ---------------------------------------------------------------------------
 //  This file is part of reSID, a MOS6581 SID emulator engine.
-//  Copyright (C) 2003  Dag Lem <resid@nimrod.no>
+//  Copyright (C) 2004  Dag Lem <resid@nimrod.no>
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -54,7 +54,7 @@ void ExternalFilter::enable_filter(bool enable)
 // ----------------------------------------------------------------------------
 void ExternalFilter::set_chip_model(chip_model model)
 {
-  if (model == MOS6581) {
+  if ((model == MOS6581)||(model == DTVSID)) {
     // Maximum mixer DC output level; to be removed if the external
     // filter is turned off: ((wave DC + voice DC)*voices + mixer DC)*volume
     // See voice.cc and filter.cc for an explanation of the values.
