@@ -1,6 +1,6 @@
 //  ---------------------------------------------------------------------------
 //  This file is part of reSID, a MOS6581 SID emulator engine.
-//  Copyright (C) 2003  Dag Lem <resid@nimrod.no>
+//  Copyright (C) 2004  Dag Lem <resid@nimrod.no>
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -35,7 +35,7 @@ void Voice::set_chip_model(chip_model model)
 {
   wave.set_chip_model(model);
 
-  if (model == MOS6581) {
+  if (model == MOS6581 || model == DTVSID) {
     // The waveform D/A converter introduces a DC offset in the signal
     // to the envelope multiplying D/A converter. The "zero" level of
     // the waveform D/A converter can be found as follows:
