@@ -1,6 +1,6 @@
 //  ---------------------------------------------------------------------------
 //  This file is part of reSID, a MOS6581 SID emulator engine.
-//  Copyright (C) 2003  Dag Lem <resid@nimrod.no>
+//  Copyright (C) 2004  Dag Lem <resid@nimrod.no>
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -16,6 +16,9 @@
 //  along with this program; if not, write to the Free Software
 //  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 //  ---------------------------------------------------------------------------
+// C64 DTV modifications written by
+//   Daniel Kahlin <daniel@kahlin.net>
+// Copyright (C) 2007  Daniel Kahlin <daniel@kahlin.net>
 
 #define __WAVE_CC__
 #include "wave.h"
@@ -48,7 +51,7 @@ void WaveformGenerator::set_sync_source(WaveformGenerator* source)
 // ----------------------------------------------------------------------------
 void WaveformGenerator::set_chip_model(chip_model model)
 {
-  if (model == MOS6581) {
+  if (model == MOS6581 || model == DTVSID) {
     wave__ST = wave6581__ST;
     wave_P_T = wave6581_P_T;
     wave_PS_ = wave6581_PS_;
@@ -126,6 +129,11 @@ reg8 WaveformGenerator::readOSC()
   return output() >> 4;
 }
 
+void WaveformGenerator::writeACC_HI(reg8 value)
+{
+  accumulator = (value << 16) | (accumulator & 0xffff);
+}
+
 // ----------------------------------------------------------------------------
 // SID reset.
 // ----------------------------------------------------------------------------
