@@ -41,7 +41,7 @@
 #include <string.h>
 #include <ctype.h>
 
-#if 0
+#ifdef HAVE_STRINGS_H
 #include <strings.h>
 #endif
 
@@ -117,13 +117,6 @@ static int *hashTable = NULL;
 
 static resource_callback_desc_t *resource_modified_callback = NULL;
 
-#ifndef HAVE_NETWORK
-int network_get_mode(void)
-{
-    return NETWORK_IDLE;
-}
-#endif
-
 /* calculate the hash key */
 static unsigned int resources_calc_hash_key(const char *name)
 {
@@ -213,6 +206,8 @@ static void resources_check_hash_table(FILE *f)
 }
 #endif
 
+/* Configuration filename set via -config */
+char *vice_config_file = NULL;
 
 /* ------------------------------------------------------------------------- */
 int resources_register_int(const resource_int_t *r)
@@ -320,6 +315,7 @@ void resources_shutdown(void)
     lib_free(resources);
     lib_free(hashTable);
     lib_free(machine_id);
+    lib_free(vice_config_file);
 }
 
 static resource_ram_t *lookup(const char *name)
@@ -998,7 +994,11 @@ int resources_load(const char *fname)
     char *default_name = NULL;
 
     if (fname == NULL) {
-        default_name = archdep_default_resource_file_name();
+        if (vice_config_file == NULL) {
+            default_name = archdep_default_resource_file_name();
+        } else {
+            default_name = lib_stralloc(vice_config_file);
+        }
         fname = default_name;
     }
 
@@ -1105,7 +1105,11 @@ int resources_save(const char *fname)
     char *default_name = NULL;
 
     if (fname == NULL) {
-        default_name = archdep_default_save_resource_file_name();
+        if (vice_config_file == NULL) {
+            default_name = archdep_default_save_resource_file_name();
+        } else {
+            default_name = lib_stralloc(vice_config_file);
+        }
         fname = default_name;
     }
 
