@@ -637,11 +637,10 @@ inline static void setup_voice(voice_t *pv)
     pv->gateflip = 0;
 }
 
-static int fastsid_calculate_samples(sound_t *psid, SWORD *pbuf, int nr,
-                                     int interleave, int *delta_t)
+static SDWORD fastsid_calculate_single_sample(sound_t *psid, int i)
 {
     DWORD o0, o1, o2;
-    int dosync1, dosync2, i;
+    int dosync1, dosync2;
     voice_t *v0, *v1, *v2;
 
     setup_sid(psid);
@@ -652,79 +651,97 @@ static int fastsid_calculate_samples(sound_t *psid, SWORD *pbuf, int nr,
     v2 = &psid->v[2];
     setup_voice(v2);
 
-    for (i = 0; i < nr; i++) {
-        /* addfptrs, noise & hard sync test */
-        dosync1 = 0;
-        if ((v0->f += v0->fs) < v0->fs) {
-            v0->rv = NSHIFT(v0->rv, 16);
-            if (v1->sync)
-                dosync1 = 1;
-        }
-        dosync2 = 0;
-        if ((v1->f += v1->fs) < v1->fs) {
-            v1->rv = NSHIFT(v1->rv, 16);
-            if (v2->sync)
-                dosync2 = 1;
-        }
-        if ((v2->f += v2->fs) < v2->fs) {
-            v2->rv = NSHIFT(v2->rv, 16);
-            if (v0->sync) {
-                /* hard sync */
-                v0->rv = NSHIFT(v0->rv, v0->f >> 28);
-                v0->f = 0;
-            }
-        }
-
+    /* addfptrs, noise & hard sync test */
+    dosync1 = 0;
+    if ((v0->f += v0->fs) < v0->fs) {
+        v0->rv = NSHIFT(v0->rv, 16);
+        if (v1->sync)
+            dosync1 = 1;
+    }
+    dosync2 = 0;
+    if ((v1->f += v1->fs) < v1->fs) {
+        v1->rv = NSHIFT(v1->rv, 16);
+        if (v2->sync)
+            dosync2 = 1;
+    }
+    if ((v2->f += v2->fs) < v2->fs) {
+        v2->rv = NSHIFT(v2->rv, 16);
+        if (v0->sync) {
         /* hard sync */
-        if (dosync2) {
-            v2->rv = NSHIFT(v2->rv, v2->f >> 28);
-            v2->f = 0;
-        }
-        if (dosync1) {
-            v1->rv = NSHIFT(v1->rv, v1->f >> 28);
-            v1->f = 0;
+            v0->rv = NSHIFT(v0->rv, v0->f >> 28);
+            v0->f = 0;
         }
+    }
 
-        /* do adsr */
-        if ((v0->adsr += v0->adsrs) + 0x80000000 < v0->adsrz + 0x80000000)
-            trigger_adsr(v0);
-        if ((v1->adsr += v1->adsrs) + 0x80000000 < v1->adsrz + 0x80000000)
-            trigger_adsr(v1);
-        if ((v2->adsr += v2->adsrs) + 0x80000000 < v2->adsrz + 0x80000000)
-            trigger_adsr(v2);
+    /* hard sync */
+    if (dosync2) {
+        v2->rv = NSHIFT(v2->rv, v2->f >> 28);
+        v2->f = 0;
+    }
+    if (dosync1) {
+        v1->rv = NSHIFT(v1->rv, v1->f >> 28);
+        v1->f = 0;
+    }
 
-        /* oscillators */
-        o0 = v0->adsr >> 16;
-        o1 = v1->adsr >> 16;
-        o2 = v2->adsr >> 16;
-        if (o0)
-            o0 *= doosc(v0);
-        if (o1)
-            o1 *= doosc(v1);
-        if (psid->has3 && o2)
-            o2 *= doosc(v2);
-        else
-            o2 = 0;
-        /* sample */
-        if (psid->emulatefilter) {
-            v0->filtIO = ampMod1x8[(o0 >> 22)];
-            dofilter(v0);
-            o0 = ((DWORD)(v0->filtIO) + 0x80) << (7 + 15);
-            v1->filtIO = ampMod1x8[(o1 >> 22)];
-            dofilter(v1);
-            o1 = ((DWORD)(v1->filtIO) + 0x80) << (7 + 15);
-            v2->filtIO = ampMod1x8[(o2 >> 22)];
-            dofilter(v2);
-            o2 = ((DWORD)(v2->filtIO) + 0x80) << (7 + 15);
-        }
+    /* do adsr */
+    if ((v0->adsr += v0->adsrs) + 0x80000000 < v0->adsrz + 0x80000000)
+        trigger_adsr(v0);
+    if ((v1->adsr += v1->adsrs) + 0x80000000 < v1->adsrz + 0x80000000)
+        trigger_adsr(v1);
+    if ((v2->adsr += v2->adsrs) + 0x80000000 < v2->adsrz + 0x80000000)
+        trigger_adsr(v2);
 
-        pbuf[i * interleave] = ((SDWORD)((o0 + o1 + o2) >> 20) - 0x600)
-                               * psid->vol;
+    /* oscillators */
+    o0 = v0->adsr >> 16;
+    o1 = v1->adsr >> 16;
+    o2 = v2->adsr >> 16;
+    if (o0)
+        o0 *= doosc(v0);
+    if (o1)
+        o1 *= doosc(v1);
+    if (psid->has3 && o2)
+        o2 *= doosc(v2);
+    else
+        o2 = 0;
+    /* sample */
+    if (psid->emulatefilter) {
+        v0->filtIO = ampMod1x8[(o0 >> 22)];
+        dofilter(v0);
+        o0 = ((DWORD)(v0->filtIO) + 0x80) << (7 + 15);
+        v1->filtIO = ampMod1x8[(o1 >> 22)];
+        dofilter(v1);
+        o1 = ((DWORD)(v1->filtIO) + 0x80) << (7 + 15);
+        v2->filtIO = ampMod1x8[(o2 >> 22)];
+        dofilter(v2);
+        o2 = ((DWORD)(v2->filtIO) + 0x80) << (7 + 15);
+    }
+
+    return ((SDWORD)((o0 + o1 + o2) >> 20) - 0x600) * psid->vol;
+}
+
+static int fastsid_calculate_samples(sound_t *psid, SWORD *pbuf, int nr,
+                                     int interleave, int *delta_t)
+{
+    int i;
+
+    for (i = 0; i < nr; i++) {
+        pbuf[i * interleave] = fastsid_calculate_single_sample(psid, i);
     }
 
     return nr;
 }
 
+int fastsid_calculate_samples_mix(sound_t *psid, SWORD *pbuf, int nr,
+                                  int interleave, int *delta_t)
+{
+    int i;
+
+    for (i = 0; i< nr; i++) {
+        pbuf[i * interleave] = sound_audio_mix(pbuf[i * interleave], (SWORD)fastsid_calculate_single_sample(psid, i));
+    }
+
+    return nr;
+}
 
 static void init_filter(sound_t *psid, int freq)
 {
@@ -839,7 +856,20 @@ static int fastsid_init(sound_t *psid, int speed, int cycles_per_sec)
         return 0;
     }
 
-    psid->newsid = sid_model == 1;
+    psid->newsid = 0;
+    switch (sid_model) {
+    default:
+    case 0: /* 6581 */
+    case 3: /* 6581R4 */
+    case 4: /* DTVSID */
+        psid->newsid = 0;
+	break;
+    case 1: /* 8580 */
+    case 2: /* 8580 + digi boost */
+        psid->newsid = 1;
+	break;
+    }
+
     for (i = 0; i < 4096; i++) {
         wavetable10[i] = (WORD)(i < 2048 ? i << 4 : 0xffff - (i << 4));
         wavetable20[i] = (WORD)(i << 3);
