@@ -30,7 +30,7 @@
 #define _UIAPI
 
 typedef enum {
-    UI_JAM_RESET, UI_JAM_HARD_RESET, UI_JAM_MONITOR
+    UI_JAM_RESET, UI_JAM_HARD_RESET, UI_JAM_MONITOR, UI_JAM_NONE
 } ui_jam_action_t;
 
 typedef enum {
@@ -56,6 +56,9 @@ extern void ui_error(const char *format,...);
 /* Display a mesage without interrupting emulation */
 extern void ui_display_statustext(const char *text, int fade_out);
 
+/* Let the user browse for a filename; display format as a titel */
+extern char* ui_get_file(const char *format,...);
+
 /* Drive related UI.  */
 extern void ui_enable_drive_status(ui_drive_enable_t state,
                                    int *drive_led_color);
