@@ -137,7 +137,7 @@ typedef struct via_context_s {
     void (*store_t2l)(struct via_context_s *, BYTE);
     BYTE (*read_pra)(struct via_context_s *, WORD);
     BYTE (*read_prb)(struct via_context_s *);
-    void (*set_int)(struct via_context_s *, unsigned int, int);
+    void (*set_int)(struct via_context_s *, unsigned int, int, CLOCK);
     void (*restore_int)(struct via_context_s *, unsigned int, int);
     void (*set_ca2)(int state);
     void (*set_cb2)(int state);
