@@ -3,6 +3,7 @@
  *
  * Written by
  *  Ettore Perazzoli <ettore@comm2000.it>
+ *  Daniel Kahlin <daniel@kahlin.net>
  *
  * This file is part of VICE, the Versatile Commodore Emulator.
  * See README for copyright notice.
@@ -50,17 +51,22 @@ static void init_drawing_tables(void)
 {
     unsigned int byte, color, pos;
 
-    for (byte = 0; byte < 0x100; byte++)
-        for (color = 0; color < 0x100; color++)
-            if (color & 0x8)            /* Multicolor mode. */
-                for (pos = 0; pos < 8; pos += 2)
+    for (byte = 0; byte < 0x100; byte++) {
+        for (color = 0; color < 0x100; color++) {
+            if (color & 0x8) {         /* Multicolor mode. */
+                for (pos = 0; pos < 8; pos += 2) {
                     drawing_table[byte][color][pos]
                         = drawing_table[byte][color][pos + 1]
                         = (byte >> (6 - pos)) & 0x3;
-            else                      /* Standard mode. */
-                for (pos = 0; pos < 8; pos++)
+                }
+            } else {                   /* Standard mode. */
+                for (pos = 0; pos < 8; pos++) {
                     drawing_table[byte][color][pos]
                         = ((byte >> (7 - pos)) & 0x1) * 2;
+                }
+            }
+        }
+    }
 }
 
 
@@ -106,46 +112,74 @@ static int fill_cache(raster_cache_t *cache, unsigned int *xs,
 }
 
 #define PUT_PIXEL(p, d, c, b, x, t) \
-    if (!t || drawing_table[(d)][(b)][(x)]) \
-        *((VIC_PIXEL *)(p) + (x)) = (c)[drawing_table[(d)][(b)][(x)]]
-
-#define PUT_PIXEL2(p, d, c, b, x, t) \
-    if (!t || drawing_table[(d)][(b)][(x)]) \
-        *((VIC_PIXEL2 *)(p) + (x)) = (c)[drawing_table[(d)][(b)][(x)]]
+    if (!t || drawing_table[(d)][(b)][(x)]) { \
+        *((VIC_PIXEL *)(p) + (x)) = (c)[drawing_table[(d)][(b)][(x)]];  \
+    }
 
 #define GET_CHAR_DATA(code, row) \
     *(vic.chargen_ptr + ((code) * vic.char_height) \
     + (row & ((vic.char_height >> 1) | 7)))
 
-inline static void draw(BYTE *p, unsigned int xs, unsigned int xe, int reverse,
+inline static void draw(BYTE *p, unsigned int xs, unsigned int xe,
                         int transparent)
 /* transparent>0: don't overwrite background */
 {
-    static VIC_PIXEL c[4];
-    unsigned int i;
-    int b, x;
-    BYTE d;
+    VIC_PIXEL c[4];
+    unsigned int i, x;
+    BYTE b, d, dr;
 
     /* Last character may exceed border, so we have some extra work */
     /* bordercheck asumes p pointing to display_xstart */
     p += xs * 8 * VIC_PIXEL_WIDTH;
 
     c[0] = VIC_PIXEL(vic.raster.background_color);
+
+    /* if any of mc_border_color, auxiliary_color or reverse have
+       changed, handle the first char specially! */
+    if (vic.mc_border_color != vic.old_mc_border_color ||
+        vic.auxiliary_color != vic.old_auxiliary_color ||
+        vic.reverse != vic.old_reverse) {
+
+        b = *(vic.color_ptr + vic.memptr + xs);
+        d = GET_CHAR_DATA(*(vic.screen_ptr + vic.memptr + xs),
+                          vic.raster.ycounter);
+        c[2] = VIC_PIXEL(b & 0x7);
+
+        /* put the first pixel to handle border or auxiliary color
+           changes */
+        c[1] = VIC_PIXEL(vic.old_mc_border_color);
+        c[3] = VIC_PIXEL(vic.old_auxiliary_color);
+        dr = (vic.old_reverse & !(b & 0x8)) ? ~d : d;
+        PUT_PIXEL(p, dr, c, b, 0, transparent);
+
+        /* put two more pixels to handle reverse changes */
+        c[1] = VIC_PIXEL(vic.mc_border_color);
+        c[3] = VIC_PIXEL(vic.auxiliary_color);
+        PUT_PIXEL(p, dr, c, b, 1, transparent);
+        PUT_PIXEL(p, dr, c, b, 2, transparent);
+
+        /* put the last 5 pixels normally to complete the char */
+        dr = (vic.reverse & !(b & 0x8)) ? ~d : d;
+        for (x = 3; x < 8; x++) {
+            PUT_PIXEL(p, dr, c, b, x, transparent);
+        }
+
+        /* mark this char as processed */
+        xs++;
+    }
+
+    /* put the rest of the chars if any */
     c[1] = VIC_PIXEL(vic.mc_border_color);
     c[3] = VIC_PIXEL(vic.auxiliary_color);
-
-    /* xe can be -1.  */
     for (i = xs; (int)i <= (int)xe; i++, p += 8 * VIC_PIXEL_WIDTH) {
         b = *(vic.color_ptr + vic.memptr + i);
         c[2] = VIC_PIXEL(b & 0x7);
-        if (reverse & !(b & 0x8))
-            d = ~(GET_CHAR_DATA(*(vic.screen_ptr + vic.memptr + i),
-                                vic.raster.ycounter));
-        else
-            d = GET_CHAR_DATA(*(vic.screen_ptr + vic.memptr + i),
-                              vic.raster.ycounter);
-        for (x = 0; x < 8; x++)
-            PUT_PIXEL(p, d, c, b, x, transparent);
+        d = GET_CHAR_DATA(*(vic.screen_ptr + vic.memptr + i),
+                          vic.raster.ycounter);
+        dr = (vic.reverse & !(b & 0x8)) ? ~d : d;
+        for (x = 0; x < 8; x++) {
+            PUT_PIXEL(p, dr, c, b, x, transparent);
+        }
     }
 }
 
@@ -156,17 +190,7 @@ static void draw_line(void)
     p = (vic.raster.draw_buffer_ptr
         + vic.raster.display_xstart);
 
-    draw(p, 0, vic.text_cols - 1, 0, 0);
-}
-
-static void draw_reverse_line(void)
-{
-    BYTE *p;
-
-    p = (vic.raster.draw_buffer_ptr
-        + vic.raster.display_xstart);
-
-    draw(p, 0, vic.text_cols - 1, 1, 0);
+    draw(p, 0, vic.text_cols - 1, 0);
 }
 
 static void draw_line_cached(raster_cache_t *cache, unsigned int xs,
@@ -179,19 +203,7 @@ static void draw_line_cached(raster_cache_t *cache, unsigned int xs,
 
     /* Scale back xs and xe from 8 pixel units to text_cols.  */
     draw(p, xs >> VIC_PIXEL_WIDTH_SHIFT,
-         ((xe + 1) >> VIC_PIXEL_WIDTH_SHIFT) - 1, 0, 0);
-}
-
-static void draw_reverse_line_cached(raster_cache_t *cache, unsigned int xs,
-                                     unsigned int xe)
-{
-    BYTE *p;
-
-    p = (vic.raster.draw_buffer_ptr
-        + vic.raster.display_xstart);
-
-    draw(p, xs >> VIC_PIXEL_WIDTH_SHIFT,
-         ((xe + 1) >> VIC_PIXEL_WIDTH_SHIFT) - 1, 1, 0);
+         ((xe + 1) >> VIC_PIXEL_WIDTH_SHIFT) - 1, 0);
 }
 
 static void draw_std_background(unsigned int start_pixel,
@@ -210,17 +222,7 @@ static void draw_std_foreground(unsigned int start_char,
     p = (vic.raster.draw_buffer_ptr
         + vic.raster.display_xstart);
 
-    draw(p, start_char, end_char, 0, 1);
-}
-
-static void draw_rev_foreground(unsigned int start_char, unsigned int end_char)
-{
-    BYTE *p;
-
-    p = (vic.raster.draw_buffer_ptr
-        + vic.raster.display_xstart);
-
-    draw(p, start_char, end_char, 1, 1);
+    draw(p, start_char, end_char, 1);
 }
 
 static void setup_modes(void)
@@ -231,12 +233,6 @@ static void setup_modes(void)
                      draw_line,
                      draw_std_background,
                      draw_std_foreground);
-    raster_modes_set(vic.raster.modes, VIC_REVERSE_MODE,
-                     fill_cache,
-                     draw_reverse_line_cached,
-                     draw_reverse_line,
-                     draw_std_background,
-                     draw_rev_foreground);
 }
 
 void vic_draw_init(void)
