@@ -32,7 +32,13 @@
 #include "alarm.h"
 #include "log.h"
 #include "maincpu.h"
+
+#ifdef WATCOM_COMPILE
+#include "../mem.h"
+#else
 #include "mem.h"
+#endif
+
 #include "snapshot.h"
 #include "sound.h"
 #include "types.h"
