@@ -40,7 +40,13 @@
 #include "clkguard.h"
 #include "lib.h"
 #include "log.h"
+
+#ifdef WATCOM_COMPILE
+#include "../mem.h"
+#else
 #include "mem.h"
+#endif
+
 #include "machine.h"
 #include "maincpu.h"
 #include "raster-line.h"
@@ -128,7 +134,7 @@ static void vic_set_geometry(void)
                         vic.screen_width + vic.max_text_cols * 8,
                         vic.screen_width + vic.max_text_cols * 8);
 #ifdef __MSDOS__
-  video_ack_vga_mode();
+    video_ack_vga_mode();
 #endif
 }
 
@@ -163,15 +169,17 @@ void vic_raster_draw_alarm_handler(CLOCK offset, void *data)
             + (vic.text_lines - vic.row_counter) * vic.char_height;
 
         /* if XPOS is 0 VIC displays one more rasterline */
-        if (vic.raster.display_xstart == 0)
+        if (vic.raster.display_xstart == 0) {
             vic.raster.display_ystop++;
+        }
 
         pending_mem_offset = possible_mem_offset;
     }
 
     /*  update memptr */
-    if (vic.area == 1)
+    if (vic.area == 1) {
         vic.memptr += pending_mem_offset;
+    }
     
     pending_mem_offset = 0;
 
@@ -184,9 +192,10 @@ void vic_raster_draw_alarm_handler(CLOCK offset, void *data)
     /* xstart may have changed; recalculate xstop */
     vic.raster.display_xstop = vic.raster.display_xstart + vic.text_cols * 8
                                * VIC_PIXEL_WIDTH;
-    if (vic.raster.display_xstop >= (int)(vic.screen_width * VIC_PIXEL_WIDTH))
+    if (vic.raster.display_xstop >= (int)(vic.screen_width * VIC_PIXEL_WIDTH)) {
         vic.raster.display_xstop = (int)((vic.screen_width - 1)
                                    * VIC_PIXEL_WIDTH);
+    }
 
     /* increment ycounter and set offset for memptr */
     if (vic.area == 1) {
@@ -203,8 +212,9 @@ void vic_raster_draw_alarm_handler(CLOCK offset, void *data)
             }
         }
 
-        if (vic.raster.current_line >= vic.raster.display_ystop)
+        if (vic.raster.current_line >= vic.raster.display_ystop) {
             vic.area = 2;
+        }
     }
 
     /* handle start of frame */
@@ -257,9 +267,6 @@ static void update_pixel_tables(raster_t *raster)
         *((BYTE *)(vic.pixel_table.doub + i))
         = *((BYTE *)(vic.pixel_table.doub + i) + 1)
         = vic.pixel_table.sing[i];
-        *((WORD *)(vic.pixel_table.quad + i))
-        = *((WORD *)(vic.pixel_table.quad + i) + 1)
-        = vic.pixel_table.doub[i];
     }
 }
 
@@ -273,8 +280,9 @@ static int init_raster(void)
     raster->sprite_status = NULL;
     raster_line_changes_init(raster);
 
-    if (raster_init(raster, VIC_NUM_VMODES) < 0)
+    if (raster_init(raster, VIC_NUM_VMODES) < 0) {
         return -1;
+    }
 
     update_pixel_tables(raster);
 
@@ -287,8 +295,9 @@ static int init_raster(void)
 
     raster_set_title(raster, machine_name);
 
-    if (raster_realize(raster) < 0)
+    if (raster_realize(raster) < 0) {
         return -1;
+    }
 
     raster->display_ystart = vic.first_displayed_line;
     raster->display_ystop = vic.first_displayed_line + 1;
@@ -301,8 +310,9 @@ static int init_raster(void)
 
 static void clk_overflow_callback(CLOCK sub, void *data)
 {
-    if (vic.last_emulate_line_clk > (CLOCK)0)
+    if (vic.last_emulate_line_clk > (CLOCK)0) {
         vic.last_emulate_line_clk -= sub;
+    }
 }
 
 
@@ -318,11 +328,16 @@ raster_t *vic_init(void)
 
     vic_change_timing();
 
-    if (init_raster() < 0)
+    if (init_raster() < 0) {
         return NULL;
+    }
 
     vic.auxiliary_color = 0;
     vic.mc_border_color = 0;
+    vic.old_auxiliary_color = 0;
+    vic.old_mc_border_color = 0;
+    vic.reverse = 0;
+    vic.old_reverse = 0;
 
     vic.color_ptr = mem_ram;
     vic.screen_ptr = mem_ram;
@@ -406,10 +421,11 @@ void vic_update_memory_ptrs(void)
                            char_addr,
                            char_addr & 0xfff));
     } else {
-        if (char_addr == 0x1c00)
+        if (char_addr == 0x1c00) {
             new_chargen_ptr = vic20memrom_chargen_rom; /* handle wraparound */
-        else
+        } else {
             new_chargen_ptr = mem_ram + char_addr;
+        }
         VIC_DEBUG_REGISTER (("Character memory at $%04X.", char_addr));
     }
 
