@@ -5,6 +5,10 @@
  *  Andreas Boose <viceteam@t-online.de>
  *  Ettore Perazzoli <ettore@comm2000.it>
  *
+ * DTV sections written by
+ *  Hannu Nuotio <hannu.nuotio@tut.fi>
+ *  Daniel Kahlin <daniel@kahlin.net>
+ *
  * This file is part of VICE, the Versatile Commodore Emulator.
  * See README for copyright notice.
  *
@@ -86,10 +90,16 @@ inline static void line_becomes_bad(const int cycle)
 
         xpos = cycle - (VICII_FETCH_CYCLE + 3);
 
+        if (vicii.viciidtv) {
+            /* there is a skew of DMA delay on the DTV.
+    	    this fix partly works. */
+            xpos -=  1;
+        }
+
         num_chars = VICII_SCREEN_TEXTCOLS - xpos;
 
         /* Take over the bus until the memory fetch is done.  */
-        if (vicii.fastmode == 0)
+        if (vicii.fastmode == 0 && !vicii.badline_disable && !vicii.colorfetch_disable)
             dma_maincpu_steal_cycles(maincpu_clk, num_chars, 0);
 
         if (num_chars <= VICII_SCREEN_TEXTCOLS) {
@@ -132,7 +142,7 @@ inline static void line_becomes_bad(const int cycle)
 
         /* Force the DMA.  */
         if (num_chars > 0)
-            vicii_fetch_matrix(pos, num_chars, num_0xff_fetches);
+            vicii_fetch_matrix(pos, num_chars, num_0xff_fetches, cycle);
 
         /* Set the value by which `vicii.mem_counter' is incremented on
            this line.  */
