@@ -5,6 +5,10 @@
  *  Andreas Boose <viceteam@t-online.de>
  *  Ettore Perazzoli <ettore@comm2000.it>
  *
+ * DTV sections written by
+ *  Hannu Nuotio <hannu.nuotio@tut.fi>
+ *  Daniel Kahlin <daniel@kahlin.net>
+ *
  * This file is part of VICE, the Versatile Commodore Emulator.
  * See README for copyright notice.
  *
@@ -35,7 +39,13 @@
 #include "dma.h"
 #include "log.h"
 #include "maincpu.h"
+
+#ifdef WATCOM_COMPILE
+#include "../mem.h"
+#else
 #include "mem.h"
+#endif
+
 #include "raster-sprite-status.h"
 #include "raster-sprite.h"
 #include "raster.h"
@@ -48,22 +58,33 @@
 
 /* Emulate a matrix line fetch, `num' bytes starting from `offs'.  This takes
    care of the 10-bit counter wraparound.  */
-void vicii_fetch_matrix(int offs, int num, int num_0xff)
+void vicii_fetch_matrix(int offs, int num, int num_0xff, int cycle)
 {
     int start_char;
     int c;
+    BYTE *colorram = NULL;
 
     /*log_debug("OFF %02i NUM %02i NFF %02i",offs,num,num_0xff);*/
 
+    if (vicii.viciidtv) {
+        colorram = vicii.color_ram_ptr;
+    } else {
+        colorram = mem_color_ram_vicii;
+    }
+
     if (num_0xff > 0) {
         if (num <= num_0xff) {
             memset(vicii.vbuf + offs, 0xff, num);
-            memset(vicii.cbuf + offs, vicii.ram_base_phi2[reg_pc] & 0xf, num);
+
+            if (!vicii.colorfetch_disable)
+                memset(vicii.cbuf + offs, vicii.ram_base_phi2[reg_pc] & 0xf, num);
             vicii.background_color_source = 0xff;
         } else {
             memset(vicii.vbuf + offs, 0xff, num_0xff);
-            memset(vicii.cbuf + offs, vicii.ram_base_phi2[reg_pc] & 0xf,
-                   num_0xff);
+
+            if (!vicii.colorfetch_disable)
+                memset(vicii.cbuf + offs, vicii.ram_base_phi2[reg_pc] & 0xf,
+                       num_0xff);
         }
     }
 
@@ -77,12 +98,17 @@ void vicii_fetch_matrix(int offs, int num, int num_0xff)
 
         if (c >= num) {
             memcpy(vicii.vbuf + offs, vicii.screen_base_phi2 + start_char, num);
-            memcpy(vicii.cbuf + offs, mem_color_ram_vicii + start_char, num);
+            if (!vicii.colorfetch_disable)
+                memcpy(vicii.cbuf + offs, colorram + start_char, num);
         } else {
             memcpy(vicii.vbuf + offs, vicii.screen_base_phi2 + start_char, c);
             memcpy(vicii.vbuf + offs + c, vicii.screen_base_phi2, num - c);
-            memcpy(vicii.cbuf + offs, mem_color_ram_vicii + start_char, c);
-            memcpy(vicii.cbuf + offs + c, mem_color_ram_vicii, num - c);
+
+            if (!vicii.colorfetch_disable)
+                memcpy(vicii.cbuf + offs, colorram + start_char, c);
+
+            if (!vicii.colorfetch_disable)
+                memcpy(vicii.cbuf + offs + c, colorram, num - c);
         }
         vicii.background_color_source = vicii.vbuf[VICII_SCREEN_TEXTCOLS
                                         - 1 /*- vicii.buf_offset*/];
@@ -91,19 +117,37 @@ void vicii_fetch_matrix(int offs, int num, int num_0xff)
     /* Set correct background color in in the xsmooth area.
        As this only affects the next line, the xsmooth color is immediately
        set if the right border is opened.  */
+    /* A.M.: This is not true! Immediate change is necessary.
+       See the crunch table in Multiplexer part of Krestage */
     if (offs + num >= VICII_SCREEN_TEXTCOLS) {
         switch (vicii.get_background_from_vbuf) {
           case VICII_HIRES_BITMAP_MODE:
+#if 0
             raster_changes_next_line_add_int(
                 &vicii.raster,
                 &vicii.raster.xsmooth_color,
                 vicii.background_color_source & 0x0f);
+#else
+            raster_changes_background_add_int(
+                &vicii.raster,
+                VICII_RASTER_X(cycle),
+                &vicii.raster.xsmooth_color,
+                vicii.background_color_source & 0x0f);
+#endif
             break;
           case VICII_EXTENDED_TEXT_MODE:
+#if 0
             raster_changes_next_line_add_int(
                 &vicii.raster,
                 &vicii.raster.xsmooth_color,
                 vicii.regs[0x21 + (vicii.background_color_source >> 6)]);
+#else
+            raster_changes_background_add_int(
+                &vicii.raster,
+                VICII_RASTER_X(cycle),
+                &vicii.raster.xsmooth_color,
+                vicii.regs[0x21 + (vicii.background_color_source >> 6)]);
+#endif
             break;
         }
     }
@@ -125,7 +169,7 @@ inline static int do_matrix_fetch(CLOCK sub)
             && vicii.allow_bad_lines
             && raster->current_line >= vicii.first_dma_line
             && raster->current_line <= vicii.last_dma_line) {
-            vicii_fetch_matrix(0, VICII_SCREEN_TEXTCOLS, 0);
+            vicii_fetch_matrix(0, VICII_SCREEN_TEXTCOLS, 0, VICII_FETCH_CYCLE);
 
             raster->draw_idle_state = 0;
             raster->ycounter = 0;
@@ -135,7 +179,7 @@ inline static int do_matrix_fetch(CLOCK sub)
             vicii.ycounter_reset_checked = 1;
             vicii.memory_fetch_done = 2;
 
-            if (vicii.fastmode == 0)
+            if ((vicii.fastmode == 0) && !vicii.badline_disable && !vicii.colorfetch_disable) 
                 dma_maincpu_steal_cycles(vicii.fetch_clk,
                                          VICII_SCREEN_TEXTCOLS + 3 - sub, sub);
             vicii.bad_line = 1;
@@ -360,6 +404,8 @@ inline static int handle_fetch_sprite(long offset, CLOCK sub,
     bank_phi1 = vicii.ram_base_phi1 + vicii.vbank_phi1;
     bank_phi2 = vicii.ram_base_phi2 + vicii.vbank_phi2;
     spr_base = vicii.screen_base_phi1 + 0x3f8 + sf->first;
+    if (vicii.viciidtv)
+        spr_base += (vicii.regs[0x4d]<<16);
 
     /* Fetch sprite data.  */
     for (i = sf->first; i <= sf->last; i++, spr_base++) {
@@ -400,6 +446,11 @@ inline static int handle_fetch_sprite(long offset, CLOCK sub,
                     src_phi2 = mem_chargen_rom_ptr + ((*spr_base & 0x3f) << 6);
             }
 
+            if (vicii.viciidtv) {
+                src_phi1 += (vicii.regs[0x4d]<<16);
+                src_phi2 += (vicii.regs[0x4d]<<16);
+            }
+
             dest[0] = src_phi2[my_memptr];
             dest[1] = src_phi1[++my_memptr & 0x3f];
             dest[2] = src_phi2[++my_memptr & 0x3f];
@@ -410,7 +461,7 @@ inline static int handle_fetch_sprite(long offset, CLOCK sub,
 
     /*log_debug("SF %i VBL %i SUB %i",sf->num,vicii.bad_line,sub);*/
 
-    if (vicii.fastmode == 0)
+    if ((vicii.fastmode == 0) && !vicii.badline_disable)
         dma_maincpu_steal_cycles(vicii.fetch_clk, num_cycles - sub, sub);
 
     *write_offset = sub == 0 ? num_cycles : 0;
