@@ -32,7 +32,7 @@
 
 extern void vicii_fetch_init(void);
 extern void vicii_fetch_alarm_handler(CLOCK offset, void *data);
-extern void vicii_fetch_matrix(int offs, int num, int num_0xff);
+extern void vicii_fetch_matrix(int offs, int num, int num_0xff, int cycle);
 
 #endif
 
