@@ -33,7 +33,13 @@
 #include "alarm.h"
 #include "interrupt.h"
 #include "log.h"
+
+#ifdef WATCOM_COMPILE
+#include "../mem.h"
+#else
 #include "mem.h"
+#endif
+
 #include "raster-sprite-status.h"
 #include "raster-sprite.h"
 #include "snapshot.h"
@@ -424,6 +430,7 @@ int vicii_snapshot_read_module(snapshot_t *s)
     }
 
     vicii.raster.xsmooth = vicii.regs[0x16] & 0x7;
+    vicii.raster.sprite_xsmooth = vicii.regs[0x16] & 0x7;
     vicii.raster.ysmooth = vicii.regs[0x11] & 0x7;
     vicii.raster.current_line = VICII_RASTER_Y(maincpu_clk); /* FIXME? */
 
