@@ -74,15 +74,15 @@
 #define VICII_PAL_DEBUG_FIRST_DISPLAYED_LINE         0x00
 #define VICII_PAL_DEBUG_LAST_DISPLAYED_LINE          0x137
 
-#define VICII_NTSC_NORMAL_FIRST_DISPLAYED_LINE       0x20
-#define VICII_NTSC_NORMAL_LAST_DISPLAYED_LINE        0x102
+#define VICII_NTSC_NORMAL_FIRST_DISPLAYED_LINE       0x1c
+#define VICII_NTSC_NORMAL_LAST_DISPLAYED_LINE        0x112
 #define VICII_NTSC_FULL_FIRST_DISPLAYED_LINE         0x1e /* enough space to show full sprites in the upper border */
 #define VICII_NTSC_FULL_LAST_DISPLAYED_LINE          0x10f /* enough space to show full sprites in the lower border */
 #define VICII_NTSC_DEBUG_FIRST_DISPLAYED_LINE        0x14
 #define VICII_NTSC_DEBUG_LAST_DISPLAYED_LINE         0x11a
 
-#define VICII_NTSCOLD_NORMAL_FIRST_DISPLAYED_LINE    0x20
-#define VICII_NTSCOLD_NORMAL_LAST_DISPLAYED_LINE     0x102
+#define VICII_NTSCOLD_NORMAL_FIRST_DISPLAYED_LINE    0x1c
+#define VICII_NTSCOLD_NORMAL_LAST_DISPLAYED_LINE     0x112
 #define VICII_NTSCOLD_FULL_FIRST_DISPLAYED_LINE      0x1e /* enough space to show full sprites in the upper border */
 #define VICII_NTSCOLD_FULL_LAST_DISPLAYED_LINE       0x10f /* enough space to show full sprites in the lower border */
 #define VICII_NTSCOLD_DEBUG_FIRST_DISPLAYED_LINE     0x14
