@@ -5,6 +5,10 @@
  *  Ettore Perazzoli <ettore@comm2000.it>
  *  Andreas Boose <viceteam@t-online.de>
  *
+ * DTV sections written by
+ *  Hannu Nuotio <hannu.nuotio@tut.fi>
+ *  Daniel Kahlin <daniel@kahlin.net>
+ *
  * This file is part of VICE, the Versatile Commodore Emulator.
  * See README for copyright notice.
  *
@@ -40,16 +44,20 @@
 
 #define VICII_40COL_START_PIXEL vicii.screen_leftborderwidth
 #define VICII_40COL_STOP_PIXEL  (vicii.screen_leftborderwidth + VICII_SCREEN_XPIX)
-#define VICII_38COL_START_PIXEL (vicii.screen_leftborderwidth + 7)
-#define VICII_38COL_STOP_PIXEL  (vicii.screen_leftborderwidth + 311)
+/* these are one pixel 'off' on the DTV */
+#define VICII_38COL_START_PIXEL (vicii.screen_leftborderwidth + 7 + vicii.viciidtv)
+#define VICII_38COL_STOP_PIXEL  (vicii.screen_leftborderwidth + 311 + vicii.viciidtv)
 
 #define VICII_NUM_SPRITES      8
 #define VICII_MAX_SPRITE_WIDTH 56  /* expanded sprite in bug area */
 #define VICII_NUM_COLORS       16
-
+#define VICIIDTV_NUM_COLORS    256
 
 /* Available video modes.  The number is given by
    ((vicii.regs[0x11] & 0x60) | (vicii.regs[0x16] & 0x10)) >> 4.  */
+/* Also for DTV: 
+   | (vicii.regs[0x3c] & 0x04)<<1 | (vicii.regs[0x3c] & 0x01)<<3
+   + FRED/FRED2, CHUNKY/PIXEL/ILLEGAL_LINEAR separation */
 enum vicii_video_mode_s {
     VICII_NORMAL_TEXT_MODE,
     VICII_MULTICOLOR_TEXT_MODE,
@@ -59,19 +67,42 @@ enum vicii_video_mode_s {
     VICII_ILLEGAL_TEXT_MODE,
     VICII_ILLEGAL_BITMAP_MODE_1,
     VICII_ILLEGAL_BITMAP_MODE_2,
+/* DTV modes */
+    VICII_8BPP_NORMAL_TEXT_MODE,
+    VICII_8BPP_MULTICOLOR_TEXT_MODE,
+    VICII_8BPP_HIRES_BITMAP_MODE, /* TODO: doesn't exist */
+    VICII_8BPP_MULTICOLOR_BITMAP_MODE,
+    VICII_8BPP_EXTENDED_TEXT_MODE,
+    VICII_8BPP_CHUNKY_MODE,
+    VICII_8BPP_TWO_PLANE_BITMAP_MODE,
+    VICII_8BPP_FRED_MODE,
+    VICII_8BPP_FRED2_MODE,
+    VICII_8BPP_PIXEL_CELL_MODE,
+    VICII_ILLEGAL_LINEAR_MODE,
     VICII_IDLE_MODE,           /* Special mode for idle state.  */
-    VICII_NUM_VMODES
+    VICII_NUM_VMODES  /* valid for DTV only */
 };
 typedef enum vicii_video_mode_s vicii_video_mode_t;
 
 #define VICII_IS_ILLEGAL_MODE(x) ((x) >= VICII_ILLEGAL_TEXT_MODE \
-                                 && (x) != VICII_IDLE_MODE)
+                                 && (x) <= VICII_ILLEGAL_BITMAP_MODE_2)
+
 #define VICII_IS_BITMAP_MODE(x)  ((x) & 0x02)
 
 #define VICII_IS_TEXT_MODE(x)    ((x) == VICII_NORMAL_TEXT_MODE \
                                  || (x) == VICII_MULTICOLOR_TEXT_MODE \
                                  || (x) == VICII_EXTENDED_TEXT_MODE)
 
+/* The actual modes with modulo bug (possibly incomplete) */
+/*
+#define VICII_MODULO_BUG(x)      ((x) == VICII_8BPP_FRED_MODE \
+                                 || (x) == VICII_8BPP_FRED2_MODE \
+                                 || (x) == VICII_ILLEGAL_TEXT_MODE \
+                                 || (x) == VICII_8BPP_TWO_PLANE_BITMAP_MODE)
+*/
+/* Temporary list to keep all demos running correctly */
+#define VICII_MODULO_BUG(x)      ((x) == VICII_ILLEGAL_TEXT_MODE)
+
 /* These timings are taken from the ``VIC Article'' by Christian Bauer
    <bauec002@goofy.zdv.uni-mainz.de>.  Thanks Christian!
    Note: we measure cycles from 0 to 62, not from 1 to 63 as he does.  */
@@ -92,6 +123,10 @@ typedef enum vicii_video_mode_s vicii_video_mode_t;
    SCREEN_WIDTH if outside the visible range.  */
 #define VICII_RASTER_X(cycle)      (((int)(cycle) - 17) * 8 + vicii.screen_leftborderwidth)
 
+/* Adjusted RASTER_X position to account for -2 pixel difference on some
+   C64DTV stores */
+#define VICIIDTV_RASTER_X_ADJ(cycle)     (VICII_RASTER_X(cycle) - 2)
+
 /* Current vertical position of the raster.  Unlike `rasterline', which is
    only accurate if a pending drawing event has been served, this is
    guarranteed to be always correct.  It is a bit slow, though.  */
@@ -102,6 +137,9 @@ typedef enum vicii_video_mode_s vicii_video_mode_t;
 /* Cycle # within the current line.  */
 #define VICII_RASTER_CYCLE(clk)    ((unsigned int)((clk) \
                                    % vicii.cycles_per_line))
+/* DTV Cycle # within the current line.
+   Handles the "hole" on PAL systems at cycles 54-55 and the 1 cycle shift */
+#define VICIIDTV_RASTER_CYCLE(clk) ((unsigned int)( (((clk)-1) % vicii.cycles_per_line) + ((vicii.cycles_per_line == 63 && (((clk)-1) % vicii.cycles_per_line) > 53)?2:0)) )
 
 /* `clk' value for the beginning of the current line.  */
 #define VICII_LINE_START_CLK(clk)  (((clk) / vicii.cycles_per_line) \
@@ -152,7 +190,22 @@ struct vicii_s {
     raster_t raster;
 
     /* VIC-II registers.  */
-    int regs[64];
+    int regs[0x50];
+
+    /* DTV Linear Counters */
+    int counta;
+    int counta_mod;
+    int counta_step;
+    int countb;
+    int countb_mod;
+    int countb_step;
+
+    /* DTV Palette lookup */
+    BYTE dtvpalette[256];
+
+    /* DTV raster IRQ */
+    int raster_irq_offset;
+    int raster_irq_prevent;
 
     /* Interrupt register.  */
     int irq_status;             /* = 0; */
@@ -262,6 +315,13 @@ struct vicii_s {
     /* Data to display in idle state.  */
     int idle_data;
 
+    /* left border idle data */
+    int idle_data_l[4];
+    /* middle idle data */
+    int idle_data_m[4];
+    /* right border idle data */
+    int idle_data_r[4];
+
     /* Where do we currently fetch idle state from?  If `IDLE_NONE', we are
        not in idle state and thus do not need to update `idle_data'.  */
     vicii_idle_data_location_t idle_data_location;
@@ -335,6 +395,9 @@ struct vicii_s {
     /* Flag: Enable VIC-IIe features.  */
     unsigned int viciie;
 
+    /* Flag: Enable DTV VIC-II features.  */
+    unsigned int viciidtv;
+
     /* VIC-IIe clock mode.  */
     unsigned int fastmode;
 
@@ -348,6 +411,30 @@ struct vicii_s {
     struct video_chip_cap_s *video_chip_cap;
 
     unsigned int int_num;
+
+    /* Flag: DTV extended register enable */
+    unsigned int extended_enable;
+
+    /* Flag: DTV extended register lockout */
+    unsigned int extended_lockout;
+
+    /* Flag: DTV badline disable */
+    unsigned int badline_disable;
+
+    /* Flag: DTV colorfetch disable */
+    unsigned int colorfetch_disable;
+
+    /* Flag: DTV overscan */
+    unsigned int overscan;
+
+    /* Flag: DTV high color */
+    unsigned int high_color;
+    
+    /* Flag: DTV border off */
+    unsigned int border_off;
+
+    /* Pointer to color ram */
+    BYTE *color_ram_ptr;
 };
 typedef struct vicii_s vicii_t;
 
