@@ -32,13 +32,14 @@
 
 /* 16 color 1x2 renderers */
 
-void render_08_1x2_04(const DWORD *colortab, const BYTE *src, BYTE *trg,
+void render_08_1x2_04(const video_render_color_tables_t *color_tab, const BYTE *src, BYTE *trg,
                       unsigned int width, const unsigned int height,
                       const unsigned int xs, const unsigned int ys,
                       const unsigned int xt, const unsigned int yt,
                       const unsigned int pitchs, const unsigned int pitcht,
                       const unsigned int doublescan)
 {
+    const DWORD *colortab = color_tab->physical_colors;
     const BYTE *tmpsrc;
     BYTE *tmptrg;
     unsigned int x, y, wstart, wfast, wend, yys;
@@ -106,13 +107,14 @@ void render_08_1x2_04(const DWORD *colortab, const BYTE *src, BYTE *trg,
     }
 }
 
-void render_16_1x2_04(const DWORD *colortab, const BYTE *src, BYTE *trg,
+void render_16_1x2_04(const video_render_color_tables_t *color_tab, const BYTE *src, BYTE *trg,
                       unsigned int width, const unsigned int height,
                       const unsigned int xs, const unsigned int ys,
                       const unsigned int xt, const unsigned int yt,
                       const unsigned int pitchs, const unsigned int pitcht,
                       const unsigned int doublescan)
 {
+    const DWORD *colortab = color_tab->physical_colors;
     const BYTE *tmpsrc;
     WORD *tmptrg;
     unsigned int x,y,wstart,wfast,wend,yys;
@@ -180,13 +182,14 @@ void render_16_1x2_04(const DWORD *colortab, const BYTE *src, BYTE *trg,
     }
 }
 
-void render_24_1x2_04(const DWORD *colortab, const BYTE *src, BYTE *trg,
+void render_24_1x2_04(const video_render_color_tables_t *color_tab, const BYTE *src, BYTE *trg,
                       unsigned int width, const unsigned int height,
                       const unsigned int xs, const unsigned int ys,
                       const unsigned int xt, const unsigned int yt,
                       const unsigned int pitchs, const unsigned int pitcht,
                       const unsigned int doublescan)
 {
+    const DWORD *colortab = color_tab->physical_colors;
     const BYTE *tmpsrc;
     BYTE *tmptrg;
     unsigned int x, y, wstart, wfast, wend, yys;
@@ -311,13 +314,14 @@ void render_24_1x2_04(const DWORD *colortab, const BYTE *src, BYTE *trg,
     }
 }
 
-void render_32_1x2_04(const DWORD *colortab, const BYTE *src, BYTE *trg,
+void render_32_1x2_04(const video_render_color_tables_t *color_tab, const BYTE *src, BYTE *trg,
                       unsigned int width, const unsigned int height,
                       const unsigned int xs, const unsigned int ys,
                       const unsigned int xt, const unsigned int yt,
                       const unsigned int pitchs, const unsigned int pitcht,
                       const unsigned int doublescan)
 {
+    const DWORD *colortab = color_tab->physical_colors;
     const BYTE *tmpsrc;
     DWORD *tmptrg;
     unsigned int x, y, wstart, wfast, wend, yys;
