@@ -30,28 +30,30 @@
 
 #include "types.h"
 
-extern void render_08_1x2_04(const DWORD *colortab, const BYTE *src, BYTE *trg,
+#include "video.h"
+
+extern void render_08_1x2_04(const video_render_color_tables_t *color_tab, const BYTE *src, BYTE *trg,
                              unsigned int width, const unsigned int height,
                              const unsigned int xs, const unsigned int ys,
                              const unsigned int xt, const unsigned int yt,
                              const unsigned int pitchs,
                              const unsigned int pitcht,
                              const unsigned int doublescan);
-extern void render_16_1x2_04(const DWORD *colortab, const BYTE *src, BYTE *trg,
+extern void render_16_1x2_04(const video_render_color_tables_t *color_tab, const BYTE *src, BYTE *trg,
                              unsigned int width, const unsigned int height,
                              const unsigned int xs, const unsigned int ys,
                              const unsigned int xt, const unsigned int yt,
                              const unsigned int pitchs,
                              const unsigned int pitcht,
                              const unsigned int doublescan);
-extern void render_24_1x2_04(const DWORD *colortab, const BYTE *src, BYTE *trg,
+extern void render_24_1x2_04(const video_render_color_tables_t *color_tab, const BYTE *src, BYTE *trg,
                              unsigned int width, const unsigned int height,
                              const unsigned int xs, const unsigned int ys,
                              const unsigned int xt, const unsigned int yt,
                              const unsigned int pitchs,
                              const unsigned int pitcht,
                              const unsigned int doublescan);
-extern void render_32_1x2_04(const DWORD *colortab, const BYTE *src, BYTE *trg,
+extern void render_32_1x2_04(const video_render_color_tables_t *color_tab, const BYTE *src, BYTE *trg,
                              unsigned int width, const unsigned int height,
                              const unsigned int xs, const unsigned int ys,
                              const unsigned int xt, const unsigned int yt,
@@ -59,4 +61,3 @@ extern void render_32_1x2_04(const DWORD *colortab, const BYTE *src, BYTE *trg,
                              const unsigned int pitcht,
                              const unsigned int doublescan);
 #endif
-
