@@ -61,9 +61,7 @@ int vsync_frame_counter;
 #include "network.h"
 #include "resources.h"
 #include "sound.h"
-#ifdef HAS_TRANSLATION
 #include "translate.h"
-#endif
 #include "types.h"
 #include "vsync.h"
 #include "vsyncapi.h"
@@ -129,31 +127,29 @@ int vsync_resources_init(void)
 /* ------------------------------------------------------------------------- */
 
 /* Vsync-related command-line options. */
-#ifdef HAS_TRANSLATION
 static const cmdline_option_t cmdline_options[] = {
-    { "-speed", SET_RESOURCE, 1, NULL, NULL, "Speed", NULL,
-      IDCLS_P_PERCENT, IDCLS_LIMIT_SPEED_TO_VALUE },
-    { "-refresh", SET_RESOURCE, 1, NULL, NULL, "RefreshRate", NULL,
-      IDCLS_P_VALUE, IDCLS_UPDATE_EVERY_VALUE_FRAMES },
-    { "-warp", SET_RESOURCE, 0, NULL, NULL, "WarpMode", (resource_value_t)1,
-      0, IDCLS_ENABLE_WARP_MODE },
-    { "+warp", SET_RESOURCE, 0, NULL, NULL, "WarpMode", (resource_value_t)0,
-      0, IDCLS_DISABLE_WARP_MODE },
+    { "-speed", SET_RESOURCE, 1,
+      NULL, NULL, "Speed", NULL,
+      USE_PARAM_ID, USE_DESCRIPTION_ID,
+      IDCLS_P_PERCENT, IDCLS_LIMIT_SPEED_TO_VALUE,
+      NULL, NULL },
+    { "-refresh", SET_RESOURCE, 1,
+      NULL, NULL, "RefreshRate", NULL,
+      USE_PARAM_ID, USE_DESCRIPTION_ID,
+      IDCLS_P_VALUE, IDCLS_UPDATE_EVERY_VALUE_FRAMES,
+      NULL, NULL },
+    { "-warp", SET_RESOURCE, 0,
+      NULL, NULL, "WarpMode", (resource_value_t)1,
+      USE_PARAM_STRING, USE_DESCRIPTION_ID,
+      IDCLS_UNUSED, IDCLS_ENABLE_WARP_MODE,
+      NULL, NULL },
+    { "+warp", SET_RESOURCE, 0,
+      NULL, NULL, "WarpMode", (resource_value_t)0,
+      USE_PARAM_STRING, USE_DESCRIPTION_ID,
+      IDCLS_UNUSED, IDCLS_DISABLE_WARP_MODE,
+      NULL, NULL },
     { NULL }
 };
-#else
-static const cmdline_option_t cmdline_options[] = {
-    { "-speed", SET_RESOURCE, 1, NULL, NULL, "Speed", NULL,
-      N_("<percent>"), N_("Limit emulation speed to specified value") },
-    { "-refresh", SET_RESOURCE, 1, NULL, NULL, "RefreshRate", NULL,
-      N_("<value>"), N_("Update every <value> frames (`0' for automatic)") },
-    { "-warp", SET_RESOURCE, 0, NULL, NULL, "WarpMode", (resource_value_t)1,
-      NULL, N_("Enable warp mode") },
-    { "+warp", SET_RESOURCE, 0, NULL, NULL, "WarpMode", (resource_value_t)0,
-      NULL, N_("Disable warp mode") },
-    { NULL }
-};
-#endif
 
 int vsync_cmdline_options_init(void)
 {
@@ -316,7 +312,7 @@ int vsync_do_vsync(struct video_canvas_s *c, int been_skipped)
     signed long delay;
     long frame_ticks_remainder, frame_ticks_integer, compval;
 
-#ifdef WIN32
+#if defined(WIN32) || defined(HAVE_OPENGL_SYNC)
     float refresh_cmp;
     int refresh_div;
 #endif
@@ -409,7 +405,7 @@ int vsync_do_vsync(struct video_canvas_s *c, int been_skipped)
 
     /* This is the time between the start of the next frame and now. */
     delay = (signed long)(now - next_frame_start);
-#ifdef WIN32
+#if defined(WIN32) || defined(HAVE_OPENGL_SYNC)
     refresh_cmp = (float)(c->refreshrate / refresh_frequency);
     refresh_div = (int)(refresh_cmp + 0.5f);
     refresh_cmp /= (float)refresh_div;
@@ -434,7 +430,7 @@ int vsync_do_vsync(struct video_canvas_s *c, int been_skipped)
     if (!warp_mode_enabled && timer_speed && delay < 0) {
         vsyncarch_sleep(-delay);
     }
-#ifdef WIN32
+#if defined(WIN32) || defined(HAVE_OPENGL_SYNC)
     vsyncarch_prepare_vbl();
 #endif
     /*
@@ -470,7 +466,7 @@ int vsync_do_vsync(struct video_canvas_s *c, int been_skipped)
         skip_next_frame = 0;
         skipped_redraw = 0;
     }
-#ifdef WIN32
+#if defined(WIN32) || defined(HAVE_OPENGL_SYNC)
 	}
 #endif
 
@@ -481,7 +477,7 @@ int vsync_do_vsync(struct video_canvas_s *c, int been_skipped)
     if ((signed long)(now - next_frame_start) >= vsyncarch_freq) {
 #if !defined(__OS2__) && !defined(DEBUG)
         if (!warp_mode_enabled && relative_speed) {
-            log_warning(LOG_DEFAULT, _("Your machine is too slow for current settings!"));
+            log_warning(LOG_DEFAULT, "Your machine is too slow for current settings!");
         }
 #endif
         vsync_sync_reset();
@@ -536,5 +532,49 @@ int vsync_do_vsync(struct video_canvas_s *c, int been_skipped)
     return skip_next_frame;
 }
 
+#if defined(WIN32) || defined (HAVE_OPENGL_SYNC) 
+
+static unsigned long last = 0;
+static unsigned long nosynccount = 0;
+
+void vsyncarch_verticalblank(video_canvas_t *c, float rate, int frames)
+{
+    unsigned long nowi, lastx, max, frm, vbl;
+
+    if (c->refreshrate <= 0.0f)
+        return;
+
+    nowi = vsyncarch_frequency();
+
+    /* calculate counter cycles per frame */
+    frm = (unsigned long)((float)(nowi * frames) / rate);
+
+    nowi = vsyncarch_gettime();
+
+    lastx = last - (frm * nosynccount);
+    max = (frm * 7) >> 3;
+    vbl = 0;
+    while (max >= (nowi - lastx)) {
+	vsyncarch_sync_with_raster(c);
+        nowi = vsyncarch_gettime();
+        vbl = 1;
+    }
+    if ((!vbl) && (nosynccount < 16)) {
+        nosynccount ++;
+    } else {
+        last = nowi;
+        nosynccount = 0;
+    }
+}
+
+void vsyncarch_prepare_vbl(void)
+{
+    /* keep vertical blank data prepared */
+    last = vsyncarch_gettime();
+    nosynccount = 0;
+}
+
+#endif /* WIN32 || HAVE_OPENGL_SYNC */
+
 #endif
 
