@@ -45,6 +45,10 @@
 #include <zlib.h>
 #endif
 
+#ifdef HAVE_STRINGS_H
+#include <strings.h>
+#endif
+
 #include "archdep.h"
 #include "ioutil.h"
 #include "lib.h"
@@ -314,6 +318,7 @@ static char *try_uncompress_with_tzx(const char *name)
 }
 
 /* is the name zipcode -name? */
+#ifndef __riscos
 static int is_zipcode_name(char *name)
 {
     if (name[0] >= '1' && name[0] <= '4' && name[1] == '!')
@@ -356,7 +361,7 @@ static int is_valid_extension(char *end, int l, int nameoffset)
     }
     return 0;
 }
-
+#endif
 
 /* If `name' has a correct extension, try to list its contents and search for
    the first file with a proper extension; if found, extract it.  If this
